import * as e from "../../../../../assets/svelte/svelte_internal_client.js";
import { getContext as Sr, untrack as Zt, tick as xt, createEventDispatcher as Re, onMount as Je, onDestroy as Tr, afterUpdate as zr } from "../../../../../assets/svelte/svelte_svelte.js";
import "../../../../../assets/svelte/svelte_internal_flags_legacy.js";
import { spring as Qt } from "../../../../../assets/svelte/svelte_motion.js";
import { fade as mn, fly as wn } from "../../../../../assets/svelte/svelte_transition.js";
import "../../../../../assets/svelte/svelte_animate.js";
const _n = [
  { color: "red", primary: 600, secondary: 100 },
  { color: "green", primary: 600, secondary: 100 },
  { color: "blue", primary: 600, secondary: 100 },
  { color: "yellow", primary: 500, secondary: 100 },
  { color: "purple", primary: 600, secondary: 100 },
  { color: "teal", primary: 600, secondary: 100 },
  { color: "orange", primary: 600, secondary: 100 },
  { color: "cyan", primary: 600, secondary: 100 },
  { color: "lime", primary: 500, secondary: 100 },
  { color: "pink", primary: 600, secondary: 100 }
], Jt = {
  inherit: "inherit",
  current: "currentColor",
  transparent: "transparent",
  black: "#000",
  white: "#fff",
  slate: {
    50: "#f8fafc",
    100: "#f1f5f9",
    200: "#e2e8f0",
    300: "#cbd5e1",
    400: "#94a3b8",
    500: "#64748b",
    600: "#475569",
    700: "#334155",
    800: "#1e293b",
    900: "#0f172a",
    950: "#020617"
  },
  gray: {
    50: "#f9fafb",
    100: "#f3f4f6",
    200: "#e5e7eb",
    300: "#d1d5db",
    400: "#9ca3af",
    500: "#6b7280",
    600: "#4b5563",
    700: "#374151",
    800: "#1f2937",
    900: "#111827",
    950: "#030712"
  },
  zinc: {
    50: "#fafafa",
    100: "#f4f4f5",
    200: "#e4e4e7",
    300: "#d4d4d8",
    400: "#a1a1aa",
    500: "#71717a",
    600: "#52525b",
    700: "#3f3f46",
    800: "#27272a",
    900: "#18181b",
    950: "#09090b"
  },
  neutral: {
    50: "#fafafa",
    100: "#f5f5f5",
    200: "#e5e5e5",
    300: "#d4d4d4",
    400: "#a3a3a3",
    500: "#737373",
    600: "#525252",
    700: "#404040",
    800: "#262626",
    900: "#171717",
    950: "#0a0a0a"
  },
  stone: {
    50: "#fafaf9",
    100: "#f5f5f4",
    200: "#e7e5e4",
    300: "#d6d3d1",
    400: "#a8a29e",
    500: "#78716c",
    600: "#57534e",
    700: "#44403c",
    800: "#292524",
    900: "#1c1917",
    950: "#0c0a09"
  },
  red: {
    50: "#fef2f2",
    100: "#fee2e2",
    200: "#fecaca",
    300: "#fca5a5",
    400: "#f87171",
    500: "#ef4444",
    600: "#dc2626",
    700: "#b91c1c",
    800: "#991b1b",
    900: "#7f1d1d",
    950: "#450a0a"
  },
  orange: {
    50: "#fff7ed",
    100: "#ffedd5",
    200: "#fed7aa",
    300: "#fdba74",
    400: "#fb923c",
    500: "#f97316",
    600: "#ea580c",
    700: "#c2410c",
    800: "#9a3412",
    900: "#7c2d12",
    950: "#431407"
  },
  amber: {
    50: "#fffbeb",
    100: "#fef3c7",
    200: "#fde68a",
    300: "#fcd34d",
    400: "#fbbf24",
    500: "#f59e0b",
    600: "#d97706",
    700: "#b45309",
    800: "#92400e",
    900: "#78350f",
    950: "#451a03"
  },
  yellow: {
    50: "#fefce8",
    100: "#fef9c3",
    200: "#fef08a",
    300: "#fde047",
    400: "#facc15",
    500: "#eab308",
    600: "#ca8a04",
    700: "#a16207",
    800: "#854d0e",
    900: "#713f12",
    950: "#422006"
  },
  lime: {
    50: "#f7fee7",
    100: "#ecfccb",
    200: "#d9f99d",
    300: "#bef264",
    400: "#a3e635",
    500: "#84cc16",
    600: "#65a30d",
    700: "#4d7c0f",
    800: "#3f6212",
    900: "#365314",
    950: "#1a2e05"
  },
  green: {
    50: "#f0fdf4",
    100: "#dcfce7",
    200: "#bbf7d0",
    300: "#86efac",
    400: "#4ade80",
    500: "#22c55e",
    600: "#16a34a",
    700: "#15803d",
    800: "#166534",
    900: "#14532d",
    950: "#052e16"
  },
  emerald: {
    50: "#ecfdf5",
    100: "#d1fae5",
    200: "#a7f3d0",
    300: "#6ee7b7",
    400: "#34d399",
    500: "#10b981",
    600: "#059669",
    700: "#047857",
    800: "#065f46",
    900: "#064e3b",
    950: "#022c22"
  },
  teal: {
    50: "#f0fdfa",
    100: "#ccfbf1",
    200: "#99f6e4",
    300: "#5eead4",
    400: "#2dd4bf",
    500: "#14b8a6",
    600: "#0d9488",
    700: "#0f766e",
    800: "#115e59",
    900: "#134e4a",
    950: "#042f2e"
  },
  cyan: {
    50: "#ecfeff",
    100: "#cffafe",
    200: "#a5f3fc",
    300: "#67e8f9",
    400: "#22d3ee",
    500: "#06b6d4",
    600: "#0891b2",
    700: "#0e7490",
    800: "#155e75",
    900: "#164e63",
    950: "#083344"
  },
  sky: {
    50: "#f0f9ff",
    100: "#e0f2fe",
    200: "#bae6fd",
    300: "#7dd3fc",
    400: "#38bdf8",
    500: "#0ea5e9",
    600: "#0284c7",
    700: "#0369a1",
    800: "#075985",
    900: "#0c4a6e",
    950: "#082f49"
  },
  blue: {
    50: "#eff6ff",
    100: "#dbeafe",
    200: "#bfdbfe",
    300: "#93c5fd",
    400: "#60a5fa",
    500: "#3b82f6",
    600: "#2563eb",
    700: "#1d4ed8",
    800: "#1e40af",
    900: "#1e3a8a",
    950: "#172554"
  },
  indigo: {
    50: "#eef2ff",
    100: "#e0e7ff",
    200: "#c7d2fe",
    300: "#a5b4fc",
    400: "#818cf8",
    500: "#6366f1",
    600: "#4f46e5",
    700: "#4338ca",
    800: "#3730a3",
    900: "#312e81",
    950: "#1e1b4b"
  },
  violet: {
    50: "#f5f3ff",
    100: "#ede9fe",
    200: "#ddd6fe",
    300: "#c4b5fd",
    400: "#a78bfa",
    500: "#8b5cf6",
    600: "#7c3aed",
    700: "#6d28d9",
    800: "#5b21b6",
    900: "#4c1d95",
    950: "#2e1065"
  },
  purple: {
    50: "#faf5ff",
    100: "#f3e8ff",
    200: "#e9d5ff",
    300: "#d8b4fe",
    400: "#c084fc",
    500: "#a855f7",
    600: "#9333ea",
    700: "#7e22ce",
    800: "#6b21a8",
    900: "#581c87",
    950: "#3b0764"
  },
  fuchsia: {
    50: "#fdf4ff",
    100: "#fae8ff",
    200: "#f5d0fe",
    300: "#f0abfc",
    400: "#e879f9",
    500: "#d946ef",
    600: "#c026d3",
    700: "#a21caf",
    800: "#86198f",
    900: "#701a75",
    950: "#4a044e"
  },
  pink: {
    50: "#fdf2f8",
    100: "#fce7f3",
    200: "#fbcfe8",
    300: "#f9a8d4",
    400: "#f472b6",
    500: "#ec4899",
    600: "#db2777",
    700: "#be185d",
    800: "#9d174d",
    900: "#831843",
    950: "#500724"
  },
  rose: {
    50: "#fff1f2",
    100: "#ffe4e6",
    200: "#fecdd3",
    300: "#fda4af",
    400: "#fb7185",
    500: "#f43f5e",
    600: "#e11d48",
    700: "#be123c",
    800: "#9f1239",
    900: "#881337",
    950: "#4c0519"
  }
};
_n.reduce((a, { color: t, primary: r, secondary: n }) => ({
  ...a,
  [t]: {
    primary: Jt[t][r],
    secondary: Jt[t][n]
  }
}), {});
const bn = "GRADIO_ROOT";
class ft extends Error {
  constructor(t) {
    super(t), this.name = "ShareError";
  }
}
async function xn(a, t) {
  if (window.__gradio_space__ == null)
    throw new ft("Must be on Spaces to share.");
  let r, n, s;
  {
    let c;
    if (typeof a == "object" && a.path)
      c = a.path;
    else if (typeof a == "string")
      c = a;
    else
      throw new Error("Invalid data format for base64 type");
    r = kn(c), n = c.split(";")[0].split(":")[1], s = "file." + n.split("/")[1];
  }
  const i = new File([r], s, { type: n }), o = await fetch("https://huggingface.co/uploads", {
    method: "POST",
    body: i,
    headers: {
      "Content-Type": i.type,
      "X-Requested-With": "XMLHttpRequest"
    }
  });
  if (!o.ok) {
    if (o.headers.get("content-type")?.includes("application/json")) {
      const c = await o.json();
      throw new ft(`Upload failed: ${c.error}`);
    }
    throw new ft("Upload failed.");
  }
  return await o.text();
}
function kn(a) {
  for (var t = a.split(","), r = t[0].match(/:(.*?);/)[1], n = atob(t[1]), s = n.length, i = new Uint8Array(s); s--; )
    i[s] = n.charCodeAt(s);
  return new Blob([i], { type: r });
}
const yn = typeof window < "u", Cn = [
  "elem_id",
  "elem_classes",
  "visible",
  "interactive",
  "server_fns",
  "server",
  "id",
  "target",
  "theme_mode",
  "version",
  "root",
  "autoscroll",
  "max_file_size",
  "formatter",
  "client",
  "load_component",
  "scale",
  "min_width",
  "theme",
  "padding",
  "loading_status",
  "label",
  "show_label",
  "validation_error",
  "show_progress",
  "api_prefix",
  "container",
  "attached_events"
];
class Dn {
  load_component;
  #e = e.state(e.proxy({}));
  get shared() {
    return e.get(this.#e);
  }
  set shared(t) {
    e.set(this.#e, t, !0);
  }
  #t = e.state(e.proxy({}));
  get props() {
    return e.get(this.#t);
  }
  set props(t) {
    e.set(this.#t, t, !0);
  }
  #r = e.state(e.proxy({}));
  get i18n() {
    return e.get(this.#r);
  }
  set i18n(t) {
    e.set(this.#r, t, !0);
  }
  dispatcher;
  last_update = null;
  shared_props = Cn;
  constructor(t, r) {
    for (const i in t.shared_props)
      this.shared[i] = t.shared_props[i];
    for (const i in t.props)
      this.props[i] = t.props[i];
    if (r)
      for (const i in r)
        this.props[i] === void 0 && (this.props[i] = r[i]);
    if (this.i18n = this.props.i18n, this.load_component = this.shared.load_component, !yn || t.props?.__GRADIO_BROWSER_TEST__) {
      this.dispatcher = () => {
      };
      return;
    }
    const { register: n, dispatcher: s } = Sr(bn);
    n(t.shared_props.id, this.set_data.bind(this), this.get_data.bind(this)), this.dispatcher = s, e.user_effect(() => {
      for (const i in t.shared_props)
        this.shared[i] = t.shared_props[i];
      for (const i in t.props)
        this.props[i] = t.props[i];
      n(t.shared_props.id, this.set_data.bind(this), this.get_data.bind(this)), Zt(() => {
        this.shared.id = t.shared_props.id;
      });
    });
  }
  dispatch(t, r) {
    this.dispatcher(this.shared.id, t, r);
  }
  async get_data() {
    return e.snapshot(this.props);
  }
  update(t) {
    this.set_data(t);
  }
  set_data(t) {
    for (const r in t)
      if (this.shared_props.includes(r)) {
        const n = r;
        this.shared[n] = t[n];
        continue;
      } else
        this.props[r] = t[r];
  }
}
var En = e.from_svg('<svg class="resize-handle svelte-1stq1b1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 10 10"><line x1="1" y1="9" x2="9" y2="1" stroke="gray" stroke-width="0.5" class="svelte-1stq1b1"></line><line x1="5" y1="9" x2="9" y2="5" stroke="gray" stroke-width="0.5" class="svelte-1stq1b1"></line></svg>'), Fn = e.from_html("<!> <!>", 1), An = e.from_html('<div class="placeholder svelte-1stq1b1"></div>'), Ln = e.from_html("<!> <!>", 1);
function Mn(a, t) {
  e.push(t, !1);
  let r = e.prop(t, "height", 8, void 0), n = e.prop(t, "min_height", 8, void 0), s = e.prop(t, "max_height", 8, void 0), i = e.prop(t, "width", 8, void 0), o = e.prop(t, "elem_id", 8, ""), l = e.prop(t, "elem_classes", 24, () => []), c = e.prop(t, "variant", 8, "solid"), w = e.prop(t, "border_mode", 8, "base"), h = e.prop(t, "padding", 8, !0), _ = e.prop(t, "type", 8, "normal"), b = e.prop(t, "test_id", 8, void 0), D = e.prop(t, "explicit_call", 8, !1), T = e.prop(t, "container", 8, !0), E = e.prop(t, "visible", 8, !0), k = e.prop(t, "allow_overflow", 8, !0), y = e.prop(t, "overflow_behavior", 8, "auto"), d = e.prop(t, "scale", 8, null), p = e.prop(t, "min_width", 8, 0), v = e.prop(t, "flex", 12, !1), u = e.prop(t, "resizable", 8, !1), f = e.prop(t, "rtl", 8, !1), g = e.prop(t, "fullscreen", 12, !1), x = e.prop(t, "label", 8, void 0), m = e.mutable_source(g()), F = e.mutable_source(), B = _() === "fieldset" ? "fieldset" : "div", C = e.mutable_source(0), O = e.mutable_source(0), N = e.mutable_source(null);
  function ie($) {
    g() && $.key === "Escape" && g(!1);
  }
  const H = ($) => {
    if ($ !== void 0) {
      if (typeof $ == "number")
        return $ + "px";
      if (typeof $ == "string")
        return $;
    }
  }, Z = ($) => {
    let te = $.clientY;
    const Q = (Y) => {
      const ne = Y.clientY - te;
      te = Y.clientY, e.mutate(F, e.get(F).style.height = `${e.get(F).offsetHeight + ne}px`);
    }, re = () => {
      window.removeEventListener("mousemove", Q), window.removeEventListener("mouseup", re);
    };
    window.addEventListener("mousemove", Q), window.addEventListener("mouseup", re);
  };
  e.legacy_pre_effect(
    () => (e.deep_read_state(g()), e.get(m), e.get(F)),
    () => {
      g() !== e.get(m) && (e.set(m, g()), g() ? (e.set(N, e.get(F).getBoundingClientRect()), e.set(C, e.get(F).offsetHeight), e.set(O, e.get(F).offsetWidth), window.addEventListener("keydown", ie)) : (e.set(N, null), window.removeEventListener("keydown", ie)));
    }
  ), e.legacy_pre_effect(() => e.deep_read_state(E()), () => {
    E() || v(!1);
  }), e.legacy_pre_effect_reset(), e.init();
  var R = e.comment(), G = e.first_child(R);
  {
    var ae = ($) => {
      var te = Ln(), Q = e.first_child(te);
      e.element(Q, () => B, !1, (ne, z) => {
        e.bind_this(ne, (P) => e.set(F, P), () => e.get(F)), e.attribute_effect(
          ne,
          (P, K) => ({
            "data-testid": b(),
            id: o(),
            class: `block ${P ?? ""}`,
            dir: f() ? "rtl" : "ltr",
            "aria-label": x(),
            style: "",
            [e.CLASS]: {
              hidden: E() === "hidden",
              padded: h(),
              flex: v(),
              border_focus: w() === "focus",
              border_contrast: w() === "contrast",
              "hide-container": !D() && !T(),
              fullscreen: g(),
              animating: g() && e.get(N) !== null,
              "auto-margin": d() === null
            },
            [e.STYLE]: K
          }),
          [
            () => (e.deep_read_state(l()), e.untrack(() => l()?.join(" ") || "")),
            () => ({
              height: (e.deep_read_state(g()), e.deep_read_state(r()), e.untrack(() => g() ? void 0 : H(r()))),
              "min-height": (e.deep_read_state(g()), e.deep_read_state(n()), e.untrack(() => g() ? void 0 : H(n()))),
              "max-height": (e.deep_read_state(g()), e.deep_read_state(s()), e.untrack(() => g() ? void 0 : H(s()))),
              "--start-top": (e.get(N), e.untrack(() => e.get(N) ? `${e.get(N).top}px` : "0px")),
              "--start-left": (e.get(N), e.untrack(() => e.get(N) ? `${e.get(N).left}px` : "0px")),
              "--start-width": (e.get(N), e.untrack(() => e.get(N) ? `${e.get(N).width}px` : "0px")),
              "--start-height": (e.get(N), e.untrack(() => e.get(N) ? `${e.get(N).height}px` : "0px")),
              width: (e.deep_read_state(g()), e.deep_read_state(i()), e.untrack(() => g() ? void 0 : typeof i() == "number" ? `calc(min(${i()}px, 100%))` : H(i()))),
              "border-style": c(),
              overflow: k() ? y() : "hidden",
              "flex-grow": d(),
              "min-width": `calc(min(${p()}px, 100%))`,
              "border-width": "var(--block-border-width)"
            })
          ],
          void 0,
          void 0,
          "svelte-1stq1b1"
        );
        var S = Fn(), L = e.first_child(S);
        e.slot(L, t, "default", {}, null);
        var A = e.sibling(L, 2);
        {
          var V = (P) => {
            var K = En();
            e.event("mousedown", K, Z), e.append(P, K);
          };
          e.if(A, (P) => {
            u() && P(V);
          });
        }
        e.append(z, S);
      });
      var re = e.sibling(Q, 2);
      {
        var Y = (ne) => {
          var z = An();
          let S;
          e.template_effect(() => S = e.set_style(z, "", S, {
            height: e.get(C) + "px",
            width: e.get(O) + "px"
          })), e.append(ne, z);
        };
        e.if(re, (ne) => {
          g() && ne(Y);
        });
      }
      e.append($, te);
    };
    e.if(G, ($) => {
      (E() === !0 || E() === "hidden") && $(ae);
    });
  }
  e.append(a, R), e.pop();
}
function jt() {
  return {
    async: !1,
    breaks: !1,
    extensions: null,
    gfm: !0,
    hooks: null,
    pedantic: !1,
    renderer: null,
    silent: !1,
    tokenizer: null,
    walkTokens: null
  };
}
let Ge = jt();
function Rr(a) {
  Ge = a;
}
const Ir = /[&<>"']/, Bn = new RegExp(Ir.source, "g"), Hr = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/, Sn = new RegExp(Hr.source, "g"), Tn = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#39;"
}, $t = (a) => Tn[a];
function Me(a, t) {
  if (t) {
    if (Ir.test(a))
      return a.replace(Bn, $t);
  } else if (Hr.test(a))
    return a.replace(Sn, $t);
  return a;
}
const zn = /&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/ig;
function Rn(a) {
  return a.replace(zn, (t, r) => (r = r.toLowerCase(), r === "colon" ? ":" : r.charAt(0) === "#" ? r.charAt(1) === "x" ? String.fromCharCode(parseInt(r.substring(2), 16)) : String.fromCharCode(+r.substring(1)) : ""));
}
const In = /(^|[^\[])\^/g;
function pe(a, t) {
  let r = typeof a == "string" ? a : a.source;
  t = t || "";
  const n = {
    replace: (s, i) => {
      let o = typeof i == "string" ? i : i.source;
      return o = o.replace(In, "$1"), r = r.replace(s, o), n;
    },
    getRegex: () => new RegExp(r, t)
  };
  return n;
}
function er(a) {
  try {
    a = encodeURI(a).replace(/%25/g, "%");
  } catch {
    return null;
  }
  return a;
}
const rt = { exec: () => null };
function tr(a, t) {
  const r = a.replace(/\|/g, (i, o, l) => {
    let c = !1, w = o;
    for (; --w >= 0 && l[w] === "\\"; )
      c = !c;
    return c ? "|" : " |";
  }), n = r.split(/ \|/);
  let s = 0;
  if (n[0].trim() || n.shift(), n.length > 0 && !n[n.length - 1].trim() && n.pop(), t)
    if (n.length > t)
      n.splice(t);
    else
      for (; n.length < t; )
        n.push("");
  for (; s < n.length; s++)
    n[s] = n[s].trim().replace(/\\\|/g, "|");
  return n;
}
function ct(a, t, r) {
  const n = a.length;
  if (n === 0)
    return "";
  let s = 0;
  for (; s < n && a.charAt(n - s - 1) === t; )
    s++;
  return a.slice(0, n - s);
}
function Hn(a, t) {
  if (a.indexOf(t[1]) === -1)
    return -1;
  let r = 0;
  for (let n = 0; n < a.length; n++)
    if (a[n] === "\\")
      n++;
    else if (a[n] === t[0])
      r++;
    else if (a[n] === t[1] && (r--, r < 0))
      return n;
  return -1;
}
function rr(a, t, r, n) {
  const s = t.href, i = t.title ? Me(t.title) : null, o = a[1].replace(/\\([\[\]])/g, "$1");
  if (a[0].charAt(0) !== "!") {
    n.state.inLink = !0;
    const l = {
      type: "link",
      raw: r,
      href: s,
      title: i,
      text: o,
      tokens: n.inlineTokens(o)
    };
    return n.state.inLink = !1, l;
  }
  return {
    type: "image",
    raw: r,
    href: s,
    title: i,
    text: Me(o)
  };
}
function On(a, t) {
  const r = a.match(/^(\s+)(?:```)/);
  if (r === null)
    return t;
  const n = r[1];
  return t.split(`
`).map((s) => {
    const i = s.match(/^\s+/);
    if (i === null)
      return s;
    const [o] = i;
    return o.length >= n.length ? s.slice(n.length) : s;
  }).join(`
`);
}
class wt {
  options;
  rules;
  // set by the lexer
  lexer;
  // set by the lexer
  constructor(t) {
    this.options = t || Ge;
  }
  space(t) {
    const r = this.rules.block.newline.exec(t);
    if (r && r[0].length > 0)
      return {
        type: "space",
        raw: r[0]
      };
  }
  code(t) {
    const r = this.rules.block.code.exec(t);
    if (r) {
      const n = r[0].replace(/^ {1,4}/gm, "");
      return {
        type: "code",
        raw: r[0],
        codeBlockStyle: "indented",
        text: this.options.pedantic ? n : ct(n, `
`)
      };
    }
  }
  fences(t) {
    const r = this.rules.block.fences.exec(t);
    if (r) {
      const n = r[0], s = On(n, r[3] || "");
      return {
        type: "code",
        raw: n,
        lang: r[2] ? r[2].trim().replace(this.rules.inline.anyPunctuation, "$1") : r[2],
        text: s
      };
    }
  }
  heading(t) {
    const r = this.rules.block.heading.exec(t);
    if (r) {
      let n = r[2].trim();
      if (/#$/.test(n)) {
        const s = ct(n, "#");
        (this.options.pedantic || !s || / $/.test(s)) && (n = s.trim());
      }
      return {
        type: "heading",
        raw: r[0],
        depth: r[1].length,
        text: n,
        tokens: this.lexer.inline(n)
      };
    }
  }
  hr(t) {
    const r = this.rules.block.hr.exec(t);
    if (r)
      return {
        type: "hr",
        raw: r[0]
      };
  }
  blockquote(t) {
    const r = this.rules.block.blockquote.exec(t);
    if (r) {
      let n = r[0].replace(/\n {0,3}((?:=+|-+) *)(?=\n|$)/g, `
    $1`);
      n = ct(n.replace(/^ *>[ \t]?/gm, ""), `
`);
      const s = this.lexer.state.top;
      this.lexer.state.top = !0;
      const i = this.lexer.blockTokens(n);
      return this.lexer.state.top = s, {
        type: "blockquote",
        raw: r[0],
        tokens: i,
        text: n
      };
    }
  }
  list(t) {
    let r = this.rules.block.list.exec(t);
    if (r) {
      let n = r[1].trim();
      const s = n.length > 1, i = {
        type: "list",
        raw: "",
        ordered: s,
        start: s ? +n.slice(0, -1) : "",
        loose: !1,
        items: []
      };
      n = s ? `\\d{1,9}\\${n.slice(-1)}` : `\\${n}`, this.options.pedantic && (n = s ? n : "[*+-]");
      const o = new RegExp(`^( {0,3}${n})((?:[	 ][^\\n]*)?(?:\\n|$))`);
      let l = "", c = "", w = !1;
      for (; t; ) {
        let h = !1;
        if (!(r = o.exec(t)) || this.rules.block.hr.test(t))
          break;
        l = r[0], t = t.substring(l.length);
        let _ = r[2].split(`
`, 1)[0].replace(/^\t+/, (y) => " ".repeat(3 * y.length)), b = t.split(`
`, 1)[0], D = 0;
        this.options.pedantic ? (D = 2, c = _.trimStart()) : (D = r[2].search(/[^ ]/), D = D > 4 ? 1 : D, c = _.slice(D), D += r[1].length);
        let T = !1;
        if (!_ && /^ *$/.test(b) && (l += b + `
`, t = t.substring(b.length + 1), h = !0), !h) {
          const y = new RegExp(`^ {0,${Math.min(3, D - 1)}}(?:[*+-]|\\d{1,9}[.)])((?:[ 	][^\\n]*)?(?:\\n|$))`), d = new RegExp(`^ {0,${Math.min(3, D - 1)}}((?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$)`), p = new RegExp(`^ {0,${Math.min(3, D - 1)}}(?:\`\`\`|~~~)`), v = new RegExp(`^ {0,${Math.min(3, D - 1)}}#`);
          for (; t; ) {
            const u = t.split(`
`, 1)[0];
            if (b = u, this.options.pedantic && (b = b.replace(/^ {1,4}(?=( {4})*[^ ])/g, "  ")), p.test(b) || v.test(b) || y.test(b) || d.test(t))
              break;
            if (b.search(/[^ ]/) >= D || !b.trim())
              c += `
` + b.slice(D);
            else {
              if (T || _.search(/[^ ]/) >= 4 || p.test(_) || v.test(_) || d.test(_))
                break;
              c += `
` + b;
            }
            !T && !b.trim() && (T = !0), l += u + `
`, t = t.substring(u.length + 1), _ = b.slice(D);
          }
        }
        i.loose || (w ? i.loose = !0 : /\n *\n *$/.test(l) && (w = !0));
        let E = null, k;
        this.options.gfm && (E = /^\[[ xX]\] /.exec(c), E && (k = E[0] !== "[ ] ", c = c.replace(/^\[[ xX]\] +/, ""))), i.items.push({
          type: "list_item",
          raw: l,
          task: !!E,
          checked: k,
          loose: !1,
          text: c,
          tokens: []
        }), i.raw += l;
      }
      i.items[i.items.length - 1].raw = l.trimEnd(), i.items[i.items.length - 1].text = c.trimEnd(), i.raw = i.raw.trimEnd();
      for (let h = 0; h < i.items.length; h++)
        if (this.lexer.state.top = !1, i.items[h].tokens = this.lexer.blockTokens(i.items[h].text, []), !i.loose) {
          const _ = i.items[h].tokens.filter((D) => D.type === "space"), b = _.length > 0 && _.some((D) => /\n.*\n/.test(D.raw));
          i.loose = b;
        }
      if (i.loose)
        for (let h = 0; h < i.items.length; h++)
          i.items[h].loose = !0;
      return i;
    }
  }
  html(t) {
    const r = this.rules.block.html.exec(t);
    if (r)
      return {
        type: "html",
        block: !0,
        raw: r[0],
        pre: r[1] === "pre" || r[1] === "script" || r[1] === "style",
        text: r[0]
      };
  }
  def(t) {
    const r = this.rules.block.def.exec(t);
    if (r) {
      const n = r[1].toLowerCase().replace(/\s+/g, " "), s = r[2] ? r[2].replace(/^<(.*)>$/, "$1").replace(this.rules.inline.anyPunctuation, "$1") : "", i = r[3] ? r[3].substring(1, r[3].length - 1).replace(this.rules.inline.anyPunctuation, "$1") : r[3];
      return {
        type: "def",
        tag: n,
        raw: r[0],
        href: s,
        title: i
      };
    }
  }
  table(t) {
    const r = this.rules.block.table.exec(t);
    if (!r || !/[:|]/.test(r[2]))
      return;
    const n = tr(r[1]), s = r[2].replace(/^\||\| *$/g, "").split("|"), i = r[3] && r[3].trim() ? r[3].replace(/\n[ \t]*$/, "").split(`
`) : [], o = {
      type: "table",
      raw: r[0],
      header: [],
      align: [],
      rows: []
    };
    if (n.length === s.length) {
      for (const l of s)
        /^ *-+: *$/.test(l) ? o.align.push("right") : /^ *:-+: *$/.test(l) ? o.align.push("center") : /^ *:-+ *$/.test(l) ? o.align.push("left") : o.align.push(null);
      for (const l of n)
        o.header.push({
          text: l,
          tokens: this.lexer.inline(l)
        });
      for (const l of i)
        o.rows.push(tr(l, o.header.length).map((c) => ({
          text: c,
          tokens: this.lexer.inline(c)
        })));
      return o;
    }
  }
  lheading(t) {
    const r = this.rules.block.lheading.exec(t);
    if (r)
      return {
        type: "heading",
        raw: r[0],
        depth: r[2].charAt(0) === "=" ? 1 : 2,
        text: r[1],
        tokens: this.lexer.inline(r[1])
      };
  }
  paragraph(t) {
    const r = this.rules.block.paragraph.exec(t);
    if (r) {
      const n = r[1].charAt(r[1].length - 1) === `
` ? r[1].slice(0, -1) : r[1];
      return {
        type: "paragraph",
        raw: r[0],
        text: n,
        tokens: this.lexer.inline(n)
      };
    }
  }
  text(t) {
    const r = this.rules.block.text.exec(t);
    if (r)
      return {
        type: "text",
        raw: r[0],
        text: r[0],
        tokens: this.lexer.inline(r[0])
      };
  }
  escape(t) {
    const r = this.rules.inline.escape.exec(t);
    if (r)
      return {
        type: "escape",
        raw: r[0],
        text: Me(r[1])
      };
  }
  tag(t) {
    const r = this.rules.inline.tag.exec(t);
    if (r)
      return !this.lexer.state.inLink && /^<a /i.test(r[0]) ? this.lexer.state.inLink = !0 : this.lexer.state.inLink && /^<\/a>/i.test(r[0]) && (this.lexer.state.inLink = !1), !this.lexer.state.inRawBlock && /^<(pre|code|kbd|script)(\s|>)/i.test(r[0]) ? this.lexer.state.inRawBlock = !0 : this.lexer.state.inRawBlock && /^<\/(pre|code|kbd|script)(\s|>)/i.test(r[0]) && (this.lexer.state.inRawBlock = !1), {
        type: "html",
        raw: r[0],
        inLink: this.lexer.state.inLink,
        inRawBlock: this.lexer.state.inRawBlock,
        block: !1,
        text: r[0]
      };
  }
  link(t) {
    const r = this.rules.inline.link.exec(t);
    if (r) {
      const n = r[2].trim();
      if (!this.options.pedantic && /^</.test(n)) {
        if (!/>$/.test(n))
          return;
        const o = ct(n.slice(0, -1), "\\");
        if ((n.length - o.length) % 2 === 0)
          return;
      } else {
        const o = Hn(r[2], "()");
        if (o > -1) {
          const c = (r[0].indexOf("!") === 0 ? 5 : 4) + r[1].length + o;
          r[2] = r[2].substring(0, o), r[0] = r[0].substring(0, c).trim(), r[3] = "";
        }
      }
      let s = r[2], i = "";
      if (this.options.pedantic) {
        const o = /^([^'"]*[^\s])\s+(['"])(.*)\2/.exec(s);
        o && (s = o[1], i = o[3]);
      } else
        i = r[3] ? r[3].slice(1, -1) : "";
      return s = s.trim(), /^</.test(s) && (this.options.pedantic && !/>$/.test(n) ? s = s.slice(1) : s = s.slice(1, -1)), rr(r, {
        href: s && s.replace(this.rules.inline.anyPunctuation, "$1"),
        title: i && i.replace(this.rules.inline.anyPunctuation, "$1")
      }, r[0], this.lexer);
    }
  }
  reflink(t, r) {
    let n;
    if ((n = this.rules.inline.reflink.exec(t)) || (n = this.rules.inline.nolink.exec(t))) {
      const s = (n[2] || n[1]).replace(/\s+/g, " "), i = r[s.toLowerCase()];
      if (!i) {
        const o = n[0].charAt(0);
        return {
          type: "text",
          raw: o,
          text: o
        };
      }
      return rr(n, i, n[0], this.lexer);
    }
  }
  emStrong(t, r, n = "") {
    let s = this.rules.inline.emStrongLDelim.exec(t);
    if (!s || s[3] && n.match(/[\p{L}\p{N}]/u))
      return;
    if (!(s[1] || s[2] || "") || !n || this.rules.inline.punctuation.exec(n)) {
      const o = [...s[0]].length - 1;
      let l, c, w = o, h = 0;
      const _ = s[0][0] === "*" ? this.rules.inline.emStrongRDelimAst : this.rules.inline.emStrongRDelimUnd;
      for (_.lastIndex = 0, r = r.slice(-1 * t.length + o); (s = _.exec(r)) != null; ) {
        if (l = s[1] || s[2] || s[3] || s[4] || s[5] || s[6], !l)
          continue;
        if (c = [...l].length, s[3] || s[4]) {
          w += c;
          continue;
        } else if ((s[5] || s[6]) && o % 3 && !((o + c) % 3)) {
          h += c;
          continue;
        }
        if (w -= c, w > 0)
          continue;
        c = Math.min(c, c + w + h);
        const b = [...s[0]][0].length, D = t.slice(0, o + s.index + b + c);
        if (Math.min(o, c) % 2) {
          const E = D.slice(1, -1);
          return {
            type: "em",
            raw: D,
            text: E,
            tokens: this.lexer.inlineTokens(E)
          };
        }
        const T = D.slice(2, -2);
        return {
          type: "strong",
          raw: D,
          text: T,
          tokens: this.lexer.inlineTokens(T)
        };
      }
    }
  }
  codespan(t) {
    const r = this.rules.inline.code.exec(t);
    if (r) {
      let n = r[2].replace(/\n/g, " ");
      const s = /[^ ]/.test(n), i = /^ /.test(n) && / $/.test(n);
      return s && i && (n = n.substring(1, n.length - 1)), n = Me(n, !0), {
        type: "codespan",
        raw: r[0],
        text: n
      };
    }
  }
  br(t) {
    const r = this.rules.inline.br.exec(t);
    if (r)
      return {
        type: "br",
        raw: r[0]
      };
  }
  del(t) {
    const r = this.rules.inline.del.exec(t);
    if (r)
      return {
        type: "del",
        raw: r[0],
        text: r[2],
        tokens: this.lexer.inlineTokens(r[2])
      };
  }
  autolink(t) {
    const r = this.rules.inline.autolink.exec(t);
    if (r) {
      let n, s;
      return r[2] === "@" ? (n = Me(r[1]), s = "mailto:" + n) : (n = Me(r[1]), s = n), {
        type: "link",
        raw: r[0],
        text: n,
        href: s,
        tokens: [
          {
            type: "text",
            raw: n,
            text: n
          }
        ]
      };
    }
  }
  url(t) {
    let r;
    if (r = this.rules.inline.url.exec(t)) {
      let n, s;
      if (r[2] === "@")
        n = Me(r[0]), s = "mailto:" + n;
      else {
        let i;
        do
          i = r[0], r[0] = this.rules.inline._backpedal.exec(r[0])?.[0] ?? "";
        while (i !== r[0]);
        n = Me(r[0]), r[1] === "www." ? s = "http://" + r[0] : s = r[0];
      }
      return {
        type: "link",
        raw: r[0],
        text: n,
        href: s,
        tokens: [
          {
            type: "text",
            raw: n,
            text: n
          }
        ]
      };
    }
  }
  inlineText(t) {
    const r = this.rules.inline.text.exec(t);
    if (r) {
      let n;
      return this.lexer.state.inRawBlock ? n = r[0] : n = Me(r[0]), {
        type: "text",
        raw: r[0],
        text: n
      };
    }
  }
}
const Zn = /^(?: *(?:\n|$))+/, Vn = /^( {4}[^\n]+(?:\n(?: *(?:\n|$))*)?)+/, Nn = /^ {0,3}(`{3,}(?=[^`\n]*(?:\n|$))|~{3,})([^\n]*)(?:\n|$)(?:|([\s\S]*?)(?:\n|$))(?: {0,3}\1[~`]* *(?=\n|$)|$)/, it = /^ {0,3}((?:-[\t ]*){3,}|(?:_[ \t]*){3,}|(?:\*[ \t]*){3,})(?:\n+|$)/, Pn = /^ {0,3}(#{1,6})(?=\s|$)(.*)(?:\n+|$)/, Or = /(?:[*+-]|\d{1,9}[.)])/, Zr = pe(/^(?!bull |blockCode|fences|blockquote|heading|html)((?:.|\n(?!\s*?\n|bull |blockCode|fences|blockquote|heading|html))+?)\n {0,3}(=+|-+) *(?:\n+|$)/).replace(/bull/g, Or).replace(/blockCode/g, / {4}/).replace(/fences/g, / {0,3}(?:`{3,}|~{3,})/).replace(/blockquote/g, / {0,3}>/).replace(/heading/g, / {0,3}#{1,6}/).replace(/html/g, / {0,3}<[^\n>]+>\n/).getRegex(), qt = /^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html|table| +\n)[^\n]+)*)/, jn = /^[^\n]+/, Ut = /(?!\s*\])(?:\\.|[^\[\]\\])+/, qn = pe(/^ {0,3}\[(label)\]: *(?:\n *)?([^<\s][^\s]*|<.*?>)(?:(?: +(?:\n *)?| *\n *)(title))? *(?:\n+|$)/).replace("label", Ut).replace("title", /(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/).getRegex(), Un = pe(/^( {0,3}bull)([ \t][^\n]+?)?(?:\n|$)/).replace(/bull/g, Or).getRegex(), kt = "address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option|p|param|search|section|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul", Yt = /<!--(?:-?>|[\s\S]*?(?:-->|$))/, Yn = pe("^ {0,3}(?:<(script|pre|style|textarea)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)|comment[^\\n]*(\\n+|$)|<\\?[\\s\\S]*?(?:\\?>\\n*|$)|<![A-Z][\\s\\S]*?(?:>\\n*|$)|<!\\[CDATA\\[[\\s\\S]*?(?:\\]\\]>\\n*|$)|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:(?:\\n *)+\\n|$)|<(?!script|pre|style|textarea)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$)|</(?!script|pre|style|textarea)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$))", "i").replace("comment", Yt).replace("tag", kt).replace("attribute", / +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex(), Vr = pe(qt).replace("hr", it).replace("heading", " {0,3}#{1,6}(?:\\s|$)").replace("|lheading", "").replace("|table", "").replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", kt).getRegex(), Wn = pe(/^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/).replace("paragraph", Vr).getRegex(), Wt = {
  blockquote: Wn,
  code: Vn,
  def: qn,
  fences: Nn,
  heading: Pn,
  hr: it,
  html: Yn,
  lheading: Zr,
  list: Un,
  newline: Zn,
  paragraph: Vr,
  table: rt,
  text: jn
}, nr = pe("^ *([^\\n ].*)\\n {0,3}((?:\\| *)?:?-+:? *(?:\\| *:?-+:? *)*(?:\\| *)?)(?:\\n((?:(?! *\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)").replace("hr", it).replace("heading", " {0,3}#{1,6}(?:\\s|$)").replace("blockquote", " {0,3}>").replace("code", " {4}[^\\n]").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", kt).getRegex(), Xn = {
  ...Wt,
  table: nr,
  paragraph: pe(qt).replace("hr", it).replace("heading", " {0,3}#{1,6}(?:\\s|$)").replace("|lheading", "").replace("table", nr).replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", kt).getRegex()
}, Gn = {
  ...Wt,
  html: pe(`^ *(?:comment *(?:\\n|\\s*$)|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)|<tag(?:"[^"]*"|'[^']*'|\\s[^'"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))`).replace("comment", Yt).replace(/tag/g, "(?!(?:a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)\\b)\\w+(?!:|[^\\w\\s@]*@)\\b").getRegex(),
  def: /^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/,
  heading: /^(#{1,6})(.*)(?:\n+|$)/,
  fences: rt,
  // fences not supported
  lheading: /^(.+?)\n {0,3}(=+|-+) *(?:\n+|$)/,
  paragraph: pe(qt).replace("hr", it).replace("heading", ` *#{1,6} *[^
]`).replace("lheading", Zr).replace("|table", "").replace("blockquote", " {0,3}>").replace("|fences", "").replace("|list", "").replace("|html", "").replace("|tag", "").getRegex()
}, Nr = /^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/, Kn = /^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/, Pr = /^( {2,}|\\)\n(?!\s*$)/, Qn = /^(`+|[^`])(?:(?= {2,}\n)|[\s\S]*?(?:(?=[\\<!\[`*_]|\b_|$)|[^ ](?= {2,}\n)))/, at = "\\p{P}\\p{S}", Jn = pe(/^((?![*_])[\spunctuation])/, "u").replace(/punctuation/g, at).getRegex(), $n = /\[[^[\]]*?\]\([^\(\)]*?\)|`[^`]*?`|<[^<>]*?>/g, ei = pe(/^(?:\*+(?:((?!\*)[punct])|[^\s*]))|^_+(?:((?!_)[punct])|([^\s_]))/, "u").replace(/punct/g, at).getRegex(), ti = pe("^[^_*]*?__[^_*]*?\\*[^_*]*?(?=__)|[^*]+(?=[^*])|(?!\\*)[punct](\\*+)(?=[\\s]|$)|[^punct\\s](\\*+)(?!\\*)(?=[punct\\s]|$)|(?!\\*)[punct\\s](\\*+)(?=[^punct\\s])|[\\s](\\*+)(?!\\*)(?=[punct])|(?!\\*)[punct](\\*+)(?!\\*)(?=[punct])|[^punct\\s](\\*+)(?=[^punct\\s])", "gu").replace(/punct/g, at).getRegex(), ri = pe("^[^_*]*?\\*\\*[^_*]*?_[^_*]*?(?=\\*\\*)|[^_]+(?=[^_])|(?!_)[punct](_+)(?=[\\s]|$)|[^punct\\s](_+)(?!_)(?=[punct\\s]|$)|(?!_)[punct\\s](_+)(?=[^punct\\s])|[\\s](_+)(?!_)(?=[punct])|(?!_)[punct](_+)(?!_)(?=[punct])", "gu").replace(/punct/g, at).getRegex(), ni = pe(/\\([punct])/, "gu").replace(/punct/g, at).getRegex(), ii = pe(/^<(scheme:[^\s\x00-\x1f<>]*|email)>/).replace("scheme", /[a-zA-Z][a-zA-Z0-9+.-]{1,31}/).replace("email", /[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/).getRegex(), ai = pe(Yt).replace("(?:-->|$)", "-->").getRegex(), si = pe("^comment|^</[a-zA-Z][\\w:-]*\\s*>|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>|^<\\?[\\s\\S]*?\\?>|^<![a-zA-Z]+\\s[\\s\\S]*?>|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>").replace("comment", ai).replace("attribute", /\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/).getRegex(), _t = /(?:\[(?:\\.|[^\[\]\\])*\]|\\.|`[^`]*`|[^\[\]\\`])*?/, oi = pe(/^!?\[(label)\]\(\s*(href)(?:\s+(title))?\s*\)/).replace("label", _t).replace("href", /<(?:\\.|[^\n<>\\])+>|[^\s\x00-\x1f]*/).replace("title", /"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/).getRegex(), jr = pe(/^!?\[(label)\]\[(ref)\]/).replace("label", _t).replace("ref", Ut).getRegex(), qr = pe(/^!?\[(ref)\](?:\[\])?/).replace("ref", Ut).getRegex(), li = pe("reflink|nolink(?!\\()", "g").replace("reflink", jr).replace("nolink", qr).getRegex(), Xt = {
  _backpedal: rt,
  // only used for GFM url
  anyPunctuation: ni,
  autolink: ii,
  blockSkip: $n,
  br: Pr,
  code: Kn,
  del: rt,
  emStrongLDelim: ei,
  emStrongRDelimAst: ti,
  emStrongRDelimUnd: ri,
  escape: Nr,
  link: oi,
  nolink: qr,
  punctuation: Jn,
  reflink: jr,
  reflinkSearch: li,
  tag: si,
  text: Qn,
  url: rt
}, ci = {
  ...Xt,
  link: pe(/^!?\[(label)\]\((.*?)\)/).replace("label", _t).getRegex(),
  reflink: pe(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace("label", _t).getRegex()
}, Vt = {
  ...Xt,
  escape: pe(Nr).replace("])", "~|])").getRegex(),
  url: pe(/^((?:ftp|https?):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/, "i").replace("email", /[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/).getRegex(),
  _backpedal: /(?:[^?!.,:;*_'"~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_'"~)]+(?!$))+/,
  del: /^(~~?)(?=[^\s~])([\s\S]*?[^\s~])\1(?=[^~]|$)/,
  text: /^([`~]+|[^`~])(?:(?= {2,}\n)|(?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)|[\s\S]*?(?:(?=[\\<!\[`*~_]|\b_|https?:\/\/|ftp:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)))/
}, ui = {
  ...Vt,
  br: pe(Pr).replace("{2,}", "*").getRegex(),
  text: pe(Vt.text).replace("\\b_", "\\b_| {2,}\\n").replace(/\{2,\}/g, "*").getRegex()
}, ut = {
  normal: Wt,
  gfm: Xn,
  pedantic: Gn
}, tt = {
  normal: Xt,
  gfm: Vt,
  breaks: ui,
  pedantic: ci
};
class He {
  tokens;
  options;
  state;
  tokenizer;
  inlineQueue;
  constructor(t) {
    this.tokens = [], this.tokens.links = /* @__PURE__ */ Object.create(null), this.options = t || Ge, this.options.tokenizer = this.options.tokenizer || new wt(), this.tokenizer = this.options.tokenizer, this.tokenizer.options = this.options, this.tokenizer.lexer = this, this.inlineQueue = [], this.state = {
      inLink: !1,
      inRawBlock: !1,
      top: !0
    };
    const r = {
      block: ut.normal,
      inline: tt.normal
    };
    this.options.pedantic ? (r.block = ut.pedantic, r.inline = tt.pedantic) : this.options.gfm && (r.block = ut.gfm, this.options.breaks ? r.inline = tt.breaks : r.inline = tt.gfm), this.tokenizer.rules = r;
  }
  /**
   * Expose Rules
   */
  static get rules() {
    return {
      block: ut,
      inline: tt
    };
  }
  /**
   * Static Lex Method
   */
  static lex(t, r) {
    return new He(r).lex(t);
  }
  /**
   * Static Lex Inline Method
   */
  static lexInline(t, r) {
    return new He(r).inlineTokens(t);
  }
  /**
   * Preprocessing
   */
  lex(t) {
    t = t.replace(/\r\n|\r/g, `
`), this.blockTokens(t, this.tokens);
    for (let r = 0; r < this.inlineQueue.length; r++) {
      const n = this.inlineQueue[r];
      this.inlineTokens(n.src, n.tokens);
    }
    return this.inlineQueue = [], this.tokens;
  }
  blockTokens(t, r = []) {
    this.options.pedantic ? t = t.replace(/\t/g, "    ").replace(/^ +$/gm, "") : t = t.replace(/^( *)(\t+)/gm, (l, c, w) => c + "    ".repeat(w.length));
    let n, s, i, o;
    for (; t; )
      if (!(this.options.extensions && this.options.extensions.block && this.options.extensions.block.some((l) => (n = l.call({ lexer: this }, t, r)) ? (t = t.substring(n.raw.length), r.push(n), !0) : !1))) {
        if (n = this.tokenizer.space(t)) {
          t = t.substring(n.raw.length), n.raw.length === 1 && r.length > 0 ? r[r.length - 1].raw += `
` : r.push(n);
          continue;
        }
        if (n = this.tokenizer.code(t)) {
          t = t.substring(n.raw.length), s = r[r.length - 1], s && (s.type === "paragraph" || s.type === "text") ? (s.raw += `
` + n.raw, s.text += `
` + n.text, this.inlineQueue[this.inlineQueue.length - 1].src = s.text) : r.push(n);
          continue;
        }
        if (n = this.tokenizer.fences(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.heading(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.hr(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.blockquote(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.list(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.html(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.def(t)) {
          t = t.substring(n.raw.length), s = r[r.length - 1], s && (s.type === "paragraph" || s.type === "text") ? (s.raw += `
` + n.raw, s.text += `
` + n.raw, this.inlineQueue[this.inlineQueue.length - 1].src = s.text) : this.tokens.links[n.tag] || (this.tokens.links[n.tag] = {
            href: n.href,
            title: n.title
          });
          continue;
        }
        if (n = this.tokenizer.table(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.lheading(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (i = t, this.options.extensions && this.options.extensions.startBlock) {
          let l = 1 / 0;
          const c = t.slice(1);
          let w;
          this.options.extensions.startBlock.forEach((h) => {
            w = h.call({ lexer: this }, c), typeof w == "number" && w >= 0 && (l = Math.min(l, w));
          }), l < 1 / 0 && l >= 0 && (i = t.substring(0, l + 1));
        }
        if (this.state.top && (n = this.tokenizer.paragraph(i))) {
          s = r[r.length - 1], o && s.type === "paragraph" ? (s.raw += `
` + n.raw, s.text += `
` + n.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = s.text) : r.push(n), o = i.length !== t.length, t = t.substring(n.raw.length);
          continue;
        }
        if (n = this.tokenizer.text(t)) {
          t = t.substring(n.raw.length), s = r[r.length - 1], s && s.type === "text" ? (s.raw += `
` + n.raw, s.text += `
` + n.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = s.text) : r.push(n);
          continue;
        }
        if (t) {
          const l = "Infinite loop on byte: " + t.charCodeAt(0);
          if (this.options.silent) {
            console.error(l);
            break;
          } else
            throw new Error(l);
        }
      }
    return this.state.top = !0, r;
  }
  inline(t, r = []) {
    return this.inlineQueue.push({ src: t, tokens: r }), r;
  }
  /**
   * Lexing/Compiling
   */
  inlineTokens(t, r = []) {
    let n, s, i, o = t, l, c, w;
    if (this.tokens.links) {
      const h = Object.keys(this.tokens.links);
      if (h.length > 0)
        for (; (l = this.tokenizer.rules.inline.reflinkSearch.exec(o)) != null; )
          h.includes(l[0].slice(l[0].lastIndexOf("[") + 1, -1)) && (o = o.slice(0, l.index) + "[" + "a".repeat(l[0].length - 2) + "]" + o.slice(this.tokenizer.rules.inline.reflinkSearch.lastIndex));
    }
    for (; (l = this.tokenizer.rules.inline.blockSkip.exec(o)) != null; )
      o = o.slice(0, l.index) + "[" + "a".repeat(l[0].length - 2) + "]" + o.slice(this.tokenizer.rules.inline.blockSkip.lastIndex);
    for (; (l = this.tokenizer.rules.inline.anyPunctuation.exec(o)) != null; )
      o = o.slice(0, l.index) + "++" + o.slice(this.tokenizer.rules.inline.anyPunctuation.lastIndex);
    for (; t; )
      if (c || (w = ""), c = !1, !(this.options.extensions && this.options.extensions.inline && this.options.extensions.inline.some((h) => (n = h.call({ lexer: this }, t, r)) ? (t = t.substring(n.raw.length), r.push(n), !0) : !1))) {
        if (n = this.tokenizer.escape(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.tag(t)) {
          t = t.substring(n.raw.length), s = r[r.length - 1], s && n.type === "text" && s.type === "text" ? (s.raw += n.raw, s.text += n.text) : r.push(n);
          continue;
        }
        if (n = this.tokenizer.link(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.reflink(t, this.tokens.links)) {
          t = t.substring(n.raw.length), s = r[r.length - 1], s && n.type === "text" && s.type === "text" ? (s.raw += n.raw, s.text += n.text) : r.push(n);
          continue;
        }
        if (n = this.tokenizer.emStrong(t, o, w)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.codespan(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.br(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.del(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (n = this.tokenizer.autolink(t)) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (!this.state.inLink && (n = this.tokenizer.url(t))) {
          t = t.substring(n.raw.length), r.push(n);
          continue;
        }
        if (i = t, this.options.extensions && this.options.extensions.startInline) {
          let h = 1 / 0;
          const _ = t.slice(1);
          let b;
          this.options.extensions.startInline.forEach((D) => {
            b = D.call({ lexer: this }, _), typeof b == "number" && b >= 0 && (h = Math.min(h, b));
          }), h < 1 / 0 && h >= 0 && (i = t.substring(0, h + 1));
        }
        if (n = this.tokenizer.inlineText(i)) {
          t = t.substring(n.raw.length), n.raw.slice(-1) !== "_" && (w = n.raw.slice(-1)), c = !0, s = r[r.length - 1], s && s.type === "text" ? (s.raw += n.raw, s.text += n.text) : r.push(n);
          continue;
        }
        if (t) {
          const h = "Infinite loop on byte: " + t.charCodeAt(0);
          if (this.options.silent) {
            console.error(h);
            break;
          } else
            throw new Error(h);
        }
      }
    return r;
  }
}
class bt {
  options;
  constructor(t) {
    this.options = t || Ge;
  }
  code(t, r, n) {
    const s = (r || "").match(/^\S*/)?.[0];
    return t = t.replace(/\n$/, "") + `
`, s ? '<pre><code class="language-' + Me(s) + '">' + (n ? t : Me(t, !0)) + `</code></pre>
` : "<pre><code>" + (n ? t : Me(t, !0)) + `</code></pre>
`;
  }
  blockquote(t) {
    return `<blockquote>
${t}</blockquote>
`;
  }
  html(t, r) {
    return t;
  }
  heading(t, r, n) {
    return `<h${r}>${t}</h${r}>
`;
  }
  hr() {
    return `<hr>
`;
  }
  list(t, r, n) {
    const s = r ? "ol" : "ul", i = r && n !== 1 ? ' start="' + n + '"' : "";
    return "<" + s + i + `>
` + t + "</" + s + `>
`;
  }
  listitem(t, r, n) {
    return `<li>${t}</li>
`;
  }
  checkbox(t) {
    return "<input " + (t ? 'checked="" ' : "") + 'disabled="" type="checkbox">';
  }
  paragraph(t) {
    return `<p>${t}</p>
`;
  }
  table(t, r) {
    return r && (r = `<tbody>${r}</tbody>`), `<table>
<thead>
` + t + `</thead>
` + r + `</table>
`;
  }
  tablerow(t) {
    return `<tr>
${t}</tr>
`;
  }
  tablecell(t, r) {
    const n = r.header ? "th" : "td";
    return (r.align ? `<${n} align="${r.align}">` : `<${n}>`) + t + `</${n}>
`;
  }
  /**
   * span level renderer
   */
  strong(t) {
    return `<strong>${t}</strong>`;
  }
  em(t) {
    return `<em>${t}</em>`;
  }
  codespan(t) {
    return `<code>${t}</code>`;
  }
  br() {
    return "<br>";
  }
  del(t) {
    return `<del>${t}</del>`;
  }
  link(t, r, n) {
    const s = er(t);
    if (s === null)
      return n;
    t = s;
    let i = '<a href="' + t + '"';
    return r && (i += ' title="' + r + '"'), i += ">" + n + "</a>", i;
  }
  image(t, r, n) {
    const s = er(t);
    if (s === null)
      return n;
    t = s;
    let i = `<img src="${t}" alt="${n}"`;
    return r && (i += ` title="${r}"`), i += ">", i;
  }
  text(t) {
    return t;
  }
}
class Gt {
  // no need for block level renderers
  strong(t) {
    return t;
  }
  em(t) {
    return t;
  }
  codespan(t) {
    return t;
  }
  del(t) {
    return t;
  }
  html(t) {
    return t;
  }
  text(t) {
    return t;
  }
  link(t, r, n) {
    return "" + n;
  }
  image(t, r, n) {
    return "" + n;
  }
  br() {
    return "";
  }
}
class Oe {
  options;
  renderer;
  textRenderer;
  constructor(t) {
    this.options = t || Ge, this.options.renderer = this.options.renderer || new bt(), this.renderer = this.options.renderer, this.renderer.options = this.options, this.textRenderer = new Gt();
  }
  /**
   * Static Parse Method
   */
  static parse(t, r) {
    return new Oe(r).parse(t);
  }
  /**
   * Static Parse Inline Method
   */
  static parseInline(t, r) {
    return new Oe(r).parseInline(t);
  }
  /**
   * Parse Loop
   */
  parse(t, r = !0) {
    let n = "";
    for (let s = 0; s < t.length; s++) {
      const i = t[s];
      if (this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[i.type]) {
        const o = i, l = this.options.extensions.renderers[o.type].call({ parser: this }, o);
        if (l !== !1 || !["space", "hr", "heading", "code", "table", "blockquote", "list", "html", "paragraph", "text"].includes(o.type)) {
          n += l || "";
          continue;
        }
      }
      switch (i.type) {
        case "space":
          continue;
        case "hr": {
          n += this.renderer.hr();
          continue;
        }
        case "heading": {
          const o = i;
          n += this.renderer.heading(this.parseInline(o.tokens), o.depth, Rn(this.parseInline(o.tokens, this.textRenderer)));
          continue;
        }
        case "code": {
          const o = i;
          n += this.renderer.code(o.text, o.lang, !!o.escaped);
          continue;
        }
        case "table": {
          const o = i;
          let l = "", c = "";
          for (let h = 0; h < o.header.length; h++)
            c += this.renderer.tablecell(this.parseInline(o.header[h].tokens), { header: !0, align: o.align[h] });
          l += this.renderer.tablerow(c);
          let w = "";
          for (let h = 0; h < o.rows.length; h++) {
            const _ = o.rows[h];
            c = "";
            for (let b = 0; b < _.length; b++)
              c += this.renderer.tablecell(this.parseInline(_[b].tokens), { header: !1, align: o.align[b] });
            w += this.renderer.tablerow(c);
          }
          n += this.renderer.table(l, w);
          continue;
        }
        case "blockquote": {
          const o = i, l = this.parse(o.tokens);
          n += this.renderer.blockquote(l);
          continue;
        }
        case "list": {
          const o = i, l = o.ordered, c = o.start, w = o.loose;
          let h = "";
          for (let _ = 0; _ < o.items.length; _++) {
            const b = o.items[_], D = b.checked, T = b.task;
            let E = "";
            if (b.task) {
              const k = this.renderer.checkbox(!!D);
              w ? b.tokens.length > 0 && b.tokens[0].type === "paragraph" ? (b.tokens[0].text = k + " " + b.tokens[0].text, b.tokens[0].tokens && b.tokens[0].tokens.length > 0 && b.tokens[0].tokens[0].type === "text" && (b.tokens[0].tokens[0].text = k + " " + b.tokens[0].tokens[0].text)) : b.tokens.unshift({
                type: "text",
                text: k + " "
              }) : E += k + " ";
            }
            E += this.parse(b.tokens, w), h += this.renderer.listitem(E, T, !!D);
          }
          n += this.renderer.list(h, l, c);
          continue;
        }
        case "html": {
          const o = i;
          n += this.renderer.html(o.text, o.block);
          continue;
        }
        case "paragraph": {
          const o = i;
          n += this.renderer.paragraph(this.parseInline(o.tokens));
          continue;
        }
        case "text": {
          let o = i, l = o.tokens ? this.parseInline(o.tokens) : o.text;
          for (; s + 1 < t.length && t[s + 1].type === "text"; )
            o = t[++s], l += `
` + (o.tokens ? this.parseInline(o.tokens) : o.text);
          n += r ? this.renderer.paragraph(l) : l;
          continue;
        }
        default: {
          const o = 'Token with "' + i.type + '" type was not found.';
          if (this.options.silent)
            return console.error(o), "";
          throw new Error(o);
        }
      }
    }
    return n;
  }
  /**
   * Parse Inline Tokens
   */
  parseInline(t, r) {
    r = r || this.renderer;
    let n = "";
    for (let s = 0; s < t.length; s++) {
      const i = t[s];
      if (this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[i.type]) {
        const o = this.options.extensions.renderers[i.type].call({ parser: this }, i);
        if (o !== !1 || !["escape", "html", "link", "image", "strong", "em", "codespan", "br", "del", "text"].includes(i.type)) {
          n += o || "";
          continue;
        }
      }
      switch (i.type) {
        case "escape": {
          const o = i;
          n += r.text(o.text);
          break;
        }
        case "html": {
          const o = i;
          n += r.html(o.text);
          break;
        }
        case "link": {
          const o = i;
          n += r.link(o.href, o.title, this.parseInline(o.tokens, r));
          break;
        }
        case "image": {
          const o = i;
          n += r.image(o.href, o.title, o.text);
          break;
        }
        case "strong": {
          const o = i;
          n += r.strong(this.parseInline(o.tokens, r));
          break;
        }
        case "em": {
          const o = i;
          n += r.em(this.parseInline(o.tokens, r));
          break;
        }
        case "codespan": {
          const o = i;
          n += r.codespan(o.text);
          break;
        }
        case "br": {
          n += r.br();
          break;
        }
        case "del": {
          const o = i;
          n += r.del(this.parseInline(o.tokens, r));
          break;
        }
        case "text": {
          const o = i;
          n += r.text(o.text);
          break;
        }
        default: {
          const o = 'Token with "' + i.type + '" type was not found.';
          if (this.options.silent)
            return console.error(o), "";
          throw new Error(o);
        }
      }
    }
    return n;
  }
}
class pt {
  options;
  constructor(t) {
    this.options = t || Ge;
  }
  static passThroughHooks = /* @__PURE__ */ new Set([
    "preprocess",
    "postprocess",
    "processAllTokens"
  ]);
  /**
   * Process markdown before marked
   */
  preprocess(t) {
    return t;
  }
  /**
   * Process HTML after marked is finished
   */
  postprocess(t) {
    return t;
  }
  /**
   * Process all tokens before walk tokens
   */
  processAllTokens(t) {
    return t;
  }
}
class Ur {
  defaults = jt();
  options = this.setOptions;
  parse = this.#e(He.lex, Oe.parse);
  parseInline = this.#e(He.lexInline, Oe.parseInline);
  Parser = Oe;
  Renderer = bt;
  TextRenderer = Gt;
  Lexer = He;
  Tokenizer = wt;
  Hooks = pt;
  constructor(...t) {
    this.use(...t);
  }
  /**
   * Run callback for every token
   */
  walkTokens(t, r) {
    let n = [];
    for (const s of t)
      switch (n = n.concat(r.call(this, s)), s.type) {
        case "table": {
          const i = s;
          for (const o of i.header)
            n = n.concat(this.walkTokens(o.tokens, r));
          for (const o of i.rows)
            for (const l of o)
              n = n.concat(this.walkTokens(l.tokens, r));
          break;
        }
        case "list": {
          const i = s;
          n = n.concat(this.walkTokens(i.items, r));
          break;
        }
        default: {
          const i = s;
          this.defaults.extensions?.childTokens?.[i.type] ? this.defaults.extensions.childTokens[i.type].forEach((o) => {
            const l = i[o].flat(1 / 0);
            n = n.concat(this.walkTokens(l, r));
          }) : i.tokens && (n = n.concat(this.walkTokens(i.tokens, r)));
        }
      }
    return n;
  }
  use(...t) {
    const r = this.defaults.extensions || { renderers: {}, childTokens: {} };
    return t.forEach((n) => {
      const s = { ...n };
      if (s.async = this.defaults.async || s.async || !1, n.extensions && (n.extensions.forEach((i) => {
        if (!i.name)
          throw new Error("extension name required");
        if ("renderer" in i) {
          const o = r.renderers[i.name];
          o ? r.renderers[i.name] = function(...l) {
            let c = i.renderer.apply(this, l);
            return c === !1 && (c = o.apply(this, l)), c;
          } : r.renderers[i.name] = i.renderer;
        }
        if ("tokenizer" in i) {
          if (!i.level || i.level !== "block" && i.level !== "inline")
            throw new Error("extension level must be 'block' or 'inline'");
          const o = r[i.level];
          o ? o.unshift(i.tokenizer) : r[i.level] = [i.tokenizer], i.start && (i.level === "block" ? r.startBlock ? r.startBlock.push(i.start) : r.startBlock = [i.start] : i.level === "inline" && (r.startInline ? r.startInline.push(i.start) : r.startInline = [i.start]));
        }
        "childTokens" in i && i.childTokens && (r.childTokens[i.name] = i.childTokens);
      }), s.extensions = r), n.renderer) {
        const i = this.defaults.renderer || new bt(this.defaults);
        for (const o in n.renderer) {
          if (!(o in i))
            throw new Error(`renderer '${o}' does not exist`);
          if (o === "options")
            continue;
          const l = o, c = n.renderer[l], w = i[l];
          i[l] = (...h) => {
            let _ = c.apply(i, h);
            return _ === !1 && (_ = w.apply(i, h)), _ || "";
          };
        }
        s.renderer = i;
      }
      if (n.tokenizer) {
        const i = this.defaults.tokenizer || new wt(this.defaults);
        for (const o in n.tokenizer) {
          if (!(o in i))
            throw new Error(`tokenizer '${o}' does not exist`);
          if (["options", "rules", "lexer"].includes(o))
            continue;
          const l = o, c = n.tokenizer[l], w = i[l];
          i[l] = (...h) => {
            let _ = c.apply(i, h);
            return _ === !1 && (_ = w.apply(i, h)), _;
          };
        }
        s.tokenizer = i;
      }
      if (n.hooks) {
        const i = this.defaults.hooks || new pt();
        for (const o in n.hooks) {
          if (!(o in i))
            throw new Error(`hook '${o}' does not exist`);
          if (o === "options")
            continue;
          const l = o, c = n.hooks[l], w = i[l];
          pt.passThroughHooks.has(o) ? i[l] = (h) => {
            if (this.defaults.async)
              return Promise.resolve(c.call(i, h)).then((b) => w.call(i, b));
            const _ = c.call(i, h);
            return w.call(i, _);
          } : i[l] = (...h) => {
            let _ = c.apply(i, h);
            return _ === !1 && (_ = w.apply(i, h)), _;
          };
        }
        s.hooks = i;
      }
      if (n.walkTokens) {
        const i = this.defaults.walkTokens, o = n.walkTokens;
        s.walkTokens = function(l) {
          let c = [];
          return c.push(o.call(this, l)), i && (c = c.concat(i.call(this, l))), c;
        };
      }
      this.defaults = { ...this.defaults, ...s };
    }), this;
  }
  setOptions(t) {
    return this.defaults = { ...this.defaults, ...t }, this;
  }
  lexer(t, r) {
    return He.lex(t, r ?? this.defaults);
  }
  parser(t, r) {
    return Oe.parse(t, r ?? this.defaults);
  }
  #e(t, r) {
    return (n, s) => {
      const i = { ...s }, o = { ...this.defaults, ...i };
      this.defaults.async === !0 && i.async === !1 && (o.silent || console.warn("marked(): The async option was set to true by an extension. The async: false option sent to parse will be ignored."), o.async = !0);
      const l = this.#t(!!o.silent, !!o.async);
      if (typeof n > "u" || n === null)
        return l(new Error("marked(): input parameter is undefined or null"));
      if (typeof n != "string")
        return l(new Error("marked(): input parameter is of type " + Object.prototype.toString.call(n) + ", string expected"));
      if (o.hooks && (o.hooks.options = o), o.async)
        return Promise.resolve(o.hooks ? o.hooks.preprocess(n) : n).then((c) => t(c, o)).then((c) => o.hooks ? o.hooks.processAllTokens(c) : c).then((c) => o.walkTokens ? Promise.all(this.walkTokens(c, o.walkTokens)).then(() => c) : c).then((c) => r(c, o)).then((c) => o.hooks ? o.hooks.postprocess(c) : c).catch(l);
      try {
        o.hooks && (n = o.hooks.preprocess(n));
        let c = t(n, o);
        o.hooks && (c = o.hooks.processAllTokens(c)), o.walkTokens && this.walkTokens(c, o.walkTokens);
        let w = r(c, o);
        return o.hooks && (w = o.hooks.postprocess(w)), w;
      } catch (c) {
        return l(c);
      }
    };
  }
  #t(t, r) {
    return (n) => {
      if (n.message += `
Please report this to https://github.com/markedjs/marked.`, t) {
        const s = "<p>An error occurred:</p><pre>" + Me(n.message + "", !0) + "</pre>";
        return r ? Promise.resolve(s) : s;
      }
      if (r)
        return Promise.reject(n);
      throw n;
    };
  }
}
const Xe = new Ur();
function fe(a, t) {
  return Xe.parse(a, t);
}
fe.options = fe.setOptions = function(a) {
  return Xe.setOptions(a), fe.defaults = Xe.defaults, Rr(fe.defaults), fe;
};
fe.getDefaults = jt;
fe.defaults = Ge;
fe.use = function(...a) {
  return Xe.use(...a), fe.defaults = Xe.defaults, Rr(fe.defaults), fe;
};
fe.walkTokens = function(a, t) {
  return Xe.walkTokens(a, t);
};
fe.parseInline = Xe.parseInline;
fe.Parser = Oe;
fe.parser = Oe.parse;
fe.Renderer = bt;
fe.TextRenderer = Gt;
fe.Lexer = He;
fe.lexer = He.lex;
fe.Tokenizer = wt;
fe.Hooks = pt;
fe.parse = fe;
fe.options;
fe.setOptions;
fe.use;
fe.walkTokens;
fe.parseInline;
Oe.parse;
He.lex;
function di(a) {
  if (typeof a == "function" && (a = {
    highlight: a
  }), !a || typeof a.highlight != "function")
    throw new Error("Must provide highlight function");
  return typeof a.langPrefix != "string" && (a.langPrefix = "language-"), typeof a.emptyLangClass != "string" && (a.emptyLangClass = ""), {
    async: !!a.async,
    walkTokens(t) {
      if (t.type !== "code")
        return;
      const r = ir(t.lang);
      if (a.async)
        return Promise.resolve(a.highlight(t.text, r, t.lang || "")).then(ar(t));
      const n = a.highlight(t.text, r, t.lang || "");
      if (n instanceof Promise)
        throw new Error("markedHighlight is not set to async but the highlight function is async. Set the async option to true on markedHighlight to await the async highlight function.");
      ar(t)(n);
    },
    useNewRenderer: !0,
    renderer: {
      code(t, r, n) {
        typeof t == "object" && (n = t.escaped, r = t.lang, t = t.text);
        const s = ir(r), i = s ? a.langPrefix + or(s) : a.emptyLangClass, o = i ? ` class="${i}"` : "";
        return t = t.replace(/\n$/, ""), `<pre><code${o}>${n ? t : or(t, !0)}
</code></pre>`;
      }
    }
  };
}
function ir(a) {
  return (a || "").match(/\S*/)[0];
}
function ar(a) {
  return (t) => {
    typeof t == "string" && t !== a.text && (a.escaped = !0, a.text = t);
  };
}
const Yr = /[&<>"']/, hi = new RegExp(Yr.source, "g"), Wr = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/, gi = new RegExp(Wr.source, "g"), fi = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#39;"
}, sr = (a) => fi[a];
function or(a, t) {
  if (t) {
    if (Yr.test(a))
      return a.replace(hi, sr);
  } else if (Wr.test(a))
    return a.replace(gi, sr);
  return a;
}
const pi = /[\0-\x1F!-,\.\/:-@\[-\^`\{-\xA9\xAB-\xB4\xB6-\xB9\xBB-\xBF\xD7\xF7\u02C2-\u02C5\u02D2-\u02DF\u02E5-\u02EB\u02ED\u02EF-\u02FF\u0375\u0378\u0379\u037E\u0380-\u0385\u0387\u038B\u038D\u03A2\u03F6\u0482\u0530\u0557\u0558\u055A-\u055F\u0589-\u0590\u05BE\u05C0\u05C3\u05C6\u05C8-\u05CF\u05EB-\u05EE\u05F3-\u060F\u061B-\u061F\u066A-\u066D\u06D4\u06DD\u06DE\u06E9\u06FD\u06FE\u0700-\u070F\u074B\u074C\u07B2-\u07BF\u07F6-\u07F9\u07FB\u07FC\u07FE\u07FF\u082E-\u083F\u085C-\u085F\u086B-\u089F\u08B5\u08C8-\u08D2\u08E2\u0964\u0965\u0970\u0984\u098D\u098E\u0991\u0992\u09A9\u09B1\u09B3-\u09B5\u09BA\u09BB\u09C5\u09C6\u09C9\u09CA\u09CF-\u09D6\u09D8-\u09DB\u09DE\u09E4\u09E5\u09F2-\u09FB\u09FD\u09FF\u0A00\u0A04\u0A0B-\u0A0E\u0A11\u0A12\u0A29\u0A31\u0A34\u0A37\u0A3A\u0A3B\u0A3D\u0A43-\u0A46\u0A49\u0A4A\u0A4E-\u0A50\u0A52-\u0A58\u0A5D\u0A5F-\u0A65\u0A76-\u0A80\u0A84\u0A8E\u0A92\u0AA9\u0AB1\u0AB4\u0ABA\u0ABB\u0AC6\u0ACA\u0ACE\u0ACF\u0AD1-\u0ADF\u0AE4\u0AE5\u0AF0-\u0AF8\u0B00\u0B04\u0B0D\u0B0E\u0B11\u0B12\u0B29\u0B31\u0B34\u0B3A\u0B3B\u0B45\u0B46\u0B49\u0B4A\u0B4E-\u0B54\u0B58-\u0B5B\u0B5E\u0B64\u0B65\u0B70\u0B72-\u0B81\u0B84\u0B8B-\u0B8D\u0B91\u0B96-\u0B98\u0B9B\u0B9D\u0BA0-\u0BA2\u0BA5-\u0BA7\u0BAB-\u0BAD\u0BBA-\u0BBD\u0BC3-\u0BC5\u0BC9\u0BCE\u0BCF\u0BD1-\u0BD6\u0BD8-\u0BE5\u0BF0-\u0BFF\u0C0D\u0C11\u0C29\u0C3A-\u0C3C\u0C45\u0C49\u0C4E-\u0C54\u0C57\u0C5B-\u0C5F\u0C64\u0C65\u0C70-\u0C7F\u0C84\u0C8D\u0C91\u0CA9\u0CB4\u0CBA\u0CBB\u0CC5\u0CC9\u0CCE-\u0CD4\u0CD7-\u0CDD\u0CDF\u0CE4\u0CE5\u0CF0\u0CF3-\u0CFF\u0D0D\u0D11\u0D45\u0D49\u0D4F-\u0D53\u0D58-\u0D5E\u0D64\u0D65\u0D70-\u0D79\u0D80\u0D84\u0D97-\u0D99\u0DB2\u0DBC\u0DBE\u0DBF\u0DC7-\u0DC9\u0DCB-\u0DCE\u0DD5\u0DD7\u0DE0-\u0DE5\u0DF0\u0DF1\u0DF4-\u0E00\u0E3B-\u0E3F\u0E4F\u0E5A-\u0E80\u0E83\u0E85\u0E8B\u0EA4\u0EA6\u0EBE\u0EBF\u0EC5\u0EC7\u0ECE\u0ECF\u0EDA\u0EDB\u0EE0-\u0EFF\u0F01-\u0F17\u0F1A-\u0F1F\u0F2A-\u0F34\u0F36\u0F38\u0F3A-\u0F3D\u0F48\u0F6D-\u0F70\u0F85\u0F98\u0FBD-\u0FC5\u0FC7-\u0FFF\u104A-\u104F\u109E\u109F\u10C6\u10C8-\u10CC\u10CE\u10CF\u10FB\u1249\u124E\u124F\u1257\u1259\u125E\u125F\u1289\u128E\u128F\u12B1\u12B6\u12B7\u12BF\u12C1\u12C6\u12C7\u12D7\u1311\u1316\u1317\u135B\u135C\u1360-\u137F\u1390-\u139F\u13F6\u13F7\u13FE-\u1400\u166D\u166E\u1680\u169B-\u169F\u16EB-\u16ED\u16F9-\u16FF\u170D\u1715-\u171F\u1735-\u173F\u1754-\u175F\u176D\u1771\u1774-\u177F\u17D4-\u17D6\u17D8-\u17DB\u17DE\u17DF\u17EA-\u180A\u180E\u180F\u181A-\u181F\u1879-\u187F\u18AB-\u18AF\u18F6-\u18FF\u191F\u192C-\u192F\u193C-\u1945\u196E\u196F\u1975-\u197F\u19AC-\u19AF\u19CA-\u19CF\u19DA-\u19FF\u1A1C-\u1A1F\u1A5F\u1A7D\u1A7E\u1A8A-\u1A8F\u1A9A-\u1AA6\u1AA8-\u1AAF\u1AC1-\u1AFF\u1B4C-\u1B4F\u1B5A-\u1B6A\u1B74-\u1B7F\u1BF4-\u1BFF\u1C38-\u1C3F\u1C4A-\u1C4C\u1C7E\u1C7F\u1C89-\u1C8F\u1CBB\u1CBC\u1CC0-\u1CCF\u1CD3\u1CFB-\u1CFF\u1DFA\u1F16\u1F17\u1F1E\u1F1F\u1F46\u1F47\u1F4E\u1F4F\u1F58\u1F5A\u1F5C\u1F5E\u1F7E\u1F7F\u1FB5\u1FBD\u1FBF-\u1FC1\u1FC5\u1FCD-\u1FCF\u1FD4\u1FD5\u1FDC-\u1FDF\u1FED-\u1FF1\u1FF5\u1FFD-\u203E\u2041-\u2053\u2055-\u2070\u2072-\u207E\u2080-\u208F\u209D-\u20CF\u20F1-\u2101\u2103-\u2106\u2108\u2109\u2114\u2116-\u2118\u211E-\u2123\u2125\u2127\u2129\u212E\u213A\u213B\u2140-\u2144\u214A-\u214D\u214F-\u215F\u2189-\u24B5\u24EA-\u2BFF\u2C2F\u2C5F\u2CE5-\u2CEA\u2CF4-\u2CFF\u2D26\u2D28-\u2D2C\u2D2E\u2D2F\u2D68-\u2D6E\u2D70-\u2D7E\u2D97-\u2D9F\u2DA7\u2DAF\u2DB7\u2DBF\u2DC7\u2DCF\u2DD7\u2DDF\u2E00-\u2E2E\u2E30-\u3004\u3008-\u3020\u3030\u3036\u3037\u303D-\u3040\u3097\u3098\u309B\u309C\u30A0\u30FB\u3100-\u3104\u3130\u318F-\u319F\u31C0-\u31EF\u3200-\u33FF\u4DC0-\u4DFF\u9FFD-\u9FFF\uA48D-\uA4CF\uA4FE\uA4FF\uA60D-\uA60F\uA62C-\uA63F\uA673\uA67E\uA6F2-\uA716\uA720\uA721\uA789\uA78A\uA7C0\uA7C1\uA7CB-\uA7F4\uA828-\uA82B\uA82D-\uA83F\uA874-\uA87F\uA8C6-\uA8CF\uA8DA-\uA8DF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA954-\uA95F\uA97D-\uA97F\uA9C1-\uA9CE\uA9DA-\uA9DF\uA9FF\uAA37-\uAA3F\uAA4E\uAA4F\uAA5A-\uAA5F\uAA77-\uAA79\uAAC3-\uAADA\uAADE\uAADF\uAAF0\uAAF1\uAAF7-\uAB00\uAB07\uAB08\uAB0F\uAB10\uAB17-\uAB1F\uAB27\uAB2F\uAB5B\uAB6A-\uAB6F\uABEB\uABEE\uABEF\uABFA-\uABFF\uD7A4-\uD7AF\uD7C7-\uD7CA\uD7FC-\uD7FF\uE000-\uF8FF\uFA6E\uFA6F\uFADA-\uFAFF\uFB07-\uFB12\uFB18-\uFB1C\uFB29\uFB37\uFB3D\uFB3F\uFB42\uFB45\uFBB2-\uFBD2\uFD3E-\uFD4F\uFD90\uFD91\uFDC8-\uFDEF\uFDFC-\uFDFF\uFE10-\uFE1F\uFE30-\uFE32\uFE35-\uFE4C\uFE50-\uFE6F\uFE75\uFEFD-\uFF0F\uFF1A-\uFF20\uFF3B-\uFF3E\uFF40\uFF5B-\uFF65\uFFBF-\uFFC1\uFFC8\uFFC9\uFFD0\uFFD1\uFFD8\uFFD9\uFFDD-\uFFFF]|\uD800[\uDC0C\uDC27\uDC3B\uDC3E\uDC4E\uDC4F\uDC5E-\uDC7F\uDCFB-\uDD3F\uDD75-\uDDFC\uDDFE-\uDE7F\uDE9D-\uDE9F\uDED1-\uDEDF\uDEE1-\uDEFF\uDF20-\uDF2C\uDF4B-\uDF4F\uDF7B-\uDF7F\uDF9E\uDF9F\uDFC4-\uDFC7\uDFD0\uDFD6-\uDFFF]|\uD801[\uDC9E\uDC9F\uDCAA-\uDCAF\uDCD4-\uDCD7\uDCFC-\uDCFF\uDD28-\uDD2F\uDD64-\uDDFF\uDF37-\uDF3F\uDF56-\uDF5F\uDF68-\uDFFF]|\uD802[\uDC06\uDC07\uDC09\uDC36\uDC39-\uDC3B\uDC3D\uDC3E\uDC56-\uDC5F\uDC77-\uDC7F\uDC9F-\uDCDF\uDCF3\uDCF6-\uDCFF\uDD16-\uDD1F\uDD3A-\uDD7F\uDDB8-\uDDBD\uDDC0-\uDDFF\uDE04\uDE07-\uDE0B\uDE14\uDE18\uDE36\uDE37\uDE3B-\uDE3E\uDE40-\uDE5F\uDE7D-\uDE7F\uDE9D-\uDEBF\uDEC8\uDEE7-\uDEFF\uDF36-\uDF3F\uDF56-\uDF5F\uDF73-\uDF7F\uDF92-\uDFFF]|\uD803[\uDC49-\uDC7F\uDCB3-\uDCBF\uDCF3-\uDCFF\uDD28-\uDD2F\uDD3A-\uDE7F\uDEAA\uDEAD-\uDEAF\uDEB2-\uDEFF\uDF1D-\uDF26\uDF28-\uDF2F\uDF51-\uDFAF\uDFC5-\uDFDF\uDFF7-\uDFFF]|\uD804[\uDC47-\uDC65\uDC70-\uDC7E\uDCBB-\uDCCF\uDCE9-\uDCEF\uDCFA-\uDCFF\uDD35\uDD40-\uDD43\uDD48-\uDD4F\uDD74\uDD75\uDD77-\uDD7F\uDDC5-\uDDC8\uDDCD\uDDDB\uDDDD-\uDDFF\uDE12\uDE38-\uDE3D\uDE3F-\uDE7F\uDE87\uDE89\uDE8E\uDE9E\uDEA9-\uDEAF\uDEEB-\uDEEF\uDEFA-\uDEFF\uDF04\uDF0D\uDF0E\uDF11\uDF12\uDF29\uDF31\uDF34\uDF3A\uDF45\uDF46\uDF49\uDF4A\uDF4E\uDF4F\uDF51-\uDF56\uDF58-\uDF5C\uDF64\uDF65\uDF6D-\uDF6F\uDF75-\uDFFF]|\uD805[\uDC4B-\uDC4F\uDC5A-\uDC5D\uDC62-\uDC7F\uDCC6\uDCC8-\uDCCF\uDCDA-\uDD7F\uDDB6\uDDB7\uDDC1-\uDDD7\uDDDE-\uDDFF\uDE41-\uDE43\uDE45-\uDE4F\uDE5A-\uDE7F\uDEB9-\uDEBF\uDECA-\uDEFF\uDF1B\uDF1C\uDF2C-\uDF2F\uDF3A-\uDFFF]|\uD806[\uDC3B-\uDC9F\uDCEA-\uDCFE\uDD07\uDD08\uDD0A\uDD0B\uDD14\uDD17\uDD36\uDD39\uDD3A\uDD44-\uDD4F\uDD5A-\uDD9F\uDDA8\uDDA9\uDDD8\uDDD9\uDDE2\uDDE5-\uDDFF\uDE3F-\uDE46\uDE48-\uDE4F\uDE9A-\uDE9C\uDE9E-\uDEBF\uDEF9-\uDFFF]|\uD807[\uDC09\uDC37\uDC41-\uDC4F\uDC5A-\uDC71\uDC90\uDC91\uDCA8\uDCB7-\uDCFF\uDD07\uDD0A\uDD37-\uDD39\uDD3B\uDD3E\uDD48-\uDD4F\uDD5A-\uDD5F\uDD66\uDD69\uDD8F\uDD92\uDD99-\uDD9F\uDDAA-\uDEDF\uDEF7-\uDFAF\uDFB1-\uDFFF]|\uD808[\uDF9A-\uDFFF]|\uD809[\uDC6F-\uDC7F\uDD44-\uDFFF]|[\uD80A\uD80B\uD80E-\uD810\uD812-\uD819\uD824-\uD82B\uD82D\uD82E\uD830-\uD833\uD837\uD839\uD83D\uD83F\uD87B-\uD87D\uD87F\uD885-\uDB3F\uDB41-\uDBFF][\uDC00-\uDFFF]|\uD80D[\uDC2F-\uDFFF]|\uD811[\uDE47-\uDFFF]|\uD81A[\uDE39-\uDE3F\uDE5F\uDE6A-\uDECF\uDEEE\uDEEF\uDEF5-\uDEFF\uDF37-\uDF3F\uDF44-\uDF4F\uDF5A-\uDF62\uDF78-\uDF7C\uDF90-\uDFFF]|\uD81B[\uDC00-\uDE3F\uDE80-\uDEFF\uDF4B-\uDF4E\uDF88-\uDF8E\uDFA0-\uDFDF\uDFE2\uDFE5-\uDFEF\uDFF2-\uDFFF]|\uD821[\uDFF8-\uDFFF]|\uD823[\uDCD6-\uDCFF\uDD09-\uDFFF]|\uD82C[\uDD1F-\uDD4F\uDD53-\uDD63\uDD68-\uDD6F\uDEFC-\uDFFF]|\uD82F[\uDC6B-\uDC6F\uDC7D-\uDC7F\uDC89-\uDC8F\uDC9A-\uDC9C\uDC9F-\uDFFF]|\uD834[\uDC00-\uDD64\uDD6A-\uDD6C\uDD73-\uDD7A\uDD83\uDD84\uDD8C-\uDDA9\uDDAE-\uDE41\uDE45-\uDFFF]|\uD835[\uDC55\uDC9D\uDCA0\uDCA1\uDCA3\uDCA4\uDCA7\uDCA8\uDCAD\uDCBA\uDCBC\uDCC4\uDD06\uDD0B\uDD0C\uDD15\uDD1D\uDD3A\uDD3F\uDD45\uDD47-\uDD49\uDD51\uDEA6\uDEA7\uDEC1\uDEDB\uDEFB\uDF15\uDF35\uDF4F\uDF6F\uDF89\uDFA9\uDFC3\uDFCC\uDFCD]|\uD836[\uDC00-\uDDFF\uDE37-\uDE3A\uDE6D-\uDE74\uDE76-\uDE83\uDE85-\uDE9A\uDEA0\uDEB0-\uDFFF]|\uD838[\uDC07\uDC19\uDC1A\uDC22\uDC25\uDC2B-\uDCFF\uDD2D-\uDD2F\uDD3E\uDD3F\uDD4A-\uDD4D\uDD4F-\uDEBF\uDEFA-\uDFFF]|\uD83A[\uDCC5-\uDCCF\uDCD7-\uDCFF\uDD4C-\uDD4F\uDD5A-\uDFFF]|\uD83B[\uDC00-\uDDFF\uDE04\uDE20\uDE23\uDE25\uDE26\uDE28\uDE33\uDE38\uDE3A\uDE3C-\uDE41\uDE43-\uDE46\uDE48\uDE4A\uDE4C\uDE50\uDE53\uDE55\uDE56\uDE58\uDE5A\uDE5C\uDE5E\uDE60\uDE63\uDE65\uDE66\uDE6B\uDE73\uDE78\uDE7D\uDE7F\uDE8A\uDE9C-\uDEA0\uDEA4\uDEAA\uDEBC-\uDFFF]|\uD83C[\uDC00-\uDD2F\uDD4A-\uDD4F\uDD6A-\uDD6F\uDD8A-\uDFFF]|\uD83E[\uDC00-\uDFEF\uDFFA-\uDFFF]|\uD869[\uDEDE-\uDEFF]|\uD86D[\uDF35-\uDF3F]|\uD86E[\uDC1E\uDC1F]|\uD873[\uDEA2-\uDEAF]|\uD87A[\uDFE1-\uDFFF]|\uD87E[\uDE1E-\uDFFF]|\uD884[\uDF4B-\uDFFF]|\uDB40[\uDC00-\uDCFF\uDDF0-\uDFFF]/g, vi = Object.hasOwnProperty;
class Kt {
  /**
   * Create a new slug class.
   */
  constructor() {
    this.occurrences, this.reset();
  }
  /**
   * Generate a unique slug.
  *
  * Tracks previously generated slugs: repeated calls with the same value
  * will result in different slugs.
  * Use the `slug` function to get same slugs.
   *
   * @param  {string} value
   *   String of text to slugify
   * @param  {boolean} [maintainCase=false]
   *   Keep the current case, otherwise make all lowercase
   * @return {string}
   *   A unique slug string
   */
  slug(t, r) {
    const n = this;
    let s = mi(t, r === !0);
    const i = s;
    for (; vi.call(n.occurrences, s); )
      n.occurrences[i]++, s = i + "-" + n.occurrences[i];
    return n.occurrences[s] = 0, s;
  }
  /**
   * Reset - Forget all previous slugs
   *
   * @return void
   */
  reset() {
    this.occurrences = /* @__PURE__ */ Object.create(null);
  }
}
function mi(a, t) {
  return typeof a != "string" ? "" : (t || (a = a.toLowerCase()), a.replace(pi, "").replace(/ /g, "-"));
}
let Xr = new Kt(), Gr = [];
function wi({ prefix: a = "", globalSlugs: t = !1 } = {}) {
  return {
    headerIds: !1,
    // prevent deprecation warning; remove this once headerIds option is removed
    hooks: {
      preprocess(r) {
        return t || _i(), r;
      }
    },
    renderer: {
      heading(r, n, s) {
        s = s.toLowerCase().trim().replace(/<[!\/a-z].*?>/gi, "");
        const i = `${a}${Xr.slug(s)}`, o = { level: n, text: r, id: i };
        return Gr.push(o), `<h${n} id="${i}">${r}</h${n}>
`;
      }
    }
  };
}
function _i() {
  Gr = [], Xr = new Kt();
}
var lr = typeof globalThis < "u" ? globalThis : typeof window < "u" ? window : typeof global < "u" ? global : typeof self < "u" ? self : {};
function el(a) {
  return a && a.__esModule && Object.prototype.hasOwnProperty.call(a, "default") ? a.default : a;
}
var Lt = { exports: {} }, cr;
function bi() {
  return cr || (cr = 1, (function(a) {
    var t = typeof window < "u" ? window : typeof WorkerGlobalScope < "u" && self instanceof WorkerGlobalScope ? self : {};
    var r = (function(n) {
      var s = /(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i, i = 0, o = {}, l = {
        /**
         * By default, Prism will attempt to highlight all code elements (by calling {@link Prism.highlightAll}) on the
         * current page after the page finished loading. This might be a problem if e.g. you wanted to asynchronously load
         * additional languages or plugins yourself.
         *
         * By setting this value to `true`, Prism will not automatically highlight all code elements on the page.
         *
         * You obviously have to change this value before the automatic highlighting started. To do this, you can add an
         * empty Prism object into the global scope before loading the Prism script like this:
         *
         * ```js
         * window.Prism = window.Prism || {};
         * Prism.manual = true;
         * // add a new <script> to load Prism's script
         * ```
         *
         * @default false
         * @type {boolean}
         * @memberof Prism
         * @public
         */
        manual: n.Prism && n.Prism.manual,
        /**
         * By default, if Prism is in a web worker, it assumes that it is in a worker it created itself, so it uses
         * `addEventListener` to communicate with its parent instance. However, if you're using Prism manually in your
         * own worker, you don't want it to do this.
         *
         * By setting this value to `true`, Prism will not add its own listeners to the worker.
         *
         * You obviously have to change this value before Prism executes. To do this, you can add an
         * empty Prism object into the global scope before loading the Prism script like this:
         *
         * ```js
         * window.Prism = window.Prism || {};
         * Prism.disableWorkerMessageHandler = true;
         * // Load Prism's script
         * ```
         *
         * @default false
         * @type {boolean}
         * @memberof Prism
         * @public
         */
        disableWorkerMessageHandler: n.Prism && n.Prism.disableWorkerMessageHandler,
        /**
         * A namespace for utility methods.
         *
         * All function in this namespace that are not explicitly marked as _public_ are for __internal use only__ and may
         * change or disappear at any time.
         *
         * @namespace
         * @memberof Prism
         */
        util: {
          encode: function d(p) {
            return p instanceof c ? new c(p.type, d(p.content), p.alias) : Array.isArray(p) ? p.map(d) : p.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/\u00a0/g, " ");
          },
          /**
           * Returns the name of the type of the given value.
           *
           * @param {any} o
           * @returns {string}
           * @example
           * type(null)      === 'Null'
           * type(undefined) === 'Undefined'
           * type(123)       === 'Number'
           * type('foo')     === 'String'
           * type(true)      === 'Boolean'
           * type([1, 2])    === 'Array'
           * type({})        === 'Object'
           * type(String)    === 'Function'
           * type(/abc+/)    === 'RegExp'
           */
          type: function(d) {
            return Object.prototype.toString.call(d).slice(8, -1);
          },
          /**
           * Returns a unique number for the given object. Later calls will still return the same number.
           *
           * @param {Object} obj
           * @returns {number}
           */
          objId: function(d) {
            return d.__id || Object.defineProperty(d, "__id", { value: ++i }), d.__id;
          },
          /**
           * Creates a deep clone of the given object.
           *
           * The main intended use of this function is to clone language definitions.
           *
           * @param {T} o
           * @param {Record<number, any>} [visited]
           * @returns {T}
           * @template T
           */
          clone: function d(p, v) {
            v = v || {};
            var u, f;
            switch (l.util.type(p)) {
              case "Object":
                if (f = l.util.objId(p), v[f])
                  return v[f];
                u = /** @type {Record<string, any>} */
                {}, v[f] = u;
                for (var g in p)
                  p.hasOwnProperty(g) && (u[g] = d(p[g], v));
                return (
                  /** @type {any} */
                  u
                );
              case "Array":
                return f = l.util.objId(p), v[f] ? v[f] : (u = [], v[f] = u, /** @type {Array} */
                /** @type {any} */
                p.forEach(function(x, m) {
                  u[m] = d(x, v);
                }), /** @type {any} */
                u);
              default:
                return p;
            }
          },
          /**
           * Returns the Prism language of the given element set by a `language-xxxx` or `lang-xxxx` class.
           *
           * If no language is set for the element or the element is `null` or `undefined`, `none` will be returned.
           *
           * @param {Element} element
           * @returns {string}
           */
          getLanguage: function(d) {
            for (; d; ) {
              var p = s.exec(d.className);
              if (p)
                return p[1].toLowerCase();
              d = d.parentElement;
            }
            return "none";
          },
          /**
           * Sets the Prism `language-xxxx` class of the given element.
           *
           * @param {Element} element
           * @param {string} language
           * @returns {void}
           */
          setLanguage: function(d, p) {
            d.className = d.className.replace(RegExp(s, "gi"), ""), d.classList.add("language-" + p);
          },
          /**
           * Returns the script element that is currently executing.
           *
           * This does __not__ work for line script element.
           *
           * @returns {HTMLScriptElement | null}
           */
          currentScript: function() {
            if (typeof document > "u")
              return null;
            if (document.currentScript && document.currentScript.tagName === "SCRIPT")
              return (
                /** @type {any} */
                document.currentScript
              );
            try {
              throw new Error();
            } catch (u) {
              var d = (/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(u.stack) || [])[1];
              if (d) {
                var p = document.getElementsByTagName("script");
                for (var v in p)
                  if (p[v].src == d)
                    return p[v];
              }
              return null;
            }
          },
          /**
           * Returns whether a given class is active for `element`.
           *
           * The class can be activated if `element` or one of its ancestors has the given class and it can be deactivated
           * if `element` or one of its ancestors has the negated version of the given class. The _negated version_ of the
           * given class is just the given class with a `no-` prefix.
           *
           * Whether the class is active is determined by the closest ancestor of `element` (where `element` itself is
           * closest ancestor) that has the given class or the negated version of it. If neither `element` nor any of its
           * ancestors have the given class or the negated version of it, then the default activation will be returned.
           *
           * In the paradoxical situation where the closest ancestor contains __both__ the given class and the negated
           * version of it, the class is considered active.
           *
           * @param {Element} element
           * @param {string} className
           * @param {boolean} [defaultActivation=false]
           * @returns {boolean}
           */
          isActive: function(d, p, v) {
            for (var u = "no-" + p; d; ) {
              var f = d.classList;
              if (f.contains(p))
                return !0;
              if (f.contains(u))
                return !1;
              d = d.parentElement;
            }
            return !!v;
          }
        },
        /**
         * This namespace contains all currently loaded languages and the some helper functions to create and modify languages.
         *
         * @namespace
         * @memberof Prism
         * @public
         */
        languages: {
          /**
           * The grammar for plain, unformatted text.
           */
          plain: o,
          plaintext: o,
          text: o,
          txt: o,
          /**
           * Creates a deep copy of the language with the given id and appends the given tokens.
           *
           * If a token in `redef` also appears in the copied language, then the existing token in the copied language
           * will be overwritten at its original position.
           *
           * ## Best practices
           *
           * Since the position of overwriting tokens (token in `redef` that overwrite tokens in the copied language)
           * doesn't matter, they can technically be in any order. However, this can be confusing to others that trying to
           * understand the language definition because, normally, the order of tokens matters in Prism grammars.
           *
           * Therefore, it is encouraged to order overwriting tokens according to the positions of the overwritten tokens.
           * Furthermore, all non-overwriting tokens should be placed after the overwriting ones.
           *
           * @param {string} id The id of the language to extend. This has to be a key in `Prism.languages`.
           * @param {Grammar} redef The new tokens to append.
           * @returns {Grammar} The new language created.
           * @public
           * @example
           * Prism.languages['css-with-colors'] = Prism.languages.extend('css', {
           *     // Prism.languages.css already has a 'comment' token, so this token will overwrite CSS' 'comment' token
           *     // at its original position
           *     'comment': { ... },
           *     // CSS doesn't have a 'color' token, so this token will be appended
           *     'color': /\b(?:red|green|blue)\b/
           * });
           */
          extend: function(d, p) {
            var v = l.util.clone(l.languages[d]);
            for (var u in p)
              v[u] = p[u];
            return v;
          },
          /**
           * Inserts tokens _before_ another token in a language definition or any other grammar.
           *
           * ## Usage
           *
           * This helper method makes it easy to modify existing languages. For example, the CSS language definition
           * not only defines CSS highlighting for CSS documents, but also needs to define highlighting for CSS embedded
           * in HTML through `<style>` elements. To do this, it needs to modify `Prism.languages.markup` and add the
           * appropriate tokens. However, `Prism.languages.markup` is a regular JavaScript object literal, so if you do
           * this:
           *
           * ```js
           * Prism.languages.markup.style = {
           *     // token
           * };
           * ```
           *
           * then the `style` token will be added (and processed) at the end. `insertBefore` allows you to insert tokens
           * before existing tokens. For the CSS example above, you would use it like this:
           *
           * ```js
           * Prism.languages.insertBefore('markup', 'cdata', {
           *     'style': {
           *         // token
           *     }
           * });
           * ```
           *
           * ## Special cases
           *
           * If the grammars of `inside` and `insert` have tokens with the same name, the tokens in `inside`'s grammar
           * will be ignored.
           *
           * This behavior can be used to insert tokens after `before`:
           *
           * ```js
           * Prism.languages.insertBefore('markup', 'comment', {
           *     'comment': Prism.languages.markup.comment,
           *     // tokens after 'comment'
           * });
           * ```
           *
           * ## Limitations
           *
           * The main problem `insertBefore` has to solve is iteration order. Since ES2015, the iteration order for object
           * properties is guaranteed to be the insertion order (except for integer keys) but some browsers behave
           * differently when keys are deleted and re-inserted. So `insertBefore` can't be implemented by temporarily
           * deleting properties which is necessary to insert at arbitrary positions.
           *
           * To solve this problem, `insertBefore` doesn't actually insert the given tokens into the target object.
           * Instead, it will create a new object and replace all references to the target object with the new one. This
           * can be done without temporarily deleting properties, so the iteration order is well-defined.
           *
           * However, only references that can be reached from `Prism.languages` or `insert` will be replaced. I.e. if
           * you hold the target object in a variable, then the value of the variable will not change.
           *
           * ```js
           * var oldMarkup = Prism.languages.markup;
           * var newMarkup = Prism.languages.insertBefore('markup', 'comment', { ... });
           *
           * assert(oldMarkup !== Prism.languages.markup);
           * assert(newMarkup === Prism.languages.markup);
           * ```
           *
           * @param {string} inside The property of `root` (e.g. a language id in `Prism.languages`) that contains the
           * object to be modified.
           * @param {string} before The key to insert before.
           * @param {Grammar} insert An object containing the key-value pairs to be inserted.
           * @param {Object<string, any>} [root] The object containing `inside`, i.e. the object that contains the
           * object to be modified.
           *
           * Defaults to `Prism.languages`.
           * @returns {Grammar} The new grammar object.
           * @public
           */
          insertBefore: function(d, p, v, u) {
            u = u || /** @type {any} */
            l.languages;
            var f = u[d], g = {};
            for (var x in f)
              if (f.hasOwnProperty(x)) {
                if (x == p)
                  for (var m in v)
                    v.hasOwnProperty(m) && (g[m] = v[m]);
                v.hasOwnProperty(x) || (g[x] = f[x]);
              }
            var F = u[d];
            return u[d] = g, l.languages.DFS(l.languages, function(B, C) {
              C === F && B != d && (this[B] = g);
            }), g;
          },
          // Traverse a language definition with Depth First Search
          DFS: function d(p, v, u, f) {
            f = f || {};
            var g = l.util.objId;
            for (var x in p)
              if (p.hasOwnProperty(x)) {
                v.call(p, x, p[x], u || x);
                var m = p[x], F = l.util.type(m);
                F === "Object" && !f[g(m)] ? (f[g(m)] = !0, d(m, v, null, f)) : F === "Array" && !f[g(m)] && (f[g(m)] = !0, d(m, v, x, f));
              }
          }
        },
        plugins: {},
        /**
         * This is the most high-level function in Prism’s API.
         * It fetches all the elements that have a `.language-xxxx` class and then calls {@link Prism.highlightElement} on
         * each one of them.
         *
         * This is equivalent to `Prism.highlightAllUnder(document, async, callback)`.
         *
         * @param {boolean} [async=false] Same as in {@link Prism.highlightAllUnder}.
         * @param {HighlightCallback} [callback] Same as in {@link Prism.highlightAllUnder}.
         * @memberof Prism
         * @public
         */
        highlightAll: function(d, p) {
          l.highlightAllUnder(document, d, p);
        },
        /**
         * Fetches all the descendants of `container` that have a `.language-xxxx` class and then calls
         * {@link Prism.highlightElement} on each one of them.
         *
         * The following hooks will be run:
         * 1. `before-highlightall`
         * 2. `before-all-elements-highlight`
         * 3. All hooks of {@link Prism.highlightElement} for each element.
         *
         * @param {ParentNode} container The root element, whose descendants that have a `.language-xxxx` class will be highlighted.
         * @param {boolean} [async=false] Whether each element is to be highlighted asynchronously using Web Workers.
         * @param {HighlightCallback} [callback] An optional callback to be invoked on each element after its highlighting is done.
         * @memberof Prism
         * @public
         */
        highlightAllUnder: function(d, p, v) {
          var u = {
            callback: v,
            container: d,
            selector: 'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code'
          };
          l.hooks.run("before-highlightall", u), u.elements = Array.prototype.slice.apply(u.container.querySelectorAll(u.selector)), l.hooks.run("before-all-elements-highlight", u);
          for (var f = 0, g; g = u.elements[f++]; )
            l.highlightElement(g, p === !0, u.callback);
        },
        /**
         * Highlights the code inside a single element.
         *
         * The following hooks will be run:
         * 1. `before-sanity-check`
         * 2. `before-highlight`
         * 3. All hooks of {@link Prism.highlight}. These hooks will be run by an asynchronous worker if `async` is `true`.
         * 4. `before-insert`
         * 5. `after-highlight`
         * 6. `complete`
         *
         * Some the above hooks will be skipped if the element doesn't contain any text or there is no grammar loaded for
         * the element's language.
         *
         * @param {Element} element The element containing the code.
         * It must have a class of `language-xxxx` to be processed, where `xxxx` is a valid language identifier.
         * @param {boolean} [async=false] Whether the element is to be highlighted asynchronously using Web Workers
         * to improve performance and avoid blocking the UI when highlighting very large chunks of code. This option is
         * [disabled by default](https://prismjs.com/faq.html#why-is-asynchronous-highlighting-disabled-by-default).
         *
         * Note: All language definitions required to highlight the code must be included in the main `prism.js` file for
         * asynchronous highlighting to work. You can build your own bundle on the
         * [Download page](https://prismjs.com/download.html).
         * @param {HighlightCallback} [callback] An optional callback to be invoked after the highlighting is done.
         * Mostly useful when `async` is `true`, since in that case, the highlighting is done asynchronously.
         * @memberof Prism
         * @public
         */
        highlightElement: function(d, p, v) {
          var u = l.util.getLanguage(d), f = l.languages[u];
          l.util.setLanguage(d, u);
          var g = d.parentElement;
          g && g.nodeName.toLowerCase() === "pre" && l.util.setLanguage(g, u);
          var x = d.textContent, m = {
            element: d,
            language: u,
            grammar: f,
            code: x
          };
          function F(C) {
            m.highlightedCode = C, l.hooks.run("before-insert", m), m.element.innerHTML = m.highlightedCode, l.hooks.run("after-highlight", m), l.hooks.run("complete", m), v && v.call(m.element);
          }
          if (l.hooks.run("before-sanity-check", m), g = m.element.parentElement, g && g.nodeName.toLowerCase() === "pre" && !g.hasAttribute("tabindex") && g.setAttribute("tabindex", "0"), !m.code) {
            l.hooks.run("complete", m), v && v.call(m.element);
            return;
          }
          if (l.hooks.run("before-highlight", m), !m.grammar) {
            F(l.util.encode(m.code));
            return;
          }
          if (p && n.Worker) {
            var B = new Worker(l.filename);
            B.onmessage = function(C) {
              F(C.data);
            }, B.postMessage(JSON.stringify({
              language: m.language,
              code: m.code,
              immediateClose: !0
            }));
          } else
            F(l.highlight(m.code, m.grammar, m.language));
        },
        /**
         * Low-level function, only use if you know what you’re doing. It accepts a string of text as input
         * and the language definitions to use, and returns a string with the HTML produced.
         *
         * The following hooks will be run:
         * 1. `before-tokenize`
         * 2. `after-tokenize`
         * 3. `wrap`: On each {@link Token}.
         *
         * @param {string} text A string with the code to be highlighted.
         * @param {Grammar} grammar An object containing the tokens to use.
         *
         * Usually a language definition like `Prism.languages.markup`.
         * @param {string} language The name of the language definition passed to `grammar`.
         * @returns {string} The highlighted HTML.
         * @memberof Prism
         * @public
         * @example
         * Prism.highlight('var foo = true;', Prism.languages.javascript, 'javascript');
         */
        highlight: function(d, p, v) {
          var u = {
            code: d,
            grammar: p,
            language: v
          };
          if (l.hooks.run("before-tokenize", u), !u.grammar)
            throw new Error('The language "' + u.language + '" has no grammar.');
          return u.tokens = l.tokenize(u.code, u.grammar), l.hooks.run("after-tokenize", u), c.stringify(l.util.encode(u.tokens), u.language);
        },
        /**
         * This is the heart of Prism, and the most low-level function you can use. It accepts a string of text as input
         * and the language definitions to use, and returns an array with the tokenized code.
         *
         * When the language definition includes nested tokens, the function is called recursively on each of these tokens.
         *
         * This method could be useful in other contexts as well, as a very crude parser.
         *
         * @param {string} text A string with the code to be highlighted.
         * @param {Grammar} grammar An object containing the tokens to use.
         *
         * Usually a language definition like `Prism.languages.markup`.
         * @returns {TokenStream} An array of strings and tokens, a token stream.
         * @memberof Prism
         * @public
         * @example
         * let code = `var foo = 0;`;
         * let tokens = Prism.tokenize(code, Prism.languages.javascript);
         * tokens.forEach(token => {
         *     if (token instanceof Prism.Token && token.type === 'number') {
         *         console.log(`Found numeric literal: ${token.content}`);
         *     }
         * });
         */
        tokenize: function(d, p) {
          var v = p.rest;
          if (v) {
            for (var u in v)
              p[u] = v[u];
            delete p.rest;
          }
          var f = new _();
          return b(f, f.head, d), h(d, f, p, f.head, 0), T(f);
        },
        /**
         * @namespace
         * @memberof Prism
         * @public
         */
        hooks: {
          all: {},
          /**
           * Adds the given callback to the list of callbacks for the given hook.
           *
           * The callback will be invoked when the hook it is registered for is run.
           * Hooks are usually directly run by a highlight function but you can also run hooks yourself.
           *
           * One callback function can be registered to multiple hooks and the same hook multiple times.
           *
           * @param {string} name The name of the hook.
           * @param {HookCallback} callback The callback function which is given environment variables.
           * @public
           */
          add: function(d, p) {
            var v = l.hooks.all;
            v[d] = v[d] || [], v[d].push(p);
          },
          /**
           * Runs a hook invoking all registered callbacks with the given environment variables.
           *
           * Callbacks will be invoked synchronously and in the order in which they were registered.
           *
           * @param {string} name The name of the hook.
           * @param {Object<string, any>} env The environment variables of the hook passed to all callbacks registered.
           * @public
           */
          run: function(d, p) {
            var v = l.hooks.all[d];
            if (!(!v || !v.length))
              for (var u = 0, f; f = v[u++]; )
                f(p);
          }
        },
        Token: c
      };
      n.Prism = l;
      function c(d, p, v, u) {
        this.type = d, this.content = p, this.alias = v, this.length = (u || "").length | 0;
      }
      c.stringify = function d(p, v) {
        if (typeof p == "string")
          return p;
        if (Array.isArray(p)) {
          var u = "";
          return p.forEach(function(F) {
            u += d(F, v);
          }), u;
        }
        var f = {
          type: p.type,
          content: d(p.content, v),
          tag: "span",
          classes: ["token", p.type],
          attributes: {},
          language: v
        }, g = p.alias;
        g && (Array.isArray(g) ? Array.prototype.push.apply(f.classes, g) : f.classes.push(g)), l.hooks.run("wrap", f);
        var x = "";
        for (var m in f.attributes)
          x += " " + m + '="' + (f.attributes[m] || "").replace(/"/g, "&quot;") + '"';
        return "<" + f.tag + ' class="' + f.classes.join(" ") + '"' + x + ">" + f.content + "</" + f.tag + ">";
      };
      function w(d, p, v, u) {
        d.lastIndex = p;
        var f = d.exec(v);
        if (f && u && f[1]) {
          var g = f[1].length;
          f.index += g, f[0] = f[0].slice(g);
        }
        return f;
      }
      function h(d, p, v, u, f, g) {
        for (var x in v)
          if (!(!v.hasOwnProperty(x) || !v[x])) {
            var m = v[x];
            m = Array.isArray(m) ? m : [m];
            for (var F = 0; F < m.length; ++F) {
              if (g && g.cause == x + "," + F)
                return;
              var B = m[F], C = B.inside, O = !!B.lookbehind, N = !!B.greedy, ie = B.alias;
              if (N && !B.pattern.global) {
                var H = B.pattern.toString().match(/[imsuy]*$/)[0];
                B.pattern = RegExp(B.pattern.source, H + "g");
              }
              for (var Z = B.pattern || B, R = u.next, G = f; R !== p.tail && !(g && G >= g.reach); G += R.value.length, R = R.next) {
                var ae = R.value;
                if (p.length > d.length)
                  return;
                if (!(ae instanceof c)) {
                  var $ = 1, te;
                  if (N) {
                    if (te = w(Z, G, d, O), !te || te.index >= d.length)
                      break;
                    var ne = te.index, Q = te.index + te[0].length, re = G;
                    for (re += R.value.length; ne >= re; )
                      R = R.next, re += R.value.length;
                    if (re -= R.value.length, G = re, R.value instanceof c)
                      continue;
                    for (var Y = R; Y !== p.tail && (re < Q || typeof Y.value == "string"); Y = Y.next)
                      $++, re += Y.value.length;
                    $--, ae = d.slice(G, re), te.index -= G;
                  } else if (te = w(Z, 0, ae, O), !te)
                    continue;
                  var ne = te.index, z = te[0], S = ae.slice(0, ne), L = ae.slice(ne + z.length), A = G + ae.length;
                  g && A > g.reach && (g.reach = A);
                  var V = R.prev;
                  S && (V = b(p, V, S), G += S.length), D(p, V, $);
                  var P = new c(x, C ? l.tokenize(z, C) : z, ie, z);
                  if (R = b(p, V, P), L && b(p, R, L), $ > 1) {
                    var K = {
                      cause: x + "," + F,
                      reach: A
                    };
                    h(d, p, v, R.prev, G, K), g && K.reach > g.reach && (g.reach = K.reach);
                  }
                }
              }
            }
          }
      }
      function _() {
        var d = { value: null, prev: null, next: null }, p = { value: null, prev: d, next: null };
        d.next = p, this.head = d, this.tail = p, this.length = 0;
      }
      function b(d, p, v) {
        var u = p.next, f = { value: v, prev: p, next: u };
        return p.next = f, u.prev = f, d.length++, f;
      }
      function D(d, p, v) {
        for (var u = p.next, f = 0; f < v && u !== d.tail; f++)
          u = u.next;
        p.next = u, u.prev = p, d.length -= f;
      }
      function T(d) {
        for (var p = [], v = d.head.next; v !== d.tail; )
          p.push(v.value), v = v.next;
        return p;
      }
      if (!n.document)
        return n.addEventListener && (l.disableWorkerMessageHandler || n.addEventListener("message", function(d) {
          var p = JSON.parse(d.data), v = p.language, u = p.code, f = p.immediateClose;
          n.postMessage(l.highlight(u, l.languages[v], v)), f && n.close();
        }, !1)), l;
      var E = l.util.currentScript();
      E && (l.filename = E.src, E.hasAttribute("data-manual") && (l.manual = !0));
      function k() {
        l.manual || l.highlightAll();
      }
      if (!l.manual) {
        var y = document.readyState;
        y === "loading" || y === "interactive" && E && E.defer ? document.addEventListener("DOMContentLoaded", k) : window.requestAnimationFrame ? window.requestAnimationFrame(k) : window.setTimeout(k, 16);
      }
      return l;
    })(t);
    a.exports && (a.exports = r), typeof lr < "u" && (lr.Prism = r), r.languages.markup = {
      comment: {
        pattern: /<!--(?:(?!<!--)[\s\S])*?-->/,
        greedy: !0
      },
      prolog: {
        pattern: /<\?[\s\S]+?\?>/,
        greedy: !0
      },
      doctype: {
        // https://www.w3.org/TR/xml/#NT-doctypedecl
        pattern: /<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,
        greedy: !0,
        inside: {
          "internal-subset": {
            pattern: /(^[^\[]*\[)[\s\S]+(?=\]>$)/,
            lookbehind: !0,
            greedy: !0,
            inside: null
            // see below
          },
          string: {
            pattern: /"[^"]*"|'[^']*'/,
            greedy: !0
          },
          punctuation: /^<!|>$|[[\]]/,
          "doctype-tag": /^DOCTYPE/i,
          name: /[^\s<>'"]+/
        }
      },
      cdata: {
        pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
        greedy: !0
      },
      tag: {
        pattern: /<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,
        greedy: !0,
        inside: {
          tag: {
            pattern: /^<\/?[^\s>\/]+/,
            inside: {
              punctuation: /^<\/?/,
              namespace: /^[^\s>\/:]+:/
            }
          },
          "special-attr": [],
          "attr-value": {
            pattern: /=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,
            inside: {
              punctuation: [
                {
                  pattern: /^=/,
                  alias: "attr-equals"
                },
                {
                  pattern: /^(\s*)["']|["']$/,
                  lookbehind: !0
                }
              ]
            }
          },
          punctuation: /\/?>/,
          "attr-name": {
            pattern: /[^\s>\/]+/,
            inside: {
              namespace: /^[^\s>\/:]+:/
            }
          }
        }
      },
      entity: [
        {
          pattern: /&[\da-z]{1,8};/i,
          alias: "named-entity"
        },
        /&#x?[\da-f]{1,8};/i
      ]
    }, r.languages.markup.tag.inside["attr-value"].inside.entity = r.languages.markup.entity, r.languages.markup.doctype.inside["internal-subset"].inside = r.languages.markup, r.hooks.add("wrap", function(n) {
      n.type === "entity" && (n.attributes.title = n.content.replace(/&amp;/, "&"));
    }), Object.defineProperty(r.languages.markup.tag, "addInlined", {
      /**
       * Adds an inlined language to markup.
       *
       * An example of an inlined language is CSS with `<style>` tags.
       *
       * @param {string} tagName The name of the tag that contains the inlined language. This name will be treated as
       * case insensitive.
       * @param {string} lang The language key.
       * @example
       * addInlined('style', 'css');
       */
      value: function(s, i) {
        var o = {};
        o["language-" + i] = {
          pattern: /(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,
          lookbehind: !0,
          inside: r.languages[i]
        }, o.cdata = /^<!\[CDATA\[|\]\]>$/i;
        var l = {
          "included-cdata": {
            pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
            inside: o
          }
        };
        l["language-" + i] = {
          pattern: /[\s\S]+/,
          inside: r.languages[i]
        };
        var c = {};
        c[s] = {
          pattern: RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g, function() {
            return s;
          }), "i"),
          lookbehind: !0,
          greedy: !0,
          inside: l
        }, r.languages.insertBefore("markup", "cdata", c);
      }
    }), Object.defineProperty(r.languages.markup.tag, "addAttribute", {
      /**
       * Adds an pattern to highlight languages embedded in HTML attributes.
       *
       * An example of an inlined language is CSS with `style` attributes.
       *
       * @param {string} attrName The name of the tag that contains the inlined language. This name will be treated as
       * case insensitive.
       * @param {string} lang The language key.
       * @example
       * addAttribute('style', 'css');
       */
      value: function(n, s) {
        r.languages.markup.tag.inside["special-attr"].push({
          pattern: RegExp(
            /(^|["'\s])/.source + "(?:" + n + ")" + /\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,
            "i"
          ),
          lookbehind: !0,
          inside: {
            "attr-name": /^[^\s=]+/,
            "attr-value": {
              pattern: /=[\s\S]+/,
              inside: {
                value: {
                  pattern: /(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,
                  lookbehind: !0,
                  alias: [s, "language-" + s],
                  inside: r.languages[s]
                },
                punctuation: [
                  {
                    pattern: /^=/,
                    alias: "attr-equals"
                  },
                  /"|'/
                ]
              }
            }
          }
        });
      }
    }), r.languages.html = r.languages.markup, r.languages.mathml = r.languages.markup, r.languages.svg = r.languages.markup, r.languages.xml = r.languages.extend("markup", {}), r.languages.ssml = r.languages.xml, r.languages.atom = r.languages.xml, r.languages.rss = r.languages.xml, (function(n) {
      var s = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;
      n.languages.css = {
        comment: /\/\*[\s\S]*?\*\//,
        atrule: {
          pattern: RegExp("@[\\w-](?:" + /[^;{\s"']|\s+(?!\s)/.source + "|" + s.source + ")*?" + /(?:;|(?=\s*\{))/.source),
          inside: {
            rule: /^@[\w-]+/,
            "selector-function-argument": {
              pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,
              lookbehind: !0,
              alias: "selector"
            },
            keyword: {
              pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/,
              lookbehind: !0
            }
            // See rest below
          }
        },
        url: {
          // https://drafts.csswg.org/css-values-3/#urls
          pattern: RegExp("\\burl\\((?:" + s.source + "|" + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ")\\)", "i"),
          greedy: !0,
          inside: {
            function: /^url/i,
            punctuation: /^\(|\)$/,
            string: {
              pattern: RegExp("^" + s.source + "$"),
              alias: "url"
            }
          }
        },
        selector: {
          pattern: RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|` + s.source + ")*(?=\\s*\\{)"),
          lookbehind: !0
        },
        string: {
          pattern: s,
          greedy: !0
        },
        property: {
          pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,
          lookbehind: !0
        },
        important: /!important\b/i,
        function: {
          pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,
          lookbehind: !0
        },
        punctuation: /[(){};:,]/
      }, n.languages.css.atrule.inside.rest = n.languages.css;
      var i = n.languages.markup;
      i && (i.tag.addInlined("style", "css"), i.tag.addAttribute("style", "css"));
    })(r), r.languages.clike = {
      comment: [
        {
          pattern: /(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,
          lookbehind: !0,
          greedy: !0
        },
        {
          pattern: /(^|[^\\:])\/\/.*/,
          lookbehind: !0,
          greedy: !0
        }
      ],
      string: {
        pattern: /(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,
        greedy: !0
      },
      "class-name": {
        pattern: /(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,
        lookbehind: !0,
        inside: {
          punctuation: /[.\\]/
        }
      },
      keyword: /\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,
      boolean: /\b(?:false|true)\b/,
      function: /\b\w+(?=\()/,
      number: /\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,
      operator: /[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,
      punctuation: /[{}[\];(),.:]/
    }, r.languages.javascript = r.languages.extend("clike", {
      "class-name": [
        r.languages.clike["class-name"],
        {
          pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,
          lookbehind: !0
        }
      ],
      keyword: [
        {
          pattern: /((?:^|\})\s*)catch\b/,
          lookbehind: !0
        },
        {
          pattern: /(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,
          lookbehind: !0
        }
      ],
      // Allow for all non-ASCII characters (See http://stackoverflow.com/a/2008444)
      function: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,
      number: {
        pattern: RegExp(
          /(^|[^\w$])/.source + "(?:" + // constant
          (/NaN|Infinity/.source + "|" + // binary integer
          /0[bB][01]+(?:_[01]+)*n?/.source + "|" + // octal integer
          /0[oO][0-7]+(?:_[0-7]+)*n?/.source + "|" + // hexadecimal integer
          /0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source + "|" + // decimal bigint
          /\d+(?:_\d+)*n/.source + "|" + // decimal number (integer or float) but no bigint
          /(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source) + ")" + /(?![\w$])/.source
        ),
        lookbehind: !0
      },
      operator: /--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/
    }), r.languages.javascript["class-name"][0].pattern = /(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/, r.languages.insertBefore("javascript", "keyword", {
      regex: {
        pattern: RegExp(
          // lookbehind
          // eslint-disable-next-line regexp/no-dupe-characters-character-class
          /((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source + // Regex pattern:
          // There are 2 regex patterns here. The RegExp set notation proposal added support for nested character
          // classes if the `v` flag is present. Unfortunately, nested CCs are both context-free and incompatible
          // with the only syntax, so we have to define 2 different regex patterns.
          /\//.source + "(?:" + /(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}/.source + "|" + // `v` flag syntax. This supports 3 levels of nested character classes.
          /(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/.source + ")" + // lookahead
          /(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source
        ),
        lookbehind: !0,
        greedy: !0,
        inside: {
          "regex-source": {
            pattern: /^(\/)[\s\S]+(?=\/[a-z]*$)/,
            lookbehind: !0,
            alias: "language-regex",
            inside: r.languages.regex
          },
          "regex-delimiter": /^\/|\/$/,
          "regex-flags": /^[a-z]+$/
        }
      },
      // This must be declared before keyword because we use "function" inside the look-forward
      "function-variable": {
        pattern: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,
        alias: "function"
      },
      parameter: [
        {
          pattern: /(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,
          lookbehind: !0,
          inside: r.languages.javascript
        },
        {
          pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,
          lookbehind: !0,
          inside: r.languages.javascript
        },
        {
          pattern: /(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,
          lookbehind: !0,
          inside: r.languages.javascript
        },
        {
          pattern: /((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,
          lookbehind: !0,
          inside: r.languages.javascript
        }
      ],
      constant: /\b[A-Z](?:[A-Z_]|\dx?)*\b/
    }), r.languages.insertBefore("javascript", "string", {
      hashbang: {
        pattern: /^#!.*/,
        greedy: !0,
        alias: "comment"
      },
      "template-string": {
        pattern: /`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,
        greedy: !0,
        inside: {
          "template-punctuation": {
            pattern: /^`|`$/,
            alias: "string"
          },
          interpolation: {
            pattern: /((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,
            lookbehind: !0,
            inside: {
              "interpolation-punctuation": {
                pattern: /^\$\{|\}$/,
                alias: "punctuation"
              },
              rest: r.languages.javascript
            }
          },
          string: /[\s\S]+/
        }
      },
      "string-property": {
        pattern: /((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,
        lookbehind: !0,
        greedy: !0,
        alias: "property"
      }
    }), r.languages.insertBefore("javascript", "operator", {
      "literal-property": {
        pattern: /((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,
        lookbehind: !0,
        alias: "property"
      }
    }), r.languages.markup && (r.languages.markup.tag.addInlined("script", "javascript"), r.languages.markup.tag.addAttribute(
      /on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source,
      "javascript"
    )), r.languages.js = r.languages.javascript, (function() {
      if (typeof r > "u" || typeof document > "u")
        return;
      Element.prototype.matches || (Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector);
      var n = "Loading…", s = function(E, k) {
        return "✖ Error " + E + " while fetching file: " + k;
      }, i = "✖ Error: File does not exist or is empty", o = {
        js: "javascript",
        py: "python",
        rb: "ruby",
        ps1: "powershell",
        psm1: "powershell",
        sh: "bash",
        bat: "batch",
        h: "c",
        tex: "latex"
      }, l = "data-src-status", c = "loading", w = "loaded", h = "failed", _ = "pre[data-src]:not([" + l + '="' + w + '"]):not([' + l + '="' + c + '"])';
      function b(E, k, y) {
        var d = new XMLHttpRequest();
        d.open("GET", E, !0), d.onreadystatechange = function() {
          d.readyState == 4 && (d.status < 400 && d.responseText ? k(d.responseText) : d.status >= 400 ? y(s(d.status, d.statusText)) : y(i));
        }, d.send(null);
      }
      function D(E) {
        var k = /^\s*(\d+)\s*(?:(,)\s*(?:(\d+)\s*)?)?$/.exec(E || "");
        if (k) {
          var y = Number(k[1]), d = k[2], p = k[3];
          return d ? p ? [y, Number(p)] : [y, void 0] : [y, y];
        }
      }
      r.hooks.add("before-highlightall", function(E) {
        E.selector += ", " + _;
      }), r.hooks.add("before-sanity-check", function(E) {
        var k = (
          /** @type {HTMLPreElement} */
          E.element
        );
        if (k.matches(_)) {
          E.code = "", k.setAttribute(l, c);
          var y = k.appendChild(document.createElement("CODE"));
          y.textContent = n;
          var d = k.getAttribute("data-src"), p = E.language;
          if (p === "none") {
            var v = (/\.(\w+)$/.exec(d) || [, "none"])[1];
            p = o[v] || v;
          }
          r.util.setLanguage(y, p), r.util.setLanguage(k, p);
          var u = r.plugins.autoloader;
          u && u.loadLanguages(p), b(
            d,
            function(f) {
              k.setAttribute(l, w);
              var g = D(k.getAttribute("data-range"));
              if (g) {
                var x = f.split(/\r\n?|\n/g), m = g[0], F = g[1] == null ? x.length : g[1];
                m < 0 && (m += x.length), m = Math.max(0, Math.min(m - 1, x.length)), F < 0 && (F += x.length), F = Math.max(0, Math.min(F, x.length)), f = x.slice(m, F).join(`
`), k.hasAttribute("data-start") || k.setAttribute("data-start", String(m + 1));
              }
              y.textContent = f, r.highlightElement(y);
            },
            function(f) {
              k.setAttribute(l, h), y.textContent = f;
            }
          );
        }
      }), r.plugins.fileHighlight = {
        /**
         * Executes the File Highlight plugin for all matching `pre` elements under the given container.
         *
         * Note: Elements which are already loaded or currently loading will not be touched by this method.
         *
         * @param {ParentNode} [container=document]
         */
        highlight: function(k) {
          for (var y = (k || document).querySelectorAll(_), d = 0, p; p = y[d++]; )
            r.highlightElement(p);
        }
      };
      var T = !1;
      r.fileHighlight = function() {
        T || (console.warn("Prism.fileHighlight is deprecated. Use `Prism.plugins.fileHighlight.highlight` instead."), T = !0), r.plugins.fileHighlight.highlight.apply(this, arguments);
      };
    })();
  })(Lt)), Lt.exports;
}
var Mt = bi(), ur = {}, dr;
function xi() {
  return dr || (dr = 1, Prism.languages.python = {
    comment: {
      pattern: /(^|[^\\])#.*/,
      lookbehind: !0,
      greedy: !0
    },
    "string-interpolation": {
      pattern: /(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i,
      greedy: !0,
      inside: {
        interpolation: {
          // "{" <expression> <optional "!s", "!r", or "!a"> <optional ":" format specifier> "}"
          pattern: /((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/,
          lookbehind: !0,
          inside: {
            "format-spec": {
              pattern: /(:)[^:(){}]+(?=\}$)/,
              lookbehind: !0
            },
            "conversion-option": {
              pattern: /![sra](?=[:}]$)/,
              alias: "punctuation"
            },
            rest: null
          }
        },
        string: /[\s\S]+/
      }
    },
    "triple-quoted-string": {
      pattern: /(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i,
      greedy: !0,
      alias: "string"
    },
    string: {
      pattern: /(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i,
      greedy: !0
    },
    function: {
      pattern: /((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g,
      lookbehind: !0
    },
    "class-name": {
      pattern: /(\bclass\s+)\w+/i,
      lookbehind: !0
    },
    decorator: {
      pattern: /(^[\t ]*)@\w+(?:\.\w+)*/m,
      lookbehind: !0,
      alias: ["annotation", "punctuation"],
      inside: {
        punctuation: /\./
      }
    },
    keyword: /\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/,
    builtin: /\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/,
    boolean: /\b(?:False|None|True)\b/,
    number: /\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i,
    operator: /[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,
    punctuation: /[{}[\];(),.:]/
  }, Prism.languages.python["string-interpolation"].inside.interpolation.inside.rest = Prism.languages.python, Prism.languages.py = Prism.languages.python), ur;
}
xi();
(function(a) {
  var t = /\\(?:[^a-z()[\]]|[a-z*]+)/i, r = {
    "equation-command": {
      pattern: t,
      alias: "regex"
    }
  };
  a.languages.latex = {
    comment: /%.*/,
    // the verbatim environment prints whitespace to the document
    cdata: {
      pattern: /(\\begin\{((?:lstlisting|verbatim)\*?)\})[\s\S]*?(?=\\end\{\2\})/,
      lookbehind: !0
    },
    /*
     * equations can be between $$ $$ or $ $ or \( \) or \[ \]
     * (all are multiline)
     */
    equation: [
      {
        pattern: /\$\$(?:\\[\s\S]|[^\\$])+\$\$|\$(?:\\[\s\S]|[^\\$])+\$|\\\([\s\S]*?\\\)|\\\[[\s\S]*?\\\]/,
        inside: r,
        alias: "string"
      },
      {
        pattern: /(\\begin\{((?:align|eqnarray|equation|gather|math|multline)\*?)\})[\s\S]*?(?=\\end\{\2\})/,
        lookbehind: !0,
        inside: r,
        alias: "string"
      }
    ],
    /*
     * arguments which are keywords or references are highlighted
     * as keywords
     */
    keyword: {
      pattern: /(\\(?:begin|cite|documentclass|end|label|ref|usepackage)(?:\[[^\]]+\])?\{)[^}]+(?=\})/,
      lookbehind: !0
    },
    url: {
      pattern: /(\\url\{)[^}]+(?=\})/,
      lookbehind: !0
    },
    /*
     * section or chapter headlines are highlighted as bold so that
     * they stand out more
     */
    headline: {
      pattern: /(\\(?:chapter|frametitle|paragraph|part|section|subparagraph|subsection|subsubparagraph|subsubsection|subsubsubparagraph)\*?(?:\[[^\]]+\])?\{)[^}]+(?=\})/,
      lookbehind: !0,
      alias: "class-name"
    },
    function: {
      pattern: t,
      alias: "selector"
    },
    punctuation: /[[\]{}&]/
  }, a.languages.tex = a.languages.latex, a.languages.context = a.languages.latex;
})(Prism);
(function(a) {
  var t = "\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b", r = {
    pattern: /(^(["']?)\w+\2)[ \t]+\S.*/,
    lookbehind: !0,
    alias: "punctuation",
    // this looks reasonably well in all themes
    inside: null
    // see below
  }, n = {
    bash: r,
    environment: {
      pattern: RegExp("\\$" + t),
      alias: "constant"
    },
    variable: [
      // [0]: Arithmetic Environment
      {
        pattern: /\$?\(\([\s\S]+?\)\)/,
        greedy: !0,
        inside: {
          // If there is a $ sign at the beginning highlight $(( and )) as variable
          variable: [
            {
              pattern: /(^\$\(\([\s\S]+)\)\)/,
              lookbehind: !0
            },
            /^\$\(\(/
          ],
          number: /\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,
          // Operators according to https://www.gnu.org/software/bash/manual/bashref.html#Shell-Arithmetic
          operator: /--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/,
          // If there is no $ sign at the beginning highlight (( and )) as punctuation
          punctuation: /\(\(?|\)\)?|,|;/
        }
      },
      // [1]: Command Substitution
      {
        pattern: /\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/,
        greedy: !0,
        inside: {
          variable: /^\$\(|^`|\)$|`$/
        }
      },
      // [2]: Brace expansion
      {
        pattern: /\$\{[^}]+\}/,
        greedy: !0,
        inside: {
          operator: /:[-=?+]?|[!\/]|##?|%%?|\^\^?|,,?/,
          punctuation: /[\[\]]/,
          environment: {
            pattern: RegExp("(\\{)" + t),
            lookbehind: !0,
            alias: "constant"
          }
        }
      },
      /\$(?:\w+|[#?*!@$])/
    ],
    // Escape sequences from echo and printf's manuals, and escaped quotes.
    entity: /\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/
  };
  a.languages.bash = {
    shebang: {
      pattern: /^#!\s*\/.*/,
      alias: "important"
    },
    comment: {
      pattern: /(^|[^"{\\$])#.*/,
      lookbehind: !0
    },
    "function-name": [
      // a) function foo {
      // b) foo() {
      // c) function foo() {
      // but not “foo {”
      {
        // a) and c)
        pattern: /(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/,
        lookbehind: !0,
        alias: "function"
      },
      {
        // b)
        pattern: /\b[\w-]+(?=\s*\(\s*\)\s*\{)/,
        alias: "function"
      }
    ],
    // Highlight variable names as variables in for and select beginnings.
    "for-or-select": {
      pattern: /(\b(?:for|select)\s+)\w+(?=\s+in\s)/,
      alias: "variable",
      lookbehind: !0
    },
    // Highlight variable names as variables in the left-hand part
    // of assignments (“=” and “+=”).
    "assign-left": {
      pattern: /(^|[\s;|&]|[<>]\()\w+(?:\.\w+)*(?=\+?=)/,
      inside: {
        environment: {
          pattern: RegExp("(^|[\\s;|&]|[<>]\\()" + t),
          lookbehind: !0,
          alias: "constant"
        }
      },
      alias: "variable",
      lookbehind: !0
    },
    // Highlight parameter names as variables
    parameter: {
      pattern: /(^|\s)-{1,2}(?:\w+:[+-]?)?\w+(?:\.\w+)*(?=[=\s]|$)/,
      alias: "variable",
      lookbehind: !0
    },
    string: [
      // Support for Here-documents https://en.wikipedia.org/wiki/Here_document
      {
        pattern: /((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/,
        lookbehind: !0,
        greedy: !0,
        inside: n
      },
      // Here-document with quotes around the tag
      // → No expansion (so no “inside”).
      {
        pattern: /((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/,
        lookbehind: !0,
        greedy: !0,
        inside: {
          bash: r
        }
      },
      // “Normal” string
      {
        // https://www.gnu.org/software/bash/manual/html_node/Double-Quotes.html
        pattern: /(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/,
        lookbehind: !0,
        greedy: !0,
        inside: n
      },
      {
        // https://www.gnu.org/software/bash/manual/html_node/Single-Quotes.html
        pattern: /(^|[^$\\])'[^']*'/,
        lookbehind: !0,
        greedy: !0
      },
      {
        // https://www.gnu.org/software/bash/manual/html_node/ANSI_002dC-Quoting.html
        pattern: /\$'(?:[^'\\]|\\[\s\S])*'/,
        greedy: !0,
        inside: {
          entity: n.entity
        }
      }
    ],
    environment: {
      pattern: RegExp("\\$?" + t),
      alias: "constant"
    },
    variable: n.variable,
    function: {
      pattern: /(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cargo|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|java|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|sysctl|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/,
      lookbehind: !0
    },
    keyword: {
      pattern: /(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/,
      lookbehind: !0
    },
    // https://www.gnu.org/software/bash/manual/html_node/Shell-Builtin-Commands.html
    builtin: {
      pattern: /(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/,
      lookbehind: !0,
      // Alias added to make those easier to distinguish from strings.
      alias: "class-name"
    },
    boolean: {
      pattern: /(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/,
      lookbehind: !0
    },
    "file-descriptor": {
      pattern: /\B&\d\b/,
      alias: "important"
    },
    operator: {
      // Lots of redirections here, but not just that.
      pattern: /\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/,
      inside: {
        "file-descriptor": {
          pattern: /^\d/,
          alias: "important"
        }
      }
    },
    punctuation: /\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/,
    number: {
      pattern: /(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/,
      lookbehind: !0
    }
  }, r.inside = a.languages.bash;
  for (var s = [
    "comment",
    "function-name",
    "for-or-select",
    "assign-left",
    "parameter",
    "string",
    "environment",
    "function",
    "keyword",
    "builtin",
    "boolean",
    "file-descriptor",
    "operator",
    "punctuation",
    "number"
  ], i = n.variable[1].inside, o = 0; o < s.length; o++)
    i[s[o]] = a.languages.bash[s[o]];
  a.languages.sh = a.languages.bash, a.languages.shell = a.languages.bash;
})(Prism);
Prism.languages.c = Prism.languages.extend("clike", {
  comment: {
    pattern: /\/\/(?:[^\r\n\\]|\\(?:\r\n?|\n|(?![\r\n])))*|\/\*[\s\S]*?(?:\*\/|$)/,
    greedy: !0
  },
  string: {
    // https://en.cppreference.com/w/c/language/string_literal
    pattern: /"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,
    greedy: !0
  },
  "class-name": {
    pattern: /(\b(?:enum|struct)\s+(?:__attribute__\s*\(\([\s\S]*?\)\)\s*)?)\w+|\b[a-z]\w*_t\b/,
    lookbehind: !0
  },
  keyword: /\b(?:_Alignas|_Alignof|_Atomic|_Bool|_Complex|_Generic|_Imaginary|_Noreturn|_Static_assert|_Thread_local|__attribute__|asm|auto|break|case|char|const|continue|default|do|double|else|enum|extern|float|for|goto|if|inline|int|long|register|return|short|signed|sizeof|static|struct|switch|typedef|typeof|union|unsigned|void|volatile|while)\b/,
  function: /\b[a-z_]\w*(?=\s*\()/i,
  number: /(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ful]{0,4}/i,
  operator: />>=?|<<=?|->|([-+&|:])\1|[?:~]|[-+*/%&|^!=<>]=?/
});
Prism.languages.insertBefore("c", "string", {
  char: {
    // https://en.cppreference.com/w/c/language/character_constant
    pattern: /'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n]){0,32}'/,
    greedy: !0
  }
});
Prism.languages.insertBefore("c", "string", {
  macro: {
    // allow for multiline macro definitions
    // spaces after the # character compile fine with gcc
    pattern: /(^[\t ]*)#\s*[a-z](?:[^\r\n\\/]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|\\(?:\r\n|[\s\S]))*/im,
    lookbehind: !0,
    greedy: !0,
    alias: "property",
    inside: {
      string: [
        {
          // highlight the path of the include statement as a string
          pattern: /^(#\s*include\s*)<[^>]+>/,
          lookbehind: !0
        },
        Prism.languages.c.string
      ],
      char: Prism.languages.c.char,
      comment: Prism.languages.c.comment,
      "macro-name": [
        {
          pattern: /(^#\s*define\s+)\w+\b(?!\()/i,
          lookbehind: !0
        },
        {
          pattern: /(^#\s*define\s+)\w+\b(?=\()/i,
          lookbehind: !0,
          alias: "function"
        }
      ],
      // highlight macro directives as keywords
      directive: {
        pattern: /^(#\s*)[a-z]+/,
        lookbehind: !0,
        alias: "keyword"
      },
      "directive-hash": /^#/,
      punctuation: /##|\\(?=[\r\n])/,
      expression: {
        pattern: /\S[\s\S]*/,
        inside: Prism.languages.c
      }
    }
  }
});
Prism.languages.insertBefore("c", "function", {
  // highlight predefined macros as constants
  constant: /\b(?:EOF|NULL|SEEK_CUR|SEEK_END|SEEK_SET|__DATE__|__FILE__|__LINE__|__TIMESTAMP__|__TIME__|__func__|stderr|stdin|stdout)\b/
});
delete Prism.languages.c.boolean;
var hr = {}, gr;
function ki() {
  return gr || (gr = 1, (function(a) {
    var t = /\b(?:alignas|alignof|asm|auto|bool|break|case|catch|char|char16_t|char32_t|char8_t|class|co_await|co_return|co_yield|compl|concept|const|const_cast|consteval|constexpr|constinit|continue|decltype|default|delete|do|double|dynamic_cast|else|enum|explicit|export|extern|final|float|for|friend|goto|if|import|inline|int|int16_t|int32_t|int64_t|int8_t|long|module|mutable|namespace|new|noexcept|nullptr|operator|override|private|protected|public|register|reinterpret_cast|requires|return|short|signed|sizeof|static|static_assert|static_cast|struct|switch|template|this|thread_local|throw|try|typedef|typeid|typename|uint16_t|uint32_t|uint64_t|uint8_t|union|unsigned|using|virtual|void|volatile|wchar_t|while)\b/, r = /\b(?!<keyword>)\w+(?:\s*\.\s*\w+)*\b/.source.replace(/<keyword>/g, function() {
      return t.source;
    });
    a.languages.cpp = a.languages.extend("c", {
      "class-name": [
        {
          pattern: RegExp(/(\b(?:class|concept|enum|struct|typename)\s+)(?!<keyword>)\w+/.source.replace(/<keyword>/g, function() {
            return t.source;
          })),
          lookbehind: !0
        },
        // This is intended to capture the class name of method implementations like:
        //   void foo::bar() const {}
        // However! The `foo` in the above example could also be a namespace, so we only capture the class name if
        // it starts with an uppercase letter. This approximation should give decent results.
        /\b[A-Z]\w*(?=\s*::\s*\w+\s*\()/,
        // This will capture the class name before destructors like:
        //   Foo::~Foo() {}
        /\b[A-Z_]\w*(?=\s*::\s*~\w+\s*\()/i,
        // This also intends to capture the class name of method implementations but here the class has template
        // parameters, so it can't be a namespace (until C++ adds generic namespaces).
        /\b\w+(?=\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>\s*::\s*\w+\s*\()/
      ],
      keyword: t,
      number: {
        pattern: /(?:\b0b[01']+|\b0x(?:[\da-f']+(?:\.[\da-f']*)?|\.[\da-f']+)(?:p[+-]?[\d']+)?|(?:\b[\d']+(?:\.[\d']*)?|\B\.[\d']+)(?:e[+-]?[\d']+)?)[ful]{0,4}/i,
        greedy: !0
      },
      operator: />>=?|<<=?|->|--|\+\+|&&|\|\||[?:~]|<=>|[-+*/%&|^!=<>]=?|\b(?:and|and_eq|bitand|bitor|not|not_eq|or|or_eq|xor|xor_eq)\b/,
      boolean: /\b(?:false|true)\b/
    }), a.languages.insertBefore("cpp", "string", {
      module: {
        // https://en.cppreference.com/w/cpp/language/modules
        pattern: RegExp(
          /(\b(?:import|module)\s+)/.source + "(?:" + // header-name
          /"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|<[^<>\r\n]*>/.source + "|" + // module name or partition or both
          /<mod-name>(?:\s*:\s*<mod-name>)?|:\s*<mod-name>/.source.replace(/<mod-name>/g, function() {
            return r;
          }) + ")"
        ),
        lookbehind: !0,
        greedy: !0,
        inside: {
          string: /^[<"][\s\S]+/,
          operator: /:/,
          punctuation: /\./
        }
      },
      "raw-string": {
        pattern: /R"([^()\\ ]{0,16})\([\s\S]*?\)\1"/,
        alias: "string",
        greedy: !0
      }
    }), a.languages.insertBefore("cpp", "keyword", {
      "generic-function": {
        pattern: /\b(?!operator\b)[a-z_]\w*\s*<(?:[^<>]|<[^<>]*>)*>(?=\s*\()/i,
        inside: {
          function: /^\w+/,
          generic: {
            pattern: /<[\s\S]+/,
            alias: "class-name",
            inside: a.languages.cpp
          }
        }
      }
    }), a.languages.insertBefore("cpp", "operator", {
      "double-colon": {
        pattern: /::/,
        alias: "punctuation"
      }
    }), a.languages.insertBefore("cpp", "class-name", {
      // the base clause is an optional list of parent classes
      // https://en.cppreference.com/w/cpp/language/class
      "base-clause": {
        pattern: /(\b(?:class|struct)\s+\w+\s*:\s*)[^;{}"'\s]+(?:\s+[^;{}"'\s]+)*(?=\s*[;{])/,
        lookbehind: !0,
        greedy: !0,
        inside: a.languages.extend("cpp", {})
      }
    }), a.languages.insertBefore("inside", "double-colon", {
      // All untokenized words that are not namespaces should be class names
      "class-name": /\b[a-z_]\w*\b(?!\s*::)/i
    }, a.languages.cpp["base-clause"]);
  })(Prism)), hr;
}
ki();
Prism.languages.json = {
  property: {
    pattern: /(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?=\s*:)/,
    lookbehind: !0,
    greedy: !0
  },
  string: {
    pattern: /(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?!\s*:)/,
    lookbehind: !0,
    greedy: !0
  },
  comment: {
    pattern: /\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,
    greedy: !0
  },
  number: /-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,
  punctuation: /[{}[\],]/,
  operator: /:/,
  boolean: /\b(?:false|true)\b/,
  null: {
    pattern: /\bnull\b/,
    alias: "keyword"
  }
};
Prism.languages.webmanifest = Prism.languages.json;
Prism.languages.sql = {
  comment: {
    pattern: /(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/|#).*)/,
    lookbehind: !0
  },
  variable: [
    {
      pattern: /@(["'`])(?:\\[\s\S]|(?!\1)[^\\])+\1/,
      greedy: !0
    },
    /@[\w.$]+/
  ],
  string: {
    pattern: /(^|[^@\\])("|')(?:\\[\s\S]|(?!\2)[^\\]|\2\2)*\2/,
    greedy: !0,
    lookbehind: !0
  },
  identifier: {
    pattern: /(^|[^@\\])`(?:\\[\s\S]|[^`\\]|``)*`/,
    greedy: !0,
    lookbehind: !0,
    inside: {
      punctuation: /^`|`$/
    }
  },
  function: /\b(?:AVG|COUNT|FIRST|FORMAT|LAST|LCASE|LEN|MAX|MID|MIN|MOD|NOW|ROUND|SUM|UCASE)(?=\s*\()/i,
  // Should we highlight user defined functions too?
  keyword: /\b(?:ACTION|ADD|AFTER|ALGORITHM|ALL|ALTER|ANALYZE|ANY|APPLY|AS|ASC|AUTHORIZATION|AUTO_INCREMENT|BACKUP|BDB|BEGIN|BERKELEYDB|BIGINT|BINARY|BIT|BLOB|BOOL|BOOLEAN|BREAK|BROWSE|BTREE|BULK|BY|CALL|CASCADED?|CASE|CHAIN|CHAR(?:ACTER|SET)?|CHECK(?:POINT)?|CLOSE|CLUSTERED|COALESCE|COLLATE|COLUMNS?|COMMENT|COMMIT(?:TED)?|COMPUTE|CONNECT|CONSISTENT|CONSTRAINT|CONTAINS(?:TABLE)?|CONTINUE|CONVERT|CREATE|CROSS|CURRENT(?:_DATE|_TIME|_TIMESTAMP|_USER)?|CURSOR|CYCLE|DATA(?:BASES?)?|DATE(?:TIME)?|DAY|DBCC|DEALLOCATE|DEC|DECIMAL|DECLARE|DEFAULT|DEFINER|DELAYED|DELETE|DELIMITERS?|DENY|DESC|DESCRIBE|DETERMINISTIC|DISABLE|DISCARD|DISK|DISTINCT|DISTINCTROW|DISTRIBUTED|DO|DOUBLE|DROP|DUMMY|DUMP(?:FILE)?|DUPLICATE|ELSE(?:IF)?|ENABLE|ENCLOSED|END|ENGINE|ENUM|ERRLVL|ERRORS|ESCAPED?|EXCEPT|EXEC(?:UTE)?|EXISTS|EXIT|EXPLAIN|EXTENDED|FETCH|FIELDS|FILE|FILLFACTOR|FIRST|FIXED|FLOAT|FOLLOWING|FOR(?: EACH ROW)?|FORCE|FOREIGN|FREETEXT(?:TABLE)?|FROM|FULL|FUNCTION|GEOMETRY(?:COLLECTION)?|GLOBAL|GOTO|GRANT|GROUP|HANDLER|HASH|HAVING|HOLDLOCK|HOUR|IDENTITY(?:COL|_INSERT)?|IF|IGNORE|IMPORT|INDEX|INFILE|INNER|INNODB|INOUT|INSERT|INT|INTEGER|INTERSECT|INTERVAL|INTO|INVOKER|ISOLATION|ITERATE|JOIN|KEYS?|KILL|LANGUAGE|LAST|LEAVE|LEFT|LEVEL|LIMIT|LINENO|LINES|LINESTRING|LOAD|LOCAL|LOCK|LONG(?:BLOB|TEXT)|LOOP|MATCH(?:ED)?|MEDIUM(?:BLOB|INT|TEXT)|MERGE|MIDDLEINT|MINUTE|MODE|MODIFIES|MODIFY|MONTH|MULTI(?:LINESTRING|POINT|POLYGON)|NATIONAL|NATURAL|NCHAR|NEXT|NO|NONCLUSTERED|NULLIF|NUMERIC|OFF?|OFFSETS?|ON|OPEN(?:DATASOURCE|QUERY|ROWSET)?|OPTIMIZE|OPTION(?:ALLY)?|ORDER|OUT(?:ER|FILE)?|OVER|PARTIAL|PARTITION|PERCENT|PIVOT|PLAN|POINT|POLYGON|PRECEDING|PRECISION|PREPARE|PREV|PRIMARY|PRINT|PRIVILEGES|PROC(?:EDURE)?|PUBLIC|PURGE|QUICK|RAISERROR|READS?|REAL|RECONFIGURE|REFERENCES|RELEASE|RENAME|REPEAT(?:ABLE)?|REPLACE|REPLICATION|REQUIRE|RESIGNAL|RESTORE|RESTRICT|RETURN(?:ING|S)?|REVOKE|RIGHT|ROLLBACK|ROUTINE|ROW(?:COUNT|GUIDCOL|S)?|RTREE|RULE|SAVE(?:POINT)?|SCHEMA|SECOND|SELECT|SERIAL(?:IZABLE)?|SESSION(?:_USER)?|SET(?:USER)?|SHARE|SHOW|SHUTDOWN|SIMPLE|SMALLINT|SNAPSHOT|SOME|SONAME|SQL|START(?:ING)?|STATISTICS|STATUS|STRIPED|SYSTEM_USER|TABLES?|TABLESPACE|TEMP(?:ORARY|TABLE)?|TERMINATED|TEXT(?:SIZE)?|THEN|TIME(?:STAMP)?|TINY(?:BLOB|INT|TEXT)|TOP?|TRAN(?:SACTIONS?)?|TRIGGER|TRUNCATE|TSEQUAL|TYPES?|UNBOUNDED|UNCOMMITTED|UNDEFINED|UNION|UNIQUE|UNLOCK|UNPIVOT|UNSIGNED|UPDATE(?:TEXT)?|USAGE|USE|USER|USING|VALUES?|VAR(?:BINARY|CHAR|CHARACTER|YING)|VIEW|WAITFOR|WARNINGS|WHEN|WHERE|WHILE|WITH(?: ROLLUP|IN)?|WORK|WRITE(?:TEXT)?|YEAR)\b/i,
  boolean: /\b(?:FALSE|NULL|TRUE)\b/i,
  number: /\b0x[\da-f]+\b|\b\d+(?:\.\d*)?|\B\.\d+\b/i,
  operator: /[-+*\/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?|\b(?:AND|BETWEEN|DIV|ILIKE|IN|IS|LIKE|NOT|OR|REGEXP|RLIKE|SOUNDS LIKE|XOR)\b/i,
  punctuation: /[;[\]()`,.]/
};
var fr = {}, pr;
function yi() {
  return pr || (pr = 1, (function(a) {
    var t = /\b(?:abstract|assert|boolean|break|byte|case|catch|char|class|const|continue|default|do|double|else|enum|exports|extends|final|finally|float|for|goto|if|implements|import|instanceof|int|interface|long|module|native|new|non-sealed|null|open|opens|package|permits|private|protected|provides|public|record(?!\s*[(){}[\]<>=%~.:,;?+\-*/&|^])|requires|return|sealed|short|static|strictfp|super|switch|synchronized|this|throw|throws|to|transient|transitive|try|uses|var|void|volatile|while|with|yield)\b/, r = /(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source, n = {
      pattern: RegExp(/(^|[^\w.])/.source + r + /[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source),
      lookbehind: !0,
      inside: {
        namespace: {
          pattern: /^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,
          inside: {
            punctuation: /\./
          }
        },
        punctuation: /\./
      }
    };
    a.languages.java = a.languages.extend("clike", {
      string: {
        pattern: /(^|[^\\])"(?:\\.|[^"\\\r\n])*"/,
        lookbehind: !0,
        greedy: !0
      },
      "class-name": [
        n,
        {
          // variables, parameters, and constructor references
          // this to support class names (or generic parameters) which do not contain a lower case letter (also works for methods)
          pattern: RegExp(/(^|[^\w.])/.source + r + /[A-Z]\w*(?=\s+\w+\s*[;,=()]|\s*(?:\[[\s,]*\]\s*)?::\s*new\b)/.source),
          lookbehind: !0,
          inside: n.inside
        },
        {
          // class names based on keyword
          // this to support class names (or generic parameters) which do not contain a lower case letter (also works for methods)
          pattern: RegExp(/(\b(?:class|enum|extends|implements|instanceof|interface|new|record|throws)\s+)/.source + r + /[A-Z]\w*\b/.source),
          lookbehind: !0,
          inside: n.inside
        }
      ],
      keyword: t,
      function: [
        a.languages.clike.function,
        {
          pattern: /(::\s*)[a-z_]\w*/,
          lookbehind: !0
        }
      ],
      number: /\b0b[01][01_]*L?\b|\b0x(?:\.[\da-f_p+-]+|[\da-f_]+(?:\.[\da-f_p+-]+)?)\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfl]?/i,
      operator: {
        pattern: /(^|[^.])(?:<<=?|>>>?=?|->|--|\+\+|&&|\|\||::|[?:~]|[-+*/%&|^!=<>]=?)/m,
        lookbehind: !0
      },
      constant: /\b[A-Z][A-Z_\d]+\b/
    }), a.languages.insertBefore("java", "string", {
      "triple-quoted-string": {
        // http://openjdk.java.net/jeps/355#Description
        pattern: /"""[ \t]*[\r\n](?:(?:"|"")?(?:\\.|[^"\\]))*"""/,
        greedy: !0,
        alias: "string"
      },
      char: {
        pattern: /'(?:\\.|[^'\\\r\n]){1,6}'/,
        greedy: !0
      }
    }), a.languages.insertBefore("java", "class-name", {
      annotation: {
        pattern: /(^|[^.])@\w+(?:\s*\.\s*\w+)*/,
        lookbehind: !0,
        alias: "punctuation"
      },
      generics: {
        pattern: /<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&))*>)*>)*>)*>/,
        inside: {
          "class-name": n,
          keyword: t,
          punctuation: /[<>(),.:]/,
          operator: /[?&|]/
        }
      },
      import: [
        {
          pattern: RegExp(/(\bimport\s+)/.source + r + /(?:[A-Z]\w*|\*)(?=\s*;)/.source),
          lookbehind: !0,
          inside: {
            namespace: n.inside.namespace,
            punctuation: /\./,
            operator: /\*/,
            "class-name": /\w+/
          }
        },
        {
          pattern: RegExp(/(\bimport\s+static\s+)/.source + r + /(?:\w+|\*)(?=\s*;)/.source),
          lookbehind: !0,
          alias: "static",
          inside: {
            namespace: n.inside.namespace,
            static: /\b\w+$/,
            punctuation: /\./,
            operator: /\*/,
            "class-name": /\w+/
          }
        }
      ],
      namespace: {
        pattern: RegExp(
          /(\b(?:exports|import(?:\s+static)?|module|open|opens|package|provides|requires|to|transitive|uses|with)\s+)(?!<keyword>)[a-z]\w*(?:\.[a-z]\w*)*\.?/.source.replace(/<keyword>/g, function() {
            return t.source;
          })
        ),
        lookbehind: !0,
        inside: {
          punctuation: /\./
        }
      }
    });
  })(Prism)), fr;
}
yi();
Prism.languages.go = Prism.languages.extend("clike", {
  string: {
    pattern: /(^|[^\\])"(?:\\.|[^"\\\r\n])*"|`[^`]*`/,
    lookbehind: !0,
    greedy: !0
  },
  keyword: /\b(?:break|case|chan|const|continue|default|defer|else|fallthrough|for|func|go(?:to)?|if|import|interface|map|package|range|return|select|struct|switch|type|var)\b/,
  boolean: /\b(?:_|false|iota|nil|true)\b/,
  number: [
    // binary and octal integers
    /\b0(?:b[01_]+|o[0-7_]+)i?\b/i,
    // hexadecimal integers and floats
    /\b0x(?:[a-f\d_]+(?:\.[a-f\d_]*)?|\.[a-f\d_]+)(?:p[+-]?\d+(?:_\d+)*)?i?(?!\w)/i,
    // decimal integers and floats
    /(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?[\d_]+)?i?(?!\w)/i
  ],
  operator: /[*\/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\./,
  builtin: /\b(?:append|bool|byte|cap|close|complex|complex(?:64|128)|copy|delete|error|float(?:32|64)|u?int(?:8|16|32|64)?|imag|len|make|new|panic|print(?:ln)?|real|recover|rune|string|uintptr)\b/
});
Prism.languages.insertBefore("go", "string", {
  char: {
    pattern: /'(?:\\.|[^'\\\r\n]){0,10}'/,
    greedy: !0
  }
});
delete Prism.languages.go["class-name"];
var vr = {}, mr;
function Ci() {
  return mr || (mr = 1, (function(a) {
    for (var t = /\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|<self>)*\*\//.source, r = 0; r < 2; r++)
      t = t.replace(/<self>/g, function() {
        return t;
      });
    t = t.replace(/<self>/g, function() {
      return /[^\s\S]/.source;
    }), a.languages.rust = {
      comment: [
        {
          pattern: RegExp(/(^|[^\\])/.source + t),
          lookbehind: !0,
          greedy: !0
        },
        {
          pattern: /(^|[^\\:])\/\/.*/,
          lookbehind: !0,
          greedy: !0
        }
      ],
      string: {
        pattern: /b?"(?:\\[\s\S]|[^\\"])*"|b?r(#*)"(?:[^"]|"(?!\1))*"\1/,
        greedy: !0
      },
      char: {
        pattern: /b?'(?:\\(?:x[0-7][\da-fA-F]|u\{(?:[\da-fA-F]_*){1,6}\}|.)|[^\\\r\n\t'])'/,
        greedy: !0
      },
      attribute: {
        pattern: /#!?\[(?:[^\[\]"]|"(?:\\[\s\S]|[^\\"])*")*\]/,
        greedy: !0,
        alias: "attr-name",
        inside: {
          string: null
          // see below
        }
      },
      // Closure params should not be confused with bitwise OR |
      "closure-params": {
        pattern: /([=(,:]\s*|\bmove\s*)\|[^|]*\||\|[^|]*\|(?=\s*(?:\{|->))/,
        lookbehind: !0,
        greedy: !0,
        inside: {
          "closure-punctuation": {
            pattern: /^\||\|$/,
            alias: "punctuation"
          },
          rest: null
          // see below
        }
      },
      "lifetime-annotation": {
        pattern: /'\w+/,
        alias: "symbol"
      },
      "fragment-specifier": {
        pattern: /(\$\w+:)[a-z]+/,
        lookbehind: !0,
        alias: "punctuation"
      },
      variable: /\$\w+/,
      "function-definition": {
        pattern: /(\bfn\s+)\w+/,
        lookbehind: !0,
        alias: "function"
      },
      "type-definition": {
        pattern: /(\b(?:enum|struct|trait|type|union)\s+)\w+/,
        lookbehind: !0,
        alias: "class-name"
      },
      "module-declaration": [
        {
          pattern: /(\b(?:crate|mod)\s+)[a-z][a-z_\d]*/,
          lookbehind: !0,
          alias: "namespace"
        },
        {
          pattern: /(\b(?:crate|self|super)\s*)::\s*[a-z][a-z_\d]*\b(?:\s*::(?:\s*[a-z][a-z_\d]*\s*::)*)?/,
          lookbehind: !0,
          alias: "namespace",
          inside: {
            punctuation: /::/
          }
        }
      ],
      keyword: [
        // https://github.com/rust-lang/reference/blob/master/src/keywords.md
        /\b(?:Self|abstract|as|async|await|become|box|break|const|continue|crate|do|dyn|else|enum|extern|final|fn|for|if|impl|in|let|loop|macro|match|mod|move|mut|override|priv|pub|ref|return|self|static|struct|super|trait|try|type|typeof|union|unsafe|unsized|use|virtual|where|while|yield)\b/,
        // primitives and str
        // https://doc.rust-lang.org/stable/rust-by-example/primitives.html
        /\b(?:bool|char|f(?:32|64)|[ui](?:8|16|32|64|128|size)|str)\b/
      ],
      // functions can technically start with an upper-case letter, but this will introduce a lot of false positives
      // and Rust's naming conventions recommend snake_case anyway.
      // https://doc.rust-lang.org/1.0.0/style/style/naming/README.html
      function: /\b[a-z_]\w*(?=\s*(?:::\s*<|\())/,
      macro: {
        pattern: /\b\w+!/,
        alias: "property"
      },
      constant: /\b[A-Z_][A-Z_\d]+\b/,
      "class-name": /\b[A-Z]\w*\b/,
      namespace: {
        pattern: /(?:\b[a-z][a-z_\d]*\s*::\s*)*\b[a-z][a-z_\d]*\s*::(?!\s*<)/,
        inside: {
          punctuation: /::/
        }
      },
      // Hex, oct, bin, dec numbers with visual separators and type suffix
      number: /\b(?:0x[\dA-Fa-f](?:_?[\dA-Fa-f])*|0o[0-7](?:_?[0-7])*|0b[01](?:_?[01])*|(?:(?:\d(?:_?\d)*)?\.)?\d(?:_?\d)*(?:[Ee][+-]?\d+)?)(?:_?(?:f32|f64|[iu](?:8|16|32|64|size)?))?\b/,
      boolean: /\b(?:false|true)\b/,
      punctuation: /->|\.\.=|\.{1,3}|::|[{}[\];(),:]/,
      operator: /[-+*\/%!^]=?|=[=>]?|&[&=]?|\|[|=]?|<<?=?|>>?=?|[@?]/
    }, a.languages.rust["closure-params"].inside.rest = a.languages.rust, a.languages.rust.attribute.inside.string = a.languages.rust.string;
  })(Prism)), vr;
}
Ci();
var wr = {}, _r;
function Di() {
  return _r || (_r = 1, (function(a) {
    var t = /\/\*[\s\S]*?\*\/|\/\/.*|#(?!\[).*/, r = [
      {
        pattern: /\b(?:false|true)\b/i,
        alias: "boolean"
      },
      {
        pattern: /(::\s*)\b[a-z_]\w*\b(?!\s*\()/i,
        greedy: !0,
        lookbehind: !0
      },
      {
        pattern: /(\b(?:case|const)\s+)\b[a-z_]\w*(?=\s*[;=])/i,
        greedy: !0,
        lookbehind: !0
      },
      /\b(?:null)\b/i,
      /\b[A-Z_][A-Z0-9_]*\b(?!\s*\()/
    ], n = /\b0b[01]+(?:_[01]+)*\b|\b0o[0-7]+(?:_[0-7]+)*\b|\b0x[\da-f]+(?:_[\da-f]+)*\b|(?:\b\d+(?:_\d+)*\.?(?:\d+(?:_\d+)*)?|\B\.\d+)(?:e[+-]?\d+)?/i, s = /<?=>|\?\?=?|\.{3}|\??->|[!=]=?=?|::|\*\*=?|--|\+\+|&&|\|\||<<|>>|[?~]|[/^|%*&<>.+-]=?/, i = /[{}\[\](),:;]/;
    a.languages.php = {
      delimiter: {
        pattern: /\?>$|^<\?(?:php(?=\s)|=)?/i,
        alias: "important"
      },
      comment: t,
      variable: /\$+(?:\w+\b|(?=\{))/,
      package: {
        pattern: /(namespace\s+|use\s+(?:function\s+)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,
        lookbehind: !0,
        inside: {
          punctuation: /\\/
        }
      },
      "class-name-definition": {
        pattern: /(\b(?:class|enum|interface|trait)\s+)\b[a-z_]\w*(?!\\)\b/i,
        lookbehind: !0,
        alias: "class-name"
      },
      "function-definition": {
        pattern: /(\bfunction\s+)[a-z_]\w*(?=\s*\()/i,
        lookbehind: !0,
        alias: "function"
      },
      keyword: [
        {
          pattern: /(\(\s*)\b(?:array|bool|boolean|float|int|integer|object|string)\b(?=\s*\))/i,
          alias: "type-casting",
          greedy: !0,
          lookbehind: !0
        },
        {
          pattern: /([(,?]\s*)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|object|self|static|string)\b(?=\s*\$)/i,
          alias: "type-hint",
          greedy: !0,
          lookbehind: !0
        },
        {
          pattern: /(\)\s*:\s*(?:\?\s*)?)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|never|object|self|static|string|void)\b/i,
          alias: "return-type",
          greedy: !0,
          lookbehind: !0
        },
        {
          pattern: /\b(?:array(?!\s*\()|bool|float|int|iterable|mixed|object|string|void)\b/i,
          alias: "type-declaration",
          greedy: !0
        },
        {
          pattern: /(\|\s*)(?:false|null)\b|\b(?:false|null)(?=\s*\|)/i,
          alias: "type-declaration",
          greedy: !0,
          lookbehind: !0
        },
        {
          pattern: /\b(?:parent|self|static)(?=\s*::)/i,
          alias: "static-context",
          greedy: !0
        },
        {
          // yield from
          pattern: /(\byield\s+)from\b/i,
          lookbehind: !0
        },
        // `class` is always a keyword unlike other keywords
        /\bclass\b/i,
        {
          // https://www.php.net/manual/en/reserved.keywords.php
          //
          // keywords cannot be preceded by "->"
          // the complex lookbehind means `(?<!(?:->|::)\s*)`
          pattern: /((?:^|[^\s>:]|(?:^|[^-])>|(?:^|[^:]):)\s*)\b(?:abstract|and|array|as|break|callable|case|catch|clone|const|continue|declare|default|die|do|echo|else|elseif|empty|enddeclare|endfor|endforeach|endif|endswitch|endwhile|enum|eval|exit|extends|final|finally|fn|for|foreach|function|global|goto|if|implements|include|include_once|instanceof|insteadof|interface|isset|list|match|namespace|never|new|or|parent|print|private|protected|public|readonly|require|require_once|return|self|static|switch|throw|trait|try|unset|use|var|while|xor|yield|__halt_compiler)\b/i,
          lookbehind: !0
        }
      ],
      "argument-name": {
        pattern: /([(,]\s*)\b[a-z_]\w*(?=\s*:(?!:))/i,
        lookbehind: !0
      },
      "class-name": [
        {
          pattern: /(\b(?:extends|implements|instanceof|new(?!\s+self|\s+static))\s+|\bcatch\s*\()\b[a-z_]\w*(?!\\)\b/i,
          greedy: !0,
          lookbehind: !0
        },
        {
          pattern: /(\|\s*)\b[a-z_]\w*(?!\\)\b/i,
          greedy: !0,
          lookbehind: !0
        },
        {
          pattern: /\b[a-z_]\w*(?!\\)\b(?=\s*\|)/i,
          greedy: !0
        },
        {
          pattern: /(\|\s*)(?:\\?\b[a-z_]\w*)+\b/i,
          alias: "class-name-fully-qualified",
          greedy: !0,
          lookbehind: !0,
          inside: {
            punctuation: /\\/
          }
        },
        {
          pattern: /(?:\\?\b[a-z_]\w*)+\b(?=\s*\|)/i,
          alias: "class-name-fully-qualified",
          greedy: !0,
          inside: {
            punctuation: /\\/
          }
        },
        {
          pattern: /(\b(?:extends|implements|instanceof|new(?!\s+self\b|\s+static\b))\s+|\bcatch\s*\()(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,
          alias: "class-name-fully-qualified",
          greedy: !0,
          lookbehind: !0,
          inside: {
            punctuation: /\\/
          }
        },
        {
          pattern: /\b[a-z_]\w*(?=\s*\$)/i,
          alias: "type-declaration",
          greedy: !0
        },
        {
          pattern: /(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,
          alias: ["class-name-fully-qualified", "type-declaration"],
          greedy: !0,
          inside: {
            punctuation: /\\/
          }
        },
        {
          pattern: /\b[a-z_]\w*(?=\s*::)/i,
          alias: "static-context",
          greedy: !0
        },
        {
          pattern: /(?:\\?\b[a-z_]\w*)+(?=\s*::)/i,
          alias: ["class-name-fully-qualified", "static-context"],
          greedy: !0,
          inside: {
            punctuation: /\\/
          }
        },
        {
          pattern: /([(,?]\s*)[a-z_]\w*(?=\s*\$)/i,
          alias: "type-hint",
          greedy: !0,
          lookbehind: !0
        },
        {
          pattern: /([(,?]\s*)(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,
          alias: ["class-name-fully-qualified", "type-hint"],
          greedy: !0,
          lookbehind: !0,
          inside: {
            punctuation: /\\/
          }
        },
        {
          pattern: /(\)\s*:\s*(?:\?\s*)?)\b[a-z_]\w*(?!\\)\b/i,
          alias: "return-type",
          greedy: !0,
          lookbehind: !0
        },
        {
          pattern: /(\)\s*:\s*(?:\?\s*)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,
          alias: ["class-name-fully-qualified", "return-type"],
          greedy: !0,
          lookbehind: !0,
          inside: {
            punctuation: /\\/
          }
        }
      ],
      constant: r,
      function: {
        pattern: /(^|[^\\\w])\\?[a-z_](?:[\w\\]*\w)?(?=\s*\()/i,
        lookbehind: !0,
        inside: {
          punctuation: /\\/
        }
      },
      property: {
        pattern: /(->\s*)\w+/,
        lookbehind: !0
      },
      number: n,
      operator: s,
      punctuation: i
    };
    var o = {
      pattern: /\{\$(?:\{(?:\{[^{}]+\}|[^{}]+)\}|[^{}])+\}|(^|[^\\{])\$+(?:\w+(?:\[[^\r\n\[\]]+\]|->\w+)?)/,
      lookbehind: !0,
      inside: a.languages.php
    }, l = [
      {
        pattern: /<<<'([^']+)'[\r\n](?:.*[\r\n])*?\1;/,
        alias: "nowdoc-string",
        greedy: !0,
        inside: {
          delimiter: {
            pattern: /^<<<'[^']+'|[a-z_]\w*;$/i,
            alias: "symbol",
            inside: {
              punctuation: /^<<<'?|[';]$/
            }
          }
        }
      },
      {
        pattern: /<<<(?:"([^"]+)"[\r\n](?:.*[\r\n])*?\1;|([a-z_]\w*)[\r\n](?:.*[\r\n])*?\2;)/i,
        alias: "heredoc-string",
        greedy: !0,
        inside: {
          delimiter: {
            pattern: /^<<<(?:"[^"]+"|[a-z_]\w*)|[a-z_]\w*;$/i,
            alias: "symbol",
            inside: {
              punctuation: /^<<<"?|[";]$/
            }
          },
          interpolation: o
        }
      },
      {
        pattern: /`(?:\\[\s\S]|[^\\`])*`/,
        alias: "backtick-quoted-string",
        greedy: !0
      },
      {
        pattern: /'(?:\\[\s\S]|[^\\'])*'/,
        alias: "single-quoted-string",
        greedy: !0
      },
      {
        pattern: /"(?:\\[\s\S]|[^\\"])*"/,
        alias: "double-quoted-string",
        greedy: !0,
        inside: {
          interpolation: o
        }
      }
    ];
    a.languages.insertBefore("php", "variable", {
      string: l,
      attribute: {
        pattern: /#\[(?:[^"'\/#]|\/(?![*/])|\/\/.*$|#(?!\[).*$|\/\*(?:[^*]|\*(?!\/))*\*\/|"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*')+\](?=\s*[a-z$#])/im,
        greedy: !0,
        inside: {
          "attribute-content": {
            pattern: /^(#\[)[\s\S]+(?=\]$)/,
            lookbehind: !0,
            // inside can appear subset of php
            inside: {
              comment: t,
              string: l,
              "attribute-class-name": [
                {
                  pattern: /([^:]|^)\b[a-z_]\w*(?!\\)\b/i,
                  alias: "class-name",
                  greedy: !0,
                  lookbehind: !0
                },
                {
                  pattern: /([^:]|^)(?:\\?\b[a-z_]\w*)+/i,
                  alias: [
                    "class-name",
                    "class-name-fully-qualified"
                  ],
                  greedy: !0,
                  lookbehind: !0,
                  inside: {
                    punctuation: /\\/
                  }
                }
              ],
              constant: r,
              number: n,
              operator: s,
              punctuation: i
            }
          },
          delimiter: {
            pattern: /^#\[|\]$/,
            alias: "punctuation"
          }
        }
      }
    }), a.hooks.add("before-tokenize", function(c) {
      if (/<\?/.test(c.code)) {
        var w = /<\?(?:[^"'/#]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|(?:\/\/|#(?!\[))(?:[^?\n\r]|\?(?!>))*(?=$|\?>|[\r\n])|#\[|\/\*(?:[^*]|\*(?!\/))*(?:\*\/|$))*?(?:\?>|$)/g;
        a.languages["markup-templating"].buildPlaceholders(c, "php", w);
      }
    }), a.hooks.add("after-tokenize", function(c) {
      a.languages["markup-templating"].tokenizePlaceholders(c, "php");
    });
  })(Prism)), wr;
}
Di();
(function(a) {
  var t = /[*&][^\s[\]{},]+/, r = /!(?:<[\w\-%#;/?:@&=+$,.!~*'()[\]]+>|(?:[a-zA-Z\d-]*!)?[\w\-%#;/?:@&=+$.~*'()]+)?/, n = "(?:" + r.source + "(?:[ 	]+" + t.source + ")?|" + t.source + "(?:[ 	]+" + r.source + ")?)", s = /(?:[^\s\x00-\x08\x0e-\x1f!"#%&'*,\-:>?@[\]`{|}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]|[?:-]<PLAIN>)(?:[ \t]*(?:(?![#:])<PLAIN>|:<PLAIN>))*/.source.replace(/<PLAIN>/g, function() {
    return /[^\s\x00-\x08\x0e-\x1f,[\]{}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]/.source;
  }), i = /"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/.source;
  function o(l, c) {
    c = (c || "").replace(/m/g, "") + "m";
    var w = /([:\-,[{]\s*(?:\s<<prop>>[ \t]+)?)(?:<<value>>)(?=[ \t]*(?:$|,|\]|\}|(?:[\r\n]\s*)?#))/.source.replace(/<<prop>>/g, function() {
      return n;
    }).replace(/<<value>>/g, function() {
      return l;
    });
    return RegExp(w, c);
  }
  a.languages.yaml = {
    scalar: {
      pattern: RegExp(/([\-:]\s*(?:\s<<prop>>[ \t]+)?[|>])[ \t]*(?:((?:\r?\n|\r)[ \t]+)\S[^\r\n]*(?:\2[^\r\n]+)*)/.source.replace(/<<prop>>/g, function() {
        return n;
      })),
      lookbehind: !0,
      alias: "string"
    },
    comment: /#.*/,
    key: {
      pattern: RegExp(/((?:^|[:\-,[{\r\n?])[ \t]*(?:<<prop>>[ \t]+)?)<<key>>(?=\s*:\s)/.source.replace(/<<prop>>/g, function() {
        return n;
      }).replace(/<<key>>/g, function() {
        return "(?:" + s + "|" + i + ")";
      })),
      lookbehind: !0,
      greedy: !0,
      alias: "atrule"
    },
    directive: {
      pattern: /(^[ \t]*)%.+/m,
      lookbehind: !0,
      alias: "important"
    },
    datetime: {
      pattern: o(/\d{4}-\d\d?-\d\d?(?:[tT]|[ \t]+)\d\d?:\d{2}:\d{2}(?:\.\d*)?(?:[ \t]*(?:Z|[-+]\d\d?(?::\d{2})?))?|\d{4}-\d{2}-\d{2}|\d\d?:\d{2}(?::\d{2}(?:\.\d*)?)?/.source),
      lookbehind: !0,
      alias: "number"
    },
    boolean: {
      pattern: o(/false|true/.source, "i"),
      lookbehind: !0,
      alias: "important"
    },
    null: {
      pattern: o(/null|~/.source, "i"),
      lookbehind: !0,
      alias: "important"
    },
    string: {
      pattern: o(i),
      lookbehind: !0,
      greedy: !0
    },
    number: {
      pattern: o(/[+-]?(?:0x[\da-f]+|0o[0-7]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|\.inf|\.nan)/.source, "i"),
      lookbehind: !0
    },
    tag: r,
    important: t,
    punctuation: /---|[:[\]{}\-,|>?]|\.\.\./
  }, a.languages.yml = a.languages.yaml;
})(Prism);
(function(a) {
  function t(r, n) {
    return "___" + r.toUpperCase() + n + "___";
  }
  Object.defineProperties(a.languages["markup-templating"] = {}, {
    buildPlaceholders: {
      /**
       * Tokenize all inline templating expressions matching `placeholderPattern`.
       *
       * If `replaceFilter` is provided, only matches of `placeholderPattern` for which `replaceFilter` returns
       * `true` will be replaced.
       *
       * @param {object} env The environment of the `before-tokenize` hook.
       * @param {string} language The language id.
       * @param {RegExp} placeholderPattern The matches of this pattern will be replaced by placeholders.
       * @param {(match: string) => boolean} [replaceFilter]
       */
      value: function(r, n, s, i) {
        if (r.language === n) {
          var o = r.tokenStack = [];
          r.code = r.code.replace(s, function(l) {
            if (typeof i == "function" && !i(l))
              return l;
            for (var c = o.length, w; r.code.indexOf(w = t(n, c)) !== -1; )
              ++c;
            return o[c] = l, w;
          }), r.grammar = a.languages.markup;
        }
      }
    },
    tokenizePlaceholders: {
      /**
       * Replace placeholders with proper tokens after tokenizing.
       *
       * @param {object} env The environment of the `after-tokenize` hook.
       * @param {string} language The language id.
       */
      value: function(r, n) {
        if (r.language !== n || !r.tokenStack)
          return;
        r.grammar = a.languages[n];
        var s = 0, i = Object.keys(r.tokenStack);
        function o(l) {
          for (var c = 0; c < l.length && !(s >= i.length); c++) {
            var w = l[c];
            if (typeof w == "string" || w.content && typeof w.content == "string") {
              var h = i[s], _ = r.tokenStack[h], b = typeof w == "string" ? w : w.content, D = t(n, h), T = b.indexOf(D);
              if (T > -1) {
                ++s;
                var E = b.substring(0, T), k = new a.Token(n, a.tokenize(_, r.grammar), "language-" + n, _), y = b.substring(T + D.length), d = [];
                E && d.push.apply(d, o([E])), d.push(k), y && d.push.apply(d, o([y])), typeof w == "string" ? l.splice.apply(l, [c, 1].concat(d)) : w.content = d;
              }
            } else w.content && o(w.content);
          }
          return l;
        }
        o(r.tokens);
      }
    }
  });
})(Prism);
const Ei = '<svg class="md-link-icon" viewBox="0 0 16 16" version="1.1" width="16" height="16" aria-hidden="true" fill="currentColor"><path d="m7.775 3.275 1.25-1.25a3.5 3.5 0 1 1 4.95 4.95l-2.5 2.5a3.5 3.5 0 0 1-4.95 0 .751.751 0 0 1 .018-1.042.751.751 0 0 1 1.042-.018 1.998 1.998 0 0 0 2.83 0l2.5-2.5a2.002 2.002 0 0 0-2.83-2.83l-1.25 1.25a.751.751 0 0 1-1.042-.018.751.751 0 0 1-.018-1.042Zm-4.69 9.64a1.998 1.998 0 0 0 2.83 0l1.25-1.25a.751.751 0 0 1 1.042.018.751.751 0 0 1 .018 1.042l-1.25 1.25a3.5 3.5 0 1 1-4.95-4.95l2.5-2.5a3.5 3.5 0 0 1 4.95 0 .751.751 0 0 1-.018 1.042.751.751 0 0 1-1.042.018 1.998 1.998 0 0 0-2.83 0l-2.5 2.5a1.998 1.998 0 0 0 0 2.83Z"></path></svg>', Fi = `
<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 15 15" color="currentColor" aria-hidden="true" aria-label="Copy" stroke-width="1.3" width="15" height="15">
  <path fill="currentColor" d="M12.728 4.545v8.182H4.545V4.545zm0 -0.909H4.545a0.909 0.909 0 0 0 -0.909 0.909v8.182a0.909 0.909 0 0 0 0.909 0.909h8.182a0.909 0.909 0 0 0 0.909 -0.909V4.545a0.909 0.909 0 0 0 -0.909 -0.909"/>
  <path fill="currentColor" d="M1.818 8.182H0.909V1.818a0.909 0.909 0 0 1 0.909 -0.909h6.364v0.909H1.818Z"/>
</svg>

`, Ai = `<svg xmlns="http://www.w3.org/2000/svg" width="17" height="17" viewBox="0 0 17 17" aria-hidden="true" aria-label="Copied" fill="none" stroke="currentColor" stroke-width="1.3">
  <path d="m13.813 4.781 -7.438 7.438 -3.188 -3.188"/>
</svg>
`, br = `<button title="copy" class="copy_code_button">
  <span class="copy-text">${Fi}</span>
  <span class="check">${Ai}</span>
</button>`, Kr = /[&<>"']/, Li = new RegExp(Kr.source, "g"), Qr = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/, Mi = new RegExp(Qr.source, "g"), Bi = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#39;"
}, xr = (a) => Bi[a] || "";
function Bt(a, t) {
  if (t) {
    if (Kr.test(a))
      return a.replace(Li, xr);
  } else if (Qr.test(a))
    return a.replace(Mi, xr);
  return a;
}
function Si(a) {
  const t = a.map((r) => ({
    start: new RegExp(r.left.replace(/[-\/\\^$*+?.()|[\]{}]/g, "\\$&")),
    end: new RegExp(r.right.replace(/[-\/\\^$*+?.()|[\]{}]/g, "\\$&"))
  }));
  return {
    name: "latex",
    level: "block",
    start(r) {
      for (const n of t) {
        const s = r.match(n.start);
        if (s)
          return s.index;
      }
      return -1;
    },
    tokenizer(r, n) {
      for (const s of t) {
        const i = new RegExp(`${s.start.source}([\\s\\S]+?)${s.end.source}`).exec(r);
        if (i)
          return {
            type: "latex",
            raw: i[0],
            text: i[1].trim()
          };
      }
    },
    renderer(r) {
      return `<div class="latex-block">${r.text}</div>`;
    }
  };
}
function Ti() {
  return {
    name: "mermaid",
    level: "block",
    start(a) {
      return a.match(/^```mermaid\s*\n/)?.index;
    },
    tokenizer(a) {
      const t = /^```mermaid\s*\n([\s\S]*?)```\s*(?:\n|$)/.exec(a);
      if (t)
        return {
          type: "mermaid",
          raw: t[0],
          text: t[1].trim()
        };
    },
    renderer(a) {
      return `<div class="mermaid">${a.text}</div>
`;
    }
  };
}
const zi = {
  code(a, t, r) {
    const n = (t ?? "").match(/\S*/)?.[0] ?? "";
    return a = a.replace(/\n$/, "") + `
`, !n || n === "mermaid" ? '<div class="code_wrap">' + br + "<pre><code>" + (r ? a : Bt(a, !0)) + `</code></pre></div>
` : '<div class="code_wrap">' + br + '<pre><code class="language-' + Bt(n) + '">' + (r ? a : Bt(a, !0)) + `</code></pre></div>
`;
  }
}, Ri = new Kt();
function Ii({ header_links: a, line_breaks: t, latex_delimiters: r }) {
  const n = new Ur();
  n.use({
    gfm: !0,
    pedantic: !1,
    breaks: t
  }, di({
    highlight: (o, l) => Mt.languages?.[l] ? Mt.highlight(o, Mt.languages[l], l) : o
  }), { renderer: zi }), a && (n.use(wi()), n.use({
    extensions: [
      {
        name: "heading",
        level: "block",
        renderer(o) {
          const l = o.raw.toLowerCase().trim().replace(/<[!\/a-z].*?>/gi, ""), c = "h" + Ri.slug(l), w = o.depth, h = this.parser.parseInline(o.tokens);
          return `<h${w} id="${c}"><a class="md-header-anchor" href="#${c}">${Ei}</a>${h}</h${w}>
`;
        }
      }
    ]
  }));
  const s = Ti(), i = Si(r);
  return n.use({
    extensions: [s, i]
  }), n;
}
const Nt = (a) => JSON.parse(JSON.stringify(a)), Hi = (a) => a.nodeType === 1, Oi = (a) => aa.has(a.tagName), Zi = (a) => "action" in a, Vi = (a) => a.tagName === "IFRAME", Ni = (a) => "formAction" in a, Pi = (a) => "protocol" in a, dt = /* @__PURE__ */ (() => {
  const a = /^(?:\w+script|data):/i;
  return (t) => a.test(t);
})(), ji = /* @__PURE__ */ (() => {
  const a = /(?:script|data):/i;
  return (t) => a.test(t);
})(), qi = (a) => {
  const t = {};
  for (let r = 0, n = a.length; r < n; r++) {
    const s = a[r];
    for (const i in s)
      t[i] ? t[i] = t[i].concat(s[i]) : t[i] = s[i];
  }
  return t;
}, Jr = (a, t) => {
  let r = a.firstChild;
  for (; r; ) {
    const n = r.nextSibling;
    Hi(r) && (t(r, a), r.parentNode && Jr(r, t)), r = n;
  }
}, Ui = (a, t) => {
  const r = document.createNodeIterator(a, NodeFilter.SHOW_ELEMENT);
  let n;
  for (; n = r.nextNode(); ) {
    const s = n.parentNode;
    s && t(n, s);
  }
}, Yi = (a, t) => !!globalThis.document && !!globalThis.document.createNodeIterator ? Ui(a, t) : Jr(a, t), $r = [
  "a",
  "abbr",
  "acronym",
  "address",
  "area",
  "article",
  "aside",
  "audio",
  "b",
  "bdi",
  "bdo",
  "bgsound",
  "big",
  "blockquote",
  "body",
  "br",
  "button",
  "canvas",
  "caption",
  "center",
  "cite",
  "code",
  "col",
  "colgroup",
  "datalist",
  "dd",
  "del",
  "details",
  "dfn",
  "dialog",
  "dir",
  "div",
  "dl",
  "dt",
  "em",
  "fieldset",
  "figcaption",
  "figure",
  "font",
  "footer",
  "form",
  "h1",
  "h2",
  "h3",
  "h4",
  "h5",
  "h6",
  "head",
  "header",
  "hgroup",
  "hr",
  "html",
  "i",
  "img",
  "input",
  "ins",
  "kbd",
  "keygen",
  "label",
  "layer",
  "legend",
  "li",
  "link",
  "listing",
  "main",
  "map",
  "mark",
  "marquee",
  "menu",
  "meta",
  "meter",
  "nav",
  "nobr",
  "ol",
  "optgroup",
  "option",
  "output",
  "p",
  "picture",
  "popup",
  "pre",
  "progress",
  "q",
  "rb",
  "rp",
  "rt",
  "rtc",
  "ruby",
  "s",
  "samp",
  "section",
  "select",
  "selectmenu",
  "small",
  "source",
  "span",
  "strike",
  "strong",
  "style",
  "sub",
  "summary",
  "sup",
  "table",
  "tbody",
  "td",
  "tfoot",
  "th",
  "thead",
  "time",
  "tr",
  "track",
  "tt",
  "u",
  "ul",
  "var",
  "video",
  "wbr"
], Wi = [
  "basefont",
  "command",
  "data",
  "iframe",
  "image",
  "plaintext",
  "portal",
  "slot",
  // 'template', //TODO: Not exactly correct to never allow this, too strict
  "textarea",
  "title",
  "xmp"
], Xi = /* @__PURE__ */ new Set([
  ...$r,
  ...Wi
]), en = [
  "svg",
  "a",
  "altglyph",
  "altglyphdef",
  "altglyphitem",
  "animatecolor",
  "animatemotion",
  "animatetransform",
  "circle",
  "clippath",
  "defs",
  "desc",
  "ellipse",
  "filter",
  "font",
  "g",
  "glyph",
  "glyphref",
  "hkern",
  "image",
  "line",
  "lineargradient",
  "marker",
  "mask",
  "metadata",
  "mpath",
  "path",
  "pattern",
  "polygon",
  "polyline",
  "radialgradient",
  "rect",
  "stop",
  "style",
  "switch",
  "symbol",
  "text",
  "textpath",
  "title",
  "tref",
  "tspan",
  "view",
  "vkern",
  /* FILTERS */
  "feBlend",
  "feColorMatrix",
  "feComponentTransfer",
  "feComposite",
  "feConvolveMatrix",
  "feDiffuseLighting",
  "feDisplacementMap",
  "feDistantLight",
  "feFlood",
  "feFuncA",
  "feFuncB",
  "feFuncG",
  "feFuncR",
  "feGaussianBlur",
  "feImage",
  "feMerge",
  "feMergeNode",
  "feMorphology",
  "feOffset",
  "fePointLight",
  "feSpecularLighting",
  "feSpotLight",
  "feTile",
  "feTurbulence"
], Gi = [
  "animate",
  "color-profile",
  "cursor",
  "discard",
  "fedropshadow",
  "font-face",
  "font-face-format",
  "font-face-name",
  "font-face-src",
  "font-face-uri",
  "foreignobject",
  "hatch",
  "hatchpath",
  "mesh",
  "meshgradient",
  "meshpatch",
  "meshrow",
  "missing-glyph",
  "script",
  "set",
  "solidcolor",
  "unknown",
  "use"
], Ki = /* @__PURE__ */ new Set([
  ...en,
  ...Gi
]), tn = [
  "math",
  "menclose",
  "merror",
  "mfenced",
  "mfrac",
  "mglyph",
  "mi",
  "mlabeledtr",
  "mmultiscripts",
  "mn",
  "mo",
  "mover",
  "mpadded",
  "mphantom",
  "mroot",
  "mrow",
  "ms",
  "mspace",
  "msqrt",
  "mstyle",
  "msub",
  "msup",
  "msubsup",
  "mtable",
  "mtd",
  "mtext",
  "mtr",
  "munder",
  "munderover"
], Qi = [
  "maction",
  "maligngroup",
  "malignmark",
  "mlongdiv",
  "mscarries",
  "mscarry",
  "msgroup",
  "mstack",
  "msline",
  "msrow",
  "semantics",
  "annotation",
  "annotation-xml",
  "mprescripts",
  "none"
], Ji = /* @__PURE__ */ new Set([
  ...tn,
  ...Qi
]), $i = [
  "abbr",
  "accept",
  "accept-charset",
  "accesskey",
  "action",
  "align",
  "alink",
  "allow",
  "allowfullscreen",
  "alt",
  "anchor",
  "archive",
  "as",
  "async",
  "autocapitalize",
  "autocomplete",
  "autocorrect",
  "autofocus",
  "autopictureinpicture",
  "autoplay",
  "axis",
  "background",
  "behavior",
  "bgcolor",
  "border",
  "bordercolor",
  "capture",
  "cellpadding",
  "cellspacing",
  "challenge",
  "char",
  "charoff",
  "charset",
  "checked",
  "cite",
  "class",
  "classid",
  "clear",
  "code",
  "codebase",
  "codetype",
  "color",
  "cols",
  "colspan",
  "compact",
  "content",
  "contenteditable",
  "controls",
  "controlslist",
  "conversiondestination",
  "coords",
  "crossorigin",
  "csp",
  "data",
  "datetime",
  "declare",
  "decoding",
  "default",
  "defer",
  "dir",
  "direction",
  "dirname",
  "disabled",
  "disablepictureinpicture",
  "disableremoteplayback",
  "disallowdocumentaccess",
  "download",
  "draggable",
  "elementtiming",
  "enctype",
  "end",
  "enterkeyhint",
  "event",
  "exportparts",
  "face",
  "for",
  "form",
  "formaction",
  "formenctype",
  "formmethod",
  "formnovalidate",
  "formtarget",
  "frame",
  "frameborder",
  "headers",
  "height",
  "hidden",
  "high",
  "href",
  "hreflang",
  "hreftranslate",
  "hspace",
  "http-equiv",
  "id",
  "imagesizes",
  "imagesrcset",
  "importance",
  "impressiondata",
  "impressionexpiry",
  "incremental",
  "inert",
  "inputmode",
  "integrity",
  "invisible",
  "ismap",
  "keytype",
  "kind",
  "label",
  "lang",
  "language",
  "latencyhint",
  "leftmargin",
  "link",
  "list",
  "loading",
  "longdesc",
  "loop",
  "low",
  "lowsrc",
  "manifest",
  "marginheight",
  "marginwidth",
  "max",
  "maxlength",
  "mayscript",
  "media",
  "method",
  "min",
  "minlength",
  "multiple",
  "muted",
  "name",
  "nohref",
  "nomodule",
  "nonce",
  "noresize",
  "noshade",
  "novalidate",
  "nowrap",
  "object",
  "open",
  "optimum",
  "part",
  "pattern",
  "ping",
  "placeholder",
  "playsinline",
  "policy",
  "poster",
  "preload",
  "pseudo",
  "readonly",
  "referrerpolicy",
  "rel",
  "reportingorigin",
  "required",
  "resources",
  "rev",
  "reversed",
  "role",
  "rows",
  "rowspan",
  "rules",
  "sandbox",
  "scheme",
  "scope",
  "scopes",
  "scrollamount",
  "scrolldelay",
  "scrolling",
  "select",
  "selected",
  "shadowroot",
  "shadowrootdelegatesfocus",
  "shape",
  "size",
  "sizes",
  "slot",
  "span",
  "spellcheck",
  "src",
  "srclang",
  "srcset",
  "standby",
  "start",
  "step",
  "style",
  "summary",
  "tabindex",
  "target",
  "text",
  "title",
  "topmargin",
  "translate",
  "truespeed",
  "trusttoken",
  "type",
  "usemap",
  "valign",
  "value",
  "valuetype",
  "version",
  "virtualkeyboardpolicy",
  "vlink",
  "vspace",
  "webkitdirectory",
  "width",
  "wrap"
], ea = [
  "accent-height",
  "accumulate",
  "additive",
  "alignment-baseline",
  "ascent",
  "attributename",
  "attributetype",
  "azimuth",
  "basefrequency",
  "baseline-shift",
  "begin",
  "bias",
  "by",
  "class",
  "clip",
  "clippathunits",
  "clip-path",
  "clip-rule",
  "color",
  "color-interpolation",
  "color-interpolation-filters",
  "color-profile",
  "color-rendering",
  "cx",
  "cy",
  "d",
  "dx",
  "dy",
  "diffuseconstant",
  "direction",
  "display",
  "divisor",
  "dominant-baseline",
  "dur",
  "edgemode",
  "elevation",
  "end",
  "fill",
  "fill-opacity",
  "fill-rule",
  "filter",
  "filterunits",
  "flood-color",
  "flood-opacity",
  "font-family",
  "font-size",
  "font-size-adjust",
  "font-stretch",
  "font-style",
  "font-variant",
  "font-weight",
  "fx",
  "fy",
  "g1",
  "g2",
  "glyph-name",
  "glyphref",
  "gradientunits",
  "gradienttransform",
  "height",
  "href",
  "id",
  "image-rendering",
  "in",
  "in2",
  "k",
  "k1",
  "k2",
  "k3",
  "k4",
  "kerning",
  "keypoints",
  "keysplines",
  "keytimes",
  "lang",
  "lengthadjust",
  "letter-spacing",
  "kernelmatrix",
  "kernelunitlength",
  "lighting-color",
  "local",
  "marker-end",
  "marker-mid",
  "marker-start",
  "markerheight",
  "markerunits",
  "markerwidth",
  "maskcontentunits",
  "maskunits",
  "max",
  "mask",
  "media",
  "method",
  "mode",
  "min",
  "name",
  "numoctaves",
  "offset",
  "operator",
  "opacity",
  "order",
  "orient",
  "orientation",
  "origin",
  "overflow",
  "paint-order",
  "path",
  "pathlength",
  "patterncontentunits",
  "patterntransform",
  "patternunits",
  "points",
  "preservealpha",
  "preserveaspectratio",
  "primitiveunits",
  "r",
  "rx",
  "ry",
  "radius",
  "refx",
  "refy",
  "repeatcount",
  "repeatdur",
  "restart",
  "result",
  "rotate",
  "scale",
  "seed",
  "shape-rendering",
  "specularconstant",
  "specularexponent",
  "spreadmethod",
  "startoffset",
  "stddeviation",
  "stitchtiles",
  "stop-color",
  "stop-opacity",
  "stroke-dasharray",
  "stroke-dashoffset",
  "stroke-linecap",
  "stroke-linejoin",
  "stroke-miterlimit",
  "stroke-opacity",
  "stroke",
  "stroke-width",
  "style",
  "surfacescale",
  "systemlanguage",
  "tabindex",
  "targetx",
  "targety",
  "transform",
  "transform-origin",
  "text-anchor",
  "text-decoration",
  "text-rendering",
  "textlength",
  "type",
  "u1",
  "u2",
  "unicode",
  "values",
  "viewbox",
  "visibility",
  "version",
  "vert-adv-y",
  "vert-origin-x",
  "vert-origin-y",
  "width",
  "word-spacing",
  "wrap",
  "writing-mode",
  "xchannelselector",
  "ychannelselector",
  "x",
  "x1",
  "x2",
  "xmlns",
  "y",
  "y1",
  "y2",
  "z",
  "zoomandpan"
], ta = [
  "accent",
  "accentunder",
  "align",
  "bevelled",
  "close",
  "columnsalign",
  "columnlines",
  "columnspan",
  "denomalign",
  "depth",
  "dir",
  "display",
  "displaystyle",
  "encoding",
  "fence",
  "frame",
  "height",
  "href",
  "id",
  "largeop",
  "length",
  "linethickness",
  "lspace",
  "lquote",
  "mathbackground",
  "mathcolor",
  "mathsize",
  "mathvariant",
  "maxsize",
  "minsize",
  "movablelimits",
  "notation",
  "numalign",
  "open",
  "rowalign",
  "rowlines",
  "rowspacing",
  "rowspan",
  "rspace",
  "rquote",
  "scriptlevel",
  "scriptminsize",
  "scriptsizemultiplier",
  "selection",
  "separator",
  "separators",
  "stretchy",
  "subscriptshift",
  "supscriptshift",
  "symmetric",
  "voffset",
  "width",
  "xmlns"
], ze = {
  HTML: "http://www.w3.org/1999/xhtml",
  SVG: "http://www.w3.org/2000/svg",
  MATH: "http://www.w3.org/1998/Math/MathML"
}, ra = {
  [ze.HTML]: Xi,
  [ze.SVG]: Ki,
  [ze.MATH]: Ji
}, na = {
  [ze.HTML]: "html",
  [ze.SVG]: "svg",
  [ze.MATH]: "math"
}, ia = {
  [ze.HTML]: "",
  [ze.SVG]: "svg:",
  [ze.MATH]: "math:"
}, aa = /* @__PURE__ */ new Set([
  "A",
  "AREA",
  "BUTTON",
  "FORM",
  "IFRAME",
  "INPUT"
]), rn = {
  allowComments: !0,
  allowCustomElements: !1,
  allowUnknownMarkup: !1,
  allowElements: [
    ...$r,
    ...en.map((a) => `svg:${a}`),
    ...tn.map((a) => `math:${a}`)
  ],
  allowAttributes: qi([
    Object.fromEntries($i.map((a) => [a, ["*"]])),
    Object.fromEntries(ea.map((a) => [a, ["svg:*"]])),
    Object.fromEntries(ta.map((a) => [a, ["math:*"]]))
  ])
};
var St = function(a, t, r, n, s) {
  if (n === "m") throw new TypeError("Private method is not writable");
  if (n === "a" && !s) throw new TypeError("Private accessor was defined without a setter");
  if (typeof t == "function" ? a !== t || !s : !t.has(a)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
  return n === "a" ? s.call(a, r) : s ? s.value = r : t.set(a, r), r;
}, Ye = function(a, t, r, n) {
  if (r === "a" && !n) throw new TypeError("Private accessor was defined without a getter");
  if (typeof t == "function" ? a !== t || !n : !t.has(a)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
  return r === "m" ? n : r === "a" ? n.call(a) : n ? n.value : t.get(a);
}, qe, vt, mt;
class nn {
  /* CONSTRUCTOR */
  constructor(t = {}) {
    qe.set(this, void 0), vt.set(this, void 0), mt.set(this, void 0), this.getConfiguration = () => Nt(Ye(this, qe, "f")), this.sanitize = (h) => {
      const _ = Ye(this, vt, "f"), b = Ye(this, mt, "f");
      return Yi(h, (D, T) => {
        const E = D.namespaceURI || ze.HTML, k = T.namespaceURI || ze.HTML, y = ra[E], d = na[E], p = ia[E], v = D.tagName.toLowerCase(), u = `${p}${v}`, g = `${p}*`;
        if (!y.has(v) || !_.has(u) || E !== k && v !== d)
          T.removeChild(D);
        else {
          const x = D.getAttributeNames(), m = x.length;
          if (m) {
            for (let F = 0; F < m; F++) {
              const B = x[F], C = b[B];
              (!C || !C.has(g) && !C.has(u)) && D.removeAttribute(B);
            }
            if (Oi(D))
              if (Pi(D)) {
                const F = D.getAttribute("href");
                F && ji(F) && dt(D.protocol) && D.removeAttribute("href");
              } else Zi(D) ? dt(D.action) && D.removeAttribute("action") : Ni(D) ? dt(D.formAction) && D.removeAttribute("formaction") : Vi(D) && (dt(D.src) && D.removeAttribute("formaction"), D.setAttribute("sandbox", "allow-scripts"));
          }
        }
      }), h;
    }, this.sanitizeFor = (h, _) => {
      throw new Error('"sanitizeFor" is not implemented yet');
    };
    const { allowComments: r, allowCustomElements: n, allowUnknownMarkup: s, blockElements: i, dropElements: o, dropAttributes: l } = t;
    if (r === !1)
      throw new Error('A false "allowComments" is not supported yet');
    if (n)
      throw new Error('A true "allowCustomElements" is not supported yet');
    if (s)
      throw new Error('A true "allowUnknownMarkup" is not supported yet');
    if (i)
      throw new Error('"blockElements" is not supported yet, use "allowElements" instead');
    if (o)
      throw new Error('"dropElements" is not supported yet, use "allowElements" instead');
    if (l)
      throw new Error('"dropAttributes" is not supported yet, use "allowAttributes" instead');
    St(this, qe, Nt(rn), "f");
    const { allowElements: c, allowAttributes: w } = t;
    c && (Ye(this, qe, "f").allowElements = t.allowElements), w && (Ye(this, qe, "f").allowAttributes = t.allowAttributes), St(this, vt, new Set(Ye(this, qe, "f").allowElements), "f"), St(this, mt, Object.fromEntries(Object.entries(Ye(this, qe, "f").allowAttributes || {}).map(([h, _]) => [h, new Set(_)])), "f");
  }
}
qe = /* @__PURE__ */ new WeakMap(), vt = /* @__PURE__ */ new WeakMap(), mt = /* @__PURE__ */ new WeakMap();
nn.getDefaultConfiguration = () => Nt(rn);
const sa = (a, t = location.href) => {
  try {
    return !!a && new URL(a).origin !== new URL(t).origin;
  } catch {
    return !1;
  }
};
function kr(a) {
  const t = new nn(), r = new DOMParser().parseFromString(a, "text/html");
  return an(r.body, "A", (n) => {
    n instanceof HTMLElement && "target" in n && sa(n.getAttribute("href"), location.href) && (n.setAttribute("target", "_blank"), n.setAttribute("rel", "noopener noreferrer"));
  }), t.sanitize(r).body.innerHTML;
}
function an(a, t, r) {
  a && (a.nodeName === t || typeof t == "function") && r(a);
  const n = a?.childNodes || [];
  for (let s = 0; s < n.length; s++)
    an(n[s], t, r);
}
const yr = [
  "!--",
  "!doctype",
  "a",
  "abbr",
  "acronym",
  "address",
  "applet",
  "area",
  "article",
  "aside",
  "audio",
  "b",
  "base",
  "basefont",
  "bdi",
  "bdo",
  "big",
  "blockquote",
  "body",
  "br",
  "button",
  "canvas",
  "caption",
  "center",
  "cite",
  "code",
  "col",
  "colgroup",
  "data",
  "datalist",
  "dd",
  "del",
  "details",
  "dfn",
  "dialog",
  "dir",
  "div",
  "dl",
  "dt",
  "em",
  "embed",
  "fieldset",
  "figcaption",
  "figure",
  "font",
  "footer",
  "form",
  "frame",
  "frameset",
  "h1",
  "h2",
  "h3",
  "h4",
  "h5",
  "h6",
  "head",
  "header",
  "hgroup",
  "hr",
  "html",
  "i",
  "iframe",
  "img",
  "input",
  "ins",
  "kbd",
  "label",
  "legend",
  "li",
  "link",
  "main",
  "map",
  "mark",
  "menu",
  "meta",
  "meter",
  "nav",
  "noframes",
  "noscript",
  "object",
  "ol",
  "optgroup",
  "option",
  "output",
  "p",
  "param",
  "picture",
  "pre",
  "progress",
  "q",
  "rp",
  "rt",
  "ruby",
  "s",
  "samp",
  "script",
  "search",
  "section",
  "select",
  "small",
  "source",
  "span",
  "strike",
  "strong",
  "style",
  "sub",
  "summary",
  "sup",
  "svg",
  "table",
  "tbody",
  "td",
  "template",
  "textarea",
  "tfoot",
  "th",
  "thead",
  "time",
  "title",
  "tr",
  "track",
  "tt",
  "u",
  "ul",
  "var",
  "video",
  "wbr"
], oa = [
  // Base structural elements
  "g",
  "defs",
  "use",
  "symbol",
  // Shape elements
  "rect",
  "circle",
  "ellipse",
  "line",
  "polyline",
  "polygon",
  "path",
  "image",
  // Text elements
  "text",
  "tspan",
  "textPath",
  // Gradient and effects
  "linearGradient",
  "radialGradient",
  "stop",
  "pattern",
  "clipPath",
  "mask",
  "filter",
  // Filter effects
  "feBlend",
  "feColorMatrix",
  "feComponentTransfer",
  "feComposite",
  "feConvolveMatrix",
  "feDiffuseLighting",
  "feDisplacementMap",
  "feGaussianBlur",
  "feMerge",
  "feMorphology",
  "feOffset",
  "feSpecularLighting",
  "feTurbulence",
  "feMergeNode",
  "feFuncR",
  "feFuncG",
  "feFuncB",
  "feFuncA",
  "feDistantLight",
  "fePointLight",
  "feSpotLight",
  "feFlood",
  "feTile",
  // Animation elements
  "animate",
  "animateTransform",
  "animateMotion",
  "mpath",
  "set",
  // Interactive and other elements
  "view",
  "cursor",
  "foreignObject",
  "desc",
  "title",
  "metadata",
  "switch"
], la = [
  ...yr,
  ...oa.filter((a) => !yr.includes(a))
];
var ca = e.from_html("<span><!></span>");
function ua(a, t) {
  e.push(t, !0);
  var r = this && this.__awaiter || function(g, x, m, F) {
    function B(C) {
      return C instanceof m ? C : new m(function(O) {
        O(C);
      });
    }
    return new (m || (m = Promise))(function(C, O) {
      function N(Z) {
        try {
          H(F.next(Z));
        } catch (R) {
          O(R);
        }
      }
      function ie(Z) {
        try {
          H(F.throw(Z));
        } catch (R) {
          O(R);
        }
      }
      function H(Z) {
        Z.done ? C(Z.value) : B(Z.value).then(N, ie);
      }
      H((F = F.apply(g, x || [])).next());
    });
  };
  let n = e.prop(t, "chatbot", 3, !0), s = e.prop(t, "sanitize_html", 3, !0), i = e.prop(t, "latex_delimiters", 19, () => []), o = e.prop(t, "render_markdown", 3, !0), l = e.prop(t, "line_breaks", 3, !0), c = e.prop(t, "header_links", 3, !1), w = e.prop(t, "allow_tags", 3, !1), h = e.prop(t, "theme_mode", 3, "system"), _;
  const b = Ii({
    header_links: c(),
    line_breaks: l(),
    latex_delimiters: i() || []
  });
  let D = e.derived(() => t.message && t.message.trim() ? d(t.message) : ""), T = !1;
  function E(g) {
    return !i() || i().length === 0 ? !1 : i().some((x) => g.includes(x.left) && g.includes(x.right));
  }
  function k(g) {
    return g.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
  }
  function y(g, x) {
    if (x === !0) {
      const m = /<\/?([a-zA-Z][a-zA-Z0-9-]*)([\s>])/g;
      return g.replace(m, (F, B, C) => la.includes(B.toLowerCase()) ? F : F.replace(/</g, "&lt;").replace(/>/g, "&gt;"));
    }
    if (Array.isArray(x)) {
      const m = x.map((B) => ({
        open: new RegExp(`<(${B})(\\s+[^>]*)?>`, "gi"),
        close: new RegExp(`</(${B})>`, "gi")
      }));
      let F = g;
      return m.forEach((B) => {
        F = F.replace(B.open, (C) => C.replace(/</g, "&lt;").replace(/>/g, "&gt;")), F = F.replace(B.close, (C) => C.replace(/</g, "&lt;").replace(/>/g, "&gt;"));
      }), F;
    }
    return g;
  }
  function d(g) {
    let x = g;
    if (o()) {
      const m = [];
      i().forEach((F, B) => {
        const C = k(F.left), O = k(F.right), N = new RegExp(`${C}([\\s\\S]+?)${O}`, "g");
        x = x.replace(N, (ie, H) => (m.push(ie), `%%%LATEX_BLOCK_${m.length - 1}%%%`));
      }), x = b.parse(x), x = x.replace(/%%%LATEX_BLOCK_(\d+)%%%/g, (F, B) => m[parseInt(B, 10)]);
    }
    return w() && (x = y(x, w())), s() && kr && (x = kr(x)), x;
  }
  function p(g) {
    return r(this, void 0, void 0, function* () {
      if (i().length > 0 && g && E(g))
        if (!T)
          yield Promise.all([
            Promise.resolve({              }),
            import("./auto-render-DCrXk9v9.js")
          ]).then(([, { default: x }]) => {
            T = !0, x(_, { delimiters: i(), throwOnError: !1 });
          });
        else {
          const { default: x } = yield import("./auto-render-DCrXk9v9.js");
          x(_, { delimiters: i(), throwOnError: !1 });
        }
      if (_) {
        const x = _.querySelectorAll(".mermaid");
        if (x.length > 0) {
          yield xt();
          const { default: m } = yield import("./mermaid.core-CMO0znjE.js").then((F) => F.bA);
          m.initialize({
            startOnLoad: !1,
            theme: h() === "dark" ? "dark" : "default",
            securityLevel: "antiscript"
          }), yield m.run({ nodes: Array.from(x).map((F) => F) });
        }
      }
    });
  }
  e.user_effect(() => {
    _ && document.body.contains(_) ? p(t.message) : console.error("Element is not in the DOM");
  });
  var v = ca();
  let u;
  var f = e.child(v);
  e.html(f, () => e.get(D)), e.reset(v), e.bind_this(v, (g) => _ = g, () => _), e.template_effect(() => u = e.set_class(v, 1, "md svelte-680mmo", null, u, { chatbot: n(), prose: o() })), e.append(a, v), e.pop();
}
var da = e.from_html('<div class="svelte-1i9kj8o"><!></div>');
function ha(a, t) {
  let r = e.prop(t, "info", 8);
  var n = da(), s = e.child(n);
  ua(s, {
    get message() {
      return r();
    },
    sanitize_html: !0
  }), e.reset(n), e.append(a, n);
}
var ga = e.from_html('<span data-testid="block-info"><!></span> <!>', 1);
function fa(a, t) {
  let r = e.prop(t, "show_label", 8, !0), n = e.prop(t, "info", 8, void 0), s = e.prop(t, "rtl", 8, !1);
  var i = ga(), o = e.first_child(i);
  let l;
  var c = e.child(o);
  e.slot(c, t, "default", {}, null), e.reset(o);
  var w = e.sibling(o, 2);
  {
    var h = (_) => {
      ha(_, {
        get info() {
          return n();
        }
      });
    };
    e.if(w, (_) => {
      n() && _(h);
    });
  }
  e.template_effect(() => {
    e.set_attribute(o, "dir", s() ? "rtl" : "ltr"), l = e.set_class(o, 1, "svelte-1ho2byj", null, l, {
      hide: !r(),
      "has-info": n() != null,
      "sr-only": !r()
    }), o.dir = o.dir;
  }), e.append(a, i);
}
var pa = e.from_html('<label for="" data-testid="block-label"><span class="svelte-1fzogyz"><!></span> </label>');
function va(a, t) {
  let r = e.prop(t, "label", 8, null), n = e.prop(t, "Icon", 8), s = e.prop(t, "show_label", 8, !0), i = e.prop(t, "disable", 8, !1), o = e.prop(t, "float", 8, !0), l = e.prop(t, "rtl", 8, !1);
  var c = pa();
  let w;
  var h = e.child(c), _ = e.child(h);
  n()(_, {}), e.reset(h);
  var b = e.sibling(h);
  e.reset(c), e.template_effect(() => {
    e.set_attribute(c, "dir", l() ? "rtl" : "ltr"), w = e.set_class(c, 1, "svelte-1fzogyz", null, w, {
      hide: !s(),
      "sr-only": !s(),
      float: o(),
      "hide-label": i()
    }), e.set_text(b, ` ${r() ?? ""}`), c.dir = c.dir;
  }), e.append(a, c);
}
e.from_html("<a><!></a>");
var ma = e.from_html('<span class="svelte-vvirtv"> </span>'), wa = e.from_html("<button><!> <div><!> <!></div></button>");
function nt(a, t) {
  let r = e.prop(t, "label", 3, ""), n = e.prop(t, "show_label", 3, !1), s = e.prop(t, "pending", 3, !1), i = e.prop(t, "size", 3, "small"), o = e.prop(t, "padded", 3, !0), l = e.prop(t, "highlight", 3, !1), c = e.prop(t, "disabled", 3, !1), w = e.prop(t, "hasPopup", 3, !1), h = e.prop(t, "color", 3, "var(--block-label-text-color)"), _ = e.prop(t, "transparent", 3, !1), b = e.prop(t, "background", 3, "var(--block-background-fill)"), D = e.prop(t, "border", 3, "transparent"), T = e.derived(() => l() ? "var(--color-accent)" : h());
  var E = wa();
  let k;
  E.__click = function(...m) {
    t.onclick?.apply(this, m);
  };
  let y;
  var d = e.child(E);
  {
    var p = (m) => {
      var F = ma(), B = e.child(F, !0);
      e.reset(F), e.template_effect(() => e.set_text(B, r())), e.append(m, F);
    };
    e.if(d, (m) => {
      n() && m(p);
    });
  }
  var v = e.sibling(d, 2);
  let u;
  var f = e.child(v);
  e.component(f, () => t.Icon, (m, F) => {
    F(m, {});
  });
  var g = e.sibling(f, 2);
  {
    var x = (m) => {
      var F = e.comment(), B = e.first_child(F);
      e.snippet(B, () => t.children), e.append(m, F);
    };
    e.if(g, (m) => {
      t.children && m(x);
    });
  }
  e.reset(v), e.reset(E), e.template_effect(() => {
    k = e.set_class(E, 1, "icon-button svelte-vvirtv", null, k, {
      pending: s(),
      padded: o(),
      highlight: l(),
      transparent: _()
    }), E.disabled = c(), e.set_attribute(E, "aria-label", r()), e.set_attribute(E, "aria-haspopup", w()), e.set_attribute(E, "title", r()), y = e.set_style(E, "", y, {
      "--border-color": D(),
      color: !c() && e.get(T) ? e.get(T) : "var(--block-label-text-color)",
      "--bg-color": c() ? "auto" : b()
    }), u = e.set_class(v, 1, "svelte-vvirtv", null, u, {
      "x-small": i() === "x-small",
      small: i() === "small",
      large: i() === "large",
      medium: i() === "medium"
    });
  }), e.append(a, E);
}
e.delegate(["click"]);
var _a = e.from_html('<div aria-label="Empty value"><div class="icon svelte-1xcwp1t"><!></div></div>');
function ba(a, t) {
  e.push(t, !1);
  const r = e.mutable_source();
  let n = e.prop(t, "size", 8, "small"), s = e.prop(t, "unpadded_box", 8, !1), i = e.mutable_source();
  function o(_) {
    var b;
    if (!_) return !1;
    const { height: D } = _.getBoundingClientRect(), { height: T } = ((b = _.parentElement) === null || b === void 0 ? void 0 : b.getBoundingClientRect()) || { height: D };
    return D > T + 2;
  }
  e.legacy_pre_effect(() => e.get(i), () => {
    e.set(r, o(e.get(i)));
  }), e.legacy_pre_effect_reset();
  var l = _a();
  let c;
  var w = e.child(l), h = e.child(w);
  e.slot(h, t, "default", {}, null), e.reset(w), e.reset(l), e.bind_this(l, (_) => e.set(i, _), () => e.get(i)), e.template_effect(() => c = e.set_class(l, 1, "empty svelte-1xcwp1t", null, c, {
    small: n() === "small",
    large: n() === "large",
    unpadded_box: s(),
    small_parent: e.get(r)
  })), e.append(a, l), e.pop();
}
e.from_svg('<svg width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><line x1="12" y1="19" x2="12" y2="5"></line><polyline points="5 12 12 5 19 12"></polyline></svg>');
e.from_svg('<svg width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><line x1="12" y1="5" x2="12" y2="19"></line><polyline points="19 12 12 19 5 12"></polyline></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="12px" height="24px" fill="currentColor" stroke-width="1.5" viewBox="0 0 12 24"><path d="M9 6L3 12L9 18" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="24px" height="24px" fill="currentColor" stroke-width="1.5" viewBox="0 0 24 24" color="currentColor"><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" d="M21.044 5.704a.6.6 0 0 1 .956.483v11.626a.6.6 0 0 1-.956.483l-7.889-5.813a.6.6 0 0 1 0-.966l7.89-5.813ZM10.044 5.704a.6.6 0 0 1 .956.483v11.626a.6.6 0 0 1-.956.483l-7.888-5.813a.6.6 0 0 1 0-.966l7.888-5.813Z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 32 32"><path d="M28.828 3.172a4.094 4.094 0 0 0-5.656 0L4.05 22.292A6.954 6.954 0 0 0 2 27.242V30h2.756a6.952 6.952 0 0 0 4.95-2.05L28.828 8.829a3.999 3.999 0 0 0 0-5.657zM10.91 18.26l2.829 2.829l-2.122 2.121l-2.828-2.828zm-2.619 8.276A4.966 4.966 0 0 1 4.756 28H4v-.759a4.967 4.967 0 0 1 1.464-3.535l1.91-1.91l2.829 2.828zM27.415 7.414l-12.261 12.26l-2.829-2.828l12.262-12.26a2.047 2.047 0 0 1 2.828 0a2 2 0 0 1 0 2.828z" fill="currentColor"></path><path d="M6.5 15a3.5 3.5 0 0 1-2.475-5.974l3.5-3.5a1.502 1.502 0 0 0 0-2.121a1.537 1.537 0 0 0-2.121 0L3.415 5.394L2 3.98l1.99-1.988a3.585 3.585 0 0 1 4.95 0a3.504 3.504 0 0 1 0 4.949L5.439 10.44a1.502 1.502 0 0 0 0 2.121a1.537 1.537 0 0 0 2.122 0l4.024-4.024L13 9.95l-4.025 4.024A3.475 3.475 0 0 1 6.5 15z" fill="currentColor"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M2.753 2.933a.75.75 0 0 1 .814-.68l3.043.272c2.157.205 4.224.452 5.922.732c1.66.273 3.073.594 3.844.983c.197.1.412.233.578.415c.176.192.352.506.28.9c-.067.356-.304.59-.487.729a3.001 3.001 0 0 1-.695.369c-1.02.404-2.952.79-5.984 1.169c-1.442.18-2.489.357-3.214.522c.205.045.43.089.674.132c.992.174 2.241.323 3.568.437a31.21 31.21 0 0 1 3.016.398c.46.087.893.186 1.261.296c.352.105.707.236.971.412c.13.086.304.225.42.437a.988.988 0 0 1 .063.141A1.75 1.75 0 0 0 14.5 12.25v.158c-.758.154-1.743.302-2.986.444c-2.124.243-3.409.55-4.117.859c-.296.128-.442.236-.508.3c.026.037.073.094.156.17c.15.138.369.29.65.45c.56.316 1.282.61 1.979.838l2.637.814a.75.75 0 1 1-.443 1.433l-2.655-.819c-.754-.247-1.58-.578-2.257-.96a5.082 5.082 0 0 1-.924-.65c-.255-.233-.513-.544-.62-.935c-.12-.441-.016-.88.274-1.244c.261-.328.656-.574 1.113-.773c.92-.4 2.387-.727 4.545-.974c1.366-.156 2.354-.313 3.041-.462a16.007 16.007 0 0 0-.552-.114a29.716 29.716 0 0 0-2.865-.378c-1.352-.116-2.649-.27-3.7-.454c-.524-.092-1-.194-1.395-.307c-.376-.106-.75-.241-1.021-.426a1.186 1.186 0 0 1-.43-.49a.934.934 0 0 1 .059-.873c.13-.213.32-.352.472-.442a3.23 3.23 0 0 1 .559-.251c.807-.287 2.222-.562 4.37-.83c2.695-.338 4.377-.666 5.295-.962c-.638-.21-1.623-.427-2.89-.635c-1.65-.273-3.679-.515-5.816-.718l-3.038-.272a.75.75 0 0 1-.68-.814M17 12.25a.75.75 0 0 0-1.5 0v4.19l-.72-.72a.75.75 0 1 0-1.06 1.06l2 2a.75.75 0 0 0 1.06 0l2-2a.75.75 0 1 0-1.06-1.06l-.72.72z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="24px" height="24px" viewBox="0 0 24 24"><rect x="2" y="4" width="20" height="18" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></rect><line x1="2" y1="9" x2="22" y2="9" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></line><line x1="7" y1="2" x2="7" y2="6" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></line><line x1="17" y1="2" x2="17" y2="6" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></line></svg>');
var xa = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-camera"><path d="M23 19a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h4l2-3h6l2 3h4a2 2 0 0 1 2 2z"></path><circle cx="12" cy="13" r="4"></circle></svg>');
function ka(a) {
  var t = xa();
  e.append(a, t);
}
e.from_svg('<svg viewBox="0 0 32 32"><path d="M28.828 3.172a4.094 4.094 0 0 0-5.656 0L4.05 22.292A6.954 6.954 0 0 0 2 27.242V30h2.756a6.952 6.952 0 0 0 4.95-2.05L28.828 8.829a3.999 3.999 0 0 0 0-5.657zM10.91 18.26l2.829 2.829l-2.122 2.121l-2.828-2.828zm-2.619 8.276A4.966 4.966 0 0 1 4.756 28H4v-.759a4.967 4.967 0 0 1 1.464-3.535l1.91-1.91l2.829 2.828zM27.415 7.414l-12.261 12.26l-2.829-2.828l12.262-12.26a2.047 2.047 0 0 1 2.828 0a2 2 0 0 1 0 2.828z" fill="currentColor"></path><path d="M6.5 15a3.5 3.5 0 0 1-2.475-5.974l3.5-3.5a1.502 1.502 0 0 0 0-2.121a1.537 1.537 0 0 0-2.121 0L3.415 5.394L2 3.98l1.99-1.988a3.585 3.585 0 0 1 4.95 0a3.504 3.504 0 0 1 0 4.949L5.439 10.44a1.502 1.502 0 0 0 0 2.121a1.537 1.537 0 0 0 2.122 0l4.024-4.024L13 9.95l-4.025 4.024A3.475 3.475 0 0 1 6.5 15z" fill="currentColor"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M17.74 30L16 29l4-7h6a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h9v2H6a4 4 0 0 1-4-4V8a4 4 0 0 1 4-4h20a4 4 0 0 1 4 4v12a4 4 0 0 1-4 4h-4.84Z"></path><path fill="currentColor" d="M8 10h16v2H8zm0 6h10v2H8z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" stroke-width="1.5" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg" color="currentColor"><path d="M5 13L9 17L19 7" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 16 16" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M4 6L8 10L12 6"></path></svg>');
var ya = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-circle"><circle cx="12" cy="12" r="10"></circle></svg>');
function Ca(a) {
  var t = ya();
  e.append(a, t);
}
var Da = e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xml:space="preserve" stroke="currentColor" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;"><g transform="matrix(1.14096,-0.140958,-0.140958,1.14096,-0.0559523,0.0559523)"><path d="M18,6L6.087,17.913" style="fill:none;fill-rule:nonzero;stroke-width:2px;"></path></g><path d="M4.364,4.364L19.636,19.636" style="fill:none;fill-rule:nonzero;stroke-width:2px;"></path></svg>');
function Pt(a) {
  var t = Da();
  e.append(a, t);
}
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1" stroke-linecap="round" stroke-linejoin="round" class="feather feather-closed-caption"><rect x="2" y="6" width="20" height="12" rx="2" ry="2"></rect><text x="12" y="15" font-family="sans-serif" font-size="8" font-weight="bold" fill="currentColor" stroke="none" text-anchor="middle">CC</text></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 32 32"><path fill="currentColor" d="m31 16l-7 7l-1.41-1.41L28.17 16l-5.58-5.59L24 9l7 7zM1 16l7-7l1.41 1.41L3.83 16l5.58 5.59L8 23l-7-7zm11.42 9.484L17.64 6l1.932.517L14.352 26z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 32 32"><circle cx="10" cy="12" r="2" fill="currentColor"></circle><circle cx="16" cy="9" r="2" fill="currentColor"></circle><circle cx="22" cy="12" r="2" fill="currentColor"></circle><circle cx="23" cy="18" r="2" fill="currentColor"></circle><circle cx="19" cy="23" r="2" fill="currentColor"></circle><path fill="currentColor" d="M16.54 2A14 14 0 0 0 2 16a4.82 4.82 0 0 0 6.09 4.65l1.12-.31a3 3 0 0 1 3.79 2.9V27a3 3 0 0 0 3 3a14 14 0 0 0 14-14.54A14.05 14.05 0 0 0 16.54 2Zm8.11 22.31A11.93 11.93 0 0 1 16 28a1 1 0 0 1-1-1v-3.76a5 5 0 0 0-5-5a5.07 5.07 0 0 0-1.33.18l-1.12.31A2.82 2.82 0 0 1 4 16A12 12 0 0 1 16.47 4A12.18 12.18 0 0 1 28 15.53a11.89 11.89 0 0 1-3.35 8.79Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M12 22q-2.05 0-3.875-.788t-3.187-2.15t-2.15-3.187T2 12q0-2.075.813-3.9t2.2-3.175T8.25 2.788T12.2 2q2 0 3.775.688t3.113 1.9t2.125 2.875T22 11.05q0 2.875-1.75 4.413T16 17h-1.85q-.225 0-.312.125t-.088.275q0 .3.375.863t.375 1.287q0 1.25-.687 1.85T12 22m-5.5-9q.65 0 1.075-.425T8 11.5t-.425-1.075T6.5 10t-1.075.425T5 11.5t.425 1.075T6.5 13m3-4q.65 0 1.075-.425T11 7.5t-.425-1.075T9.5 6t-1.075.425T8 7.5t.425 1.075T9.5 9m5 0q.65 0 1.075-.425T16 7.5t-.425-1.075T14.5 6t-1.075.425T13 7.5t.425 1.075T14.5 9m3 4q.65 0 1.075-.425T19 11.5t-.425-1.075T17.5 10t-1.075.425T16 11.5t.425 1.075T17.5 13"></path></svg>');
var Ea = e.from_svg('<svg id="icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32" width="100%" height="100%"><path d="M23,20a5,5,0,0,0-3.89,1.89L11.8,17.32a4.46,4.46,0,0,0,0-2.64l7.31-4.57A5,5,0,1,0,18,7a4.79,4.79,0,0,0,.2,1.32l-7.31,4.57a5,5,0,1,0,0,6.22l7.31,4.57A4.79,4.79,0,0,0,18,25a5,5,0,1,0,5-5ZM23,4a3,3,0,1,1-3,3A3,3,0,0,1,23,4ZM7,19a3,3,0,1,1,3-3A3,3,0,0,1,7,19Zm16,9a3,3,0,1,1,3-3A3,3,0,0,1,23,28Z" fill="currentColor"></path></svg>');
function Fa(a) {
  var t = Ea();
  e.append(a, t);
}
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 33 33" color="currentColor" aria-hidden="true" width="100%" height="100%"><path fill="currentColor" d="M28 10v18H10V10h18m0-2H10a2 2 0 0 0-2 2v18a2 2 0 0 0 2 2h18a2 2 0 0 0 2-2V10a2 2 0 0 0-2-2Z"></path><path fill="currentColor" d="M4 18H2V4a2 2 0 0 1 2-2h14v2H4Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 256 256"><path fill="currentColor" d="M240 192a8 8 0 0 1-8 8h-32v32a8 8 0 0 1-16 0v-32H64a8 8 0 0 1-8-8V72H24a8 8 0 0 1 0-16h32V24a8 8 0 0 1 16 0v160h160a8 8 0 0 1 8 8M96 72h88v88a8 8 0 0 0 16 0V64a8 8 0 0 0-8-8H96a8 8 0 0 0 0 16"></path></svg>');
var Aa = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 32 32"><path fill="currentColor" d="M26 24v4H6v-4H4v4a2 2 0 0 0 2 2h20a2 2 0 0 0 2-2v-4zm0-10l-1.41-1.41L17 20.17V2h-2v18.17l-7.59-7.58L6 14l10 10l10-10z"></path></svg>');
function La(a) {
  var t = Aa();
  e.append(a, t);
}
var Ma = e.from_svg('<svg class="dropdown-arrow svelte-gtiaeq" xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 18 18"><path d="M5 8l4 4 4-4z"></path></svg>');
function sn(a) {
  var t = Ma();
  e.append(a, t);
}
e.from_svg('<svg class="dropdown-arrow svelte-wyly4p" xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 18 18"><circle cx="9" cy="9" r="8" class="circle svelte-wyly4p"></circle><path d="M5 8l4 4 4-4z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-edit-2"><path d="M17 3a2.828 2.828 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5L17 3z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><g fill="none"><path fill="currentColor" d="m5.505 11.41l.53.53l-.53-.53ZM3 14.952h-.75H3ZM9.048 21v.75V21ZM11.41 5.505l-.53-.53l.53.53Zm1.831 12.34a.75.75 0 0 0 1.06-1.061l-1.06 1.06ZM7.216 9.697a.75.75 0 1 0-1.06 1.061l1.06-1.06Zm10.749 2.362l-5.905 5.905l1.06 1.06l5.905-5.904l-1.06-1.06Zm-11.93-.12l5.905-5.905l-1.06-1.06l-5.905 5.904l1.06 1.06Zm0 6.025c-.85-.85-1.433-1.436-1.812-1.933c-.367-.481-.473-.79-.473-1.08h-1.5c0 .749.312 1.375.78 1.99c.455.596 1.125 1.263 1.945 2.083l1.06-1.06Zm-1.06-7.086c-.82.82-1.49 1.488-1.945 2.084c-.468.614-.78 1.24-.78 1.99h1.5c0-.29.106-.6.473-1.08c.38-.498.962-1.083 1.812-1.933l-1.06-1.06Zm7.085 7.086c-.85.85-1.435 1.433-1.933 1.813c-.48.366-.79.472-1.08.472v1.5c.75 0 1.376-.312 1.99-.78c.596-.455 1.264-1.125 2.084-1.945l-1.06-1.06Zm-7.085 1.06c.82.82 1.487 1.49 2.084 1.945c.614.468 1.24.78 1.989.78v-1.5c-.29 0-.599-.106-1.08-.473c-.497-.38-1.083-.962-1.933-1.812l-1.06 1.06Zm12.99-12.99c.85.85 1.433 1.436 1.813 1.933c.366.481.472.79.472 1.08h1.5c0-.749-.312-1.375-.78-1.99c-.455-.596-1.125-1.263-1.945-2.083l-1.06 1.06Zm1.06 7.086c.82-.82 1.49-1.488 1.945-2.084c.468-.614.78-1.24.78-1.99h-1.5c0 .29-.106.6-.473 1.08c-.38.498-.962 1.083-1.812 1.933l1.06 1.06Zm0-8.146c-.82-.82-1.487-1.49-2.084-1.945c-.614-.468-1.24-.78-1.989-.78v1.5c.29 0 .599.106 1.08.473c.497.38 1.083.962 1.933 1.812l1.06-1.06Zm-7.085 1.06c.85-.85 1.435-1.433 1.933-1.812c.48-.367.79-.473 1.08-.473v-1.5c-.75 0-1.376.312-1.99.78c-.596.455-1.264 1.125-2.084 1.945l1.06 1.06Zm2.362 10.749L7.216 9.698l-1.06 1.061l7.085 7.085l1.06-1.06Z"></path><path stroke="currentColor" stroke-linecap="round" stroke-width="1.5" d="M9 21h12"></path></g></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M12 9v3.75m9-.75a9 9 0 11-18 0 9 9 0 0118 0zm-9 3.75h.008v.008H12v-.008z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M21.03 2.97a3.578 3.578 0 0 0-5.06 0L14 4.94l-.013-.013a1.75 1.75 0 0 0-2.475 0l-.585.586a1.75 1.75 0 0 0 0 2.475l.012.012l-6.78 6.78a2.25 2.25 0 0 0-.659 1.592v.687l-1.28 2.347c-.836 1.533.841 3.21 2.374 2.375l2.347-1.28h.688a2.25 2.25 0 0 0 1.59-.66L16 13.061l.012.012a1.75 1.75 0 0 0 2.475 0l.586-.585a1.75 1.75 0 0 0 0-2.475L19.061 10l1.97-1.97a3.578 3.578 0 0 0 0-5.06ZM12 9.061l2.94 2.94l-6.78 6.78a.75.75 0 0 1-.531.22H6.75a.75.75 0 0 0-.359.09l-2.515 1.373a.234.234 0 0 1-.159.032a.264.264 0 0 1-.138-.075a.264.264 0 0 1-.075-.138a.234.234 0 0 1 .033-.158l1.372-2.515A.75.75 0 0 0 5 17.25v-.878a.75.75 0 0 1 .22-.53L12 9.06Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="24px" height="24px" fill="currentColor" stroke-width="1.5" viewBox="0 0 24 24" color="currentColor"><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" d="M2.956 5.704A.6.6 0 0 0 2 6.187v11.626a.6.6 0 0 0 .956.483l7.889-5.813a.6.6 0 0 0 0-.966l-7.89-5.813ZM13.956 5.704a.6.6 0 0 0-.956.483v11.626a.6.6 0 0 0 .956.483l7.889-5.813a.6.6 0 0 0 0-.966l-7.89-5.813Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-file"><path d="M13 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9z"></path><polyline points="13 2 13 9 20 9"></polyline></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M11.25 11.25l.041-.02a.75.75 0 011.063.852l-.708 2.836a.75.75 0 001.063.853l.041-.021M21 12a9 9 0 11-18 0 9 9 0 0118 0zm-9-3.75h.008v.008H12V8.25z"></path></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M9 12.75L11.25 15 15 9.75M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path></svg>');
var Ba = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-image"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><circle cx="8.5" cy="8.5" r="1.5"></circle><polyline points="21 15 16 10 5 21"></polyline></svg>');
function on(a) {
  var t = Ba();
  e.append(a, t);
}
var Sa = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 256 256"><path fill="currentColor" d="M200 32h-36.26a47.92 47.92 0 0 0-71.48 0H56a16 16 0 0 0-16 16v168a16 16 0 0 0 16 16h144a16 16 0 0 0 16-16V48a16 16 0 0 0-16-16m-72 0a32 32 0 0 1 32 32H96a32 32 0 0 1 32-32m72 184H56V48h26.75A47.9 47.9 0 0 0 80 64v8a8 8 0 0 0 8 8h80a8 8 0 0 0 8-8v-8a47.9 47.9 0 0 0-2.75-16H200Z"></path></svg>');
function ln(a) {
  var t = Sa();
  e.append(a, t);
}
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--mdi" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 24 24"><path fill="currentColor" d="M5 3h2v2H5v5a2 2 0 0 1-2 2a2 2 0 0 1 2 2v5h2v2H5c-1.07-.27-2-.9-2-2v-4a2 2 0 0 0-2-2H0v-2h1a2 2 0 0 0 2-2V5a2 2 0 0 1 2-2m14 0a2 2 0 0 1 2 2v4a2 2 0 0 0 2 2h1v2h-1a2 2 0 0 0-2 2v4a2 2 0 0 1-2 2h-2v-2h2v-5a2 2 0 0 1 2-2a2 2 0 0 1-2-2V5h-2V3h2m-7 12a1 1 0 0 1 1 1a1 1 0 0 1-1 1a1 1 0 0 1-1-1a1 1 0 0 1 1-1m-4 0a1 1 0 0 1 1 1a1 1 0 0 1-1 1a1 1 0 0 1-1-1a1 1 0 0 1 1-1m8 0a1 1 0 0 1 1 1a1 1 0 0 1-1 1a1 1 0 0 1-1-1a1 1 0 0 1 1-1Z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 17 17" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M1.35327 10.9495L6.77663 15.158C7.12221 15.4229 7.50051 15.5553 7.91154 15.5553C8.32258 15.5553 8.70126 15.4229 9.0476 15.158L14.471 10.9495" stroke="currentColor" stroke-width="1.5" stroke-linecap="round"></path><path d="M7.23461 11.4324C7.23406 11.432 7.2335 11.4316 7.23295 11.4312L1.81496 7.2268C1.81471 7.22661 1.81446 7.22641 1.8142 7.22621C1.52269 6.99826 1.39429 6.73321 1.39429 6.37014C1.39429 6.00782 1.52236 5.74301 1.81325 5.51507C1.8136 5.5148 1.81394 5.51453 1.81428 5.51426L7.2331 1.30812C7.45645 1.13785 7.67632 1.06653 7.91159 1.06653C8.14692 1.06653 8.36622 1.13787 8.58861 1.30787C8.58915 1.30828 8.58969 1.30869 8.59023 1.30911L14.0082 5.51462C14.0085 5.51485 14.0088 5.51507 14.0091 5.51529C14.3008 5.74345 14.4289 6.00823 14.4289 6.37014C14.4289 6.73356 14.3006 6.99862 14.01 7.22634C14.0096 7.22662 14.0093 7.22689 14.0089 7.22717L8.59007 11.4322C8.36672 11.6024 8.14686 11.6738 7.91159 11.6738C7.67628 11.6738 7.45699 11.6024 7.23461 11.4324Z" stroke="currentColor" stroke-width="1.5"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M4 2H2v26a2 2 0 0 0 2 2h26v-2H4v-3h22v-8H4v-4h14V5H4Zm20 17v4H4v-4ZM16 7v4H4V7Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-maximize" width="100%" height="100%"><path d="M8 3H5a2 2 0 0 0-2 2v3m18 0V5a2 2 0 0 0-2-2h-3m0 18h3a2 2 0 0 0 2-2v-3M3 16v3a2 2 0 0 0 2 2h3"></path></svg>');
var Ta = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-mic"><path d="M12 1a3 3 0 0 0-3 3v8a3 3 0 0 0 6 0V4a3 3 0 0 0-3-3z"></path><path d="M19 10v2a7 7 0 0 1-14 0v-2"></path><line x1="12" y1="19" x2="12" y2="23"></line><line x1="8" y1="23" x2="16" y2="23"></line></svg>');
function za(a) {
  var t = Ta();
  e.append(a, t);
}
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-minimize" width="100%" height="100%"><path d="M8 3v3a2 2 0 0 1-2 2H3m18 0h-3a2 2 0 0 1-2-2V3m0 18v-3a2 2 0 0 1 2-2h3M3 16h3a2 2 0 0 1 2 2v3"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-music"><path d="M9 18V5l12-2v13"></path><circle cx="6" cy="18" r="3"></circle><circle cx="18" cy="16" r="3"></circle></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><g fill="none" stroke="currentColor" stroke-width="1.5"><path d="M2 12.026c0 5.146 3.867 9.387 8.847 9.96c.735.085 1.447-.228 1.97-.753a1.68 1.68 0 0 0 0-2.372c-.523-.525-.95-1.307-.555-1.934c1.576-2.508 9.738 3.251 9.738-4.9C22 6.488 17.523 2 12 2S2 6.489 2 12.026Z"></path><circle cx="17.5" cy="11.5" r=".75"></circle><circle cx="6.5" cy="11.5" r=".75"></circle><path d="M10.335 7a.75.75 0 1 1-1.5 0a.75.75 0 0 1 1.5 0Zm4.915 0a.75.75 0 1 1-1.5 0a.75.75 0 0 1 1.5 0Z"></path></g></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M10.05 23q-.75 0-1.4-.337T7.575 21.7l-5.9-8.65q-.2-.3-.175-.65t.3-.6q.475-.475 1.125-.55t1.175.3L7 13.575V4q0-.425.288-.712T8 3t.713.288T9 4v11.5q0 .6-.537.888t-1.038-.063l-2.125-1.5l3.925 5.725q.125.2.35.325t.475.125H17q.825 0 1.413-.587T19 19V5q0-.425.288-.712T20 4t.713.288T21 5v14q0 1.65-1.175 2.825T17 23zM12 1q.425 0 .713.288T13 2v9q0 .425-.288.713T12 12t-.712-.288T11 11V2q0-.425.288-.712T12 1m4 1q.425 0 .713.288T17 3v8q0 .425-.288.713T16 12t-.712-.288T15 11V3q0-.425.288-.712T16 2m-3.85 14.5"></path></svg>');
e.from_svg('<svg fill="currentColor" width="100%" height="100%" viewBox="0 0 1920 1920" xmlns="http://www.w3.org/2000/svg"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M1752.768 221.109C1532.646.986 1174.283.986 954.161 221.109l-838.588 838.588c-154.052 154.165-154.052 404.894 0 558.946 149.534 149.421 409.976 149.308 559.059 0l758.738-758.626c87.982-88.094 87.982-231.417 0-319.51-88.32-88.208-231.642-87.982-319.51 0l-638.796 638.908 79.85 79.849 638.795-638.908c43.934-43.821 115.539-43.934 159.812 0 43.934 44.047 43.934 115.877 0 159.812l-758.739 758.625c-110.23 110.118-289.355 110.005-399.36 0-110.118-110.117-110.005-289.242 0-399.247l838.588-838.588c175.963-175.962 462.382-176.188 638.909 0 176.075 176.188 176.075 462.833 0 638.908l-798.607 798.72 79.849 79.85 798.607-798.72c220.01-220.123 220.01-578.485 0-798.607" fill-rule="evenodd"></path></g></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="currentColor" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"><rect x="6" y="4" width="4" height="16"></rect><rect x="14" y="4" width="4" height="16"></rect></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="currentColor" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"><polygon points="5 3 19 12 5 21 5 3"></polygon></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><circle cx="20" cy="4" r="2" fill="currentColor"></circle><circle cx="8" cy="16" r="2" fill="currentColor"></circle><circle cx="28" cy="12" r="2" fill="currentColor"></circle><circle cx="11" cy="7" r="2" fill="currentColor"></circle><circle cx="16" cy="24" r="2" fill="currentColor"></circle><path fill="currentColor" d="M30 3.413L28.586 2L4 26.585V2H2v26a2 2 0 0 0 2 2h26v-2H5.413Z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M6 12H12M18 12H12M12 12V6M12 12V18" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path></svg>');
var Ra = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rotate-ccw" style="transform: rotateY(180deg);"><polyline points="1 4 1 10 7 10"></polyline><path d="M3.51 15a9 9 0 1 0 2.13-9.36L1 10"></path></svg>');
function Ia(a) {
  var t = Ra();
  e.append(a, t);
}
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" width="100%" height="100%"><path d="M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 1024 1024"><path fill="currentColor" d="M672 418H144c-17.7 0-32 14.3-32 32v414c0 17.7 14.3 32 32 32h528c17.7 0 32-14.3 32-32V450c0-17.7-14.3-32-32-32zm-44 402H188V494h440v326z"></path><path fill="currentColor" d="M819.3 328.5c-78.8-100.7-196-153.6-314.6-154.2l-.2-64c0-6.5-7.6-10.1-12.6-6.1l-128 101c-4 3.1-3.9 9.1 0 12.3L492 318.6c5.1 4 12.7.4 12.6-6.1v-63.9c12.9.1 25.9.9 38.8 2.5c42.1 5.2 82.1 18.2 119 38.7c38.1 21.2 71.2 49.7 98.4 84.3c27.1 34.7 46.7 73.7 58.1 115.8c11 40.7 14 82.7 8.9 124.8c-.7 5.4-1.4 10.8-2.4 16.1h74.9c14.8-103.6-11.3-213-81-302.3z"></path></svg>');
e.from_svg('<svg viewBox="0 0 22 24" width="100%" height="100%" fill="none" xmlns="http://www.w3.org/2000/svg"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M19.1168 12.1484C19.474 12.3581 19.9336 12.2384 20.1432 11.8811C20.3528 11.5238 20.2331 11.0643 19.8758 10.8547L19.1168 12.1484ZM6.94331 4.13656L6.55624 4.77902L6.56378 4.78344L6.94331 4.13656ZM5.92408 4.1598L5.50816 3.5357L5.50816 3.5357L5.92408 4.1598ZM5.51031 5.09156L4.76841 5.20151C4.77575 5.25101 4.78802 5.29965 4.80505 5.34671L5.51031 5.09156ZM7.12405 11.7567C7.26496 12.1462 7.69495 12.3477 8.08446 12.2068C8.47397 12.0659 8.67549 11.6359 8.53458 11.2464L7.12405 11.7567ZM19.8758 12.1484C20.2331 11.9388 20.3528 11.4793 20.1432 11.122C19.9336 10.7648 19.474 10.6451 19.1168 10.8547L19.8758 12.1484ZM6.94331 18.8666L6.56375 18.2196L6.55627 18.2241L6.94331 18.8666ZM5.92408 18.8433L5.50815 19.4674H5.50815L5.92408 18.8433ZM5.51031 17.9116L4.80505 17.6564C4.78802 17.7035 4.77575 17.7521 4.76841 17.8016L5.51031 17.9116ZM8.53458 11.7567C8.67549 11.3672 8.47397 10.9372 8.08446 10.7963C7.69495 10.6554 7.26496 10.8569 7.12405 11.2464L8.53458 11.7567ZM19.4963 12.2516C19.9105 12.2516 20.2463 11.9158 20.2463 11.5016C20.2463 11.0873 19.9105 10.7516 19.4963 10.7516V12.2516ZM7.82931 10.7516C7.4151 10.7516 7.07931 11.0873 7.07931 11.5016C7.07931 11.9158 7.4151 12.2516 7.82931 12.2516V10.7516ZM19.8758 10.8547L7.32284 3.48968L6.56378 4.78344L19.1168 12.1484L19.8758 10.8547ZM7.33035 3.49414C6.76609 3.15419 6.05633 3.17038 5.50816 3.5357L6.34 4.78391C6.40506 4.74055 6.4893 4.73863 6.55627 4.77898L7.33035 3.49414ZM5.50816 3.5357C4.95998 3.90102 4.67184 4.54987 4.76841 5.20151L6.25221 4.98161C6.24075 4.90427 6.27494 4.82727 6.34 4.78391L5.50816 3.5357ZM4.80505 5.34671L7.12405 11.7567L8.53458 11.2464L6.21558 4.83641L4.80505 5.34671ZM19.1168 10.8547L6.56378 18.2197L7.32284 19.5134L19.8758 12.1484L19.1168 10.8547ZM6.55627 18.2241C6.4893 18.2645 6.40506 18.2626 6.34 18.2192L5.50815 19.4674C6.05633 19.8327 6.76609 19.8489 7.33035 19.509L6.55627 18.2241ZM6.34 18.2192C6.27494 18.1759 6.24075 18.0988 6.25221 18.0215L4.76841 17.8016C4.67184 18.4532 4.95998 19.1021 5.50815 19.4674L6.34 18.2192ZM6.21558 18.1667L8.53458 11.7567L7.12405 11.2464L4.80505 17.6564L6.21558 18.1667ZM19.4963 10.7516H7.82931V12.2516H19.4963V10.7516Z" fill="currentColor"></path></g></svg>');
e.from_svg('<svg enable-background="new 0 0 32 32" height="20" width="20" viewBox="0 0 32 32" fill="currentColor" xmlns="http://www.w3.org/2000/svg"><path d="m30 8h-4.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4h-14.1v2h14.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4h4.1zm-9 4c-1.7 0-3-1.3-3-3s1.3-3 3-3 3 1.3 3 3-1.3 3-3 3z"></path><path d="m2 24h4.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4h14.1v-2h-14.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4h-4.1zm9-4c1.7 0 3 1.3 3 3s-1.3 3-3 3-3-1.3-3-3 1.3-3 3-3z"></path><path d="m0 0h32v32h-32z" fill="none"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-edit-2"><path d="M17 3a2.828 2.828 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5L17 3z"></path></svg>');
var Ha = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" class="feather feather-square"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect></svg>');
function Oa(a, t) {
  let r = e.prop(t, "fill", 8, "currentColor"), n = e.prop(t, "stroke_width", 8, 1.5);
  var s = Ha();
  e.template_effect(() => {
    e.set_attribute(s, "fill", r()), e.set_attribute(s, "stroke-width", `${n()}`);
  }), e.append(a, s);
}
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-table"><path d="M9 3H5a2 2 0 0 0-2 2v4m6-6h10a2 2 0 0 1 2 2v4M9 3v18m0 0h10a2 2 0 0 0 2-2V9M9 21H5a2 2 0 0 1-2-2V9m0 0h18"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M12 15H5a3 3 0 0 1-3-3v-2a3 3 0 0 1 3-3h5V5a1 1 0 0 0-1-1H3V2h6a3 3 0 0 1 3 3zM5 9a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h5V9zm15 14v2a1 1 0 0 0 1 1h5v-4h-5a1 1 0 0 0-1 1z"></path><path fill="currentColor" d="M2 30h28V2Zm26-2h-7a3 3 0 0 1-3-3v-2a3 3 0 0 1 3-3h5v-2a1 1 0 0 0-1-1h-6v-2h6a3 3 0 0 1 3 3Z"></path></svg>');
e.from_svg(`<svg id="icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32" fill="currentColor" width="100%" height="100%"><defs><style>.cls-1 {
				fill: none;
			}</style></defs><rect x="12" y="12" width="2" height="12"></rect><rect x="18" y="12" width="2" height="12"></rect><path d="M4,6V8H6V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8h2V6ZM8,28V8H24V28Z"></path><rect x="12" y="2" width="8" height="2"></rect><rect id="_Transparent_Rectangle_" data-name="&lt;Transparent Rectangle>" class="cls-1" width="32" height="32"></rect></svg>`);
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M23 9.005h6a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-6a2 2 0 0 0-2 2v1H11v-1a2 2 0 0 0-2-2H3a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-1h4v20a2.002 2.002 0 0 0 2 2h4v1a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-6a2 2 0 0 0-2 2v1h-4v-9h4v1a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-6a2 2 0 0 0-2 2v1h-4v-9h4v1a2 2 0 0 0 2 2Zm0-6h6v4h-6Zm-14 4H3v-4h6Zm14 18h6v4h-6Zm0-11h6v4h-6Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-scissors"><circle cx="6" cy="6" r="3"></circle><circle cx="6" cy="18" r="3"></circle><line x1="20" y1="4" x2="8.12" y2="15.88"></line><line x1="14.47" y1="14.48" x2="20" y2="20"></line><line x1="8.12" y1="8.12" x2="12" y2="12"></line></svg>');
var Za = e.from_svg('<svg aria-label="undo" xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rotate-ccw"><polyline points="1 4 1 10 7 10"></polyline><path d="M3.51 15a9 9 0 1 0 2.13-9.36L1 10"></path></svg>');
function Va(a) {
  var t = Za();
  e.append(a, t);
}
var Na = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="90%" height="90%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-upload"><path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4"></path><polyline points="17 8 12 3 7 8"></polyline><line x1="12" y1="3" x2="12" y2="15"></line></svg>');
function cn(a) {
  var t = Na();
  e.append(a, t);
}
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-video"><polygon points="23 7 16 12 23 17 23 7"></polygon><rect x="1" y="5" width="15" height="14" rx="2" ry="2"></rect></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M12 16q1.875 0 3.188-1.312T16.5 11.5t-1.312-3.187T12 7T8.813 8.313T7.5 11.5t1.313 3.188T12 16m0-1.8q-1.125 0-1.912-.788T9.3 11.5t.788-1.912T12 8.8t1.913.788t.787 1.912t-.787 1.913T12 14.2m0 4.8q-3.65 0-6.65-2.037T1 11.5q1.35-3.425 4.35-5.462T12 4t6.65 2.038T23 11.5q-1.35 3.425-4.35 5.463T12 19"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="m19.8 22.6l-4.2-4.15q-.875.275-1.762.413T12 19q-3.775 0-6.725-2.087T1 11.5q.525-1.325 1.325-2.463T4.15 7L1.4 4.2l1.4-1.4l18.4 18.4zM12 16q.275 0 .513-.025t.512-.1l-5.4-5.4q-.075.275-.1.513T7.5 11.5q0 1.875 1.313 3.188T12 16m7.3.45l-3.175-3.15q.175-.425.275-.862t.1-.938q0-1.875-1.312-3.187T12 7q-.5 0-.937.1t-.863.3L7.65 4.85q1.025-.425 2.1-.637T12 4q3.775 0 6.725 2.088T23 11.5q-.575 1.475-1.513 2.738T19.3 16.45m-4.625-4.6l-3-3q.7-.125 1.288.113t1.012.687t.613 1.038t.087 1.162"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" fill="none" xmlns="http://www.w3.org/2000/svg" stroke="currentColor" color="currentColor"><title>Low volume</title><path d="M19.5 7.5C19.5 7.5 21 9 21 11.5C21 14 19.5 15.5 19.5 15.5" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M2 13.8571V10.1429C2 9.03829 2.89543 8.14286 4 8.14286H6.9C7.09569 8.14286 7.28708 8.08544 7.45046 7.97772L13.4495 4.02228C14.1144 3.5839 15 4.06075 15 4.85714V19.1429C15 19.9392 14.1144 20.4161 13.4495 19.9777L7.45046 16.0223C7.28708 15.9146 7.09569 15.8571 6.9 15.8571H4C2.89543 15.8571 2 14.9617 2 13.8571Z" stroke-width="1.5"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" fill="none" stroke="currentColor" xmlns="http://www.w3.org/2000/svg" color="currentColor"><title>High volume</title><path d="M1 13.8571V10.1429C1 9.03829 1.89543 8.14286 3 8.14286H5.9C6.09569 8.14286 6.28708 8.08544 6.45046 7.97772L12.4495 4.02228C13.1144 3.5839 14 4.06075 14 4.85714V19.1429C14 19.9392 13.1144 20.4161 12.4495 19.9777L6.45046 16.0223C6.28708 15.9146 6.09569 15.8571 5.9 15.8571H3C1.89543 15.8571 1 14.9617 1 13.8571Z" stroke-width="1.5"></path><path d="M17.5 7.5C17.5 7.5 19 9 19 11.5C19 14 17.5 15.5 17.5 15.5" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M20.5 4.5C20.5 4.5 23 7 23 11.5C23 16 20.5 18.5 20.5 18.5" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" fill="none" xmlns="http://www.w3.org/2000/svg" stroke="currentColor" color="currentColor"><title>Muted volume</title><g clip-path="url(#clip0_3173_16686)"><path d="M18 14L20.0005 12M22 10L20.0005 12M20.0005 12L18 10M20.0005 12L22 14" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M2 13.8571V10.1429C2 9.03829 2.89543 8.14286 4 8.14286H6.9C7.09569 8.14286 7.28708 8.08544 7.45046 7.97772L13.4495 4.02228C14.1144 3.5839 15 4.06075 15 4.85714V19.1429C15 19.9392 14.1144 20.4161 13.4495 19.9777L7.45046 16.0223C7.28708 15.9146 7.09569 15.8571 6.9 15.8571H4C2.89543 15.8571 2 14.9617 2 13.8571Z" stroke-width="1.5"></path></g><defs><clipPath id="clip0_3173_16686"><rect width="24" height="24" fill="white"></rect></clipPath></defs></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" stroke-width="2" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M12 9v3.75m-9.303 3.376c-.866 1.5.217 3.374 1.948 3.374h14.71c1.73 0 2.813-1.874 1.948-3.374L13.949 3.378c-.866-1.5-3.032-1.5-3.898 0L2.697 16.126zM12 15.75h.007v.008H12v-.008z"></path></svg>');
var Pa = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M12 2c-4.963 0-9 4.038-9 9c0 3.328 1.82 6.232 4.513 7.79l-2.067 1.378A1 1 0 0 0 6 22h12a1 1 0 0 0 .555-1.832l-2.067-1.378C19.18 17.232 21 14.328 21 11c0-4.962-4.037-9-9-9zm0 16c-3.859 0-7-3.141-7-7c0-3.86 3.141-7 7-7s7 3.14 7 7c0 3.859-3.141 7-7 7z"></path><path fill="currentColor" d="M12 6c-2.757 0-5 2.243-5 5s2.243 5 5 5s5-2.243 5-5s-2.243-5-5-5zm0 8c-1.654 0-3-1.346-3-3s1.346-3 3-3s3 1.346 3 3s-1.346 3-3 3z"></path></svg>');
function un(a) {
  var t = Pa();
  e.append(a, t);
}
var ja = e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 50 50" class="svelte-3g80w1"><circle cx="25" cy="25" r="20" fill="none" stroke-width="3.0" stroke-linecap="round" stroke-dasharray="94.2477796076938 94.2477796076938" stroke-dashoffset="0" class="svelte-3g80w1"><animateTransform attributeName="transform" type="rotate" from="0 25 25" to="360 25 25" repeatCount="indefinite" class="svelte-3g80w1"></animateTransform></circle></svg>');
function qa(a) {
  var t = ja();
  e.append(a, t);
}
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 256 256"><path fill="currentColor" d="M144 120v88a8 8 0 0 1-8 8H48a8 8 0 0 1-8-8v-88a8 8 0 0 1 8-8h88a8 8 0 0 1 8 8m64 56a8 8 0 0 0-8 8v16h-24a8 8 0 0 0 0 16h24a16 16 0 0 0 16-16v-16a8 8 0 0 0-8-8m0-72a8 8 0 0 0-8 8v32a8 8 0 0 0 16 0v-32a8 8 0 0 0-8-8m-8-64h-16a8 8 0 0 0 0 16h16v16a8 8 0 0 0 16 0V56a16 16 0 0 0-16-16m-56 0h-32a8 8 0 0 0 0 16h32a8 8 0 0 0 0-16M48 88a8 8 0 0 0 8-8V56h16a8 8 0 0 0 0-16H56a16 16 0 0 0-16 16v24a8 8 0 0 0 8 8"></path></svg>');
e.from_svg('<svg width="100%" height="100%" stroke-width="1.5" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg" color="currentColor"><path d="M19.1679 9C18.0247 6.46819 15.3006 4.5 11.9999 4.5C8.31459 4.5 5.05104 7.44668 4.54932 11" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M16 9H19.4C19.7314 9 20 8.73137 20 8.4V5" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M4.88146 15C5.92458 17.5318 8.64874 19.5 12.0494 19.5C15.7347 19.5 18.9983 16.5533 19.5 13" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M8.04932 15H4.64932C4.31795 15 4.04932 15.2686 4.04932 15.6V19" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M12 20L12 4M12 20L7 15M12 20L17 15" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="m21 21l-4.343-4.343m0 0A8 8 0 1 0 5.343 5.343a8 8 0 0 0 11.314 11.314M11 8v6m-3-3h6"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="m21 21l-4.343-4.343m0 0A8 8 0 1 0 5.343 5.343a8 8 0 0 0 11.314 11.314M8 11h6"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32"><path fill="currentColor" d="M12.1 2a9.8 9.8 0 0 0-5.4 1.6l6.4 6.4a2.1 2.1 0 0 1 .2 3a2.1 2.1 0 0 1-3-.2L3.7 6.4A9.84 9.84 0 0 0 2 12.1a10.14 10.14 0 0 0 10.1 10.1a11 11 0 0 0 2.6-.3l6.7 6.7a5 5 0 0 0 7.1-7.1l-6.7-6.7a11 11 0 0 0 .3-2.6A10 10 0 0 0 12.1 2m8 10.1a7.6 7.6 0 0 1-.3 2.1l-.3 1.1l.8.8l6.7 6.7a2.88 2.88 0 0 1 .9 2.1A2.72 2.72 0 0 1 27 27a2.9 2.9 0 0 1-4.2 0l-6.7-6.7l-.8-.8l-1.1.3a7.6 7.6 0 0 1-2.1.3a8.27 8.27 0 0 1-5.7-2.3A7.63 7.63 0 0 1 4 12.1a8.3 8.3 0 0 1 .3-2.2l4.4 4.4a4.14 4.14 0 0 0 5.9.2a4.14 4.14 0 0 0-.2-5.9L10 4.2a6.5 6.5 0 0 1 2-.3a8.27 8.27 0 0 1 5.7 2.3a8.5 8.5 0 0 1 2.4 5.9"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32"><path fill="currentColor" d="M17.74 30L16 29l4-7h6a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h9v2H6a4 4 0 0 1-4-4V8a4 4 0 0 1 4-4h20a4 4 0 0 1 4 4v12a4 4 0 0 1-4 4h-4.84Z"></path><path fill="currentColor" d="M8 10h16v2H8zm0 6h10v2H8z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32"><path fill="currentColor" d="M19 10h7v2h-7zm0 5h7v2h-7zm0 5h7v2h-7z"></path><path fill="currentColor" d="M28 5H4a2 2 0 0 0-2 2v18a2 2 0 0 0 2 2h24a2.003 2.003 0 0 0 2-2V7a2 2 0 0 0-2-2M4 7h11v18H4Zm13 18V7h11l.002 18Z"></path></svg>');
function Ua(a, t) {
  e.push(t, !1);
  const r = Re();
  let n = e.prop(t, "formatter", 8), s = e.prop(t, "value", 8), i = e.prop(t, "i18n", 8), o = e.mutable_source(!1);
  e.init();
  {
    let l = e.derived_safe_equal(() => (e.deep_read_state(i()), e.untrack(() => i()("common.share"))));
    nt(a, {
      get Icon() {
        return Fa;
      },
      get label() {
        return e.get(l);
      },
      get pending() {
        return e.get(o);
      },
      onclick: async () => {
        try {
          e.set(o, !0);
          const c = await n()(s());
          r("share", { description: c });
        } catch (c) {
          console.error(c);
          let w = c instanceof ft ? c.message : "Share failed.";
          r("error", w);
        } finally {
          e.set(o, !1);
        }
      }
    });
  }
  e.pop();
}
const Ya = /^(#\s*)(.+)$/m;
function Cr(a) {
  const t = a.trim(), r = t.match(Ya);
  if (!r)
    return [!1, t || !1];
  const [n, , s] = r, i = s.trim();
  if (t === n)
    return [i, !1];
  const o = r.index !== void 0 ? r.index + n.length : 0, c = t.substring(o).trim() || !1;
  return [i, c];
}
var Wa = e.from_html('<h2 class="svelte-cmuu9m"> </h2>'), Xa = e.from_html('<p class="svelte-cmuu9m"> </p>'), Ga = e.from_html("<!> <!>", 1), Ka = e.from_html('<span class="or svelte-cmuu9m"> </span> ', 1), Qa = e.from_html(" <!>", 1), Ja = e.from_html('<div class="wrap svelte-cmuu9m"><span><!></span> <!></div>');
function Dr(a, t) {
  e.push(t, !1);
  const r = e.mutable_source(), n = e.mutable_source();
  let s = e.prop(t, "type", 8, "file"), i = e.prop(t, "i18n", 8), o = e.prop(t, "message", 8, void 0), l = e.prop(t, "mode", 8, "full"), c = e.prop(t, "hovered", 8, !1), w = e.prop(t, "placeholder", 8, void 0);
  const h = {
    image: "upload_text.drop_image",
    video: "upload_text.drop_video",
    audio: "upload_text.drop_audio",
    file: "upload_text.drop_file",
    csv: "upload_text.drop_csv",
    gallery: "upload_text.drop_gallery",
    clipboard: "upload_text.paste_clipboard"
  };
  e.legacy_pre_effect(
    () => (e.get(r), e.get(n), e.deep_read_state(w()), Cr),
    () => {
      ((v) => {
        var u = e.to_array(v, 2);
        e.set(r, u[0]), e.set(n, u[1]);
      })(w() ? Cr(w()) : [!1, !1]);
    }
  ), e.legacy_pre_effect_reset(), e.init();
  var _ = Ja(), b = e.child(_);
  let D;
  var T = e.child(b);
  {
    var E = (v) => {
      ln(v);
    }, k = (v) => {
      cn(v);
    };
    e.if(T, (v) => {
      s() === "clipboard" ? v(E) : v(k, !1);
    });
  }
  e.reset(b);
  var y = e.sibling(b, 2);
  {
    var d = (v) => {
      var u = Ga(), f = e.first_child(u);
      {
        var g = (F) => {
          var B = Wa(), C = e.child(B, !0);
          e.reset(B), e.template_effect(() => e.set_text(C, e.get(r))), e.append(F, B);
        };
        e.if(f, (F) => {
          e.get(r) && F(g);
        });
      }
      var x = e.sibling(f, 2);
      {
        var m = (F) => {
          var B = Xa(), C = e.child(B, !0);
          e.reset(B), e.template_effect(() => e.set_text(C, e.get(n))), e.append(F, B);
        };
        e.if(x, (F) => {
          e.get(n) && F(m);
        });
      }
      e.append(v, u);
    }, p = (v) => {
      var u = Qa(), f = e.first_child(u), g = e.sibling(f);
      {
        var x = (m) => {
          var F = Ka(), B = e.first_child(F), C = e.child(B);
          e.reset(B);
          var O = e.sibling(B);
          e.template_effect(
            (N, ie) => {
              e.set_text(C, `- ${N ?? ""} -`), e.set_text(O, ` ${ie ?? ""}`);
            },
            [
              () => (e.deep_read_state(i()), e.untrack(() => i()("common.or"))),
              () => (e.deep_read_state(o()), e.deep_read_state(i()), e.untrack(() => o() || i()("upload_text.click_to_upload")))
            ]
          ), e.append(m, F);
        };
        e.if(g, (m) => {
          l() !== "short" && m(x);
        });
      }
      e.template_effect((m) => e.set_text(f, `${m ?? ""} `), [
        () => (e.deep_read_state(i()), e.deep_read_state(s()), e.untrack(() => i()(h[s()] || h.file)))
      ]), e.append(v, u);
    };
    e.if(y, (v) => {
      e.get(r) || e.get(n) ? v(d) : v(p, !1);
    });
  }
  e.reset(_), e.template_effect(() => D = e.set_class(b, 1, "icon-wrap svelte-cmuu9m", null, D, { hovered: c() })), e.append(a, _), e.pop();
}
e.from_html("<div><!></div>");
var $a = e.from_html('<button aria-label="Upload file"><!></button>'), es = e.from_html('<button aria-label="Record audio"><!></button>'), ts = e.from_html('<button aria-label="Capture from camera"><!></button>'), rs = e.from_html('<button aria-label="Paste from clipboard"><!></button>'), ns = e.from_html('<span class="source-selection svelte-5d261r" data-testid="source-select"><!> <!> <!> <!></span>');
function is(a, t) {
  e.push(t, !0);
  var r = this && this.__awaiter || function(_, b, D, T) {
    function E(k) {
      return k instanceof D ? k : new D(function(y) {
        y(k);
      });
    }
    return new (D || (D = Promise))(function(k, y) {
      function d(u) {
        try {
          v(T.next(u));
        } catch (f) {
          y(f);
        }
      }
      function p(u) {
        try {
          v(T.throw(u));
        } catch (f) {
          y(f);
        }
      }
      function v(u) {
        u.done ? k(u.value) : E(u.value).then(d, p);
      }
      v((T = T.apply(_, b || [])).next());
    });
  };
  let n = e.prop(t, "active_source", 15), s = e.prop(t, "handle_clear", 3, () => {
  }), i = e.prop(t, "handle_select", 3, () => {
  }), o = e.derived(() => [...new Set(t.sources)]);
  function l(_) {
    return r(this, void 0, void 0, function* () {
      s()(), n(_), i()(_);
    });
  }
  var c = e.comment(), w = e.first_child(c);
  {
    var h = (_) => {
      var b = ns(), D = e.child(b);
      {
        var T = (u) => {
          var f = $a();
          let g;
          f.__click = () => l("upload");
          var x = e.child(f);
          cn(x), e.reset(f), e.template_effect(() => g = e.set_class(f, 1, "icon svelte-5d261r", null, g, { selected: n() === "upload" || !n() })), e.append(u, f);
        };
        e.if(D, (u) => {
          t.sources.includes("upload") && u(T);
        });
      }
      var E = e.sibling(D, 2);
      {
        var k = (u) => {
          var f = es();
          let g;
          f.__click = () => l("microphone");
          var x = e.child(f);
          za(x), e.reset(f), e.template_effect(() => g = e.set_class(f, 1, "icon svelte-5d261r", null, g, { selected: n() === "microphone" })), e.append(u, f);
        };
        e.if(E, (u) => {
          t.sources.includes("microphone") && u(k);
        });
      }
      var y = e.sibling(E, 2);
      {
        var d = (u) => {
          var f = ts();
          let g;
          f.__click = () => l("webcam");
          var x = e.child(f);
          un(x), e.reset(f), e.template_effect(() => g = e.set_class(f, 1, "icon svelte-5d261r", null, g, { selected: n() === "webcam" })), e.append(u, f);
        };
        e.if(y, (u) => {
          t.sources.includes("webcam") && u(d);
        });
      }
      var p = e.sibling(y, 2);
      {
        var v = (u) => {
          var f = rs();
          let g;
          f.__click = () => l("clipboard");
          var x = e.child(f);
          ln(x), e.reset(f), e.template_effect(() => g = e.set_class(f, 1, "icon svelte-5d261r", null, g, { selected: n() === "clipboard" })), e.append(u, f);
        };
        e.if(p, (u) => {
          t.sources.includes("clipboard") && u(v);
        });
      }
      e.reset(b), e.append(_, b);
    };
    e.if(w, (_) => {
      e.get(o).length > 1 && _(h);
    });
  }
  e.append(a, c), e.pop();
}
e.delegate(["click"]);
e.from_html('<span class="custom-button-label svelte-g7x491"> </span>');
e.from_html('<button class="custom-button svelte-g7x491"><!></button>');
e.from_html("<div><!> <!></div>");
e.from_html("<div></div>");
function Tt(a) {
  let t = ["", "k", "M", "G", "T", "P", "E", "Z"], r = 0;
  for (; a > 1e3 && r < t.length - 1; )
    a /= 1e3, r++;
  let n = t[r];
  return (Number.isInteger(a) ? a : a.toFixed(1)) + n;
}
var as = e.from_html('<div><svg viewBox="-1200 -1200 3000 3000" fill="none" xmlns="http://www.w3.org/2000/svg" class="svelte-m6d381"><g><path d="M255.926 0.754768L509.702 139.936V221.027L255.926 81.8465V0.754768Z" fill="#FF7C00" fill-opacity="0.4" class="svelte-m6d381"></path><path d="M509.69 139.936L254.981 279.641V361.255L509.69 221.55V139.936Z" fill="#FF7C00" class="svelte-m6d381"></path><path d="M0.250138 139.937L254.981 279.641V361.255L0.250138 221.55V139.937Z" fill="#FF7C00" fill-opacity="0.4" class="svelte-m6d381"></path><path d="M255.923 0.232622L0.236328 139.936V221.55L255.923 81.8469V0.232622Z" fill="#FF7C00" class="svelte-m6d381"></path></g><g><path d="M255.926 141.5L509.702 280.681V361.773L255.926 222.592V141.5Z" fill="#FF7C00" fill-opacity="0.4" class="svelte-m6d381"></path><path d="M509.69 280.679L254.981 420.384V501.998L509.69 362.293V280.679Z" fill="#FF7C00" class="svelte-m6d381"></path><path d="M0.250138 280.681L254.981 420.386V502L0.250138 362.295V280.681Z" fill="#FF7C00" fill-opacity="0.4" class="svelte-m6d381"></path><path d="M255.923 140.977L0.236328 280.68V362.294L255.923 222.591V140.977Z" fill="#FF7C00" class="svelte-m6d381"></path></g></svg></div>');
function ss(a, t) {
  e.push(t, !1);
  const r = () => e.store_get(c, "$top", s), n = () => e.store_get(w, "$bottom", s), [s, i] = e.setup_stores();
  var o = this && this.__awaiter || function(p, v, u, f) {
    function g(x) {
      return x instanceof u ? x : new u(function(m) {
        m(x);
      });
    }
    return new (u || (u = Promise))(function(x, m) {
      function F(O) {
        try {
          C(f.next(O));
        } catch (N) {
          m(N);
        }
      }
      function B(O) {
        try {
          C(f.throw(O));
        } catch (N) {
          m(N);
        }
      }
      function C(O) {
        O.done ? x(O.value) : g(O.value).then(F, B);
      }
      C((f = f.apply(p, v || [])).next());
    });
  };
  let l = e.prop(t, "margin", 8, !0);
  const c = Qt([0, 0]), w = Qt([0, 0]);
  let h;
  function _() {
    return o(this, void 0, void 0, function* () {
      yield Promise.all([c.set([125, 140]), w.set([-125, -140])]), yield Promise.all([c.set([-125, 140]), w.set([125, -140])]), yield Promise.all([c.set([-125, 0]), w.set([125, -0])]), yield Promise.all([c.set([125, 0]), w.set([-125, 0])]);
    });
  }
  function b() {
    return o(this, void 0, void 0, function* () {
      yield _(), h || b();
    });
  }
  function D() {
    return o(this, void 0, void 0, function* () {
      yield Promise.all([c.set([125, 0]), w.set([-125, 0])]), b();
    });
  }
  Je(() => (D(), () => h = !0)), e.init();
  var T = as();
  let E;
  var k = e.child(T), y = e.child(k), d = e.sibling(y);
  e.reset(k), e.reset(T), e.template_effect(() => {
    E = e.set_class(T, 1, "svelte-m6d381", null, E, { margin: l() }), e.set_style(y, `transform: translate(${r(), e.untrack(() => r()[0]) ?? ""}px, ${r(), e.untrack(() => r()[1]) ?? ""}px);`), e.set_style(d, `transform: translate(${n(), e.untrack(() => n()[0]) ?? ""}px, ${n(), e.untrack(() => n()[1]) ?? ""}px);`);
  }), e.append(a, T), e.pop(), i();
}
var os = function(a, t, r, n) {
  function s(i) {
    return i instanceof r ? i : new r(function(o) {
      o(i);
    });
  }
  return new (r || (r = Promise))(function(i, o) {
    function l(h) {
      try {
        w(n.next(h));
      } catch (_) {
        o(_);
      }
    }
    function c(h) {
      try {
        w(n.throw(h));
      } catch (_) {
        o(_);
      }
    }
    function w(h) {
      h.done ? i(h.value) : s(h.value).then(l, c);
    }
    w((n = n.apply(a, t || [])).next());
  });
};
let ht = [], zt = !1;
const ls = typeof window < "u", dn = ls ? window.requestAnimationFrame : (a) => {
};
function cs(a) {
  return os(this, arguments, void 0, function* (t, r = !0) {
    if (!(window.__gradio_mode__ === "website" || window.__gradio_mode__ !== "app" && r !== !0)) {
      if (ht.push(t), !zt) zt = !0;
      else return;
      yield xt(), dn(() => {
        let n = [0, 0];
        for (let s = 0; s < ht.length; s++) {
          const o = ht[s].getBoundingClientRect();
          (s === 0 || o.top + window.scrollY <= n[0]) && (n[0] = o.top + window.scrollY, n[1] = s);
        }
        window.scrollTo({ top: n[0] - 20, behavior: "smooth" }), zt = !1, ht = [];
      });
    }
  });
}
var us = e.from_html('<div class="validation-error svelte-124hqw6"> <button class="svelte-124hqw6"><!></button></div>'), ds = e.from_html('<div class="eta-bar svelte-124hqw6"></div>'), hs = e.from_html("<!> ", 1), gs = e.from_html("<!> <!> <!> <!>", 1), fs = e.from_html('<div class="progress-level svelte-124hqw6"><div class="progress-level-inner svelte-124hqw6"><!></div> <div class="progress-bar-wrap svelte-124hqw6"><div class="progress-bar svelte-124hqw6"></div></div></div>'), ps = e.from_html('<p class="loading svelte-124hqw6"> </p> <!>', 1), vs = e.from_html("<!> <div><!> <!></div> <!> <!>", 1), ms = e.from_html('<div class="clear-status svelte-124hqw6"><!></div> <span class="error svelte-124hqw6"> </span> <!>', 1), ws = e.from_html('<div data-testid="status-tracker"><!> <!></div>');
function _s(a, t) {
  e.push(t, !0);
  let r = e.prop(t, "eta", 7, null), n = e.prop(t, "scroll_to_output", 3, !1), s = e.prop(t, "timer", 3, !0), i = e.prop(t, "show_progress", 3, "full"), o = e.prop(t, "message", 3, null), l = e.prop(t, "progress", 3, null), c = e.prop(t, "variant", 3, "default"), w = e.prop(t, "loading_text", 3, "Loading..."), h = e.prop(t, "absolute", 3, !0), _ = e.prop(t, "translucent", 3, !1), b = e.prop(t, "border", 3, !1), D = e.prop(t, "validation_error", 7, null), T = e.prop(t, "show_validation_error", 3, !0), E = e.prop(t, "type", 3, null), k, y = !1, d = e.state(0), p = e.state(null), v = e.state(null), u = e.state(!1), f = e.state(null);
  const g = e.derived(() => E() === "input" || !t.status || t.status === "complete" || i() === "hidden" || t.status == "streaming" || !!(T() && D()));
  let x = e.state(0);
  const m = e.derived(() => e.get(v) === null || e.get(v) <= 0 || !e.get(x) ? 0 : Math.min(e.get(x) / e.get(v), 1)), F = e.derived(() => e.get(x).toFixed(1));
  let B = e.derived(() => l() == null);
  function C() {
    dn(() => {
      e.set(x, (performance.now() - e.get(d)) / 1e3), y && C();
    });
  }
  let O = e.derived(() => {
    let Y = null;
    l() != null ? Y = l().map((S) => {
      if (S.index != null && S.length != null)
        return S.index / S.length;
      if (S.progress != null)
        return S.progress;
    }) : Y = null;
    let ne, z = "";
    return Y ? (ne = Y[Y.length - 1], ne === 0 ? z = "0" : z = "150ms") : ne = void 0, {
      progress_level: Y,
      last_progress_level: ne,
      progress_bar_transition: z
    };
  });
  function N() {
    y || (e.set(p, e.set(f, null), !0), e.set(d, performance.now(), !0), y = !0, C());
  }
  function ie() {
    e.set(p, e.set(f, null), !0), y && (y = !1);
  }
  e.user_effect(() => {
    t.status === "pending" ? N() : Zt(() => {
      ie();
    });
  }), e.user_effect(() => {
    k && n() && (t.status === "pending" || t.status === "complete") && cs(k, t.autoscroll);
  }), e.user_effect(() => {
    r() === null && r(e.get(p)), r() != null && e.get(p) !== r() && (e.set(v, (performance.now() - e.get(d)) / 1e3 + r()), e.set(f, e.get(v).toFixed(1), !0), e.set(p, r(), !0));
  });
  function H() {
    e.set(u, !1);
  }
  e.user_effect(() => {
    Zt(() => {
      H();
    }), t.status === "error" && o() && e.set(u, !0);
  });
  var Z = ws();
  let R, G;
  var ae = e.child(Z);
  {
    var $ = (Y) => {
      var ne = us(), z = e.child(ne), S = e.sibling(z), L = e.child(S);
      {
        let A = e.derived(() => t.i18n ? t.i18n("common.clear") : "Clear");
        nt(L, {
          get Icon() {
            return Pt;
          },
          get label() {
            return e.get(A);
          },
          disabled: !1,
          size: "x-small",
          background: "var(--background-fill-primary)",
          color: "var(--error-background-text)",
          border: "var(--border-color-primary)",
          onclick: () => D(null)
        });
      }
      e.reset(S), e.reset(ne), e.template_effect(() => e.set_text(z, `${D() ?? ""} `)), e.append(Y, ne);
    };
    e.if(ae, (Y) => {
      D() && T() && Y($);
    });
  }
  var te = e.sibling(ae, 2);
  {
    var Q = (Y) => {
      var ne = vs(), z = e.first_child(ne);
      {
        var S = (J) => {
          var se = ds();
          let j;
          e.template_effect(() => j = e.set_style(se, "", j, {
            transform: `translateX(${(e.get(m) || 0) * 100 - 100}%)`
          })), e.append(J, se);
        };
        e.if(z, (J) => {
          c() === "default" && e.get(B) && i() === "full" && J(S);
        });
      }
      var L = e.sibling(z, 2);
      let A;
      var V = e.child(L);
      {
        var P = (J) => {
          var se = e.comment(), j = e.first_child(se);
          e.each(j, 17, l, e.index, (U, W) => {
            var X = e.comment(), ge = e.first_child(X);
            {
              var be = (le) => {
                var ce = hs(), xe = e.first_child(ce);
                {
                  var me = (Le) => {
                    var Ze = e.text();
                    e.template_effect((Pe, je) => e.set_text(Ze, `${Pe ?? ""}/${je ?? ""}`), [
                      () => Tt(e.get(W).index || 0),
                      () => Tt(e.get(W).length)
                    ]), e.append(Le, Ze);
                  }, ke = (Le) => {
                    var Ze = e.text();
                    e.template_effect((Pe) => e.set_text(Ze, Pe), [() => Tt(e.get(W).index || 0)]), e.append(Le, Ze);
                  };
                  e.if(xe, (Le) => {
                    e.get(W).length != null ? Le(me) : Le(ke, !1);
                  });
                }
                var Ee = e.sibling(xe);
                e.template_effect(() => e.set_text(Ee, ` ${e.get(W).unit ?? ""} |  `)), e.append(le, ce);
              };
              e.if(ge, (le) => {
                e.get(W).index != null && le(be);
              });
            }
            e.append(U, X);
          }), e.append(J, se);
        }, K = (J) => {
          var se = e.comment(), j = e.first_child(se);
          {
            var U = (X) => {
              var ge = e.text();
              e.template_effect(() => e.set_text(ge, `queue: ${t.queue_position + 1}/${t.queue_size ?? ""} |`)), e.append(X, ge);
            }, W = (X) => {
              var ge = e.comment(), be = e.first_child(ge);
              {
                var le = (ce) => {
                  var xe = e.text("processing |");
                  e.append(ce, xe);
                };
                e.if(
                  be,
                  (ce) => {
                    t.queue_position === 0 && ce(le);
                  },
                  !0
                );
              }
              e.append(X, ge);
            };
            e.if(
              j,
              (X) => {
                t.queue_position !== null && t.queue_size !== void 0 && t.queue_position >= 0 ? X(U) : X(W, !1);
              },
              !0
            );
          }
          e.append(J, se);
        };
        e.if(V, (J) => {
          l() ? J(P) : J(K, !1);
        });
      }
      var de = e.sibling(V, 2);
      {
        var ve = (J) => {
          var se = e.text();
          e.template_effect(() => e.set_text(se, `${e.get(F) ?? ""}${r() ? `/${e.get(f)}` : ""}s`)), e.append(J, se);
        };
        e.if(de, (J) => {
          s() && J(ve);
        });
      }
      e.reset(L);
      var we = e.sibling(L, 2);
      {
        var Ce = (J) => {
          var se = fs(), j = e.child(se), U = e.child(j);
          {
            var W = (le) => {
              var ce = e.comment(), xe = e.first_child(ce);
              e.each(xe, 17, l, e.index, (me, ke, Ee) => {
                var Le = e.comment(), Ze = e.first_child(Le);
                {
                  var Pe = (je) => {
                    var Ve = gs(), Ke = e.first_child(Ve);
                    {
                      var Ie = (Ae) => {
                        var Be = e.text(" /");
                        e.append(Ae, Be);
                      };
                      e.if(Ke, (Ae) => {
                        Ee !== 0 && Ae(Ie);
                      });
                    }
                    var st = e.sibling(Ke, 2);
                    {
                      var yt = (Ae) => {
                        var Be = e.text();
                        e.template_effect(() => e.set_text(Be, e.get(ke).desc)), e.append(Ae, Be);
                      };
                      e.if(st, (Ae) => {
                        e.get(ke).desc != null && Ae(yt);
                      });
                    }
                    var $e = e.sibling(st, 2);
                    {
                      var Ct = (Ae) => {
                        var Be = e.text("-");
                        e.append(Ae, Be);
                      };
                      e.if($e, (Ae) => {
                        e.get(ke).desc != null && e.get(O).progress_level && e.get(O).progress_level[Ee] != null && Ae(Ct);
                      });
                    }
                    var ot = e.sibling($e, 2);
                    {
                      var Dt = (Ae) => {
                        var Be = e.text();
                        e.template_effect((M) => e.set_text(Be, `${M ?? ""}%`), [
                          () => (100 * (e.get(O).progress_level[Ee] || 0)).toFixed(1)
                        ]), e.append(Ae, Be);
                      };
                      e.if(ot, (Ae) => {
                        e.get(O).progress_level != null && Ae(Dt);
                      });
                    }
                    e.append(je, Ve);
                  };
                  e.if(Ze, (je) => {
                    (e.get(ke).desc != null || e.get(O).progress_level && e.get(O).progress_level[Ee] != null) && je(Pe);
                  });
                }
                e.append(me, Le);
              }), e.append(le, ce);
            };
            e.if(U, (le) => {
              l() != null && le(W);
            });
          }
          e.reset(j);
          var X = e.sibling(j, 2), ge = e.child(X);
          let be;
          e.reset(X), e.reset(se), e.template_effect(() => be = e.set_style(ge, "", be, {
            width: `${e.get(O).last_progress_level * 100}%`,
            transition: e.get(O).progress_bar_transition
          })), e.append(J, se);
        }, _e = (J) => {
          var se = e.comment(), j = e.first_child(se);
          {
            var U = (W) => {
              {
                let X = e.derived(() => c() === "default");
                ss(W, {
                  get margin() {
                    return e.get(X);
                  }
                });
              }
            };
            e.if(
              j,
              (W) => {
                i() === "full" && W(U);
              },
              !0
            );
          }
          e.append(J, se);
        };
        e.if(we, (J) => {
          e.get(O).last_progress_level != null ? J(Ce) : J(_e, !1);
        });
      }
      var De = e.sibling(we, 2);
      {
        var he = (J) => {
          var se = ps(), j = e.first_child(se), U = e.child(j, !0);
          e.reset(j);
          var W = e.sibling(j, 2);
          e.slot(W, t, "additional-loading-text", {}, null), e.template_effect(() => e.set_text(U, w())), e.append(J, se);
        };
        e.if(De, (J) => {
          s() || J(he);
        });
      }
      e.template_effect(() => A = e.set_class(L, 1, "progress-text svelte-124hqw6", null, A, {
        "meta-text-center": c() === "center",
        "meta-text": c() === "default"
      })), e.append(Y, ne);
    }, re = (Y) => {
      var ne = e.comment(), z = e.first_child(ne);
      {
        var S = (L) => {
          var A = ms(), V = e.first_child(A), P = e.child(V);
          {
            let we = e.derived(() => t.i18n("common.clear"));
            nt(P, {
              get Icon() {
                return Pt;
              },
              get label() {
                return e.get(we);
              },
              disabled: !1,
              $$events: {
                click: () => {
                  t.on_clear_status?.();
                }
              }
            });
          }
          e.reset(V);
          var K = e.sibling(V, 2), de = e.child(K, !0);
          e.reset(K);
          var ve = e.sibling(K, 2);
          e.slot(ve, t, "error", {}, null), e.template_effect((we) => e.set_text(de, we), [() => t.i18n("common.error")]), e.append(L, A);
        };
        e.if(
          z,
          (L) => {
            t.status === "error" && L(S);
          },
          !0
        );
      }
      e.append(Y, ne);
    };
    e.if(te, (Y) => {
      t.status === "pending" ? Y(Q) : Y(re, !1);
    });
  }
  e.reset(Z), e.bind_this(Z, (Y) => k = Y, () => k), e.template_effect(() => {
    R = e.set_class(Z, 1, `wrap ${c() ?? ""} ${i() ?? ""}`, "svelte-124hqw6", R, {
      "no-click": D() && T(),
      hide: e.get(g),
      translucent: c() === "center" && (t.status === "pending" || t.status === "error") || _() || i() === "minimal" || D(),
      generating: t.status === "generating" && i() === "full",
      border: b()
    }), G = e.set_style(Z, "", G, {
      position: h() ? "absolute" : "static",
      padding: h() ? "0" : "var(--size-8) 0"
    });
  }), e.append(a, Z), e.pop();
}
e.from_html('<span class="toast-count svelte-17ll3xi"> </span>');
e.from_html('<div class="toast-separator svelte-17ll3xi"></div>');
e.from_html('<div><div data-testid="toast-text"><!></div></div> <!>', 1);
e.from_html('<div class="toast-messages svelte-17ll3xi"></div>');
e.from_html("<div></div>");
e.from_html('<div role="status" aria-live="polite" data-testid="toast-body"><div class="toast-header svelte-17ll3xi" role="button" tabindex="0"><div><!></div> <div class="toast-title-row svelte-17ll3xi"><span> <!></span> <div><!></div></div> <button type="button" aria-label="Close" data-testid="toast-close"><span aria-hidden="true">&#215;</span></button></div> <!> <!></div>');
e.from_html('<div class="toast-item svelte-l56nvb"><!></div>');
e.from_html('<div class="toast-wrap svelte-l56nvb"></div>');
var bs = e.from_html('<div class="streaming-bar svelte-xj6qzf"></div>');
function xs(a, t) {
  let r = e.prop(t, "time_limit", 8);
  var n = e.comment(), s = e.first_child(n);
  {
    var i = (o) => {
      var l = bs();
      let c;
      e.template_effect(() => c = e.set_style(l, "", c, { "animation-duration": `${r() ?? ""}s` })), e.append(o, l);
    };
    e.if(s, (o) => {
      r() && o(i);
    });
  }
  e.append(a, n);
}
const gt = (a, t, r) => Math.min(Math.max(a, t), r);
class ks {
  constructor(t, r) {
    this.stopDrag = () => {
      this.pointersCache.size === 0 ? (this.isDragging = !1, document.removeEventListener("pointermove", this.handleDrag), document.removeEventListener("pointerup", this.stopDrag)) : this.pointersCache.size === 1 && (this.isDragging = !0, this.startDragX = this.pointersCache.values().next().value.clientX, this.startDragY = this.pointersCache.values().next().value.clientY);
    }, this.handleDrag = (n) => {
      if (this.isDragging && this.pointersCache.size === 1) {
        if (this.scale == 1) {
          this.offsetX = (this.canvasWidth - this.imageWidth) / 2, this.offsetY = 0, this.renderCallBack();
          return;
        }
        let s = n.clientX - this.startDragX, i = n.clientY - this.startDragY;
        this.imageWidth * this.scale > this.canvasWidth ? s = gt(s, this.canvasWidth - this.offsetX - this.imageWidth * this.scale, -this.offsetX) : s = gt(s, -this.offsetX, this.canvasWidth - this.offsetX - this.imageWidth * this.scale), this.imageHeight * this.scale > this.canvasHeight ? i = gt(i, this.canvasHeight - this.offsetY - this.imageHeight * this.scale, -this.offsetY) : i = gt(i, -this.offsetY, this.canvasHeight - this.offsetY - this.imageHeight * this.scale), this.offsetX += s, this.offsetY += i, this.startDragX = n.clientX, this.startDragY = n.clientY, this.renderCallBack();
      }
    }, this.renderCallBack = t, this.pointersCache = r, this.scale = 1, this.offsetX = 0, this.offsetY = 0, this.canvasWidth = 0, this.canvasHeight = 0, this.imageWidth = 0, this.imageHeight = 0, this.imageRotatedWidth = 0, this.imageRotatedHeight = 0, this.isDragging = !1, this.startDragX = 0, this.startDragY = 0, this.orientation = 0;
  }
  startDrag(t) {
    this.isDragging = !0, this.startDragX = t.clientX, this.startDragY = t.clientY, document.addEventListener("pointermove", this.handleDrag), document.addEventListener("pointerup", this.stopDrag);
  }
  setRotatedImage(t) {
    t !== null && (this.orientation == 0 || this.orientation == 2 ? (this.imageRotatedWidth = t.width, this.imageRotatedHeight = t.height) : (this.imageRotatedWidth = t.height, this.imageRotatedHeight = t.width));
  }
  resize(t, r, n = 0, s = 0) {
    this.canvasWidth == t && this.canvasHeight == r || (this.canvasWidth = t, this.canvasHeight = r, this.scale = 1, this.offsetX = n, this.offsetY = s);
  }
}
const Fe = (a, t, r) => Math.min(Math.max(a, t), r);
function Rt(a, t) {
  if (a.startsWith("rgba"))
    return a.replace(/[\d.]+$/, t.toString());
  const r = a.match(/\d+/g);
  if (!r || r.length !== 3)
    return `rgba(50, 50, 50, ${t})`;
  const [n, s, i] = r;
  return `rgba(${n}, ${s}, ${i}, ${t})`;
}
class It {
  constructor(t, r, n, s, i, o, l, c, w, h, _, b, D, T = "rgb(255, 255, 255)", E = 0.5, k = 25, y = 8, d = 2, p = 4, v = 1) {
    this.stopDrag = () => {
      this.isDragging = !1, document.removeEventListener("pointermove", this.handleDrag), document.removeEventListener("pointerup", this.stopDrag);
    }, this.handleDrag = (u) => {
      if (this.isDragging && this.pointersCache.size === 1) {
        let f = (u.clientX - this.offsetMouseX) / this.canvasWindow.scale - this._xmin, g = (u.clientY - this.offsetMouseY) / this.canvasWindow.scale - this._ymin;
        const x = (this.canvasXmax - this.canvasXmin) / this.canvasWindow.scale, m = (this.canvasYmax - this.canvasYmin) / this.canvasWindow.scale;
        f = Fe(f, -this._xmin, x - this._xmax), g = Fe(g, -this._ymin, m - this._ymax), this._xmin += f, this._ymin += g, this._xmax += f, this._ymax += g, this.applyUserScale(), this.renderCallBack();
      }
    }, this.handleCreating = (u) => {
      if (this.isCreating && this.pointersCache.size === 1) {
        let [f, g] = this.toBoxCoordinates(u.clientX, u.clientY);
        f = (f - this.offsetMouseX) / this.canvasWindow.scale, g = (g - this.offsetMouseY) / this.canvasWindow.scale, f > this._xmax ? (this.creatingAnchorX == "xmax" && (this._xmin = this._xmax), this._xmax = f, this.creatingAnchorX = "xmin") : f > this._xmin && f < this._xmax && this.creatingAnchorX == "xmin" ? this._xmax = f : f > this._xmin && f < this._xmax && this.creatingAnchorX == "xmax" ? this._xmin = f : f < this._xmin && (this.creatingAnchorX == "xmin" && (this._xmax = this._xmin), this._xmin = f, this.creatingAnchorX = "xmax"), g > this._ymax ? (this.creatingAnchorY == "ymax" && (this._ymin = this._ymax), this._ymax = g, this.creatingAnchorY = "ymin") : g > this._ymin && g < this._ymax && this.creatingAnchorY == "ymin" ? this._ymax = g : g > this._ymin && g < this._ymax && this.creatingAnchorY == "ymax" ? this._ymin = g : g < this._ymin && (this.creatingAnchorY == "ymin" && (this._ymax = this._ymin), this._ymin = g, this.creatingAnchorY = "ymax"), this.applyUserScale(), this.renderCallBack();
      }
    }, this.stopCreating = (u) => {
      if (this.isCreating = !1, document.removeEventListener("pointermove", this.handleCreating), document.removeEventListener("pointerup", this.stopCreating), this.getArea() > 0) {
        const f = (this.canvasXmax - this.canvasXmin) / this.canvasWindow.scale, g = (this.canvasYmax - this.canvasYmin) / this.canvasWindow.scale;
        this._xmin = Fe(this._xmin, 0, f - this.minSize), this._ymin = Fe(this._ymin, 0, g - this.minSize), this._xmax = Fe(this._xmax, this.minSize, f), this._ymax = Fe(this._ymax, this.minSize, g), this.minSize > 0 && (this.getWidth() / this.canvasWindow.scale < this.minSize && (this.creatingAnchorX == "xmin" ? this._xmax = this._xmin + this.minSize : this._xmin = this._xmax - this.minSize), this.getHeight() / this.canvasWindow.scale < this.minSize && (this.creatingAnchorY == "ymin" ? this._ymax = this._ymin + this.minSize : this._ymin = this._ymax - this.minSize), this._xmax > f ? (this._xmin -= this._xmax - f, this._xmax = f) : this._xmin < 0 && (this._xmax -= this._xmin, this._xmin = 0), this._ymax > g ? (this._ymin -= this._ymax - g, this._ymax = g) : this._ymin < 0 && (this._ymax -= this._ymin, this._ymin = 0)), this.applyUserScale(), this.renderCallBack();
      }
      this.onFinishCreation();
    }, this.handleResize = (u) => {
      if (this.isResizing && this.pointersCache.size === 1) {
        const f = u.clientX, g = u.clientY, x = (f - this.offsetMouseX - this.resizeHandles[this.resizingHandleIndex].xmin) / this.canvasWindow.scale, m = (g - this.offsetMouseY - this.resizeHandles[this.resizingHandleIndex].ymin) / this.canvasWindow.scale, F = (this.canvasXmax - this.canvasXmin) / this.canvasWindow.scale, B = (this.canvasYmax - this.canvasYmin) / this.canvasWindow.scale;
        switch (this.resizingHandleIndex) {
          case 0:
            this._xmin += x, this._ymin += m, this._xmin = Fe(this._xmin, 0, this._xmax - this.minSize), this._ymin = Fe(this._ymin, 0, this._ymax - this.minSize);
            break;
          case 1:
            this._xmax += x, this._ymin += m, this._xmax = Fe(this._xmax, this._xmin + this.minSize, F), this._ymin = Fe(this._ymin, 0, this._ymax - this.minSize);
            break;
          case 2:
            this._xmax += x, this._ymax += m, this._xmax = Fe(this._xmax, this._xmin + this.minSize, F), this._ymax = Fe(this._ymax, this._ymin + this.minSize, B);
            break;
          case 3:
            this._xmin += x, this._ymax += m, this._xmin = Fe(this._xmin, 0, this._xmax - this.minSize), this._ymax = Fe(this._ymax, this._ymin + this.minSize, B);
            break;
          case 4:
            this._ymin += m, this._ymin = Fe(this._ymin, 0, this._ymax - this.minSize);
            break;
          case 5:
            this._xmax += x, this._xmax = Fe(this._xmax, this._xmin + this.minSize, F);
            break;
          case 6:
            this._ymax += m, this._ymax = Fe(this._ymax, this._ymin + this.minSize, B);
            break;
          case 7:
            this._xmin += x, this._xmin = Fe(this._xmin, 0, this._xmax - this.minSize);
            break;
        }
        this.applyUserScale(), this.renderCallBack();
      }
    }, this.stopResize = () => {
      this.isResizing = !1, document.removeEventListener("pointermove", this.handleResize), document.removeEventListener("pointerup", this.stopResize);
    }, this.renderCallBack = t, this.onFinishCreation = r, this.canvasWindow = n, this.pointersCache = s, this.canvasXmin = i, this.canvasYmin = o, this.canvasXmax = l, this.canvasYmax = c, this.scaleFactor = v, this.label = w, this.isDragging = !1, this.isCreating = !1, this._xmin = h, this._ymin = _, this._xmax = b, this._ymax = D, this.xmin = this._xmin * this.canvasWindow.scale, this.ymin = this._ymin * this.canvasWindow.scale, this.xmax = this._xmax * this.canvasWindow.scale, this.ymax = this._ymax * this.canvasWindow.scale, this.isResizing = !1, this.isSelected = !1, this.offsetMouseX = 0, this.offsetMouseY = 0, this.resizeHandleSize = y, this.thickness = d, this.selectedThickness = p, this.updateHandles(), this.resizingHandleIndex = -1, this.minSize = k, this.color = T, this.alpha = E, this.creatingAnchorX = "xmin", this.creatingAnchorY = "ymin";
  }
  toJSON() {
    return {
      label: this.label,
      xmin: this._xmin,
      ymin: this._ymin,
      xmax: this._xmax,
      ymax: this._ymax,
      color: this.color,
      scaleFactor: this.scaleFactor
    };
  }
  setSelected(t) {
    this.isSelected = t;
  }
  setScaleFactor(t) {
    let r = t / this.scaleFactor;
    this._xmin = Math.round(this._xmin * r), this._ymin = Math.round(this._ymin * r), this._xmax = Math.round(this._xmax * r), this._ymax = Math.round(this._ymax * r), this.applyUserScale(), this.scaleFactor = t;
  }
  updateHandles() {
    const t = this.resizeHandleSize / 2, r = this.getWidth(), n = this.getHeight();
    this.resizeHandles = [
      {
        // Top left
        xmin: this.xmin - t,
        ymin: this.ymin - t,
        xmax: this.xmin + t,
        ymax: this.ymin + t,
        cursor: "nwse-resize"
      },
      {
        // Top right
        xmin: this.xmax - t,
        ymin: this.ymin - t,
        xmax: this.xmax + t,
        ymax: this.ymin + t,
        cursor: "nesw-resize"
      },
      {
        // Bottom right
        xmin: this.xmax - t,
        ymin: this.ymax - t,
        xmax: this.xmax + t,
        ymax: this.ymax + t,
        cursor: "nwse-resize"
      },
      {
        // Bottom left
        xmin: this.xmin - t,
        ymin: this.ymax - t,
        xmax: this.xmin + t,
        ymax: this.ymax + t,
        cursor: "nesw-resize"
      },
      {
        // Top center
        xmin: this.xmin + r / 2 - t,
        ymin: this.ymin - t,
        xmax: this.xmin + r / 2 + t,
        ymax: this.ymin + t,
        cursor: "ns-resize"
      },
      {
        // Right center
        xmin: this.xmax - t,
        ymin: this.ymin + n / 2 - t,
        xmax: this.xmax + t,
        ymax: this.ymin + n / 2 + t,
        cursor: "ew-resize"
      },
      {
        // Bottom center
        xmin: this.xmin + r / 2 - t,
        ymin: this.ymax - t,
        xmax: this.xmin + r / 2 + t,
        ymax: this.ymax + t,
        cursor: "ns-resize"
      },
      {
        // Left center
        xmin: this.xmin - t,
        ymin: this.ymin + n / 2 - t,
        xmax: this.xmin + t,
        ymax: this.ymin + n / 2 + t,
        cursor: "ew-resize"
      }
    ];
  }
  getWidth() {
    return this.xmax - this.xmin;
  }
  getHeight() {
    return this.ymax - this.ymin;
  }
  getArea() {
    return this.getWidth() * this.getHeight();
  }
  toCanvasCoordinates(t, r) {
    return t = t + this.canvasXmin, r = r + this.canvasYmin, [t, r];
  }
  toBoxCoordinates(t, r) {
    return t = t - this.canvasXmin, r = r - this.canvasYmin, [t, r];
  }
  applyUserScale() {
    this.xmin = this._xmin * this.canvasWindow.scale, this.ymin = this._ymin * this.canvasWindow.scale, this.xmax = this._xmax * this.canvasWindow.scale, this.ymax = this._ymax * this.canvasWindow.scale, this.updateHandles();
  }
  updateOffset() {
    this.canvasXmin = this.canvasWindow.offsetX, this.canvasYmin = this.canvasWindow.offsetY, this.canvasXmax = this.canvasWindow.offsetX + this.canvasWindow.imageWidth * this.canvasWindow.scale, this.canvasYmax = this.canvasWindow.offsetY + this.canvasWindow.imageHeight * this.canvasWindow.scale, this.applyUserScale();
  }
  render(t) {
    let r, n;
    if (this.updateOffset(), t.beginPath(), [r, n] = this.toCanvasCoordinates(this.xmin, this.ymin), t.rect(r, n, this.getWidth(), this.getHeight()), t.fillStyle = Rt(this.color, this.alpha), t.fill(), this.isSelected ? t.lineWidth = this.selectedThickness : t.lineWidth = this.thickness, t.strokeStyle = Rt(this.color, 1), t.stroke(), t.closePath(), this.label !== null && this.label.trim() !== "") {
      this.isSelected ? t.font = "bold 14px Arial" : t.font = "12px Arial";
      const s = t.measureText(this.label).width + 10, i = 20;
      let o = this.xmin, l = this.ymin - i;
      t.fillStyle = "white", [o, l] = this.toCanvasCoordinates(o, l), t.fillRect(o, l, s, i), t.lineWidth = 1, t.strokeStyle = "black", t.strokeRect(o, l, s, i), t.fillStyle = "black", t.fillText(this.label, o + 5, l + 15);
    }
    t.fillStyle = Rt(this.color, 1);
    for (const s of this.resizeHandles)
      [r, n] = this.toCanvasCoordinates(s.xmin, s.ymin), t.fillRect(
        r,
        n,
        s.xmax - s.xmin,
        s.ymax - s.ymin
      );
  }
  startDrag(t) {
    this.isDragging = !0, this.offsetMouseX = t.clientX - this._xmin * this.canvasWindow.scale, this.offsetMouseY = t.clientY - this._ymin * this.canvasWindow.scale, document.addEventListener("pointermove", this.handleDrag), document.addEventListener("pointerup", this.stopDrag);
  }
  isPointInsideBox(t, r) {
    return [t, r] = this.toBoxCoordinates(t, r), t >= this.xmin && t <= this.xmax && r >= this.ymin && r <= this.ymax;
  }
  indexOfPointInsideHandle(t, r) {
    [t, r] = this.toBoxCoordinates(t, r);
    for (let n = 0; n < this.resizeHandles.length; n++) {
      const s = this.resizeHandles[n];
      if (t >= s.xmin && t <= s.xmax && r >= s.ymin && r <= s.ymax)
        return this.resizingHandleIndex = n, n;
    }
    return -1;
  }
  startCreating(t, r, n) {
    this.isCreating = !0, this.offsetMouseX = r, this.offsetMouseY = n, document.addEventListener("pointermove", this.handleCreating), document.addEventListener("pointerup", this.stopCreating);
  }
  startResize(t, r) {
    this.resizingHandleIndex = t, this.isResizing = !0, this.offsetMouseX = r.clientX - this.resizeHandles[t].xmin, this.offsetMouseY = r.clientY - this.resizeHandles[t].ymin, document.addEventListener("pointermove", this.handleResize), document.addEventListener("pointerup", this.stopResize);
  }
  onRotate(t) {
    const [r, n, s, i] = [this._xmin, this._xmax, this._ymin, this._ymax];
    switch (t) {
      case 1:
        this._xmin = this.canvasWindow.imageWidth - i, this._xmax = this.canvasWindow.imageWidth - s, this._ymin = r, this._ymax = n;
        break;
      case -1:
        this._xmin = s, this._xmax = i, this._ymin = this.canvasWindow.imageHeight - n, this._ymax = this.canvasWindow.imageHeight - r;
        break;
    }
    this.applyUserScale();
  }
}
class Er {
  constructor() {
    this.boxes = [], this.orientation = 0;
  }
}
const ys = "WORKER_PROXY_CONTEXT_KEY";
function hn() {
  return Sr(ys);
}
function Cs(a) {
  return a.host === window.location.host || a.host === "localhost:7860" || a.host === "127.0.0.1:7860" || // Ref: https://github.com/gradio-app/gradio/blob/v3.32.0/js/app/src/Index.svelte#L194
  a.host === "lite.local";
}
function gn(a, t) {
  const r = t.toLowerCase();
  for (const [n, s] of Object.entries(a))
    if (n.toLowerCase() === r)
      return s;
}
function Ds(a) {
  if (a == null)
    return !1;
  const t = new URL(a, window.location.href);
  return !(!Cs(t) || t.protocol !== "http:" && t.protocol !== "https:");
}
async function Fr(a) {
  if (a == null || !Ds(a))
    return a;
  const t = hn();
  if (t == null)
    return a;
  const n = new URL(a, window.location.href).pathname;
  return t.httpRequest({
    method: "GET",
    path: n,
    headers: {},
    query_string: ""
  }).then((s) => {
    if (s.status !== 200)
      throw new Error(`Failed to get file ${n} from the Wasm worker.`);
    const i = new Blob([s.body], {
      type: gn(s.headers, "content-type")
    });
    return URL.createObjectURL(i);
  });
}
var Es = e.from_html("<a><!></a>"), Fs = e.from_html("<a><!></a>");
function As(a, t) {
  const r = e.legacy_rest_props(t, ["children", "$$slots", "$$events", "$$legacy"]), n = e.legacy_rest_props(r, ["href", "download"]);
  e.push(t, !1);
  var s = this && this.__awaiter || function(E, k, y, d) {
    function p(v) {
      return v instanceof y ? v : new y(function(u) {
        u(v);
      });
    }
    return new (y || (y = Promise))(function(v, u) {
      function f(m) {
        try {
          x(d.next(m));
        } catch (F) {
          u(F);
        }
      }
      function g(m) {
        try {
          x(d.throw(m));
        } catch (F) {
          u(F);
        }
      }
      function x(m) {
        m.done ? v(m.value) : p(m.value).then(f, g);
      }
      x((d = d.apply(E, k || [])).next());
    });
  };
  let i = e.prop(t, "href", 8, void 0), o = e.prop(t, "download", 8);
  const l = Re();
  let c = e.mutable_source(!1);
  const w = hn();
  function h() {
    return s(this, void 0, void 0, function* () {
      if (e.get(c))
        return;
      if (l("click"), i() == null)
        throw new Error("href is not defined.");
      if (w == null)
        throw new Error("Wasm worker proxy is not available.");
      const k = new URL(i(), window.location.href).pathname;
      e.set(c, !0), w.httpRequest({ method: "GET", path: k, headers: {}, query_string: "" }).then((y) => {
        if (y.status !== 200)
          throw new Error(`Failed to get file ${k} from the Wasm worker.`);
        const d = new Blob([y.body], { type: gn(y.headers, "content-type") }), p = URL.createObjectURL(d), v = document.createElement("a");
        v.href = p, v.download = o(), v.click(), URL.revokeObjectURL(p);
      }).finally(() => {
        e.set(c, !1);
      });
    });
  }
  e.init();
  var _ = e.comment(), b = e.first_child(_);
  {
    var D = (E) => {
      var k = e.comment(), y = e.first_child(k);
      {
        var d = (v) => {
          var u = e.comment(), f = e.first_child(u);
          e.slot(f, t, "default", {}, null), e.append(v, u);
        }, p = (v) => {
          var u = Es();
          e.attribute_effect(u, () => ({ ...n, href: i() }));
          var f = e.child(u);
          e.slot(f, t, "default", {}, null), e.reset(u), e.event("click", u, e.preventDefault(h)), e.append(v, u);
        };
        e.if(y, (v) => {
          e.get(c) ? v(d) : v(p, !1);
        });
      }
      e.append(E, k);
    }, T = (E) => {
      var k = Fs(), y = e.derived(() => l.bind(null, "click"));
      e.attribute_effect(k, () => ({
        href: i(),
        target: e.untrack(() => typeof window < "u" && window.__is_colab__ ? "_blank" : null),
        rel: "noopener noreferrer",
        download: o(),
        ...n
      }));
      var d = e.child(k);
      e.slot(d, t, "default", {}, null), e.reset(k), e.event("click", k, function(...p) {
        e.get(y)?.apply(this, p);
      }), e.append(E, k);
    };
    e.if(b, (E) => {
      e.deep_read_state(i()), e.untrack(() => w && should_proxy_wasm_src(i())) ? E(D) : E(T, !1);
    });
  }
  e.append(a, _), e.pop();
}
async function fn(a, t) {
  return a.map(
    (r) => new Ls({
      path: r.name,
      orig_name: r.name,
      blob: r,
      size: r.size,
      mime_type: r.type,
      is_stream: t
    })
  );
}
class Ls {
  path;
  url;
  orig_name;
  size;
  blob;
  is_stream;
  mime_type;
  alt_text;
  b64;
  meta = { _type: "gradio.FileData" };
  constructor({
    path: t,
    url: r,
    orig_name: n,
    size: s,
    blob: i,
    is_stream: o,
    mime_type: l,
    alt_text: c,
    b64: w
  }) {
    this.path = t, this.url = r, this.orig_name = n, this.size = s, this.blob = r ? void 0 : i, this.is_stream = o, this.mime_type = l, this.alt_text = c, this.b64 = w;
  }
}
typeof process < "u" && process.versions && process.versions.node;
class tl extends TransformStream {
  #e = "";
  /** Constructs a new instance. */
  constructor(t = { allowCR: !1 }) {
    super({
      transform: (r, n) => {
        for (r = this.#e + r; ; ) {
          const s = r.indexOf(`
`), i = t.allowCR ? r.indexOf("\r") : -1;
          if (i !== -1 && i !== r.length - 1 && (s === -1 || s - 1 > i)) {
            n.enqueue(r.slice(0, i)), r = r.slice(i + 1);
            continue;
          }
          if (s === -1)
            break;
          const o = r[s - 1] === "\r" ? s - 1 : s;
          n.enqueue(r.slice(0, o)), r = r.slice(s + 1);
        }
        this.#e = r;
      },
      flush: (r) => {
        if (this.#e === "")
          return;
        const n = t.allowCR && this.#e.endsWith("\r") ? this.#e.slice(0, -1) : this.#e;
        r.enqueue(n);
      }
    });
  }
}
var Ms = e.from_html('<div class="file svelte-12marlv"><span><div class="progress-bar svelte-12marlv"><progress style="visibility:hidden;height:0;width:0;" max="100" class="svelte-12marlv"> </progress></div></span> <span class="file-name svelte-12marlv"> </span></div>'), Bs = e.from_html('<div><span class="uploading svelte-12marlv"> </span> <!></div>');
function Ss(a, t) {
  e.push(t, !0);
  var r = this && this.__awaiter || function(y, d, p, v) {
    function u(f) {
      return f instanceof p ? f : new p(function(g) {
        g(f);
      });
    }
    return new (p || (p = Promise))(function(f, g) {
      function x(B) {
        try {
          F(v.next(B));
        } catch (C) {
          g(C);
        }
      }
      function m(B) {
        try {
          F(v.throw(B));
        } catch (C) {
          g(C);
        }
      }
      function F(B) {
        B.done ? f(B.value) : u(B.value).then(x, m);
      }
      F((v = v.apply(y, d || [])).next());
    });
  };
  let n, s = e.state(!1), i = e.state(void 0), o = e.derived(() => e.get(i) || e.get(l)[0]), l = e.state(e.proxy(t.files.map((y) => Object.assign(Object.assign({}, y), { progress: 0 }))));
  function c(y, d) {
    e.set(
      l,
      e.get(l).map((p) => (p.orig_name === y && (p.progress += d), p)),
      !0
    );
  }
  function w(y) {
    return y.progress * 100 / (y.size || 0) || 0;
  }
  Je(() => r(void 0, void 0, void 0, function* () {
    if (n = yield t.stream_handler(new URL(`${t.root}/gradio_api/upload_progress?upload_id=${t.upload_id}`)), n == null)
      throw new Error("Event source is not defined");
    n.onmessage = function(y) {
      return r(this, void 0, void 0, function* () {
        const d = JSON.parse(y.data);
        e.get(s) || e.set(s, !0), d.msg === "done" ? (n?.close(), t.ondone === null || t.ondone === void 0 || t.ondone()) : (e.set(i, d, !0), c(d.orig_name, d.chunk_size));
      });
    };
  })), Tr(() => {
    (n != null || n != null) && n.close();
  });
  function h(y) {
    let d = 0;
    return y.forEach((p) => {
      d += w(p);
    }), document.documentElement.style.setProperty("--upload-progress-width", (d / y.length).toFixed(2) + "%"), d / y.length;
  }
  e.user_effect(() => {
    h(e.get(l));
  });
  var _ = Bs();
  let b;
  var D = e.child(_), T = e.child(D);
  e.reset(D);
  var E = e.sibling(D, 2);
  {
    var k = (y) => {
      var d = Ms(), p = e.child(d), v = e.child(p), u = e.child(v), f = e.child(u, !0);
      e.reset(u), e.reset(v), e.reset(p);
      var g = e.sibling(p, 2), x = e.child(g, !0);
      e.reset(g), e.reset(d), e.template_effect(
        (m, F) => {
          e.set_value(u, m), e.set_text(f, F), e.set_text(x, e.get(o).orig_name);
        },
        [
          () => w(e.get(o)),
          () => w(e.get(o))
        ]
      ), e.append(y, d);
    };
    e.if(E, (y) => {
      e.get(o) && y(k);
    });
  }
  e.reset(_), e.template_effect(() => {
    b = e.set_class(_, 1, "wrap svelte-12marlv", null, b, { progress: e.get(s) }), e.set_text(T, `Uploading ${e.get(l).length ?? ""}
		${e.get(l).length > 1 ? "files" : "file"}...`);
  }), e.append(a, _), e.pop();
}
function Ts() {
  let a, t;
  return {
    drag(r, n = {}) {
      t = n;
      function s() {
        a = document.createElement("input"), a.type = "file", a.style.display = "none", a.setAttribute("aria-label", "File upload"), a.setAttribute("data-testid", "file-upload");
        const _ = Array.isArray(t.accepted_types) ? t.accepted_types.join(",") : t.accepted_types || void 0;
        _ && (a.accept = _), a.multiple = t.mode === "multiple" || !1, t.mode === "directory" && (a.webkitdirectory = !0, a.setAttribute("directory", ""), a.setAttribute("mozdirectory", "")), r.appendChild(a);
      }
      s();
      function i(_) {
        _.preventDefault(), _.stopPropagation();
      }
      function o(_) {
        _.preventDefault(), _.stopPropagation(), t.on_drag_change?.(!0);
      }
      function l(_) {
        _.preventDefault(), _.stopPropagation(), t.on_drag_change?.(!1);
      }
      function c(_) {
        if (_.preventDefault(), _.stopPropagation(), t.on_drag_change?.(!1), !_.dataTransfer?.files)
          return;
        const b = Array.from(_.dataTransfer.files);
        b.length > 0 && t.on_files?.(b);
      }
      function w() {
        t.disable_click || (a.value = "", a.click());
      }
      function h() {
        if (a.files) {
          const _ = Array.from(a.files);
          _.length > 0 && t.on_files?.(_);
        }
      }
      return r.addEventListener("drag", i), r.addEventListener("dragstart", i), r.addEventListener("dragend", i), r.addEventListener("dragover", i), r.addEventListener("dragenter", o), r.addEventListener("dragleave", l), r.addEventListener("drop", c), r.addEventListener("click", w), a.addEventListener("change", h), {
        update(_) {
          t = _, a.remove(), s(), a.addEventListener("change", h);
        },
        destroy() {
          r.removeEventListener("drag", i), r.removeEventListener("dragstart", i), r.removeEventListener("dragend", i), r.removeEventListener("dragover", i), r.removeEventListener("dragenter", o), r.removeEventListener("dragleave", l), r.removeEventListener("drop", c), r.removeEventListener("click", w), a.removeEventListener("change", h), a.remove();
        }
      };
    },
    open_file_upload() {
      a && (a.value = "", a.click());
    }
  };
}
var zs = e.from_html("<button><!></button>"), Rs = e.from_html('<button aria-dropeffect="copy"><!></button>');
function Is(a, t) {
  e.push(t, !0);
  var r = this && this.__awaiter || function(z, S, L, A) {
    function V(P) {
      return P instanceof L ? P : new L(function(K) {
        K(P);
      });
    }
    return new (L || (L = Promise))(function(P, K) {
      function de(Ce) {
        try {
          we(A.next(Ce));
        } catch (_e) {
          K(_e);
        }
      }
      function ve(Ce) {
        try {
          we(A.throw(Ce));
        } catch (_e) {
          K(_e);
        }
      }
      function we(Ce) {
        Ce.done ? P(Ce.value) : V(Ce.value).then(de, ve);
      }
      we((A = A.apply(z, S || [])).next());
    });
  };
  const { drag: n, open_file_upload: s } = Ts();
  let i = e.prop(t, "filetype", 3, null), o = e.prop(t, "dragging", 15, !1), l = e.prop(t, "boundedheight", 3, !0), c = e.prop(t, "center", 3, !0), w = e.prop(t, "flex", 3, !0), h = e.prop(t, "file_count", 3, "single"), _ = e.prop(t, "disable_click", 3, !1), b = e.prop(t, "hidden", 3, !1), D = e.prop(t, "format", 3, "file"), T = e.prop(t, "uploading", 15, !1), E = e.prop(t, "show_progress", 3, !0), k = e.prop(t, "max_file_size", 3, null), y = e.prop(t, "icon_upload", 3, !1), d = e.prop(t, "height", 3, void 0), p = e.prop(t, "aria_label", 3, void 0), v = e.prop(t, "upload_promise", 15);
  function u() {
    s();
  }
  let f = "", g, x = e.state(null), m = null, B = (() => {
    if (typeof navigator < "u") {
      const z = navigator.userAgent.toLowerCase();
      return z.indexOf("iphone") > -1 || z.indexOf("ipad") > -1;
    }
    return !1;
  })();
  const C = ["image", "video", "audio", "text", "file"], O = (z) => B && z.startsWith(".") ? (m = !0, z) : B && z.includes("file/*") ? "*" : z.startsWith(".") || z.endsWith("/*") ? z : C.includes(z) ? z + "/*" : "." + z;
  e.user_effect(() => {
    if (i() == null)
      e.set(x, null);
    else if (typeof i() == "string")
      e.set(x, O(i()), !0);
    else if (B && i().includes("file/*"))
      e.set(x, "*");
    else {
      const z = i().map(O);
      e.set(x, z.join(", "), !0);
    }
  });
  function N() {
    navigator.clipboard.read().then((z) => r(this, void 0, void 0, function* () {
      for (let S = 0; S < z.length; S++) {
        const L = z[S].types.find((A) => A.startsWith("image/"));
        if (L) {
          z[S].getType(L).then((A) => r(this, void 0, void 0, function* () {
            const V = new File([A], `clipboard.${L.replace("image/", "")}`);
            yield R([V]);
          }));
          break;
        }
      }
    }));
  }
  function ie() {
    s();
  }
  function H(z, S) {
    return r(this, void 0, void 0, function* () {
      return S ? f = S : f = Math.random().toString(36).substring(2, 15), yield xt(), T(!0), v(new Promise((L) => r(this, void 0, void 0, function* () {
        try {
          const A = yield t.upload(z, t.root, f, k() !== null && k() !== void 0 ? k() : 1 / 0);
          t.onload === null || t.onload === void 0 || t.onload(h() === "single" ? A?.[0] : A), L(A || []), T(!1);
        } catch (A) {
          t.onerror === null || t.onerror === void 0 || t.onerror(A.message), T(!1), L([]);
        }
      }))), v();
    });
  }
  function Z(z, S, L) {
    if (!z || z === "*" || z === "file/*" || Array.isArray(z) && z.some((V) => V === "*" || V === "file/*"))
      return !0;
    let A;
    if (typeof z == "string")
      A = z.split(",").map((V) => V.trim());
    else if (Array.isArray(z))
      A = z;
    else
      return !1;
    return A.includes(S) || A.some((V) => {
      const [P] = V.split("/").map((K) => K.trim());
      return V.endsWith("/*") && L.startsWith(P + "/");
    });
  }
  function R(z, S) {
    return r(this, void 0, void 0, function* () {
      if (!z.length)
        return;
      let L = z.map((A) => new File([A], A instanceof File ? A.name : "file", { type: A.type }));
      return B && m && (L = L.filter((A) => G(A) ? !0 : (t.onerror === null || t.onerror === void 0 || t.onerror(`Invalid file type: ${A.name}. Only ${i()} allowed.`), !1)), L.length === 0) ? [] : (g = yield fn(L), yield H(g, S));
    });
  }
  function G(z) {
    return i() ? (Array.isArray(i()) ? i() : [i()]).some((L) => {
      const A = O(L);
      if (A.startsWith("."))
        return z.name.toLowerCase().endsWith(A.toLowerCase());
      if (A === "*")
        return !0;
      if (A.endsWith("/*")) {
        const [V] = A.split("/");
        return z.type.startsWith(V + "/");
      }
      return z.type === A;
    }) : !0;
  }
  function ae(z) {
    return r(this, void 0, void 0, function* () {
      const S = z.filter((L) => {
        const A = "." + L.name.toLowerCase().split(".").pop();
        return A && Z(e.get(x), A, L.type) || (A && Array.isArray(i()) ? i().includes(A) : A === i()) ? !0 : (t.onerror === null || t.onerror === void 0 || t.onerror(`Invalid file type only ${i()} allowed.`), !1);
      });
      if (D() != "blob")
        yield R(S);
      else {
        if (h() === "single") {
          t.onload === null || t.onload === void 0 || t.onload(S[0]);
          return;
        }
        t.onload === null || t.onload === void 0 || t.onload(S);
      }
    });
  }
  function $(z) {
    return r(this, void 0, void 0, function* () {
      var S;
      if (o(!1), !(!((S = z.dataTransfer) === null || S === void 0) && S.files)) return;
      const L = Array.from(z.dataTransfer.files).filter(G);
      if (D() != "blob")
        yield R(L);
      else {
        if (h() === "single") {
          t.onload === null || t.onload === void 0 || t.onload(L[0]);
          return;
        }
        t.onload === null || t.onload === void 0 || t.onload(L);
      }
    });
  }
  var te = {
    open_upload: u,
    paste_clipboard: N,
    open_file_upload: ie,
    load_files: R,
    load_files_from_drop: $
  }, Q = e.comment(), re = e.first_child(Q);
  {
    var Y = (z) => {
      var S = zs();
      S.__click = N;
      let L, A;
      var V = e.child(S);
      {
        var P = (K) => {
          var de = e.comment(), ve = e.first_child(de);
          e.snippet(ve, () => t.children), e.append(K, de);
        };
        e.if(V, (K) => {
          t.children && K(P);
        });
      }
      e.reset(S), e.template_effect(() => {
        e.set_attribute(S, "tabindex", b() ? -1 : 0), e.set_attribute(S, "aria-label", p() || "Paste from clipboard"), L = e.set_class(S, 1, "svelte-tgi0k0", null, L, {
          hidden: b(),
          center: c(),
          boundedheight: l(),
          flex: w(),
          "icon-mode": y()
        }), A = e.set_style(S, "", A, {
          height: y() ? "" : d() ? typeof d() == "number" ? d() + "px" : d() : "100%"
        });
      }), e.append(z, S);
    }, ne = (z) => {
      var S = e.comment(), L = e.first_child(S);
      {
        var A = (P) => {
          var K = e.comment(), de = e.first_child(K);
          {
            var ve = (we) => {
              Ss(we, {
                get root() {
                  return t.root;
                },
                get upload_id() {
                  return f;
                },
                get files() {
                  return g;
                },
                get stream_handler() {
                  return t.stream_handler;
                }
              });
            };
            e.if(de, (we) => {
              b() || we(ve);
            });
          }
          e.append(P, K);
        }, V = (P) => {
          var K = Rs();
          let de, ve;
          var we = e.child(K);
          {
            var Ce = (_e) => {
              var De = e.comment(), he = e.first_child(De);
              e.snippet(he, () => t.children), e.append(_e, De);
            };
            e.if(we, (_e) => {
              t.children && _e(Ce);
            });
          }
          e.reset(K), e.action(K, (_e, De) => n?.(_e, De), () => ({
            on_drag_change: (_e) => o(_e),
            on_files: (_e) => ae(_e),
            accepted_types: e.get(x),
            mode: h(),
            disable_click: _()
          })), e.template_effect(() => {
            e.set_attribute(K, "tabindex", b() ? -1 : 0), e.set_attribute(K, "aria-label", p() || "Click to upload or drop files"), de = e.set_class(K, 1, "svelte-tgi0k0", null, de, {
              hidden: b(),
              center: c(),
              boundedheight: l(),
              flex: w(),
              disable_click: _(),
              "icon-mode": y()
            }), ve = e.set_style(K, "", ve, {
              height: y() ? "" : d() ? typeof d() == "number" ? d() + "px" : d() : "100%"
            });
          }), e.append(P, K);
        };
        e.if(
          L,
          (P) => {
            T() && E() ? P(A) : P(V, !1);
          },
          !0
        );
      }
      e.append(z, S);
    };
    e.if(re, (z) => {
      i() === "clipboard" ? z(Y) : z(ne, !1);
    });
  }
  return e.append(a, Q), e.pop(te);
}
e.delegate(["click"]);
e.from_html("<!> <!> <!> <!> <!>", 1);
var Hs = e.from_html("<img/>");
function Ar(a, t) {
  e.push(t, !0);
  var r = Hs();
  e.attribute_effect(
    r,
    (n) => ({
      src: t.src,
      class: n,
      "data-testid": t.data_testid,
      ...t.restProps
    }),
    [() => (t.class_names || []).join(" ")],
    void 0,
    void 0,
    "svelte-5xcf1t"
  ), e.replay_events(r), e.event("load", r, function(n) {
    e.bubble_event.call(this, t, n);
  }), e.append(a, r), e.pop();
}
e.from_html("<!> <!> <!>", 1);
e.from_html('<div class="image-container svelte-1vq0uw1"><!> <button class="svelte-1vq0uw1"><div><!></div></button></div>');
e.from_html("<!> <!>", 1);
var Os = e.from_html('<button class="svelte-9xp153"><div class="wrap svelte-9xp153"><span class="icon-wrap svelte-9xp153"><!></span> </div></button>');
function Zs(a, t) {
  e.push(t, !1);
  const r = Re();
  e.init();
  var n = Os();
  e.set_style(n, "", {}, { height: "100%" });
  var s = e.child(n), i = e.child(s), o = e.child(i);
  un(o), e.reset(i);
  var l = e.sibling(i);
  l.nodeValue = " Click to Access Webcam", e.reset(s), e.reset(n), e.event("click", n, () => r("click")), e.append(a, n), e.pop();
}
function Vs() {
  return navigator.mediaDevices.enumerateDevices();
}
function Ns(a, t) {
  t.srcObject = a, t.muted = !0, t.play();
}
async function Lr(a, t, r, n) {
  const s = {
    video: n ? { deviceId: { exact: n }, ...r?.video } : r?.video || {
      width: { ideal: 1920 },
      height: { ideal: 1440 }
    },
    audio: a && (r?.audio ?? !0)
    // Defaults to true if not specified
  };
  return navigator.mediaDevices.getUserMedia(s).then((i) => (Ns(i, t), i));
}
function Ps(a) {
  return a.filter((r) => r.kind === "videoinput");
}
var js = e.from_html('<div title="grant webcam access" style="height: 100%"><!></div>'), qs = e.from_html('<div class="icon-with-text svelte-1d3tw37" style="width:var(--size-24);"><div class="icon color-primary svelte-1d3tw37" title="spinner"><!></div> </div>'), Us = e.from_html('<div class="icon-with-text svelte-1d3tw37"><div class="icon color-primary svelte-1d3tw37" title="stop recording"><!></div> </div>'), Ys = e.from_html('<div class="icon-with-text svelte-1d3tw37"><div class="icon color-primary svelte-1d3tw37" title="start recording"><!></div> </div>'), Ws = e.from_html('<div class="icon svelte-1d3tw37" title="capture photo"><!></div>'), Xs = e.from_html('<button class="icon svelte-1d3tw37" aria-label="select input source"><!></button>'), Gs = e.from_html('<option class="svelte-1d3tw37"> </option>'), Ks = e.from_html('<option class="svelte-1d3tw37"> </option>'), Qs = e.from_html('<select class="select-wrap svelte-1d3tw37" aria-label="select source"><!></select>'), Js = e.from_html('<div class="button-wrap svelte-1d3tw37"><button class="svelte-1d3tw37"><!></button> <!></div> <!>', 1), $s = e.from_html('<div class="wrap svelte-1d3tw37"><!>  <video></video> <img/> <!></div>', 2);
function eo(a, t) {
  e.push(t, !1);
  var r = this && this.__awaiter || function(L, A, V, P) {
    function K(de) {
      return de instanceof V ? de : new V(function(ve) {
        ve(de);
      });
    }
    return new (V || (V = Promise))(function(de, ve) {
      function we(De) {
        try {
          _e(P.next(De));
        } catch (he) {
          ve(he);
        }
      }
      function Ce(De) {
        try {
          _e(P.throw(De));
        } catch (he) {
          ve(he);
        }
      }
      function _e(De) {
        De.done ? de(De.value) : K(De.value).then(we, Ce);
      }
      _e((P = P.apply(L, A || [])).next());
    });
  };
  let n = e.mutable_source(), s = e.mutable_source([]), i = e.mutable_source(null), o = e.prop(t, "stream_state", 8, "closed"), l, c = e.prop(t, "streaming", 8, !1), w = e.prop(t, "pending", 8, !1), h = e.prop(t, "root", 8, ""), _ = e.prop(t, "stream_every", 8, 1), b = e.prop(t, "mode", 8, "image"), D = e.prop(t, "mirror_webcam", 8), T = e.prop(t, "include_audio", 8), E = e.prop(t, "webcam_constraints", 8, null), k = e.prop(t, "i18n", 8), y = e.prop(t, "upload", 8), d = e.prop(t, "value", 8, null), p = e.prop(t, "time_limit", 8, null);
  const v = Re();
  Je(() => {
    l = document.createElement("canvas"), c() && b() === "image" && window.setInterval(
      () => {
        e.get(n) && !w() && g();
      },
      _() * 1e3
    );
  });
  const u = (L) => r(void 0, void 0, void 0, function* () {
    const V = L.target.value;
    yield Lr(T(), e.get(n), E(), V).then((P) => r(void 0, void 0, void 0, function* () {
      F = P, e.set(i, e.get(s).find((K) => K.deviceId === V) || null), e.set(H, !1);
    }));
  });
  function f() {
    return r(this, void 0, void 0, function* () {
      try {
        Lr(T(), e.get(n), E()).then((L) => r(this, void 0, void 0, function* () {
          e.set(N, !0), e.set(s, yield Vs()), F = L;
        })).then(() => Ps(e.get(s))).then((L) => {
          e.set(s, L);
          const A = F.getTracks().map((V) => {
            var P;
            return (P = V.getSettings()) === null || P === void 0 ? void 0 : P.deviceId;
          })[0];
          e.set(i, A && L.find((V) => V.deviceId === A) || e.get(s)[0]);
        }), (!navigator.mediaDevices || !navigator.mediaDevices.getUserMedia) && v("error", k()("image.no_webcam_support"));
      } catch (L) {
        if (L instanceof DOMException && L.name == "NotAllowedError")
          v("error", k()("image.allow_webcam_access"));
        else
          throw L;
      }
    });
  }
  function g() {
    if ((!c() || c() && e.get(x)) && e.get(n).videoWidth && e.get(n).videoHeight) {
      var L = l.getContext("2d");
      if (l.width = e.get(n).videoWidth, l.height = e.get(n).videoHeight, L.drawImage(e.get(n), 0, 0, e.get(n).videoWidth, e.get(n).videoHeight), D() && (L.scale(-1, 1), L.drawImage(e.get(n), -e.get(n).videoWidth, 0)), c() && (!e.get(x) || o() === "waiting"))
        return;
      if (c()) {
        const A = l.toDataURL("image/jpeg");
        v("stream", A);
        return;
      }
      l.toBlob(
        (A) => {
          v(c() ? "stream" : "capture", A);
        },
        `image/${c() ? "jpeg" : "png"}`,
        0.8
      );
    }
  }
  let x = e.mutable_source(!1), m = [], F, B, C;
  function O() {
    if (e.get(x)) {
      C.stop();
      let L = new Blob(m, { type: B }), A = new FileReader();
      A.onload = function(V) {
        return r(this, void 0, void 0, function* () {
          var P;
          if (V.target) {
            let K = new File([L], "sample." + B.substring(6));
            const de = yield fn([K]);
            let ve = ((P = yield y()(de, h())) === null || P === void 0 ? void 0 : P.filter(Boolean))[0];
            v("capture", ve), v("stop_recording");
          }
        });
      }, A.readAsDataURL(L);
    } else if (typeof MediaRecorder < "u") {
      v("start_recording"), m = [];
      let L = ["video/webm", "video/mp4"];
      for (let A of L)
        if (MediaRecorder.isTypeSupported(A)) {
          B = A;
          break;
        }
      if (B === null) {
        console.error("No supported MediaRecorder mimeType");
        return;
      }
      C = new MediaRecorder(F, { mimeType: B }), C.addEventListener("dataavailable", function(A) {
        m.push(A.data);
      }), C.start(200);
    }
    e.set(x, !e.get(x));
  }
  let N = e.mutable_source(!1);
  function ie({ destroy: L } = {}) {
    b() === "image" && c() && e.set(x, !e.get(x)), L || (b() === "image" ? g() : O()), !e.get(x) && F && v("close_stream");
  }
  let H = e.mutable_source(!1);
  function Z(L, A) {
    const V = (P) => {
      L && !L.contains(P.target) && !P.defaultPrevented && A(P);
    };
    return document.addEventListener("click", V, !0), {
      destroy() {
        document.removeEventListener("click", V, !0);
      }
    };
  }
  function R(L) {
    L.preventDefault(), L.stopPropagation(), e.set(H, !1);
  }
  Tr(() => {
    typeof window > "u" || (ie({ destroy: !0 }), F?.getTracks().forEach((L) => L.stop()));
  });
  var G = { click_outside: Z };
  e.init();
  var ae = $s(), $ = e.child(ae);
  xs($, {
    get time_limit() {
      return p();
    }
  });
  var te = e.sibling($, 2);
  let Q;
  e.bind_this(te, (L) => e.set(n, L), () => e.get(n));
  var re = e.sibling(te, 2);
  let Y;
  var ne = e.sibling(re, 2);
  {
    var z = (L) => {
      var A = js(), V = e.child(A);
      Zs(V, { $$events: { click: async () => f() } }), e.reset(A), e.transition(1, A, () => mn, () => ({ delay: 100, duration: 200 })), e.append(L, A);
    }, S = (L) => {
      var A = Js(), V = e.first_child(A), P = e.child(V), K = e.child(P);
      {
        var de = (he) => {
          var J = e.comment(), se = e.first_child(J);
          {
            var j = (W) => {
              var X = qs(), ge = e.child(X), be = e.child(ge);
              qa(be), e.reset(ge);
              var le = e.sibling(ge);
              e.reset(X), e.template_effect((ce) => e.set_text(le, ` ${ce ?? ""}`), [
                () => (e.deep_read_state(k()), e.untrack(() => k()("audio.waiting")))
              ]), e.append(W, X);
            }, U = (W) => {
              var X = e.comment(), ge = e.first_child(X);
              {
                var be = (ce) => {
                  var xe = Us(), me = e.child(xe), ke = e.child(me);
                  Oa(ke, {}), e.reset(me);
                  var Ee = e.sibling(me);
                  e.reset(xe), e.template_effect((Le) => e.set_text(Ee, ` ${Le ?? ""}`), [
                    () => (e.deep_read_state(k()), e.untrack(() => k()("audio.stop")))
                  ]), e.append(ce, xe);
                }, le = (ce) => {
                  var xe = Ys(), me = e.child(xe), ke = e.child(me);
                  Ca(ke), e.reset(me);
                  var Ee = e.sibling(me);
                  e.reset(xe), e.template_effect((Le) => e.set_text(Ee, ` ${Le ?? ""}`), [
                    () => (e.deep_read_state(k()), e.untrack(() => k()("audio.record")))
                  ]), e.append(ce, xe);
                };
                e.if(
                  ge,
                  (ce) => {
                    c() && o() === "open" || !c() && e.get(x) ? ce(be) : ce(le, !1);
                  },
                  !0
                );
              }
              e.append(W, X);
            };
            e.if(se, (W) => {
              c() && o() === "waiting" ? W(j) : W(U, !1);
            });
          }
          e.append(he, J);
        }, ve = (he) => {
          var J = Ws(), se = e.child(J);
          ka(se), e.reset(J), e.append(he, J);
        };
        e.if(K, (he) => {
          b() === "video" || c() ? he(de) : he(ve, !1);
        });
      }
      e.reset(P);
      var we = e.sibling(P, 2);
      {
        var Ce = (he) => {
          var J = Xs(), se = e.child(J);
          sn(se), e.reset(J), e.event("click", J, () => e.set(H, !0)), e.append(he, J);
        };
        e.if(we, (he) => {
          e.get(x) || he(Ce);
        });
      }
      e.reset(V);
      var _e = e.sibling(V, 2);
      {
        var De = (he) => {
          var J = Qs(), se = e.child(J);
          {
            var j = (W) => {
              var X = Gs(), ge = e.child(X, !0);
              e.reset(X), X.value = X.__value = "", e.template_effect((be) => e.set_text(ge, be), [
                () => (e.deep_read_state(k()), e.untrack(() => k()("common.no_devices")))
              ]), e.append(W, X);
            }, U = (W) => {
              var X = e.comment(), ge = e.first_child(X);
              e.each(ge, 1, () => e.get(s), e.index, (be, le) => {
                var ce = Ks(), xe = e.child(ce, !0);
                e.reset(ce);
                var me = {};
                e.template_effect(() => {
                  e.set_selected(ce, (e.get(i), e.get(le), e.untrack(() => e.get(i).deviceId === e.get(le).deviceId))), e.set_text(xe, (e.get(le), e.untrack(() => e.get(le).label))), me !== (me = (e.get(le), e.untrack(() => e.get(le).deviceId))) && (ce.value = (ce.__value = (e.get(le), e.untrack(() => e.get(le).deviceId))) ?? "");
                }), e.append(be, ce);
              }), e.append(W, X);
            };
            e.if(se, (W) => {
              e.get(s), e.untrack(() => e.get(s).length === 0) ? W(j) : W(U, !1);
            });
          }
          e.reset(J), e.action(J, (W, X) => Z?.(W, X), () => R), e.effect(() => e.event("change", J, u)), e.append(he, J);
        };
        e.if(_e, (he) => {
          e.get(H) && e.get(i) && he(De);
        });
      }
      e.template_effect(() => e.set_attribute(P, "aria-label", b() === "image" ? "capture photo" : "start recording")), e.event("click", P, () => ie()), e.append(L, A);
    };
    e.if(ne, (L) => {
      e.get(N) ? L(S, !1) : L(z);
    });
  }
  return e.reset(ae), e.template_effect(() => {
    Q = e.set_class(te, 1, "svelte-1d3tw37", null, Q, {
      flip: D(),
      hide: !e.get(N) || e.get(N) && !!d()
    }), e.set_attribute(re, "src", (e.deep_read_state(d()), e.untrack(() => d()?.url))), Y = e.set_class(re, 1, "svelte-1d3tw37", null, Y, {
      hide: !e.get(N) || e.get(N) && !d()
    });
  }), e.append(a, ae), e.bind_prop(t, "click_outside", Z), e.pop(G);
}
e.from_html("<!> <!>", 1);
e.from_html("<div><!></div>");
e.from_html('<!> <div data-testid="image" class="image-container svelte-12il1o7"><!> <div><!> <!></div> <!></div>', 1);
e.from_html("<div><!></div>");
e.from_html("<!> <!>", 1);
e.from_html("<!> <!>", 1);
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xml:space="preserve" stroke="currentColor" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;"><line x1="4" y1="12" x2="20" y2="12" style="fill:none;stroke-width:2px;"></line><line x1="12" y1="4" x2="12" y2="20" style="fill:none;stroke-width:2px;"></line></svg>');
var to = e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xml:space="preserve" stroke="currentColor" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;"><rect x="2" y="2" width="5" height="5" rx="1" ry="1" stroke-width="2" fill="none"></rect><rect x="17" y="2" width="5" height="5" rx="1" ry="1" stroke-width="2" fill="none"></rect><rect x="2" y="17" width="5" height="5" rx="1" ry="1" stroke-width="2" fill="none"></rect><rect x="17" y="17" width="5" height="5" rx="1" ry="1" stroke-width="2" fill="none"></rect><line x1="7.5" y1="4.5" x2="16" y2="4.5" style="stroke-width:2px;"></line><line x1="7.5" y1="19.5" x2="16" y2="19.5" style="stroke-width:2px;"></line><line x1="4.5" y1="8" x2="4.5" y2="16" style="stroke-width:2px;"></line><line x1="19.5" y1="8" x2="19.5" y2="16" style="stroke-width:2px;"></line></svg>');
function ro(a) {
  var t = to();
  e.append(a, t);
}
var no = e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xml:space="preserve" stroke="currentColor" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;"><path d="M 14.4 2.85 V 11.1 V 3.95 C 14.4 3.0387 15.1388 2.3 16.05 2.3 C 16.9612 2.3 17.7 3.0387 17.7 3.95 V 11.1 V 7.25 C 17.7 6.3387 18.4388 5.6 19.35 5.6 C 20.2612 5.6 21 6.3387 21 7.25 V 16.6 C 21 20.2451 18.0451 23.2 14.4 23.2 H 13.16 C 11.4831 23.2 9.8692 22.5618 8.6459 21.4149 L 3.1915 16.3014 C 2.403 15.5622 2.3829 14.3171 3.1472 13.5528 C 3.8943 12.8057 5.1057 12.8057 5.8528 13.5528 L 7.8 15.5 V 6.15 C 7.8 5.2387 8.5387 4.5 9.45 4.5 C 10.3612 4.5 11.1 5.2387 11.1 6.15 V 11.1 V 2.85 C 11.1 1.9387 11.8388 1.2 12.75 1.2 C 13.6612 1.2 14.4 1.9387 14.4 2.85 Z" fill="none" stroke-width="2"></path></svg>');
function io(a) {
  var t = no();
  e.append(a, t);
}
var ao = e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xml:space="preserve" stroke="currentColor" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;"><path d="M10 12L14 16M14 12L10 16M4 6H20M16 6L15.7294 5.18807C15.4671 4.40125 15.3359 4.00784 15.0927 3.71698C14.8779 3.46013 14.6021 3.26132 14.2905 3.13878C13.9376 3 13.523 3 12.6936 3H11.3064C10.477 3 10.0624 3 9.70951 3.13878C9.39792 3.26132 9.12208 3.46013 8.90729 3.71698C8.66405 4.00784 8.53292 4.40125 8.27064 5.18807L8 6M18 6V16.2C18 17.8802 18 18.7202 17.673 19.362C17.3854 19.9265 16.9265 20.3854 16.362 20.673C15.7202 21 14.8802 21 13.2 21H10.8C9.11984 21 8.27976 21 7.63803 20.673C7.07354 20.3854 6.6146 19.9265 6.32698 19.362C6 18.7202 6 17.8802 6 16.2V6" fill="none" stroke-width="2"></path></svg>');
function so(a) {
  var t = ao();
  e.append(a, t);
}
var oo = e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg" fill="none" stroke="currentColor" stroke-width="2" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;"><path d="M12,2.5L2.5,12c-.7.7-.7,1.8,0,2.4l7.1,7.1c.7.7,1.8.7,2.4,0l9.5-9.5c.3-.3.5-.8.5-1.2V3.7c0-1-.8-1.7-1.7-1.7h-7.1c-.5,0-.9.2-1.2.5ZM7.3,14.1l4.7-4.7M9.9,16.7l2.2-2.2"></path><path d="M18.5,6.3c0,.5-.4.9-.9.9s-.9-.4-.9-.9.4-.9.9-.9.9.4.9.9Z"></path></svg>');
function lo(a) {
  var t = oo();
  e.append(a, t);
}
var co = e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;" xmlns="http://www.w3.org/2000/svg"><path d="M7 10.0288C7.47142 10 8.05259 10 8.8 10H15.2C15.9474 10 16.5286 10 17 10.0288M7 10.0288C6.41168 10.0647 5.99429 10.1455 5.63803 10.327C5.07354 10.6146 4.6146 11.0735 4.32698 11.638C4 12.2798 4 13.1198 4 14.8V16.2C4 17.8802 4 18.7202 4.32698 19.362C4.6146 19.9265 5.07354 20.3854 5.63803 20.673C6.27976 21 7.11984 21 8.8 21H15.2C16.8802 21 17.7202 21 18.362 20.673C18.9265 20.3854 19.3854 19.9265 19.673 19.362C20 18.7202 20 17.8802 20 16.2V14.8C20 13.1198 20 12.2798 19.673 11.638C19.3854 11.0735 18.9265 10.6146 18.362 10.327C18.0057 10.1455 17.5883 10.0647 17 10.0288M7 10.0288V8C7 5.23858 9.23858 3 12 3C14.7614 3 17 5.23858 17 8V10.0288"></path></svg>');
function uo(a) {
  var t = co();
  e.append(a, t);
}
var ho = e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;" xmlns="http://www.w3.org/2000/svg"><path d="M16.584 6C15.8124 4.2341 14.0503 3 12 3C9.23858 3 7 5.23858 7 8V10.0288M7 10.0288C7.47142 10 8.05259 10 8.8 10H15.2C16.8802 10 17.7202 10 18.362 10.327C18.9265 10.6146 19.3854 11.0735 19.673 11.638C20 12.2798 20 13.1198 20 14.8V16.2C20 17.8802 20 18.7202 19.673 19.362C19.3854 19.9265 18.9265 20.3854 18.362 20.673C17.7202 21 16.8802 21 15.2 21H8.8C7.11984 21 6.27976 21 5.63803 20.673C5.07354 20.3854 4.6146 19.9265 4.32698 19.362C4 18.7202 4 17.8802 4 16.2V14.8C4 13.1198 4 12.2798 4.32698 11.638C4.6146 11.0735 5.07354 10.6146 5.63803 10.327C5.99429 10.1455 6.41168 10.0647 7 10.0288Z"></path></svg>');
function go(a) {
  var t = ho();
  e.append(a, t);
}
var fo = e.from_html('<div class="svelte-1h7ono1"><!></div>');
function po(a, t) {
  var r = fo(), n = e.child(r);
  e.slot(n, t, "default", {}, null), e.reset(r), e.append(a, r);
}
var vo = e.from_html('<span data-testid="block-info"><!></span> <!>', 1);
function mo(a, t) {
  let r = e.prop(t, "show_label", 8, !0), n = e.prop(t, "info", 8, void 0);
  var s = vo(), i = e.first_child(s);
  let o;
  var l = e.child(i);
  e.slot(l, t, "default", {}, null), e.reset(i);
  var c = e.sibling(i, 2);
  {
    var w = (h) => {
      po(h, {
        children: (_, b) => {
          e.next();
          var D = e.text();
          e.template_effect(() => e.set_text(D, n())), e.append(_, D);
        },
        $$slots: { default: !0 }
      });
    };
    e.if(c, (h) => {
      n() && h(w);
    });
  }
  e.template_effect(() => o = e.set_class(i, 1, "svelte-19kzznq", null, o, {
    "sr-only": !r(),
    hide: !r(),
    "has-info": n() != null
  })), e.append(a, s);
}
e.from_html('<label for="" data-testid="block-label"><span class="svelte-1tbgtk6"><!></span> </label>');
e.from_html('<span class="svelte-1afayxq"> </span>');
e.from_html("<button><!> <div><!></div></button>");
e.from_html('<div aria-label="Empty value"><div class="icon svelte-1d5ze6c"><!></div></div>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="12px" height="24px" fill="currentColor" stroke-width="1.5" viewBox="0 0 12 24"><path d="M9 6L3 12L9 18" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="24px" height="24px" fill="currentColor" stroke-width="1.5" viewBox="0 0 24 24" color="currentColor"><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" d="M21.044 5.704a.6.6 0 0 1 .956.483v11.626a.6.6 0 0 1-.956.483l-7.889-5.813a.6.6 0 0 1 0-.966l7.89-5.813ZM10.044 5.704a.6.6 0 0 1 .956.483v11.626a.6.6 0 0 1-.956.483l-7.888-5.813a.6.6 0 0 1 0-.966l7.888-5.813Z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 32 32"><path d="M28.828 3.172a4.094 4.094 0 0 0-5.656 0L4.05 22.292A6.954 6.954 0 0 0 2 27.242V30h2.756a6.952 6.952 0 0 0 4.95-2.05L28.828 8.829a3.999 3.999 0 0 0 0-5.657zM10.91 18.26l2.829 2.829l-2.122 2.121l-2.828-2.828zm-2.619 8.276A4.966 4.966 0 0 1 4.756 28H4v-.759a4.967 4.967 0 0 1 1.464-3.535l1.91-1.91l2.829 2.828zM27.415 7.414l-12.261 12.26l-2.829-2.828l12.262-12.26a2.047 2.047 0 0 1 2.828 0a2 2 0 0 1 0 2.828z" fill="currentColor"></path><path d="M6.5 15a3.5 3.5 0 0 1-2.475-5.974l3.5-3.5a1.502 1.502 0 0 0 0-2.121a1.537 1.537 0 0 0-2.121 0L3.415 5.394L2 3.98l1.99-1.988a3.585 3.585 0 0 1 4.95 0a3.504 3.504 0 0 1 0 4.949L5.439 10.44a1.502 1.502 0 0 0 0 2.121a1.537 1.537 0 0 0 2.122 0l4.024-4.024L13 9.95l-4.025 4.024A3.475 3.475 0 0 1 6.5 15z" fill="currentColor"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M2.753 2.933a.75.75 0 0 1 .814-.68l3.043.272c2.157.205 4.224.452 5.922.732c1.66.273 3.073.594 3.844.983c.197.1.412.233.578.415c.176.192.352.506.28.9c-.067.356-.304.59-.487.729a3.001 3.001 0 0 1-.695.369c-1.02.404-2.952.79-5.984 1.169c-1.442.18-2.489.357-3.214.522c.205.045.43.089.674.132c.992.174 2.241.323 3.568.437a31.21 31.21 0 0 1 3.016.398c.46.087.893.186 1.261.296c.352.105.707.236.971.412c.13.086.304.225.42.437a.988.988 0 0 1 .063.141A1.75 1.75 0 0 0 14.5 12.25v.158c-.758.154-1.743.302-2.986.444c-2.124.243-3.409.55-4.117.859c-.296.128-.442.236-.508.3c.026.037.073.094.156.17c.15.138.369.29.65.45c.56.316 1.282.61 1.979.838l2.637.814a.75.75 0 1 1-.443 1.433l-2.655-.819c-.754-.247-1.58-.578-2.257-.96a5.082 5.082 0 0 1-.924-.65c-.255-.233-.513-.544-.62-.935c-.12-.441-.016-.88.274-1.244c.261-.328.656-.574 1.113-.773c.92-.4 2.387-.727 4.545-.974c1.366-.156 2.354-.313 3.041-.462a16.007 16.007 0 0 0-.552-.114a29.716 29.716 0 0 0-2.865-.378c-1.352-.116-2.649-.27-3.7-.454c-.524-.092-1-.194-1.395-.307c-.376-.106-.75-.241-1.021-.426a1.186 1.186 0 0 1-.43-.49a.934.934 0 0 1 .059-.873c.13-.213.32-.352.472-.442a3.23 3.23 0 0 1 .559-.251c.807-.287 2.222-.562 4.37-.83c2.695-.338 4.377-.666 5.295-.962c-.638-.21-1.623-.427-2.89-.635c-1.65-.273-3.679-.515-5.816-.718l-3.038-.272a.75.75 0 0 1-.68-.814M17 12.25a.75.75 0 0 0-1.5 0v4.19l-.72-.72a.75.75 0 1 0-1.06 1.06l2 2a.75.75 0 0 0 1.06 0l2-2a.75.75 0 1 0-1.06-1.06l-.72.72z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="24px" height="24px" viewBox="0 0 24 24"><rect x="2" y="4" width="20" height="18" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></rect><line x1="2" y1="9" x2="22" y2="9" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></line><line x1="7" y1="2" x2="7" y2="6" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></line><line x1="17" y1="2" x2="17" y2="6" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="none"></line></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-camera"><path d="M23 19a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h4l2-3h6l2 3h4a2 2 0 0 1 2 2z"></path><circle cx="12" cy="13" r="4"></circle></svg>');
e.from_svg('<svg viewBox="0 0 32 32"><path d="M28.828 3.172a4.094 4.094 0 0 0-5.656 0L4.05 22.292A6.954 6.954 0 0 0 2 27.242V30h2.756a6.952 6.952 0 0 0 4.95-2.05L28.828 8.829a3.999 3.999 0 0 0 0-5.657zM10.91 18.26l2.829 2.829l-2.122 2.121l-2.828-2.828zm-2.619 8.276A4.966 4.966 0 0 1 4.756 28H4v-.759a4.967 4.967 0 0 1 1.464-3.535l1.91-1.91l2.829 2.828zM27.415 7.414l-12.261 12.26l-2.829-2.828l12.262-12.26a2.047 2.047 0 0 1 2.828 0a2 2 0 0 1 0 2.828z" fill="currentColor"></path><path d="M6.5 15a3.5 3.5 0 0 1-2.475-5.974l3.5-3.5a1.502 1.502 0 0 0 0-2.121a1.537 1.537 0 0 0-2.121 0L3.415 5.394L2 3.98l1.99-1.988a3.585 3.585 0 0 1 4.95 0a3.504 3.504 0 0 1 0 4.949L5.439 10.44a1.502 1.502 0 0 0 0 2.121a1.537 1.537 0 0 0 2.122 0l4.024-4.024L13 9.95l-4.025 4.024A3.475 3.475 0 0 1 6.5 15z" fill="currentColor"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M17.74 30L16 29l4-7h6a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h9v2H6a4 4 0 0 1-4-4V8a4 4 0 0 1 4-4h20a4 4 0 0 1 4 4v12a4 4 0 0 1-4 4h-4.84Z"></path><path fill="currentColor" d="M8 10h16v2H8zm0 6h10v2H8z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="2 0 20 20" fill="none" stroke="currentColor" aria-hidden="true" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><polyline points="20 6 9 17 4 12"></polyline></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-circle"><circle cx="12" cy="12" r="10"></circle></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xml:space="preserve" stroke="currentColor" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;"><g transform="matrix(1.14096,-0.140958,-0.140958,1.14096,-0.0559523,0.0559523)"><path d="M18,6L6.087,17.913" style="fill:none;fill-rule:nonzero;stroke-width:2px;"></path></g><path d="M4.364,4.364L19.636,19.636" style="fill:none;fill-rule:nonzero;stroke-width:2px;"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 32 32"><path fill="currentColor" d="m31 16l-7 7l-1.41-1.41L28.17 16l-5.58-5.59L24 9l7 7zM1 16l7-7l1.41 1.41L3.83 16l5.58 5.59L8 23l-7-7zm11.42 9.484L17.64 6l1.932.517L14.352 26z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 32 32"><circle cx="10" cy="12" r="2" fill="currentColor"></circle><circle cx="16" cy="9" r="2" fill="currentColor"></circle><circle cx="22" cy="12" r="2" fill="currentColor"></circle><circle cx="23" cy="18" r="2" fill="currentColor"></circle><circle cx="19" cy="23" r="2" fill="currentColor"></circle><path fill="currentColor" d="M16.54 2A14 14 0 0 0 2 16a4.82 4.82 0 0 0 6.09 4.65l1.12-.31a3 3 0 0 1 3.79 2.9V27a3 3 0 0 0 3 3a14 14 0 0 0 14-14.54A14.05 14.05 0 0 0 16.54 2Zm8.11 22.31A11.93 11.93 0 0 1 16 28a1 1 0 0 1-1-1v-3.76a5 5 0 0 0-5-5a5.07 5.07 0 0 0-1.33.18l-1.12.31A2.82 2.82 0 0 1 4 16A12 12 0 0 1 16.47 4A12.18 12.18 0 0 1 28 15.53a11.89 11.89 0 0 1-3.35 8.79Z"></path></svg>');
e.from_svg('<svg id="icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32"><path d="M23,20a5,5,0,0,0-3.89,1.89L11.8,17.32a4.46,4.46,0,0,0,0-2.64l7.31-4.57A5,5,0,1,0,18,7a4.79,4.79,0,0,0,.2,1.32l-7.31,4.57a5,5,0,1,0,0,6.22l7.31,4.57A4.79,4.79,0,0,0,18,25a5,5,0,1,0,5-5ZM23,4a3,3,0,1,1-3,3A3,3,0,0,1,23,4ZM7,19a3,3,0,1,1,3-3A3,3,0,0,1,7,19Zm16,9a3,3,0,1,1,3-3A3,3,0,0,1,23,28Z" fill="currentColor"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 33 33" color="currentColor" aria-hidden="true"><path fill="currentColor" d="M28 10v18H10V10h18m0-2H10a2 2 0 0 0-2 2v18a2 2 0 0 0 2 2h18a2 2 0 0 0 2-2V10a2 2 0 0 0-2-2Z"></path><path fill="currentColor" d="M4 18H2V4a2 2 0 0 1 2-2h14v2H4Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M17 23v-4H7q-.825 0-1.413-.588T5 17V7H1V5h4V1h2v16h16v2h-4v4h-2Zm0-8V7H9V5h8q.825 0 1.413.588T19 7v8h-2Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 32 32"><path fill="currentColor" d="M26 24v4H6v-4H4v4a2 2 0 0 0 2 2h20a2 2 0 0 0 2-2v-4zm0-10l-1.41-1.41L17 20.17V2h-2v18.17l-7.59-7.58L6 14l10 10l10-10z"></path></svg>');
e.from_svg('<svg class="dropdown-arrow svelte-1ljtu2w" xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 18 18"><path d="M5 8l4 4 4-4z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-edit-2"><path d="M17 3a2.828 2.828 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5L17 3z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><g fill="none"><path fill="currentColor" d="m5.505 11.41l.53.53l-.53-.53ZM3 14.952h-.75H3ZM9.048 21v.75V21ZM11.41 5.505l-.53-.53l.53.53Zm1.831 12.34a.75.75 0 0 0 1.06-1.061l-1.06 1.06ZM7.216 9.697a.75.75 0 1 0-1.06 1.061l1.06-1.06Zm10.749 2.362l-5.905 5.905l1.06 1.06l5.905-5.904l-1.06-1.06Zm-11.93-.12l5.905-5.905l-1.06-1.06l-5.905 5.904l1.06 1.06Zm0 6.025c-.85-.85-1.433-1.436-1.812-1.933c-.367-.481-.473-.79-.473-1.08h-1.5c0 .749.312 1.375.78 1.99c.455.596 1.125 1.263 1.945 2.083l1.06-1.06Zm-1.06-7.086c-.82.82-1.49 1.488-1.945 2.084c-.468.614-.78 1.24-.78 1.99h1.5c0-.29.106-.6.473-1.08c.38-.498.962-1.083 1.812-1.933l-1.06-1.06Zm7.085 7.086c-.85.85-1.435 1.433-1.933 1.813c-.48.366-.79.472-1.08.472v1.5c.75 0 1.376-.312 1.99-.78c.596-.455 1.264-1.125 2.084-1.945l-1.06-1.06Zm-7.085 1.06c.82.82 1.487 1.49 2.084 1.945c.614.468 1.24.78 1.989.78v-1.5c-.29 0-.599-.106-1.08-.473c-.497-.38-1.083-.962-1.933-1.812l-1.06 1.06Zm12.99-12.99c.85.85 1.433 1.436 1.813 1.933c.366.481.472.79.472 1.08h1.5c0-.749-.312-1.375-.78-1.99c-.455-.596-1.125-1.263-1.945-2.083l-1.06 1.06Zm1.06 7.086c.82-.82 1.49-1.488 1.945-2.084c.468-.614.78-1.24.78-1.99h-1.5c0 .29-.106.6-.473 1.08c-.38.498-.962 1.083-1.812 1.933l1.06 1.06Zm0-8.146c-.82-.82-1.487-1.49-2.084-1.945c-.614-.468-1.24-.78-1.989-.78v1.5c.29 0 .599.106 1.08.473c.497.38 1.083.962 1.933 1.812l1.06-1.06Zm-7.085 1.06c.85-.85 1.435-1.433 1.933-1.812c.48-.367.79-.473 1.08-.473v-1.5c-.75 0-1.376.312-1.99.78c-.596.455-1.264 1.125-2.084 1.945l1.06 1.06Zm2.362 10.749L7.216 9.698l-1.06 1.061l7.085 7.085l1.06-1.06Z"></path><path stroke="currentColor" stroke-linecap="round" stroke-width="1.5" d="M9 21h12"></path></g></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M12 9v3.75m9-.75a9 9 0 11-18 0 9 9 0 0118 0zm-9 3.75h.008v.008H12v-.008z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M21.03 2.97a3.578 3.578 0 0 0-5.06 0L14 4.94l-.013-.013a1.75 1.75 0 0 0-2.475 0l-.585.586a1.75 1.75 0 0 0 0 2.475l.012.012l-6.78 6.78a2.25 2.25 0 0 0-.659 1.592v.687l-1.28 2.347c-.836 1.533.841 3.21 2.374 2.375l2.347-1.28h.688a2.25 2.25 0 0 0 1.59-.66L16 13.061l.012.012a1.75 1.75 0 0 0 2.475 0l.586-.585a1.75 1.75 0 0 0 0-2.475L19.061 10l1.97-1.97a3.578 3.578 0 0 0 0-5.06ZM12 9.061l2.94 2.94l-6.78 6.78a.75.75 0 0 1-.531.22H6.75a.75.75 0 0 0-.359.09l-2.515 1.373a.234.234 0 0 1-.159.032a.264.264 0 0 1-.138-.075a.264.264 0 0 1-.075-.138a.234.234 0 0 1 .033-.158l1.372-2.515A.75.75 0 0 0 5 17.25v-.878a.75.75 0 0 1 .22-.53L12 9.06Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-maximize"><path d="M8 3H5a2 2 0 0 0-2 2v3m18 0V5a2 2 0 0 0-2-2h-3m0 18h3a2 2 0 0 0 2-2v-3M3 16v3a2 2 0 0 0 2 2h3"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="24px" height="24px" fill="currentColor" stroke-width="1.5" viewBox="0 0 24 24" color="currentColor"><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" d="M2.956 5.704A.6.6 0 0 0 2 6.187v11.626a.6.6 0 0 0 .956.483l7.889-5.813a.6.6 0 0 0 0-.966l-7.89-5.813ZM13.956 5.704a.6.6 0 0 0-.956.483v11.626a.6.6 0 0 0 .956.483l7.889-5.813a.6.6 0 0 0 0-.966l-7.89-5.813Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-file"><path d="M13 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9z"></path><polyline points="13 2 13 9 20 9"></polyline></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M11.25 11.25l.041-.02a.75.75 0 011.063.852l-.708 2.836a.75.75 0 001.063.853l.041-.021M21 12a9 9 0 11-18 0 9 9 0 0118 0zm-9-3.75h.008v.008H12V8.25z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-image"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><circle cx="8.5" cy="8.5" r="1.5"></circle><polyline points="21 15 16 10 5 21"></polyline></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path fill="currentColor" d="M13.75 2a2.25 2.25 0 0 1 2.236 2.002V4h1.764A2.25 2.25 0 0 1 20 6.25V11h-1.5V6.25a.75.75 0 0 0-.75-.75h-2.129c-.404.603-1.091 1-1.871 1h-3.5c-.78 0-1.467-.397-1.871-1H6.25a.75.75 0 0 0-.75.75v13.5c0 .414.336.75.75.75h4.78a4 4 0 0 0 .505 1.5H6.25A2.25 2.25 0 0 1 4 19.75V6.25A2.25 2.25 0 0 1 6.25 4h1.764a2.25 2.25 0 0 1 2.236-2zm2.245 2.096L16 4.25q0-.078-.005-.154M13.75 3.5h-3.5a.75.75 0 0 0 0 1.5h3.5a.75.75 0 0 0 0-1.5M15 12a3 3 0 0 0-3 3v5c0 .556.151 1.077.415 1.524l3.494-3.494a2.25 2.25 0 0 1 3.182 0l3.494 3.494c.264-.447.415-.968.415-1.524v-5a3 3 0 0 0-3-3zm0 11a3 3 0 0 1-1.524-.415l3.494-3.494a.75.75 0 0 1 1.06 0l3.494 3.494A3 3 0 0 1 20 23zm5-7a1 1 0 1 1 0-2 1 1 0 0 1 0 2"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--mdi" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 24 24"><path fill="currentColor" d="M5 3h2v2H5v5a2 2 0 0 1-2 2a2 2 0 0 1 2 2v5h2v2H5c-1.07-.27-2-.9-2-2v-4a2 2 0 0 0-2-2H0v-2h1a2 2 0 0 0 2-2V5a2 2 0 0 1 2-2m14 0a2 2 0 0 1 2 2v4a2 2 0 0 0 2 2h1v2h-1a2 2 0 0 0-2 2v4a2 2 0 0 1-2 2h-2v-2h2v-5a2 2 0 0 1 2-2a2 2 0 0 1-2-2V5h-2V3h2m-7 12a1 1 0 0 1 1 1a1 1 0 0 1-1 1a1 1 0 0 1-1-1a1 1 0 0 1 1-1m-4 0a1 1 0 0 1 1 1a1 1 0 0 1-1 1a1 1 0 0 1-1-1a1 1 0 0 1 1-1m8 0a1 1 0 0 1 1 1a1 1 0 0 1-1 1a1 1 0 0 1-1-1a1 1 0 0 1 1-1Z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 17 17" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M1.35327 10.9495L6.77663 15.158C7.12221 15.4229 7.50051 15.5553 7.91154 15.5553C8.32258 15.5553 8.70126 15.4229 9.0476 15.158L14.471 10.9495" stroke="currentColor" stroke-width="1.5" stroke-linecap="round"></path><path d="M7.23461 11.4324C7.23406 11.432 7.2335 11.4316 7.23295 11.4312L1.81496 7.2268C1.81471 7.22661 1.81446 7.22641 1.8142 7.22621C1.52269 6.99826 1.39429 6.73321 1.39429 6.37014C1.39429 6.00782 1.52236 5.74301 1.81325 5.51507C1.8136 5.5148 1.81394 5.51453 1.81428 5.51426L7.2331 1.30812C7.45645 1.13785 7.67632 1.06653 7.91159 1.06653C8.14692 1.06653 8.36622 1.13787 8.58861 1.30787C8.58915 1.30828 8.58969 1.30869 8.59023 1.30911L14.0082 5.51462C14.0085 5.51485 14.0088 5.51507 14.0091 5.51529C14.3008 5.74345 14.4289 6.00823 14.4289 6.37014C14.4289 6.73356 14.3006 6.99862 14.01 7.22634C14.0096 7.22662 14.0093 7.22689 14.0089 7.22717L8.59007 11.4322C8.36672 11.6024 8.14686 11.6738 7.91159 11.6738C7.67628 11.6738 7.45699 11.6024 7.23461 11.4324Z" stroke="currentColor" stroke-width="1.5"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M4 2H2v26a2 2 0 0 0 2 2h26v-2H4v-3h22v-8H4v-4h14V5H4Zm20 17v4H4v-4ZM16 7v4H4V7Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"><path d="M8 3H5a2 2 0 0 0-2 2v3m18 0V5a2 2 0 0 0-2-2h-3m0 18h3a2 2 0 0 0 2-2v-3M3 16v3a2 2 0 0 0 2 2h3"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-mic"><path d="M12 1a3 3 0 0 0-3 3v8a3 3 0 0 0 6 0V4a3 3 0 0 0-3-3z"></path><path d="M19 10v2a7 7 0 0 1-14 0v-2"></path><line x1="12" y1="19" x2="12" y2="23"></line><line x1="8" y1="23" x2="16" y2="23"></line></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-minimize"><path d="M8 3v3a2 2 0 0 1-2 2H3m18 0h-3a2 2 0 0 1-2-2V3m0 18v-3a2 2 0 0 1 2-2h3M3 16h3a2 2 0 0 1 2 2v3"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-music"><path d="M9 18V5l12-2v13"></path><circle cx="6" cy="18" r="3"></circle><circle cx="18" cy="16" r="3"></circle></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><g fill="none" stroke="currentColor" stroke-width="1.5"><path d="M2 12.026c0 5.146 3.867 9.387 8.847 9.96c.735.085 1.447-.228 1.97-.753a1.68 1.68 0 0 0 0-2.372c-.523-.525-.95-1.307-.555-1.934c1.576-2.508 9.738 3.251 9.738-4.9C22 6.488 17.523 2 12 2S2 6.489 2 12.026Z"></path><circle cx="17.5" cy="11.5" r=".75"></circle><circle cx="6.5" cy="11.5" r=".75"></circle><path d="M10.335 7a.75.75 0 1 1-1.5 0a.75.75 0 0 1 1.5 0Zm4.915 0a.75.75 0 1 1-1.5 0a.75.75 0 0 1 1.5 0Z"></path></g></svg>');
e.from_svg('<svg fill="currentColor" viewBox="0 0 1920 1920" xmlns="http://www.w3.org/2000/svg"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M1752.768 221.109C1532.646.986 1174.283.986 954.161 221.109l-838.588 838.588c-154.052 154.165-154.052 404.894 0 558.946 149.534 149.421 409.976 149.308 559.059 0l758.738-758.626c87.982-88.094 87.982-231.417 0-319.51-88.32-88.208-231.642-87.982-319.51 0l-638.796 638.908 79.85 79.849 638.795-638.908c43.934-43.821 115.539-43.934 159.812 0 43.934 44.047 43.934 115.877 0 159.812l-758.739 758.625c-110.23 110.118-289.355 110.005-399.36 0-110.118-110.117-110.005-289.242 0-399.247l838.588-838.588c175.963-175.962 462.382-176.188 638.909 0 176.075 176.188 176.075 462.833 0 638.908l-798.607 798.72 79.849 79.85 798.607-798.72c220.01-220.123 220.01-578.485 0-798.607" fill-rule="evenodd"></path></g></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="currentColor" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"><rect x="6" y="4" width="4" height="16"></rect><rect x="14" y="4" width="4" height="16"></rect></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="currentColor" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"><polygon points="5 3 19 12 5 21 5 3"></polygon></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><circle cx="20" cy="4" r="2" fill="currentColor"></circle><circle cx="8" cy="16" r="2" fill="currentColor"></circle><circle cx="28" cy="12" r="2" fill="currentColor"></circle><circle cx="11" cy="7" r="2" fill="currentColor"></circle><circle cx="16" cy="24" r="2" fill="currentColor"></circle><path fill="currentColor" d="M30 3.413L28.586 2L4 26.585V2H2v26a2 2 0 0 0 2 2h26v-2H5.413Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rotate-ccw" style="transform: rotateY(180deg);"><polyline points="1 4 1 10 7 10"></polyline><path d="M3.51 15a9 9 0 1 0 2.13-9.36L1 10"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 1024 1024"><path fill="currentColor" d="M672 418H144c-17.7 0-32 14.3-32 32v414c0 17.7 14.3 32 32 32h528c17.7 0 32-14.3 32-32V450c0-17.7-14.3-32-32-32zm-44 402H188V494h440v326z"></path><path fill="currentColor" d="M819.3 328.5c-78.8-100.7-196-153.6-314.6-154.2l-.2-64c0-6.5-7.6-10.1-12.6-6.1l-128 101c-4 3.1-3.9 9.1 0 12.3L492 318.6c5.1 4 12.7.4 12.6-6.1v-63.9c12.9.1 25.9.9 38.8 2.5c42.1 5.2 82.1 18.2 119 38.7c38.1 21.2 71.2 49.7 98.4 84.3c27.1 34.7 46.7 73.7 58.1 115.8c11 40.7 14 82.7 8.9 124.8c-.7 5.4-1.4 10.8-2.4 16.1h74.9c14.8-103.6-11.3-213-81-302.3z"></path></svg>');
e.from_svg('<svg viewBox="0 0 22 24" width="100%" height="100%" fill="none" xmlns="http://www.w3.org/2000/svg"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M19.1168 12.1484C19.474 12.3581 19.9336 12.2384 20.1432 11.8811C20.3528 11.5238 20.2331 11.0643 19.8758 10.8547L19.1168 12.1484ZM6.94331 4.13656L6.55624 4.77902L6.56378 4.78344L6.94331 4.13656ZM5.92408 4.1598L5.50816 3.5357L5.50816 3.5357L5.92408 4.1598ZM5.51031 5.09156L4.76841 5.20151C4.77575 5.25101 4.78802 5.29965 4.80505 5.34671L5.51031 5.09156ZM7.12405 11.7567C7.26496 12.1462 7.69495 12.3477 8.08446 12.2068C8.47397 12.0659 8.67549 11.6359 8.53458 11.2464L7.12405 11.7567ZM19.8758 12.1484C20.2331 11.9388 20.3528 11.4793 20.1432 11.122C19.9336 10.7648 19.474 10.6451 19.1168 10.8547L19.8758 12.1484ZM6.94331 18.8666L6.56375 18.2196L6.55627 18.2241L6.94331 18.8666ZM5.92408 18.8433L5.50815 19.4674H5.50815L5.92408 18.8433ZM5.51031 17.9116L4.80505 17.6564C4.78802 17.7035 4.77575 17.7521 4.76841 17.8016L5.51031 17.9116ZM8.53458 11.7567C8.67549 11.3672 8.47397 10.9372 8.08446 10.7963C7.69495 10.6554 7.26496 10.8569 7.12405 11.2464L8.53458 11.7567ZM19.4963 12.2516C19.9105 12.2516 20.2463 11.9158 20.2463 11.5016C20.2463 11.0873 19.9105 10.7516 19.4963 10.7516V12.2516ZM7.82931 10.7516C7.4151 10.7516 7.07931 11.0873 7.07931 11.5016C7.07931 11.9158 7.4151 12.2516 7.82931 12.2516V10.7516ZM19.8758 10.8547L7.32284 3.48968L6.56378 4.78344L19.1168 12.1484L19.8758 10.8547ZM7.33035 3.49414C6.76609 3.15419 6.05633 3.17038 5.50816 3.5357L6.34 4.78391C6.40506 4.74055 6.4893 4.73863 6.55627 4.77898L7.33035 3.49414ZM5.50816 3.5357C4.95998 3.90102 4.67184 4.54987 4.76841 5.20151L6.25221 4.98161C6.24075 4.90427 6.27494 4.82727 6.34 4.78391L5.50816 3.5357ZM4.80505 5.34671L7.12405 11.7567L8.53458 11.2464L6.21558 4.83641L4.80505 5.34671ZM19.1168 10.8547L6.56378 18.2197L7.32284 19.5134L19.8758 12.1484L19.1168 10.8547ZM6.55627 18.2241C6.4893 18.2645 6.40506 18.2626 6.34 18.2192L5.50815 19.4674C6.05633 19.8327 6.76609 19.8489 7.33035 19.509L6.55627 18.2241ZM6.34 18.2192C6.27494 18.1759 6.24075 18.0988 6.25221 18.0215L4.76841 17.8016C4.67184 18.4532 4.95998 19.1021 5.50815 19.4674L6.34 18.2192ZM6.21558 18.1667L8.53458 11.7567L7.12405 11.2464L4.80505 17.6564L6.21558 18.1667ZM19.4963 10.7516H7.82931V12.2516H19.4963V10.7516Z" fill="currentColor"></path></g></svg>');
e.from_svg('<svg enable-background="new 0 0 32 32" height="20" width="20" viewBox="0 0 32 32" fill="currentColor" xmlns="http://www.w3.org/2000/svg"><path d="m30 8h-4.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4h-14.1v2h14.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4h4.1zm-9 4c-1.7 0-3-1.3-3-3s1.3-3 3-3 3 1.3 3 3-1.3 3-3 3z"></path><path d="m2 24h4.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4h14.1v-2h-14.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4h-4.1zm9-4c1.7 0 3 1.3 3 3s-1.3 3-3 3-3-1.3-3-3 1.3-3 3-3z"></path><path d="m0 0h32v32h-32z" fill="none"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-edit-2"><path d="M17 3a2.828 2.828 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5L17 3z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-square"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-table"><path d="M9 3H5a2 2 0 0 0-2 2v4m6-6h10a2 2 0 0 1 2 2v4M9 3v18m0 0h10a2 2 0 0 0 2-2V9M9 21H5a2 2 0 0 1-2-2V9m0 0h18"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M12 15H5a3 3 0 0 1-3-3v-2a3 3 0 0 1 3-3h5V5a1 1 0 0 0-1-1H3V2h6a3 3 0 0 1 3 3zM5 9a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h5V9zm15 14v2a1 1 0 0 0 1 1h5v-4h-5a1 1 0 0 0-1 1z"></path><path fill="currentColor" d="M2 30h28V2Zm26-2h-7a3 3 0 0 1-3-3v-2a3 3 0 0 1 3-3h5v-2a1 1 0 0 0-1-1h-6v-2h6a3 3 0 0 1 3 3Z"></path></svg>');
e.from_svg(`<svg id="icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32" fill="currentColor"><defs><style>.cls-1 {
				fill: none;
			}</style></defs><rect x="12" y="12" width="2" height="12"></rect><rect x="18" y="12" width="2" height="12"></rect><path d="M4,6V8H6V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8h2V6ZM8,28V8H24V28Z"></path><rect x="12" y="2" width="8" height="2"></rect><rect id="_Transparent_Rectangle_" data-name="&lt;Transparent Rectangle>" class="cls-1" width="32" height="32"></rect></svg>`);
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M23 9.005h6a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-6a2 2 0 0 0-2 2v1H11v-1a2 2 0 0 0-2-2H3a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-1h4v20a2.002 2.002 0 0 0 2 2h4v1a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-6a2 2 0 0 0-2 2v1h-4v-9h4v1a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-6a2 2 0 0 0-2 2v1h-4v-9h4v1a2 2 0 0 0 2 2Zm0-6h6v4h-6Zm-14 4H3v-4h6Zm14 18h6v4h-6Zm0-11h6v4h-6Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-scissors"><circle cx="6" cy="6" r="3"></circle><circle cx="6" cy="18" r="3"></circle><line x1="20" y1="4" x2="8.12" y2="15.88"></line><line x1="14.47" y1="14.48" x2="20" y2="20"></line><line x1="8.12" y1="8.12" x2="12" y2="12"></line></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rotate-ccw"><polyline points="1 4 1 10 7 10"></polyline><path d="M3.51 15a9 9 0 1 0 2.13-9.36L1 10"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="90%" height="90%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-upload"><path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4"></path><polyline points="17 8 12 3 7 8"></polyline><line x1="12" y1="3" x2="12" y2="15"></line></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-video"><polygon points="23 7 16 12 23 17 23 7"></polygon><rect x="1" y="5" width="15" height="14" rx="2" ry="2"></rect></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" fill="none" xmlns="http://www.w3.org/2000/svg" stroke="currentColor" color="currentColor"><title>Low volume</title><path d="M19.5 7.5C19.5 7.5 21 9 21 11.5C21 14 19.5 15.5 19.5 15.5" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M2 13.8571V10.1429C2 9.03829 2.89543 8.14286 4 8.14286H6.9C7.09569 8.14286 7.28708 8.08544 7.45046 7.97772L13.4495 4.02228C14.1144 3.5839 15 4.06075 15 4.85714V19.1429C15 19.9392 14.1144 20.4161 13.4495 19.9777L7.45046 16.0223C7.28708 15.9146 7.09569 15.8571 6.9 15.8571H4C2.89543 15.8571 2 14.9617 2 13.8571Z" stroke-width="1.5"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" fill="none" stroke="currentColor" xmlns="http://www.w3.org/2000/svg" color="currentColor"><title>High volume</title><path d="M1 13.8571V10.1429C1 9.03829 1.89543 8.14286 3 8.14286H5.9C6.09569 8.14286 6.28708 8.08544 6.45046 7.97772L12.4495 4.02228C13.1144 3.5839 14 4.06075 14 4.85714V19.1429C14 19.9392 13.1144 20.4161 12.4495 19.9777L6.45046 16.0223C6.28708 15.9146 6.09569 15.8571 5.9 15.8571H3C1.89543 15.8571 1 14.9617 1 13.8571Z" stroke-width="1.5"></path><path d="M17.5 7.5C17.5 7.5 19 9 19 11.5C19 14 17.5 15.5 17.5 15.5" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M20.5 4.5C20.5 4.5 23 7 23 11.5C23 16 20.5 18.5 20.5 18.5" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" fill="none" xmlns="http://www.w3.org/2000/svg" stroke="currentColor" color="currentColor"><title>Muted volume</title><g clip-path="url(#clip0_3173_16686)"><path d="M18 14L20.0005 12M22 10L20.0005 12M20.0005 12L18 10M20.0005 12L22 14" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M2 13.8571V10.1429C2 9.03829 2.89543 8.14286 4 8.14286H6.9C7.09569 8.14286 7.28708 8.08544 7.45046 7.97772L13.4495 4.02228C14.1144 3.5839 15 4.06075 15 4.85714V19.1429C15 19.9392 14.1144 20.4161 13.4495 19.9777L7.45046 16.0223C7.28708 15.9146 7.09569 15.8571 6.9 15.8571H4C2.89543 15.8571 2 14.9617 2 13.8571Z" stroke-width="1.5"></path></g><defs><clipPath id="clip0_3173_16686"><rect width="24" height="24" fill="white"></rect></clipPath></defs></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" stroke-width="2" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M12 9v3.75m-9.303 3.376c-.866 1.5.217 3.374 1.948 3.374h14.71c1.73 0 2.813-1.874 1.948-3.374L13.949 3.378c-.866-1.5-3.032-1.5-3.898 0L2.697 16.126zM12 15.75h.007v.008H12v-.008z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M12 2c-4.963 0-9 4.038-9 9c0 3.328 1.82 6.232 4.513 7.79l-2.067 1.378A1 1 0 0 0 6 22h12a1 1 0 0 0 .555-1.832l-2.067-1.378C19.18 17.232 21 14.328 21 11c0-4.962-4.037-9-9-9zm0 16c-3.859 0-7-3.141-7-7c0-3.86 3.141-7 7-7s7 3.14 7 7c0 3.859-3.141 7-7 7z"></path><path fill="currentColor" d="M12 6c-2.757 0-5 2.243-5 5s2.243 5 5 5s5-2.243 5-5s-2.243-5-5-5zm0 8c-1.654 0-3-1.346-3-3s1.346-3 3-3s3 1.346 3 3s-1.346 3-3 3z"></path></svg>');
const wo = [
  { color: "red", primary: 600, secondary: 100 },
  { color: "green", primary: 600, secondary: 100 },
  { color: "blue", primary: 600, secondary: 100 },
  { color: "yellow", primary: 500, secondary: 100 },
  { color: "purple", primary: 600, secondary: 100 },
  { color: "teal", primary: 600, secondary: 100 },
  { color: "orange", primary: 600, secondary: 100 },
  { color: "cyan", primary: 600, secondary: 100 },
  { color: "lime", primary: 500, secondary: 100 },
  { color: "pink", primary: 600, secondary: 100 }
], Mr = {
  inherit: "inherit",
  current: "currentColor",
  transparent: "transparent",
  black: "#000",
  white: "#fff",
  slate: {
    50: "#f8fafc",
    100: "#f1f5f9",
    200: "#e2e8f0",
    300: "#cbd5e1",
    400: "#94a3b8",
    500: "#64748b",
    600: "#475569",
    700: "#334155",
    800: "#1e293b",
    900: "#0f172a",
    950: "#020617"
  },
  gray: {
    50: "#f9fafb",
    100: "#f3f4f6",
    200: "#e5e7eb",
    300: "#d1d5db",
    400: "#9ca3af",
    500: "#6b7280",
    600: "#4b5563",
    700: "#374151",
    800: "#1f2937",
    900: "#111827",
    950: "#030712"
  },
  zinc: {
    50: "#fafafa",
    100: "#f4f4f5",
    200: "#e4e4e7",
    300: "#d4d4d8",
    400: "#a1a1aa",
    500: "#71717a",
    600: "#52525b",
    700: "#3f3f46",
    800: "#27272a",
    900: "#18181b",
    950: "#09090b"
  },
  neutral: {
    50: "#fafafa",
    100: "#f5f5f5",
    200: "#e5e5e5",
    300: "#d4d4d4",
    400: "#a3a3a3",
    500: "#737373",
    600: "#525252",
    700: "#404040",
    800: "#262626",
    900: "#171717",
    950: "#0a0a0a"
  },
  stone: {
    50: "#fafaf9",
    100: "#f5f5f4",
    200: "#e7e5e4",
    300: "#d6d3d1",
    400: "#a8a29e",
    500: "#78716c",
    600: "#57534e",
    700: "#44403c",
    800: "#292524",
    900: "#1c1917",
    950: "#0c0a09"
  },
  red: {
    50: "#fef2f2",
    100: "#fee2e2",
    200: "#fecaca",
    300: "#fca5a5",
    400: "#f87171",
    500: "#ef4444",
    600: "#dc2626",
    700: "#b91c1c",
    800: "#991b1b",
    900: "#7f1d1d",
    950: "#450a0a"
  },
  orange: {
    50: "#fff7ed",
    100: "#ffedd5",
    200: "#fed7aa",
    300: "#fdba74",
    400: "#fb923c",
    500: "#f97316",
    600: "#ea580c",
    700: "#c2410c",
    800: "#9a3412",
    900: "#7c2d12",
    950: "#431407"
  },
  amber: {
    50: "#fffbeb",
    100: "#fef3c7",
    200: "#fde68a",
    300: "#fcd34d",
    400: "#fbbf24",
    500: "#f59e0b",
    600: "#d97706",
    700: "#b45309",
    800: "#92400e",
    900: "#78350f",
    950: "#451a03"
  },
  yellow: {
    50: "#fefce8",
    100: "#fef9c3",
    200: "#fef08a",
    300: "#fde047",
    400: "#facc15",
    500: "#eab308",
    600: "#ca8a04",
    700: "#a16207",
    800: "#854d0e",
    900: "#713f12",
    950: "#422006"
  },
  lime: {
    50: "#f7fee7",
    100: "#ecfccb",
    200: "#d9f99d",
    300: "#bef264",
    400: "#a3e635",
    500: "#84cc16",
    600: "#65a30d",
    700: "#4d7c0f",
    800: "#3f6212",
    900: "#365314",
    950: "#1a2e05"
  },
  green: {
    50: "#f0fdf4",
    100: "#dcfce7",
    200: "#bbf7d0",
    300: "#86efac",
    400: "#4ade80",
    500: "#22c55e",
    600: "#16a34a",
    700: "#15803d",
    800: "#166534",
    900: "#14532d",
    950: "#052e16"
  },
  emerald: {
    50: "#ecfdf5",
    100: "#d1fae5",
    200: "#a7f3d0",
    300: "#6ee7b7",
    400: "#34d399",
    500: "#10b981",
    600: "#059669",
    700: "#047857",
    800: "#065f46",
    900: "#064e3b",
    950: "#022c22"
  },
  teal: {
    50: "#f0fdfa",
    100: "#ccfbf1",
    200: "#99f6e4",
    300: "#5eead4",
    400: "#2dd4bf",
    500: "#14b8a6",
    600: "#0d9488",
    700: "#0f766e",
    800: "#115e59",
    900: "#134e4a",
    950: "#042f2e"
  },
  cyan: {
    50: "#ecfeff",
    100: "#cffafe",
    200: "#a5f3fc",
    300: "#67e8f9",
    400: "#22d3ee",
    500: "#06b6d4",
    600: "#0891b2",
    700: "#0e7490",
    800: "#155e75",
    900: "#164e63",
    950: "#083344"
  },
  sky: {
    50: "#f0f9ff",
    100: "#e0f2fe",
    200: "#bae6fd",
    300: "#7dd3fc",
    400: "#38bdf8",
    500: "#0ea5e9",
    600: "#0284c7",
    700: "#0369a1",
    800: "#075985",
    900: "#0c4a6e",
    950: "#082f49"
  },
  blue: {
    50: "#eff6ff",
    100: "#dbeafe",
    200: "#bfdbfe",
    300: "#93c5fd",
    400: "#60a5fa",
    500: "#3b82f6",
    600: "#2563eb",
    700: "#1d4ed8",
    800: "#1e40af",
    900: "#1e3a8a",
    950: "#172554"
  },
  indigo: {
    50: "#eef2ff",
    100: "#e0e7ff",
    200: "#c7d2fe",
    300: "#a5b4fc",
    400: "#818cf8",
    500: "#6366f1",
    600: "#4f46e5",
    700: "#4338ca",
    800: "#3730a3",
    900: "#312e81",
    950: "#1e1b4b"
  },
  violet: {
    50: "#f5f3ff",
    100: "#ede9fe",
    200: "#ddd6fe",
    300: "#c4b5fd",
    400: "#a78bfa",
    500: "#8b5cf6",
    600: "#7c3aed",
    700: "#6d28d9",
    800: "#5b21b6",
    900: "#4c1d95",
    950: "#2e1065"
  },
  purple: {
    50: "#faf5ff",
    100: "#f3e8ff",
    200: "#e9d5ff",
    300: "#d8b4fe",
    400: "#c084fc",
    500: "#a855f7",
    600: "#9333ea",
    700: "#7e22ce",
    800: "#6b21a8",
    900: "#581c87",
    950: "#3b0764"
  },
  fuchsia: {
    50: "#fdf4ff",
    100: "#fae8ff",
    200: "#f5d0fe",
    300: "#f0abfc",
    400: "#e879f9",
    500: "#d946ef",
    600: "#c026d3",
    700: "#a21caf",
    800: "#86198f",
    900: "#701a75",
    950: "#4a044e"
  },
  pink: {
    50: "#fdf2f8",
    100: "#fce7f3",
    200: "#fbcfe8",
    300: "#f9a8d4",
    400: "#f472b6",
    500: "#ec4899",
    600: "#db2777",
    700: "#be185d",
    800: "#9d174d",
    900: "#831843",
    950: "#500724"
  },
  rose: {
    50: "#fff1f2",
    100: "#ffe4e6",
    200: "#fecdd3",
    300: "#fda4af",
    400: "#fb7185",
    500: "#f43f5e",
    600: "#e11d48",
    700: "#be123c",
    800: "#9f1239",
    900: "#881337",
    950: "#4c0519"
  }
};
wo.reduce((a, { color: t, primary: r, secondary: n }) => ({
  ...a,
  [t]: {
    primary: Mr[t][r],
    secondary: Mr[t][n]
  }
}), {});
e.from_html('<span class="or svelte-o75ikz"> </span> ', 1);
e.from_html('<div class="wrap svelte-o75ikz"><span><!></span> <!></div>');
e.from_html("<div><!></div>");
e.from_html('<button aria-label="Upload file"><!></button>');
e.from_html('<button aria-label="Record audio"><!></button>');
e.from_html('<button aria-label="Capture from camera"><!></button>');
e.from_html('<button aria-label="Paste from clipboard"><!></button>');
e.from_html('<span class="source-selection svelte-1l6z5zu" data-testid="source-select"><!> <!> <!> <!></span>');
var _o = e.from_html('<label class="block"><!> <input type="color" class="svelte-1yl3uhg"/></label>');
function bo(a, t) {
  e.push(t, !1);
  let r = e.prop(t, "value", 12, "#000000"), n = e.prop(t, "value_is_output", 12, !1), s = e.prop(t, "label", 8), i = e.prop(t, "info", 8, void 0), o = e.prop(t, "disabled", 8, !1), l = e.prop(t, "show_label", 8, !0);
  const c = Re();
  function w() {
    c("change", r()), n() || c("input");
  }
  zr(() => {
    n(!1);
  }), e.legacy_pre_effect(() => e.deep_read_state(r()), () => {
    r(), w();
  }), e.legacy_pre_effect_reset(), e.init();
  var h = _o(), _ = e.child(h);
  mo(_, {
    get show_label() {
      return l();
    },
    get info() {
      return i();
    },
    children: (D, T) => {
      e.next();
      var E = e.text();
      e.template_effect(() => e.set_text(E, s())), e.append(D, E);
    },
    $$slots: { default: !0 }
  });
  var b = e.sibling(_, 2);
  e.remove_input_defaults(b), e.reset(h), e.template_effect(() => b.disabled = o()), e.bind_value(b, r), e.event("focus", b, function(D) {
    e.bubble_event.call(this, t, D);
  }), e.event("blur", b, function(D) {
    e.bubble_event.call(this, t, D);
  }), e.append(a, h), e.pop();
}
e.from_html('<div><svg viewBox="-1200 -1200 3000 3000" fill="none" xmlns="http://www.w3.org/2000/svg" class="svelte-1i9rmvk"><g><path d="M255.926 0.754768L509.702 139.936V221.027L255.926 81.8465V0.754768Z" fill="#FF7C00" fill-opacity="0.4" class="svelte-1i9rmvk"></path><path d="M509.69 139.936L254.981 279.641V361.255L509.69 221.55V139.936Z" fill="#FF7C00" class="svelte-1i9rmvk"></path><path d="M0.250138 139.937L254.981 279.641V361.255L0.250138 221.55V139.937Z" fill="#FF7C00" fill-opacity="0.4" class="svelte-1i9rmvk"></path><path d="M255.923 0.232622L0.236328 139.936V221.55L255.923 81.8469V0.232622Z" fill="#FF7C00" class="svelte-1i9rmvk"></path></g><g><path d="M255.926 141.5L509.702 280.681V361.773L255.926 222.592V141.5Z" fill="#FF7C00" fill-opacity="0.4" class="svelte-1i9rmvk"></path><path d="M509.69 280.679L254.981 420.384V501.998L509.69 362.293V280.679Z" fill="#FF7C00" class="svelte-1i9rmvk"></path><path d="M0.250138 280.681L254.981 420.386V502L0.250138 362.295V280.681Z" fill="#FF7C00" fill-opacity="0.4" class="svelte-1i9rmvk"></path><path d="M255.923 140.977L0.236328 280.68V362.294L255.923 222.591V140.977Z" fill="#FF7C00" class="svelte-1i9rmvk"></path></g></svg></div>');
e.from_html('<div class="eta-bar svelte-c1s6oz"></div>');
e.from_html("<!> ", 1);
e.from_html("<!> <!> <!> <!>", 1);
e.from_html('<div class="progress-level svelte-c1s6oz"><div class="progress-level-inner svelte-c1s6oz"><!></div> <div class="progress-bar-wrap svelte-c1s6oz"><div class="progress-bar svelte-c1s6oz"></div></div></div>');
e.from_html('<p class="loading svelte-c1s6oz"> </p>');
e.from_html("<!> <div><!> <!></div> <!> <!>", 1);
e.from_html('<span class="error svelte-c1s6oz"> </span> <!>', 1);
e.from_html("<div><!></div>");
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="24px" height="24px" fill="currentColor" stroke-width="1.5" viewBox="0 0 24 24" color="currentColor"><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" d="M21.044 5.704a.6.6 0 0 1 .956.483v11.626a.6.6 0 0 1-.956.483l-7.889-5.813a.6.6 0 0 1 0-.966l7.89-5.813ZM10.044 5.704a.6.6 0 0 1 .956.483v11.626a.6.6 0 0 1-.956.483l-7.888-5.813a.6.6 0 0 1 0-.966l7.888-5.813Z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 32 32"><path d="M28.828 3.172a4.094 4.094 0 0 0-5.656 0L4.05 22.292A6.954 6.954 0 0 0 2 27.242V30h2.756a6.952 6.952 0 0 0 4.95-2.05L28.828 8.829a3.999 3.999 0 0 0 0-5.657zM10.91 18.26l2.829 2.829l-2.122 2.121l-2.828-2.828zm-2.619 8.276A4.966 4.966 0 0 1 4.756 28H4v-.759a4.967 4.967 0 0 1 1.464-3.535l1.91-1.91l2.829 2.828zM27.415 7.414l-12.261 12.26l-2.829-2.828l12.262-12.26a2.047 2.047 0 0 1 2.828 0a2 2 0 0 1 0 2.828z" fill="currentColor"></path><path d="M6.5 15a3.5 3.5 0 0 1-2.475-5.974l3.5-3.5a1.502 1.502 0 0 0 0-2.121a1.537 1.537 0 0 0-2.121 0L3.415 5.394L2 3.98l1.99-1.988a3.585 3.585 0 0 1 4.95 0a3.504 3.504 0 0 1 0 4.949L5.439 10.44a1.502 1.502 0 0 0 0 2.121a1.537 1.537 0 0 0 2.122 0l4.024-4.024L13 9.95l-4.025 4.024A3.475 3.475 0 0 1 6.5 15z" fill="currentColor"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M2.753 2.933a.75.75 0 0 1 .814-.68l3.043.272c2.157.205 4.224.452 5.922.732c1.66.273 3.073.594 3.844.983c.197.1.412.233.578.415c.176.192.352.506.28.9c-.067.356-.304.59-.487.729a3.001 3.001 0 0 1-.695.369c-1.02.404-2.952.79-5.984 1.169c-1.442.18-2.489.357-3.214.522c.205.045.43.089.674.132c.992.174 2.241.323 3.568.437a31.21 31.21 0 0 1 3.016.398c.46.087.893.186 1.261.296c.352.105.707.236.971.412c.13.086.304.225.42.437a.988.988 0 0 1 .063.141A1.75 1.75 0 0 0 14.5 12.25v.158c-.758.154-1.743.302-2.986.444c-2.124.243-3.409.55-4.117.859c-.296.128-.442.236-.508.3c.026.037.073.094.156.17c.15.138.369.29.65.45c.56.316 1.282.61 1.979.838l2.637.814a.75.75 0 1 1-.443 1.433l-2.655-.819c-.754-.247-1.58-.578-2.257-.96a5.082 5.082 0 0 1-.924-.65c-.255-.233-.513-.544-.62-.935c-.12-.441-.016-.88.274-1.244c.261-.328.656-.574 1.113-.773c.92-.4 2.387-.727 4.545-.974c1.366-.156 2.354-.313 3.041-.462a16.007 16.007 0 0 0-.552-.114a29.716 29.716 0 0 0-2.865-.378c-1.352-.116-2.649-.27-3.7-.454c-.524-.092-1-.194-1.395-.307c-.376-.106-.75-.241-1.021-.426a1.186 1.186 0 0 1-.43-.49a.934.934 0 0 1 .059-.873c.13-.213.32-.352.472-.442a3.23 3.23 0 0 1 .559-.251c.807-.287 2.222-.562 4.37-.83c2.695-.338 4.377-.666 5.295-.962c-.638-.21-1.623-.427-2.89-.635c-1.65-.273-3.679-.515-5.816-.718l-3.038-.272a.75.75 0 0 1-.68-.814M17 12.25a.75.75 0 0 0-1.5 0v4.19l-.72-.72a.75.75 0 1 0-1.06 1.06l2 2a.75.75 0 0 0 1.06 0l2-2a.75.75 0 1 0-1.06-1.06l-.72.72z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-camera"><path d="M23 19a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h4l2-3h6l2 3h4a2 2 0 0 1 2 2z"></path><circle cx="12" cy="13" r="4"></circle></svg>');
e.from_svg('<svg viewBox="0 0 32 32"><path d="M28.828 3.172a4.094 4.094 0 0 0-5.656 0L4.05 22.292A6.954 6.954 0 0 0 2 27.242V30h2.756a6.952 6.952 0 0 0 4.95-2.05L28.828 8.829a3.999 3.999 0 0 0 0-5.657zM10.91 18.26l2.829 2.829l-2.122 2.121l-2.828-2.828zm-2.619 8.276A4.966 4.966 0 0 1 4.756 28H4v-.759a4.967 4.967 0 0 1 1.464-3.535l1.91-1.91l2.829 2.828zM27.415 7.414l-12.261 12.26l-2.829-2.828l12.262-12.26a2.047 2.047 0 0 1 2.828 0a2 2 0 0 1 0 2.828z" fill="currentColor"></path><path d="M6.5 15a3.5 3.5 0 0 1-2.475-5.974l3.5-3.5a1.502 1.502 0 0 0 0-2.121a1.537 1.537 0 0 0-2.121 0L3.415 5.394L2 3.98l1.99-1.988a3.585 3.585 0 0 1 4.95 0a3.504 3.504 0 0 1 0 4.949L5.439 10.44a1.502 1.502 0 0 0 0 2.121a1.537 1.537 0 0 0 2.122 0l4.024-4.024L13 9.95l-4.025 4.024A3.475 3.475 0 0 1 6.5 15z" fill="currentColor"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M17.74 30L16 29l4-7h6a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h9v2H6a4 4 0 0 1-4-4V8a4 4 0 0 1 4-4h20a4 4 0 0 1 4 4v12a4 4 0 0 1-4 4h-4.84Z"></path><path fill="currentColor" d="M8 10h16v2H8zm0 6h10v2H8z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="2 0 20 20" fill="none" stroke="currentColor" stroke-width="3" stroke-linecap="round" stroke-linejoin="round"><polyline points="20 6 9 17 4 12"></polyline></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-circle"><circle cx="12" cy="12" r="10"></circle></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xml:space="preserve" stroke="currentColor" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linecap:round;stroke-linejoin:round;"><g transform="matrix(1.14096,-0.140958,-0.140958,1.14096,-0.0559523,0.0559523)"><path d="M18,6L6.087,17.913" style="fill:none;fill-rule:nonzero;stroke-width:2px;"></path></g><path d="M4.364,4.364L19.636,19.636" style="fill:none;fill-rule:nonzero;stroke-width:2px;"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 32 32"><path fill="currentColor" d="m31 16l-7 7l-1.41-1.41L28.17 16l-5.58-5.59L24 9l7 7zM1 16l7-7l1.41 1.41L3.83 16l5.58 5.59L8 23l-7-7zm11.42 9.484L17.64 6l1.932.517L14.352 26z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 32 32"><circle cx="10" cy="12" r="2" fill="currentColor"></circle><circle cx="16" cy="9" r="2" fill="currentColor"></circle><circle cx="22" cy="12" r="2" fill="currentColor"></circle><circle cx="23" cy="18" r="2" fill="currentColor"></circle><circle cx="19" cy="23" r="2" fill="currentColor"></circle><path fill="currentColor" d="M16.54 2A14 14 0 0 0 2 16a4.82 4.82 0 0 0 6.09 4.65l1.12-.31a3 3 0 0 1 3.79 2.9V27a3 3 0 0 0 3 3a14 14 0 0 0 14-14.54A14.05 14.05 0 0 0 16.54 2Zm8.11 22.31A11.93 11.93 0 0 1 16 28a1 1 0 0 1-1-1v-3.76a5 5 0 0 0-5-5a5.07 5.07 0 0 0-1.33.18l-1.12.31A2.82 2.82 0 0 1 4 16A12 12 0 0 1 16.47 4A12.18 12.18 0 0 1 28 15.53a11.89 11.89 0 0 1-3.35 8.79Z"></path></svg>');
e.from_svg('<svg id="icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32"><path d="M23,20a5,5,0,0,0-3.89,1.89L11.8,17.32a4.46,4.46,0,0,0,0-2.64l7.31-4.57A5,5,0,1,0,18,7a4.79,4.79,0,0,0,.2,1.32l-7.31,4.57a5,5,0,1,0,0,6.22l7.31,4.57A4.79,4.79,0,0,0,18,25a5,5,0,1,0,5-5ZM23,4a3,3,0,1,1-3,3A3,3,0,0,1,23,4ZM7,19a3,3,0,1,1,3-3A3,3,0,0,1,7,19Zm16,9a3,3,0,1,1,3-3A3,3,0,0,1,23,28Z" fill="currentColor"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 33 33" color="currentColor"><path fill="currentColor" d="M28 10v18H10V10h18m0-2H10a2 2 0 0 0-2 2v18a2 2 0 0 0 2 2h18a2 2 0 0 0 2-2V10a2 2 0 0 0-2-2Z"></path><path fill="currentColor" d="M4 18H2V4a2 2 0 0 1 2-2h14v2H4Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M17 23v-4H7q-.825 0-1.413-.588T5 17V7H1V5h4V1h2v16h16v2h-4v4h-2Zm0-8V7H9V5h8q.825 0 1.413.588T19 7v8h-2Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" stroke-width="1.5" color="currentColor"><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" d="M16.472 3.5H4.1a.6.6 0 0 0-.6.6v9.8a.6.6 0 0 0 .6.6h2.768a2 2 0 0 1 1.715.971l2.71 4.517a1.631 1.631 0 0 0 2.961-1.308l-1.022-3.408a.6.6 0 0 1 .574-.772h4.575a2 2 0 0 0 1.93-2.526l-1.91-7A2 2 0 0 0 16.473 3.5Z"></path><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" d="M7 14.5v-11"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 32 32"><path fill="currentColor" d="M26 24v4H6v-4H4v4a2 2 0 0 0 2 2h20a2 2 0 0 0 2-2v-4zm0-10l-1.41-1.41L17 20.17V2h-2v18.17l-7.59-7.58L6 14l10 10l10-10z"></path></svg>');
e.from_svg('<svg class="dropdown-arrow svelte-yl3zqg" xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 18 18"><path d="M5 8l4 4 4-4z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-edit-2"><path d="M17 3a2.828 2.828 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5L17 3z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><g fill="none"><path fill="currentColor" d="m5.505 11.41l.53.53l-.53-.53ZM3 14.952h-.75H3ZM9.048 21v.75V21ZM11.41 5.505l-.53-.53l.53.53Zm1.831 12.34a.75.75 0 0 0 1.06-1.061l-1.06 1.06ZM7.216 9.697a.75.75 0 1 0-1.06 1.061l1.06-1.06Zm10.749 2.362l-5.905 5.905l1.06 1.06l5.905-5.904l-1.06-1.06Zm-11.93-.12l5.905-5.905l-1.06-1.06l-5.905 5.904l1.06 1.06Zm0 6.025c-.85-.85-1.433-1.436-1.812-1.933c-.367-.481-.473-.79-.473-1.08h-1.5c0 .749.312 1.375.78 1.99c.455.596 1.125 1.263 1.945 2.083l1.06-1.06Zm-1.06-7.086c-.82.82-1.49 1.488-1.945 2.084c-.468.614-.78 1.24-.78 1.99h1.5c0-.29.106-.6.473-1.08c.38-.498.962-1.083 1.812-1.933l-1.06-1.06Zm7.085 7.086c-.85.85-1.435 1.433-1.933 1.813c-.48.366-.79.472-1.08.472v1.5c.75 0 1.376-.312 1.99-.78c.596-.455 1.264-1.125 2.084-1.945l-1.06-1.06Zm-7.085 1.06c.82.82 1.487 1.49 2.084 1.945c.614.468 1.24.78 1.989.78v-1.5c-.29 0-.599-.106-1.08-.473c-.497-.38-1.083-.962-1.933-1.812l-1.06 1.06Zm12.99-12.99c.85.85 1.433 1.436 1.813 1.933c.366.481.472.79.472 1.08h1.5c0-.749-.312-1.375-.78-1.99c-.455-.596-1.125-1.263-1.945-2.083l-1.06 1.06Zm1.06 7.086c.82-.82 1.49-1.488 1.945-2.084c.468-.614.78-1.24.78-1.99h-1.5c0 .29-.106.6-.473 1.08c-.38.498-.962 1.083-1.812 1.933l1.06 1.06Zm0-8.146c-.82-.82-1.487-1.49-2.084-1.945c-.614-.468-1.24-.78-1.989-.78v1.5c.29 0 .599.106 1.08.473c.497.38 1.083.962 1.933 1.812l1.06-1.06Zm-7.085 1.06c.85-.85 1.435-1.433 1.933-1.812c.48-.367.79-.473 1.08-.473v-1.5c-.75 0-1.376.312-1.99.78c-.596.455-1.264 1.125-2.084 1.945l1.06 1.06Zm2.362 10.749L7.216 9.698l-1.06 1.061l7.085 7.085l1.06-1.06Z"></path><path stroke="currentColor" stroke-linecap="round" stroke-width="1.5" d="M9 21h12"></path></g></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M12 9v3.75m9-.75a9 9 0 11-18 0 9 9 0 0118 0zm-9 3.75h.008v.008H12v-.008z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M21.03 2.97a3.578 3.578 0 0 0-5.06 0L14 4.94l-.013-.013a1.75 1.75 0 0 0-2.475 0l-.585.586a1.75 1.75 0 0 0 0 2.475l.012.012l-6.78 6.78a2.25 2.25 0 0 0-.659 1.592v.687l-1.28 2.347c-.836 1.533.841 3.21 2.374 2.375l2.347-1.28h.688a2.25 2.25 0 0 0 1.59-.66L16 13.061l.012.012a1.75 1.75 0 0 0 2.475 0l.586-.585a1.75 1.75 0 0 0 0-2.475L19.061 10l1.97-1.97a3.578 3.578 0 0 0 0-5.06ZM12 9.061l2.94 2.94l-6.78 6.78a.75.75 0 0 1-.531.22H6.75a.75.75 0 0 0-.359.09l-2.515 1.373a.234.234 0 0 1-.159.032a.264.264 0 0 1-.138-.075a.264.264 0 0 1-.075-.138a.234.234 0 0 1 .033-.158l1.372-2.515A.75.75 0 0 0 5 17.25v-.878a.75.75 0 0 1 .22-.53L12 9.06Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="24px" height="24px" fill="currentColor" stroke-width="1.5" viewBox="0 0 24 24" color="currentColor"><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" d="M2.956 5.704A.6.6 0 0 0 2 6.187v11.626a.6.6 0 0 0 .956.483l7.889-5.813a.6.6 0 0 0 0-.966l-7.89-5.813ZM13.956 5.704a.6.6 0 0 0-.956.483v11.626a.6.6 0 0 0 .956.483l7.889-5.813a.6.6 0 0 0 0-.966l-7.89-5.813Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-file"><path d="M13 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9z"></path><polyline points="13 2 13 9 20 9"></polyline></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M11.25 11.25l.041-.02a.75.75 0 011.063.852l-.708 2.836a.75.75 0 001.063.853l.041-.021M21 12a9 9 0 11-18 0 9 9 0 0118 0zm-9-3.75h.008v.008H12V8.25z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-image"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><circle cx="8.5" cy="8.5" r="1.5"></circle><polyline points="21 15 16 10 5 21"></polyline></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path fill="currentColor" d="M13.75 2a2.25 2.25 0 0 1 2.236 2.002V4h1.764A2.25 2.25 0 0 1 20 6.25V11h-1.5V6.25a.75.75 0 0 0-.75-.75h-2.129c-.404.603-1.091 1-1.871 1h-3.5c-.78 0-1.467-.397-1.871-1H6.25a.75.75 0 0 0-.75.75v13.5c0 .414.336.75.75.75h4.78a4 4 0 0 0 .505 1.5H6.25A2.25 2.25 0 0 1 4 19.75V6.25A2.25 2.25 0 0 1 6.25 4h1.764a2.25 2.25 0 0 1 2.236-2zm2.245 2.096L16 4.25q0-.078-.005-.154M13.75 3.5h-3.5a.75.75 0 0 0 0 1.5h3.5a.75.75 0 0 0 0-1.5M15 12a3 3 0 0 0-3 3v5c0 .556.151 1.077.415 1.524l3.494-3.494a2.25 2.25 0 0 1 3.182 0l3.494 3.494c.264-.447.415-.968.415-1.524v-5a3 3 0 0 0-3-3zm0 11a3 3 0 0 1-1.524-.415l3.494-3.494a.75.75 0 0 1 1.06 0l3.494 3.494A3 3 0 0 1 20 23zm5-7a1 1 0 1 1 0-2 1 1 0 0 1 0 2"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--mdi" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 24 24"><path fill="currentColor" d="M5 3h2v2H5v5a2 2 0 0 1-2 2a2 2 0 0 1 2 2v5h2v2H5c-1.07-.27-2-.9-2-2v-4a2 2 0 0 0-2-2H0v-2h1a2 2 0 0 0 2-2V5a2 2 0 0 1 2-2m14 0a2 2 0 0 1 2 2v4a2 2 0 0 0 2 2h1v2h-1a2 2 0 0 0-2 2v4a2 2 0 0 1-2 2h-2v-2h2v-5a2 2 0 0 1 2-2a2 2 0 0 1-2-2V5h-2V3h2m-7 12a1 1 0 0 1 1 1a1 1 0 0 1-1 1a1 1 0 0 1-1-1a1 1 0 0 1 1-1m-4 0a1 1 0 0 1 1 1a1 1 0 0 1-1 1a1 1 0 0 1-1-1a1 1 0 0 1 1-1m8 0a1 1 0 0 1 1 1a1 1 0 0 1-1 1a1 1 0 0 1-1-1a1 1 0 0 1 1-1Z"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 17 17" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M1.35327 10.9495L6.77663 15.158C7.12221 15.4229 7.50051 15.5553 7.91154 15.5553C8.32258 15.5553 8.70126 15.4229 9.0476 15.158L14.471 10.9495" stroke="currentColor" stroke-width="1.5" stroke-linecap="round"></path><path d="M7.23461 11.4324C7.23406 11.432 7.2335 11.4316 7.23295 11.4312L1.81496 7.2268C1.81471 7.22661 1.81446 7.22641 1.8142 7.22621C1.52269 6.99826 1.39429 6.73321 1.39429 6.37014C1.39429 6.00782 1.52236 5.74301 1.81325 5.51507C1.8136 5.5148 1.81394 5.51453 1.81428 5.51426L7.2331 1.30812C7.45645 1.13785 7.67632 1.06653 7.91159 1.06653C8.14692 1.06653 8.36622 1.13787 8.58861 1.30787C8.58915 1.30828 8.58969 1.30869 8.59023 1.30911L14.0082 5.51462C14.0085 5.51485 14.0088 5.51507 14.0091 5.51529C14.3008 5.74345 14.4289 6.00823 14.4289 6.37014C14.4289 6.73356 14.3006 6.99862 14.01 7.22634C14.0096 7.22662 14.0093 7.22689 14.0089 7.22717L8.59007 11.4322C8.36672 11.6024 8.14686 11.6738 7.91159 11.6738C7.67628 11.6738 7.45699 11.6024 7.23461 11.4324Z" stroke="currentColor" stroke-width="1.5"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" stroke-width="1.5" color="currentColor"><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" d="M16.472 20H4.1a.6.6 0 0 1-.6-.6V9.6a.6.6 0 0 1 .6-.6h2.768a2 2 0 0 0 1.715-.971l2.71-4.517a1.631 1.631 0 0 1 2.961 1.308l-1.022 3.408a.6.6 0 0 0 .574.772h4.575a2 2 0 0 1 1.93 2.526l-1.91 7A2 2 0 0 1 16.473 20Z"></path><path stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" d="M7 20V9"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M4 2H2v26a2 2 0 0 0 2 2h26v-2H4v-3h22v-8H4v-4h14V5H4Zm20 17v4H4v-4ZM16 7v4H4V7Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"><path d="M8 3H5a2 2 0 0 0-2 2v3m18 0V5a2 2 0 0 0-2-2h-3m0 18h3a2 2 0 0 0 2-2v-3M3 16v3a2 2 0 0 0 2 2h3"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-mic"><path d="M12 1a3 3 0 0 0-3 3v8a3 3 0 0 0 6 0V4a3 3 0 0 0-3-3z"></path><path d="M19 10v2a7 7 0 0 1-14 0v-2"></path><line x1="12" y1="19" x2="12" y2="23"></line><line x1="8" y1="23" x2="16" y2="23"></line></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-music"><path d="M9 18V5l12-2v13"></path><circle cx="6" cy="18" r="3"></circle><circle cx="18" cy="16" r="3"></circle></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><g fill="none" stroke="currentColor" stroke-width="1.5"><path d="M2 12.026c0 5.146 3.867 9.387 8.847 9.96c.735.085 1.447-.228 1.97-.753a1.68 1.68 0 0 0 0-2.372c-.523-.525-.95-1.307-.555-1.934c1.576-2.508 9.738 3.251 9.738-4.9C22 6.488 17.523 2 12 2S2 6.489 2 12.026Z"></path><circle cx="17.5" cy="11.5" r=".75"></circle><circle cx="6.5" cy="11.5" r=".75"></circle><path d="M10.335 7a.75.75 0 1 1-1.5 0a.75.75 0 0 1 1.5 0Zm4.915 0a.75.75 0 1 1-1.5 0a.75.75 0 0 1 1.5 0Z"></path></g></svg>');
e.from_svg('<svg fill="currentColor" viewBox="0 0 1920 1920" xmlns="http://www.w3.org/2000/svg"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M1752.768 221.109C1532.646.986 1174.283.986 954.161 221.109l-838.588 838.588c-154.052 154.165-154.052 404.894 0 558.946 149.534 149.421 409.976 149.308 559.059 0l758.738-758.626c87.982-88.094 87.982-231.417 0-319.51-88.32-88.208-231.642-87.982-319.51 0l-638.796 638.908 79.85 79.849 638.795-638.908c43.934-43.821 115.539-43.934 159.812 0 43.934 44.047 43.934 115.877 0 159.812l-758.739 758.625c-110.23 110.118-289.355 110.005-399.36 0-110.118-110.117-110.005-289.242 0-399.247l838.588-838.588c175.963-175.962 462.382-176.188 638.909 0 176.075 176.188 176.075 462.833 0 638.908l-798.607 798.72 79.849 79.85 798.607-798.72c220.01-220.123 220.01-578.485 0-798.607" fill-rule="evenodd"></path></g></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="currentColor" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"><rect x="6" y="4" width="4" height="16"></rect><rect x="14" y="4" width="4" height="16"></rect></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="currentColor" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"><polygon points="5 3 19 12 5 21 5 3"></polygon></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><circle cx="20" cy="4" r="2" fill="currentColor"></circle><circle cx="8" cy="16" r="2" fill="currentColor"></circle><circle cx="28" cy="12" r="2" fill="currentColor"></circle><circle cx="11" cy="7" r="2" fill="currentColor"></circle><circle cx="16" cy="24" r="2" fill="currentColor"></circle><path fill="currentColor" d="M30 3.413L28.586 2L4 26.585V2H2v26a2 2 0 0 0 2 2h26v-2H5.413Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rotate-ccw" style="transform: rotateY(180deg);"><polyline points="1 4 1 10 7 10"></polyline><path d="M3.51 15a9 9 0 1 0 2.13-9.36L1 10"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 1024 1024"><path fill="currentColor" d="M672 418H144c-17.7 0-32 14.3-32 32v414c0 17.7 14.3 32 32 32h528c17.7 0 32-14.3 32-32V450c0-17.7-14.3-32-32-32zm-44 402H188V494h440v326z"></path><path fill="currentColor" d="M819.3 328.5c-78.8-100.7-196-153.6-314.6-154.2l-.2-64c0-6.5-7.6-10.1-12.6-6.1l-128 101c-4 3.1-3.9 9.1 0 12.3L492 318.6c5.1 4 12.7.4 12.6-6.1v-63.9c12.9.1 25.9.9 38.8 2.5c42.1 5.2 82.1 18.2 119 38.7c38.1 21.2 71.2 49.7 98.4 84.3c27.1 34.7 46.7 73.7 58.1 115.8c11 40.7 14 82.7 8.9 124.8c-.7 5.4-1.4 10.8-2.4 16.1h74.9c14.8-103.6-11.3-213-81-302.3z"></path></svg>');
e.from_svg('<svg viewBox="0 -2 24 24" width="100%" height="100%" fill="none" xmlns="http://www.w3.org/2000/svg"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M19.1168 12.1484C19.474 12.3581 19.9336 12.2384 20.1432 11.8811C20.3528 11.5238 20.2331 11.0643 19.8758 10.8547L19.1168 12.1484ZM6.94331 4.13656L6.55624 4.77902L6.56378 4.78344L6.94331 4.13656ZM5.92408 4.1598L5.50816 3.5357L5.50816 3.5357L5.92408 4.1598ZM5.51031 5.09156L4.76841 5.20151C4.77575 5.25101 4.78802 5.29965 4.80505 5.34671L5.51031 5.09156ZM7.12405 11.7567C7.26496 12.1462 7.69495 12.3477 8.08446 12.2068C8.47397 12.0659 8.67549 11.6359 8.53458 11.2464L7.12405 11.7567ZM19.8758 12.1484C20.2331 11.9388 20.3528 11.4793 20.1432 11.122C19.9336 10.7648 19.474 10.6451 19.1168 10.8547L19.8758 12.1484ZM6.94331 18.8666L6.56375 18.2196L6.55627 18.2241L6.94331 18.8666ZM5.92408 18.8433L5.50815 19.4674H5.50815L5.92408 18.8433ZM5.51031 17.9116L4.80505 17.6564C4.78802 17.7035 4.77575 17.7521 4.76841 17.8016L5.51031 17.9116ZM8.53458 11.7567C8.67549 11.3672 8.47397 10.9372 8.08446 10.7963C7.69495 10.6554 7.26496 10.8569 7.12405 11.2464L8.53458 11.7567ZM19.4963 12.2516C19.9105 12.2516 20.2463 11.9158 20.2463 11.5016C20.2463 11.0873 19.9105 10.7516 19.4963 10.7516V12.2516ZM7.82931 10.7516C7.4151 10.7516 7.07931 11.0873 7.07931 11.5016C7.07931 11.9158 7.4151 12.2516 7.82931 12.2516V10.7516ZM19.8758 10.8547L7.32284 3.48968L6.56378 4.78344L19.1168 12.1484L19.8758 10.8547ZM7.33035 3.49414C6.76609 3.15419 6.05633 3.17038 5.50816 3.5357L6.34 4.78391C6.40506 4.74055 6.4893 4.73863 6.55627 4.77898L7.33035 3.49414ZM5.50816 3.5357C4.95998 3.90102 4.67184 4.54987 4.76841 5.20151L6.25221 4.98161C6.24075 4.90427 6.27494 4.82727 6.34 4.78391L5.50816 3.5357ZM4.80505 5.34671L7.12405 11.7567L8.53458 11.2464L6.21558 4.83641L4.80505 5.34671ZM19.1168 10.8547L6.56378 18.2197L7.32284 19.5134L19.8758 12.1484L19.1168 10.8547ZM6.55627 18.2241C6.4893 18.2645 6.40506 18.2626 6.34 18.2192L5.50815 19.4674C6.05633 19.8327 6.76609 19.8489 7.33035 19.509L6.55627 18.2241ZM6.34 18.2192C6.27494 18.1759 6.24075 18.0988 6.25221 18.0215L4.76841 17.8016C4.67184 18.4532 4.95998 19.1021 5.50815 19.4674L6.34 18.2192ZM6.21558 18.1667L8.53458 11.7567L7.12405 11.2464L4.80505 17.6564L6.21558 18.1667ZM19.4963 10.7516H7.82931V12.2516H19.4963V10.7516Z" fill="currentColor"></path></g></svg>');
e.from_svg('<svg enable-background="new 0 0 32 32" height="20" width="20" viewBox="0 0 32 32" fill="currentColor" xmlns="http://www.w3.org/2000/svg"><path d="m30 8h-4.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4h-14.1v2h14.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4h4.1zm-9 4c-1.7 0-3-1.3-3-3s1.3-3 3-3 3 1.3 3 3-1.3 3-3 3z"></path><path d="m2 24h4.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4h14.1v-2h-14.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4h-4.1zm9-4c1.7 0 3 1.3 3 3s-1.3 3-3 3-3-1.3-3-3 1.3-3 3-3z"></path><path d="m0 0h32v32h-32z" fill="none"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-edit-2"><path d="M17 3a2.828 2.828 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5L17 3z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-square"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-table"><path d="M9 3H5a2 2 0 0 0-2 2v4m6-6h10a2 2 0 0 1 2 2v4M9 3v18m0 0h10a2 2 0 0 0 2-2V9M9 21H5a2 2 0 0 1-2-2V9m0 0h18"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M12 15H5a3 3 0 0 1-3-3v-2a3 3 0 0 1 3-3h5V5a1 1 0 0 0-1-1H3V2h6a3 3 0 0 1 3 3zM5 9a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h5V9zm15 14v2a1 1 0 0 0 1 1h5v-4h-5a1 1 0 0 0-1 1z"></path><path fill="currentColor" d="M2 30h28V2Zm26-2h-7a3 3 0 0 1-3-3v-2a3 3 0 0 1 3-3h5v-2a1 1 0 0 0-1-1h-6v-2h6a3 3 0 0 1 3 3Z"></path></svg>');
e.from_svg(`<svg id="icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32" fill="currentColor"><defs><style>.cls-1 {
				fill: none;
			}</style></defs><rect x="12" y="12" width="2" height="12"></rect><rect x="18" y="12" width="2" height="12"></rect><path d="M4,6V8H6V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8h2V6ZM8,28V8H24V28Z"></path><rect x="12" y="2" width="8" height="2"></rect><rect id="_Transparent_Rectangle_" data-name="&lt;Transparent Rectangle>" class="cls-1" width="32" height="32"></rect></svg>`);
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" role="img" class="iconify iconify--carbon" width="100%" height="100%" preserveAspectRatio="xMidYMid meet" viewBox="0 0 32 32"><path fill="currentColor" d="M23 9.005h6a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-6a2 2 0 0 0-2 2v1H11v-1a2 2 0 0 0-2-2H3a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-1h4v20a2.002 2.002 0 0 0 2 2h4v1a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-6a2 2 0 0 0-2 2v1h-4v-9h4v1a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-6a2 2 0 0 0-2 2v1h-4v-9h4v1a2 2 0 0 0 2 2Zm0-6h6v4h-6Zm-14 4H3v-4h6Zm14 18h6v4h-6Zm0-11h6v4h-6Z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-scissors"><circle cx="6" cy="6" r="3"></circle><circle cx="6" cy="18" r="3"></circle><line x1="20" y1="4" x2="8.12" y2="15.88"></line><line x1="14.47" y1="14.48" x2="20" y2="20"></line><line x1="8.12" y1="8.12" x2="12" y2="12"></line></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rotate-ccw"><polyline points="1 4 1 10 7 10"></polyline><path d="M3.51 15a9 9 0 1 0 2.13-9.36L1 10"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="90%" height="90%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-upload"><path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4"></path><polyline points="17 8 12 3 7 8"></polyline><line x1="12" y1="3" x2="12" y2="15"></line></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-video"><polygon points="23 7 16 12 23 17 23 7"></polygon><rect x="1" y="5" width="15" height="14" rx="2" ry="2"></rect></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" fill="none" xmlns="http://www.w3.org/2000/svg" stroke="currentColor" color="currentColor"><title>Low volume</title><path d="M19.5 7.5C19.5 7.5 21 9 21 11.5C21 14 19.5 15.5 19.5 15.5" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M2 13.8571V10.1429C2 9.03829 2.89543 8.14286 4 8.14286H6.9C7.09569 8.14286 7.28708 8.08544 7.45046 7.97772L13.4495 4.02228C14.1144 3.5839 15 4.06075 15 4.85714V19.1429C15 19.9392 14.1144 20.4161 13.4495 19.9777L7.45046 16.0223C7.28708 15.9146 7.09569 15.8571 6.9 15.8571H4C2.89543 15.8571 2 14.9617 2 13.8571Z" stroke-width="1.5"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" fill="none" stroke="currentColor" xmlns="http://www.w3.org/2000/svg" color="currentColor"><title>High volume</title><path d="M1 13.8571V10.1429C1 9.03829 1.89543 8.14286 3 8.14286H5.9C6.09569 8.14286 6.28708 8.08544 6.45046 7.97772L12.4495 4.02228C13.1144 3.5839 14 4.06075 14 4.85714V19.1429C14 19.9392 13.1144 20.4161 12.4495 19.9777L6.45046 16.0223C6.28708 15.9146 6.09569 15.8571 5.9 15.8571H3C1.89543 15.8571 1 14.9617 1 13.8571Z" stroke-width="1.5"></path><path d="M17.5 7.5C17.5 7.5 19 9 19 11.5C19 14 17.5 15.5 17.5 15.5" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M20.5 4.5C20.5 4.5 23 7 23 11.5C23 16 20.5 18.5 20.5 18.5" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path></svg>');
e.from_svg('<svg width="100%" height="100%" viewBox="0 0 24 24" stroke-width="1.5" fill="none" xmlns="http://www.w3.org/2000/svg" stroke="currentColor" color="currentColor"><title>Muted volume</title><g clip-path="url(#clip0_3173_16686)"><path d="M18 14L20.0005 12M22 10L20.0005 12M20.0005 12L18 10M20.0005 12L22 14" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path><path d="M2 13.8571V10.1429C2 9.03829 2.89543 8.14286 4 8.14286H6.9C7.09569 8.14286 7.28708 8.08544 7.45046 7.97772L13.4495 4.02228C14.1144 3.5839 15 4.06075 15 4.85714V19.1429C15 19.9392 14.1144 20.4161 13.4495 19.9777L7.45046 16.0223C7.28708 15.9146 7.09569 15.8571 6.9 15.8571H4C2.89543 15.8571 2 14.9617 2 13.8571Z" stroke-width="1.5"></path></g><defs><clipPath id="clip0_3173_16686"><rect width="24" height="24" fill="white"></rect></clipPath></defs></svg>');
e.from_svg('<svg fill="none" stroke="currentColor" stroke-width="2" viewBox="0 0 24 24" width="100%" height="100%" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" stroke-linecap="round" stroke-linejoin="round"><path stroke-linecap="round" stroke-linejoin="round" d="M12 9v3.75m-9.303 3.376c-.866 1.5.217 3.374 1.948 3.374h14.71c1.73 0 2.813-1.874 1.948-3.374L13.949 3.378c-.866-1.5-3.032-1.5-3.898 0L2.697 16.126zM12 15.75h.007v.008H12v-.008z"></path></svg>');
e.from_svg('<svg xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 24 24"><path fill="currentColor" d="M12 2c-4.963 0-9 4.038-9 9c0 3.328 1.82 6.232 4.513 7.79l-2.067 1.378A1 1 0 0 0 6 22h12a1 1 0 0 0 .555-1.832l-2.067-1.378C19.18 17.232 21 14.328 21 11c0-4.962-4.037-9-9-9zm0 16c-3.859 0-7-3.141-7-7c0-3.86 3.141-7 7-7s7 3.14 7 7c0 3.859-3.141 7-7 7z"></path><path fill="currentColor" d="M12 6c-2.757 0-5 2.243-5 5s2.243 5 5 5s5-2.243 5-5s-2.243-5-5-5zm0 8c-1.654 0-3-1.346-3-3s1.346-3 3-3s3 1.346 3 3s-1.346 3-3 3z"></path></svg>');
e.from_html('<div role="alert" data-testid="toast-body"><div><!></div> <div><div> </div> <div> </div></div> <button type="button" aria-label="Close" data-testid="toast-close"><span aria-hidden="true">&#215;</span></button> <div></div></div>');
e.from_html("<div><!></div>");
e.from_html('<div class="toast-wrap svelte-1a9k3ta"></div>');
e.from_html("<div></div>");
e.from_html("<!> <!>", 1);
var xo = e.from_html("<a><!> <!></a>"), ko = e.from_html("<button><!> <!></button>");
function Ht(a, t) {
  e.push(t, !0);
  let r = e.prop(t, "elem_classes", 19, () => []), n = e.prop(t, "onclick", 3, () => {
  });
  var s = e.comment(), i = e.first_child(s);
  {
    var o = (c) => {
      var w = xo();
      let h, _;
      var b = e.child(w);
      {
        var D = (k) => {
          {
            let y = e.derived(() => ({ alt: `${t.value} icon`, class: "button-icon" }));
            Ar(k, {
              get src() {
                return t.icon.url;
              },
              get restProps() {
                return e.get(y);
              }
            });
          }
        };
        e.if(b, (k) => {
          t.icon && k(D);
        });
      }
      var T = e.sibling(b, 2);
      {
        var E = (k) => {
          var y = e.comment(), d = e.first_child(y);
          e.snippet(d, () => t.children), e.append(k, y);
        };
        e.if(T, (k) => {
          t.children && k(E);
        });
      }
      e.reset(w), e.template_effect(
        (k) => {
          e.set_attribute(w, "href", t.link), e.set_attribute(w, "target", t.link_target), e.set_attribute(w, "rel", t.link_target === "_blank" ? "noopener noreferrer" : void 0), e.set_attribute(w, "aria-disabled", t.disabled), h = e.set_class(w, 1, `${t.size ?? ""} ${t.variant ?? ""} ${k ?? ""}`, "svelte-1ktvk49", h, {
            hidden: t.visible === !1 || t.visible === "hidden",
            disabled: t.disabled
          }), e.set_attribute(w, "id", t.elem_id), _ = e.set_style(w, "", _, {
            "flex-grow": t.scale,
            "pointer-events": t.disabled ? "none" : null,
            width: t.scale === 0 ? "fit-content" : null,
            "min-width": typeof t.min_width == "number" ? `calc(min(${t.min_width}px, 100%))` : null
          });
        },
        [() => r().join(" ")]
      ), e.append(c, w);
    }, l = (c) => {
      var w = ko();
      w.__click = function(...k) {
        n()?.apply(this, k);
      };
      let h, _;
      var b = e.child(w);
      {
        var D = (k) => {
          {
            let y = e.derived(() => ({ alt: `${t.value} icon` })), d = e.derived(() => [`button-icon ${t.value ? "right-padded" : ""}`]);
            Ar(k, {
              get restProps() {
                return e.get(y);
              },
              get class_names() {
                return e.get(d);
              },
              get src() {
                return t.icon.url;
              }
            });
          }
        };
        e.if(b, (k) => {
          t.icon && k(D);
        });
      }
      var T = e.sibling(b, 2);
      {
        var E = (k) => {
          var y = e.comment(), d = e.first_child(y);
          e.snippet(d, () => t.children), e.append(k, y);
        };
        e.if(T, (k) => {
          t.children && k(E);
        });
      }
      e.reset(w), e.template_effect(
        (k) => {
          h = e.set_class(w, 1, `${t.size ?? ""} ${t.variant ?? ""} ${k ?? ""}`, "svelte-1ktvk49", h, {
            hidden: t.visible === !1 || t.visible === "hidden"
          }), e.set_attribute(w, "id", t.elem_id), w.disabled = t.disabled, _ = e.set_style(w, "", _, {
            "flex-grow": t.scale,
            width: t.scale === 0 ? "fit-content" : null,
            "min-width": typeof t.min_width == "number" ? `calc(min(${t.min_width}px, 100%))` : null
          });
        },
        [() => r().join(" ")]
      ), e.append(c, w);
    };
    e.if(i, (c) => {
      t.link && t.link.length > 0 ? c(o) : c(l, !1);
    });
  }
  e.append(a, s), e.pop();
}
e.delegate(["click"]);
var yo = e.from_html('<li data-testid="dropdown-option" role="option"><span>✓</span> </li>'), Co = e.from_html('<ul class="options svelte-29vd06" role="listbox"></ul>'), Do = e.from_html('<div class="reference"></div> <!>', 1);
function Eo(a, t) {
  e.push(t, !1);
  var r = e.mutable_source(), n = e.mutable_source();
  let s = e.prop(t, "choices", 8), i = e.prop(t, "filtered_indices", 8), o = e.prop(t, "show_options", 8, !1), l = e.prop(t, "disabled", 8, !1), c = e.prop(t, "selected_indices", 24, () => []), w = e.prop(t, "active_index", 8, null), h = e.mutable_source(), _ = e.mutable_source(), b = e.mutable_source(), D = e.mutable_source(), T = e.mutable_source(), E = e.mutable_source(), k = e.mutable_source(), y = e.mutable_source(), d = e.mutable_source(), p = e.mutable_source();
  function v() {
    const { top: C, bottom: O } = e.get(T).getBoundingClientRect();
    e.set(h, C), e.set(_, e.get(p) - O);
  }
  let u = null;
  function f() {
    o() && (u !== null && clearTimeout(u), u = setTimeout(
      () => {
        v(), u = null;
      },
      10
    ));
  }
  const g = Re();
  e.legacy_pre_effect(
    () => (e.deep_read_state(o()), e.get(T), e.get(E), e.deep_read_state(c()), e.safe_get(r), e.safe_get(n), e.get(b), e.get(_), e.get(h)),
    () => {
      if (o() && e.get(T)) {
        if (e.get(E) && c().length > 0) {
          let O = e.get(E).querySelectorAll("li");
          for (const N of Array.from(O))
            if (N.getAttribute("data-index") === c()[0].toString()) {
              e.set(r, e.get(E) === null || e.get(E) === void 0 ? void 0 : e.get(E).scrollTo) === null || e.safe_get(r) === void 0 || e.safe_get(r).call(e.get(E), 0, N.offsetTop);
              break;
            }
        }
        v();
        const C = e.set(n, e.get(T).parentElement) === null || e.safe_get(n) === void 0 ? void 0 : e.safe_get(n).getBoundingClientRect();
        e.set(b, C?.height || 0), e.set(D, C?.width || 0);
      }
      e.get(_) > e.get(h) ? (e.set(k, `${e.get(h)}px`), e.set(d, e.get(_)), e.set(y, null)) : (e.set(y, `${e.get(_) + e.get(b)}px`), e.set(d, e.get(h) - e.get(b)), e.set(k, null));
    }
  ), e.legacy_pre_effect_reset(), e.init();
  var x = Do();
  e.event("scroll", e.window, f);
  var m = e.first_child(x);
  e.bind_this(m, (C) => e.set(T, C), () => e.get(T));
  var F = e.sibling(m, 2);
  {
    var B = (C) => {
      var O = Co();
      let N;
      e.each(O, 5, i, e.index, (ie, H) => {
        var Z = yo();
        let R;
        var G = e.child(Z);
        let ae;
        var $ = e.sibling(G);
        e.reset(Z), e.template_effect(
          (te, Q, re) => {
            R = e.set_class(Z, 1, "item svelte-29vd06", null, R, te), e.set_attribute(Z, "data-index", e.get(H)), e.set_attribute(Z, "aria-label", (e.deep_read_state(s()), e.get(H), e.untrack(() => s()[e.get(H)][0]))), e.set_attribute(Z, "aria-selected", Q), ae = e.set_class(G, 1, "inner-item svelte-29vd06", null, ae, re), e.set_text($, ` ${e.deep_read_state(s()), e.get(H), e.untrack(() => s()[e.get(H)][0]) ?? ""}`);
          },
          [
            () => ({
              selected: c().includes(e.get(H)),
              active: e.get(H) === w(),
              "bg-gray-100": e.get(H) === w(),
              "dark:bg-gray-600": e.get(H) === w()
            }),
            () => (e.deep_read_state(c()), e.get(H), e.untrack(() => c().includes(e.get(H)))),
            () => ({ hide: !c().includes(e.get(H)) })
          ]
        ), e.append(ie, Z);
      }), e.reset(O), e.bind_this(O, (ie) => e.set(E, ie), () => e.get(E)), e.template_effect(() => N = e.set_style(O, "", N, {
        bottom: e.get(y),
        "max-height": `calc(${e.get(d)}px - var(--window-padding))`,
        width: e.get(D) + "px"
      })), e.transition(3, O, () => wn, () => ({ duration: 200, y: 5 })), e.event("mousedown", O, e.preventDefault((ie) => g("change", ie))), e.append(C, O);
    };
    e.if(F, (C) => {
      o() && !l() && C(B);
    });
  }
  e.bind_window_size("innerHeight", (C) => e.set(p, C)), e.append(a, x), e.pop();
}
function Fo(a, t) {
  return (a % t + t) % t;
}
function Br(a, t) {
  return a.reduce((r, n, s) => ((!t || n[0].toLowerCase().includes(t.toLowerCase())) && r.push(s), r), []);
}
function Ao(a, t, r) {
  a("change", t), r || a("input");
}
function Lo(a, t, r) {
  if (a.key === "Escape")
    return [!1, t];
  if ((a.key === "ArrowDown" || a.key === "ArrowUp") && r.length >= 0)
    if (t === null)
      t = a.key === "ArrowDown" ? r[0] : r[r.length - 1];
    else {
      const n = r.indexOf(t), s = a.key === "ArrowUp" ? -1 : 1;
      t = r[Fo(n + s, r.length)];
    }
  return [!0, t];
}
e.from_html('<div class="token-remove svelte-t4dyoq" role="button" tabindex="0"><!></div>');
e.from_html('<div class="token svelte-t4dyoq"><span class="svelte-t4dyoq"><!></span> <!></div>');
e.from_html('<div role="button" tabindex="0" class="token-remove remove-all svelte-t4dyoq"><!></div>');
e.from_html('<!> <span class="icon-wrap svelte-t4dyoq"><!></span>', 1);
e.from_html('<label><!> <div class="wrap svelte-t4dyoq"><div><!> <div class="secondary-wrap svelte-t4dyoq"><input autocomplete="off"/> <!></div></div> <!></div></label>');
var Mo = e.from_html('<div class="icon-wrap svelte-1632v8o"><!></div>'), Bo = e.from_html('<div><!> <div class="wrap svelte-1632v8o"><div><div class="secondary-wrap svelte-1632v8o"><input role="listbox" aria-controls="dropdown-options" autocomplete="off"/> <!></div></div> <!></div></div>');
function So(a, t) {
  e.push(t, !1);
  let r = e.prop(t, "label", 8), n = e.prop(t, "info", 8, void 0), s = e.prop(t, "value", 28, () => []), i = e.mutable_source([]), o = e.prop(t, "value_is_output", 12, !1), l = e.prop(t, "choices", 8), c = e.mutable_source(), w = e.prop(t, "disabled", 8, !1), h = e.prop(t, "show_label", 8), _ = e.prop(t, "container", 8, !0), b = e.prop(t, "allow_custom_value", 8, !1), D = e.prop(t, "filterable", 8, !0), T = e.mutable_source(), E = e.mutable_source(!1), k = e.mutable_source(), y = e.mutable_source(), d = e.mutable_source(""), p = e.mutable_source(""), v = e.mutable_source(!1), u = e.mutable_source([]), f = e.mutable_source(null), g = e.mutable_source(null), x = e.mutable_source();
  const m = Re();
  s() ? (e.set(x, l().map((S) => S[1]).indexOf(s())), e.set(g, e.get(x)), e.get(g) === -1 ? (e.set(i, s()), e.set(g, null)) : (((S) => {
    var L = e.to_array(S, 2);
    e.set(d, L[0]), e.set(i, L[1]);
  })(l()[e.get(g)]), e.set(p, e.get(d))), B()) : l().length > 0 && (e.set(x, 0), e.set(g, 0), ((S) => {
    var L = e.to_array(S, 2);
    e.set(d, L[0]), s(L[1]);
  })(l()[e.get(g)]), e.set(i, s()), e.set(p, e.get(d)));
  function F() {
    e.set(k, l().map((S) => S[0])), e.set(y, l().map((S) => S[1]));
  }
  function B() {
    F(), s() === void 0 || Array.isArray(s()) && s().length === 0 ? (e.set(d, ""), e.set(g, null)) : e.get(y).includes(s()) ? (e.set(d, e.get(k)[e.get(y).indexOf(s())]), e.set(g, e.get(y).indexOf(s()))) : b() ? (e.set(d, s()), e.set(g, null)) : (e.set(d, ""), e.set(g, null)), e.set(x, e.get(g));
  }
  function C(S) {
    if (e.set(g, parseInt(S.detail.target.dataset.index)), isNaN(e.get(g))) {
      e.set(g, null);
      return;
    }
    e.set(E, !1), e.set(f, null), e.get(T).blur();
  }
  function O(S) {
    e.set(u, l().map((L, A) => A)), e.set(E, !0), m("focus");
  }
  function N() {
    b() ? s(e.get(d)) : e.set(d, e.get(k)[e.get(y).indexOf(s())]), e.set(E, !1), e.set(f, null), m("blur");
  }
  function ie(S) {
    ((L) => {
      var A = e.to_array(L, 2);
      e.set(E, A[0]), e.set(f, A[1]);
    })(Lo(S, e.get(f), e.get(u))), S.key === "Enter" && (e.get(f) !== null ? (e.set(g, e.get(f)), e.set(E, !1), e.get(T).blur(), e.set(f, null)) : e.get(k).includes(e.get(d)) ? (e.set(g, e.get(k).indexOf(e.get(d))), e.set(E, !1), e.set(f, null), e.get(T).blur()) : b() && (s(e.get(d)), e.set(g, null), e.set(E, !1), e.set(f, null), e.get(T).blur()), m("enter", s()));
  }
  zr(() => {
    o(!1), e.set(v, !0);
  }), Je(() => {
    e.get(T).focus();
  }), e.legacy_pre_effect(
    () => (e.get(g), e.get(x), e.get(v), e.get(d), e.deep_read_state(s()), e.deep_read_state(l()), e.get(y)),
    () => {
      e.get(g) !== e.get(x) && e.get(g) !== null && e.get(v) && (((S) => {
        var L = e.to_array(S, 2);
        e.set(d, L[0]), s(L[1]);
      })(l()[e.get(g)]), e.set(x, e.get(g)), m("select", {
        index: e.get(g),
        value: e.get(y)[e.get(g)],
        selected: !0
      }));
    }
  ), e.legacy_pre_effect(
    () => (e.deep_read_state(s()), e.get(i), e.deep_read_state(o())),
    () => {
      s() != e.get(i) && (B(), Ao(m, s(), o()), e.set(i, s()));
    }
  ), e.legacy_pre_effect(() => e.deep_read_state(l()), () => {
    l(), F();
  }), e.legacy_pre_effect(
    () => (e.deep_read_state(l()), e.get(c), e.deep_read_state(b()), e.get(u), e.get(d), e.get(T)),
    () => {
      l() !== e.get(c) && (b() || B(), e.set(c, l()), e.set(u, Br(l(), e.get(d))), !b() && e.get(u).length > 0 && e.set(f, e.get(u)[0]), e.get(T) == document.activeElement && e.set(E, !0));
    }
  ), e.legacy_pre_effect(
    () => (e.get(d), e.get(p), e.get(u), e.deep_read_state(l()), e.deep_read_state(b())),
    () => {
      e.get(d) !== e.get(p) && (e.set(u, Br(l(), e.get(d))), e.set(p, e.get(d)), !b() && e.get(u).length > 0 && e.set(f, e.get(u)[0]));
    }
  ), e.legacy_pre_effect_reset(), e.init();
  var H = Bo();
  let Z;
  var R = e.child(H);
  fa(R, {
    get show_label() {
      return h();
    },
    get info() {
      return n();
    },
    children: (S, L) => {
      e.next();
      var A = e.text();
      e.template_effect(() => e.set_text(A, r())), e.append(S, A);
    },
    $$slots: { default: !0 }
  });
  var G = e.sibling(R, 2), ae = e.child(G);
  let $;
  var te = e.child(ae), Q = e.child(te);
  e.remove_input_defaults(Q);
  let re;
  e.bind_this(Q, (S) => e.set(T, S), () => e.get(T));
  var Y = e.sibling(Q, 2);
  {
    var ne = (S) => {
      var L = Mo(), A = e.child(L);
      sn(A), e.reset(L), e.append(S, L);
    };
    e.if(Y, (S) => {
      w() || S(ne);
    });
  }
  e.reset(te), e.reset(ae);
  var z = e.sibling(ae, 2);
  {
    let S = e.derived_safe_equal(() => e.get(g) === null ? [] : [e.get(g)]);
    Eo(z, {
      get show_options() {
        return e.get(E);
      },
      get choices() {
        return l();
      },
      get filtered_indices() {
        return e.get(u);
      },
      get disabled() {
        return w();
      },
      get selected_indices() {
        return e.get(S);
      },
      get active_index() {
        return e.get(f);
      },
      $$events: { change: C }
    });
  }
  e.reset(G), e.reset(H), e.template_effect(
    (S) => {
      Z = e.set_class(H, 1, "svelte-1632v8o", null, Z, { container: _() }), $ = e.set_class(ae, 1, "wrap-inner svelte-1632v8o", null, $, { show_options: e.get(E) }), e.set_attribute(Q, "aria-expanded", e.get(E)), e.set_attribute(Q, "aria-label", r()), re = e.set_class(Q, 1, "border-none svelte-1632v8o", null, re, S), Q.disabled = w(), Q.readOnly = !D();
    },
    [
      () => ({
        subdued: !e.get(k).includes(e.get(d)) && !b()
      })
    ]
  ), e.bind_value(Q, () => e.get(d), (S) => e.set(d, S)), e.event("keydown", Q, ie), e.event("keyup", Q, (S) => m("key_up", { key: S.key, input_value: e.get(d) })), e.event("blur", Q, N), e.event("focus", Q, O), e.append(a, H), e.pop();
}
e.from_html("<div> </div>");
e.from_html("<!> <!>", 1);
var To = e.from_html('<div style="margin-right: 8px;"><button aria-label="Lock label detail"><!></button></div>'), zo = e.from_html('<div style="margin-right: 8px;"><!></div>'), Ro = e.from_html('<div class="modal svelte-n7dbqn" id="model-box-edit"><div class="modal-container svelte-n7dbqn"><span class="model-content svelte-n7dbqn"><!> <div style="margin-right: 10px;"><!></div> <div style="margin-right: 40px; margin-bottom: 8px;"><!></div> <div style="margin-right: 8px;"><!></div> <!> <div><!></div></span></div></div>');
function Ot(a, t) {
  e.push(t, !1);
  let r = e.prop(t, "label", 8, ""), n = e.prop(t, "currentLabel", 12, ""), s = e.prop(t, "choices", 24, () => []), i = e.prop(t, "choicesColors", 24, () => []), o = e.prop(t, "color", 8, ""), l = e.prop(t, "currentColor", 12, ""), c = e.prop(t, "showRemove", 8, !0), w = e.prop(t, "labelDetailLock", 12, !1);
  const h = Re();
  function _(H) {
    h("change", {
      label: n(),
      color: l(),
      lock: w(),
      ret: H
      // -1: remove, 0: cancel, 1: change
    });
  }
  function b(H) {
    const { detail: Z } = H;
    let R = Z;
    Number.isInteger(R) ? (Array.isArray(i()) && R < i().length && l(i()[R]), Array.isArray(s()) && R < s().length && n(s()[R][0])) : n(R);
  }
  function D(H) {
    const { detail: Z } = H;
    l(Z);
  }
  function T(H) {
    b(H), _(1);
  }
  function E(H) {
    w(!w());
  }
  function k(H) {
    switch (H.key.toLowerCase()) {
      case "enter":
        _(1);
        break;
      case "escape":
        _(0);
        break;
    }
  }
  Je(() => (document.addEventListener("keydown", k), n(r()), l(o()), () => {
    document.removeEventListener("keydown", k);
  })), e.init();
  var y = Ro(), d = e.child(y), p = e.child(d), v = e.child(p);
  {
    var u = (H) => {
      var Z = To(), R = e.child(Z);
      let G;
      R.__click = E;
      var ae = e.child(R);
      {
        var $ = (Q) => {
          uo(Q);
        }, te = (Q) => {
          go(Q);
        };
        e.if(ae, (Q) => {
          w() ? Q($) : Q(te, !1);
        });
      }
      e.reset(R), e.reset(Z), e.template_effect(() => G = e.set_class(R, 1, "icon svelte-n7dbqn", null, G, { selected: w() === !0 })), e.append(H, Z);
    };
    e.if(v, (H) => {
      c() || H(u);
    });
  }
  var f = e.sibling(v, 2), g = e.child(f);
  So(g, {
    get value() {
      return n();
    },
    label: "Label",
    get choices() {
      return s();
    },
    show_label: !1,
    allow_custom_value: !0,
    $$events: { change: b, enter: T }
  }), e.reset(f);
  var x = e.sibling(f, 2), m = e.child(x);
  bo(m, {
    get value() {
      return l();
    },
    label: "Color",
    show_label: !1,
    $$events: { change: D }
  }), e.reset(x);
  var F = e.sibling(x, 2), B = e.child(F);
  Ht(B, {
    onclick: () => _(0),
    children: (H, Z) => {
      e.next();
      var R = e.text("Cancel");
      e.append(H, R);
    },
    $$slots: { default: !0 }
  }), e.reset(F);
  var C = e.sibling(F, 2);
  {
    var O = (H) => {
      var Z = zo(), R = e.child(Z);
      Ht(R, {
        variant: "stop",
        onclick: () => _(-1),
        children: (G, ae) => {
          e.next();
          var $ = e.text("Remove");
          e.append(G, $);
        },
        $$slots: { default: !0 }
      }), e.reset(Z), e.append(H, Z);
    };
    e.if(C, (H) => {
      c() && H(O);
    });
  }
  var N = e.sibling(C, 2), ie = e.child(N);
  Ht(ie, {
    variant: "primary",
    onclick: () => _(1),
    children: (H, Z) => {
      e.next();
      var R = e.text("OK");
      e.append(H, R);
    },
    $$slots: { default: !0 }
  }), e.reset(N), e.reset(p), e.reset(d), e.reset(y), e.append(a, y), e.pop();
}
e.delegate(["click"]);
const We = [
  "rgb(255, 168, 77)",
  "rgb(92, 172, 238)",
  "rgb(255, 99, 71)",
  "rgb(118, 238, 118)",
  "rgb(255, 145, 164)",
  "rgb(0, 191, 255)",
  "rgb(255, 218, 185)",
  "rgb(255, 69, 0)",
  "rgb(34, 139, 34)",
  "rgb(255, 240, 245)",
  "rgb(255, 193, 37)",
  "rgb(255, 193, 7)",
  "rgb(255, 250, 138)"
];
var Io = e.from_html('<button class="icon svelte-1u4bfll" aria-label="Remove box" title="Remove box (Del)"><!></button>'), Ho = e.from_html('<button class="icon svelte-1u4bfll" aria-label="Edit label" title="Edit label"><!></button>'), Oo = e.from_html('<span class="canvas-control svelte-1u4bfll"><button aria-label="Create box" title="Create box (C)"><!></button> <button aria-label="Drag boxes" title="Drag boxes (D)"><!></button> <!> <!> <button class="icon svelte-1u4bfll" aria-label="Rotate counterclockwise" title="Rotate counterclockwise"><!></button> <button class="icon svelte-1u4bfll" aria-label="Rotate clockwise" title="Rotate clockwise"><!></button></span>'), Zo = e.from_html('<div class="annotator-container" tabindex="0"><div class="canvas-container svelte-1u4bfll"><canvas class="canvas-annotator svelte-1u4bfll"></canvas></div> <!></div> <!> <!> <!>', 1);
function Vo(a, t) {
  e.push(t, !1);
  var r = e.mutable_source();
  (function(M) {
    M[M.creation = 0] = "creation", M[M.drag = 1] = "drag";
  })(e.safe_get(r) || e.set(r, {}));
  let n = e.prop(t, "imageUrl", 8, null), s = e.prop(t, "interactive", 8), i = e.prop(t, "boxAlpha", 8, 0.5), o = e.prop(t, "boxMinSize", 8, 10), l = e.prop(t, "handleSize", 8), c = e.prop(t, "boxThickness", 8), w = e.prop(t, "boxSelectedThickness", 8), h = e.prop(t, "value", 12), _ = e.prop(t, "choices", 24, () => []), b = e.prop(t, "choicesColors", 24, () => []), D = e.prop(t, "disableEditBoxes", 8, !1), T = e.prop(t, "height", 8, "100%"), E = e.prop(t, "width", 8, "100%"), k = e.prop(t, "singleBox", 8, !1), y = e.prop(t, "showRemoveButton", 12, null), d = e.prop(t, "handlesCursor", 8, !0), p = e.prop(t, "useDefaultLabel", 8, !1), v = e.prop(t, "enableKeyboardShortcuts", 8, !0);
  y() === null && y(D());
  let u = e.mutable_source(), f = e.mutable_source(), g, x = null, m = e.mutable_source(-1), F = e.mutable_source(e.safe_get(r).drag), B = /* @__PURE__ */ new Map(), C = e.mutable_source(new ks(A, B));
  h() !== null && h().boxes.length == 0 && e.set(F, e.safe_get(r).creation);
  let O = 0, N = 0, ie = 0, H = 0, Z = 1, R = 0, G = 0, ae = e.mutable_source(!1), $ = e.mutable_source(!1), te = e.mutable_source(!1), Q = e.mutable_source(p()), re = { label: "", color: "" }, Y = { x: 0, y: 0, distance: 0 };
  const ne = 100, z = Re();
  function S(M) {
    var I = parseInt(M.slice(1, 3), 16), q = parseInt(M.slice(3, 5), 16), ee = parseInt(M.slice(5, 7), 16);
    return "rgb(" + I + ", " + q + ", " + ee + ")";
  }
  function L(M) {
    const I = M.match(/(\d+(\.\d+)?)/g), q = parseInt(I[0]), ee = parseInt(I[1]), ue = parseInt(I[2]);
    return "#" + (1 << 24 | q << 16 | ee << 8 | ue).toString(16).slice(1);
  }
  function A() {
    if (g) {
      if (g.clearRect(0, 0, e.get(u).width, e.get(u).height), g.save(), g.translate(e.get(C).offsetX, e.get(C).offsetY), g.scale(e.get(C).scale, e.get(C).scale), x !== null) {
        switch (h().orientation) {
          case 0:
            g.drawImage(x, 0, 0, R, G);
            break;
          case 1:
            g.translate(R, 0), g.rotate(Math.PI / 2), g.drawImage(x, 0, 0, G, R);
            break;
          case 2:
            g.translate(R, G), g.rotate(Math.PI), g.drawImage(x, 0, 0, R, G);
            break;
          case 3:
            g.translate(0, G), g.rotate(-Math.PI / 2), g.drawImage(x, 0, 0, G, R);
            break;
        }
        g.restore();
      }
      for (const M of h().boxes.slice().reverse())
        M.render(g);
    }
  }
  function V(M) {
    e.set(m, M), h().boxes.forEach((I) => {
      I.setSelected(!1);
    }), M >= 0 && M < h().boxes.length && h().boxes[M].setSelected(!0), A();
  }
  const P = (M, I) => {
    const q = Math.sqrt(Math.pow(M.clientX - I.clientX, 2) + Math.pow(M.clientY - I.clientY, 2));
    return q < ne ? ne : q;
  };
  function K(M) {
    if (s()) {
      if (M.preventDefault(), e.get(u).setPointerCapture(M.pointerId), B.set(M.pointerId, M), B.size == 1)
        e.get(F) === e.safe_get(r).creation ? se(M) : e.get(F) === e.safe_get(r).drag && de(M);
      else if (B.size == 2) {
        e.mutate(C, e.get(C).isDragging = !1), h().boxes.forEach((Te) => {
          Te.isCreating = !1, Te.isDragging = !1, Te.isResizing = !1;
        });
        const I = Array.from(B.values()), q = I[0], ee = I[1], ue = P(q, ee), oe = e.get(u).getBoundingClientRect(), ye = (q.clientX + ee.clientX) / 2 - oe.left, Se = (q.clientY + ee.clientY) / 2 - oe.top;
        Y.distance = ue, Y.x = ye, Y.y = Se;
      }
    }
  }
  function de(M) {
    const I = e.get(u).getBoundingClientRect(), q = M.clientX - I.left, ee = M.clientY - I.top;
    let ue = !1;
    for (const [oe, ye] of h().boxes.entries()) {
      const Se = ye.indexOfPointInsideHandle(q, ee);
      if (Se >= 0) {
        ue = !0, V(oe), ye.startResize(Se, M);
        return;
      }
    }
    for (const [oe, ye] of h().boxes.entries())
      if (ye.isPointInsideBox(q, ee)) {
        ue = !0, V(oe), ye.startDrag(M);
        return;
      }
    k() || V(-1), ue || e.get(C).startDrag(M);
  }
  function ve(M) {
    s() && (B.delete(M.pointerId), e.get(u).releasePointerCapture(M.pointerId), z("change"));
  }
  function we(M) {
    s() && (B.delete(M.pointerId), e.get(u).releasePointerCapture(M.pointerId), z("change"));
  }
  function Ce(M) {
    if (s())
      if (M.preventDefault(), M.pointerType === "mouse") {
        if (!d() || h() === null || e.get(F) !== e.safe_get(r).drag)
          return;
        const I = e.get(u).getBoundingClientRect(), q = M.clientX - I.left, ee = M.clientY - I.top;
        for (const [ue, oe] of h().boxes.entries()) {
          const ye = oe.indexOfPointInsideHandle(q, ee);
          if (ye >= 0) {
            e.mutate(u, e.get(u).style.cursor = oe.resizeHandles[ye].cursor);
            return;
          }
        }
        e.mutate(u, e.get(u).style.cursor = "default");
      } else {
        if (!B.has(M.pointerId))
          return;
        if (B.set(M.pointerId, M), B.size === 2) {
          const I = Array.from(B.values()), q = I[0], ee = I[1], ue = P(q, ee), oe = e.get(u).getBoundingClientRect(), ye = (q.clientX + ee.clientX) / 2 - oe.left, Se = (q.clientY + ee.clientY) / 2 - oe.top, Te = parseFloat((e.get(C).scale * (ue / Y.distance)).toFixed(2)), lt = Te < 1 ? 1 : Te, et = lt / e.get(C).scale;
          e.mutate(C, e.get(C).offsetX = Y.x - (Y.x - e.get(C).offsetX) * et), e.mutate(C, e.get(C).offsetY = Y.y - (Y.y - e.get(C).offsetY) * et);
          const Et = ye - Y.x, Qe = Se - Y.y;
          e.mutate(C, e.get(C).offsetX += Et), e.mutate(C, e.get(C).offsetY += Qe), e.mutate(C, e.get(C).scale = lt), Y.x = ye, Y.y = Se, Y.distance = ue, A();
        }
      }
  }
  function _e() {
    const M = e.get(u).width / R, I = e.get(u).height / G, q = Math.min(M, I);
    e.mutate(C, e.get(C).scale = q), e.mutate(C, e.get(C).offsetX = (e.get(u).width - R * q) / 2), e.mutate(C, e.get(C).offsetY = (e.get(u).height - G * q) / 2), A();
  }
  function De(M) {
    if (!v() || M.target !== e.get(f) || !s())
      return;
    const I = M.key.toLowerCase();
    switch ((/* @__PURE__ */ new Set(["delete", "c", "d", "e", " "])).has(I) && (M.preventDefault(), M.stopPropagation()), I) {
      case "delete":
        me();
        break;
      case "c":
        j();
        break;
      case "d":
        U();
        break;
      case "e":
        X();
        break;
      case " ":
        _e();
        break;
    }
  }
  function he() {
    setTimeout(
      () => {
        e.get(f) === null || e.get(f) === void 0 || e.get(f).focus();
      },
      0
    );
  }
  function J(M) {
    if (!s())
      return;
    M.preventDefault();
    const I = 1 / (1 + M.deltaY / 1e3 * 0.5), q = parseFloat((e.get(C).scale * I).toFixed(2)), ee = q < 1 ? 1 : q, ue = e.get(u).getBoundingClientRect(), oe = M.clientX - ue.left, ye = M.clientY - ue.top, Se = (oe - e.get(C).offsetX) / e.get(C).scale, Te = (ye - e.get(C).offsetY) / e.get(C).scale;
    e.mutate(C, e.get(C).offsetX = oe - Se * ee), e.mutate(C, e.get(C).offsetY = ye - Te * ee), e.mutate(C, e.get(C).scale = ee), A();
  }
  function se(M) {
    const I = e.get(u).getBoundingClientRect(), q = (M.clientX - I.left - e.get(C).offsetX) / Z / e.get(C).scale, ee = (M.clientY - I.top - e.get(C).offsetY) / Z / e.get(C).scale;
    let ue;
    b().length > 0 ? ue = S(b()[0]) : k() ? h().boxes.length > 0 ? ue = h().boxes[0].color : ue = We[0] : ue = We[h().boxes.length % We.length];
    let oe = new It(A, W, e.get(C), B, O, N, ie, H, "", q, ee, q, ee, ue, i(), o(), l(), c(), w());
    oe.startCreating(M, I.left, I.top), k() ? h(h().boxes = [oe], !0) : h(h().boxes = [oe, ...h().boxes], !0), V(0), A(), z("change");
  }
  function j() {
    e.set(F, e.safe_get(r).creation), e.mutate(u, e.get(u).style.cursor = "crosshair");
  }
  function U() {
    e.set(F, e.safe_get(r).drag), e.mutate(u, e.get(u).style.cursor = "default");
  }
  function W() {
    e.get(m) >= 0 && e.get(m) < h().boxes.length && (h().boxes[e.get(m)].getArea() < 1 ? me() : (D() || (e.get(Q) ? xe() : e.set($, !0)), k() && U()));
  }
  function X() {
    e.get(m) >= 0 && e.get(m) < h().boxes.length && !D() && e.set(ae, !0);
  }
  function ge(M) {
    s() && X();
  }
  function be(M) {
    e.set(ae, !1), he();
    const { detail: I } = M;
    let q = I.label, ee = I.color, ue = I.ret;
    if (e.get(m) >= 0 && e.get(m) < h().boxes.length) {
      let oe = h().boxes[e.get(m)];
      ue == 1 ? (oe.label = q, oe.color = S(ee), A(), z("change")) : ue == -1 && me();
    }
  }
  function le(M) {
    e.set($, !1), he();
    const { detail: I } = M;
    let q = I.label, ee = I.color, ue = I.ret, oe = I.lock;
    if (e.get(m) >= 0 && e.get(m) < h().boxes.length) {
      let ye = h().boxes[e.get(m)];
      ue == 1 ? (e.set(Q, oe), re.label = q, re.color = ee, ye.label = q, ye.color = S(ee), A(), z("change")) : me();
    }
  }
  function ce(M) {
    e.set(te, !1), he();
    const { detail: I } = M;
    let q = I.label, ee = I.color, ue = I.ret, oe = I.lock;
    ue == 1 && (e.set(Q, oe), re.label = q, re.color = ee);
  }
  function xe() {
    if (e.get(m) >= 0 && e.get(m) < h().boxes.length) {
      let M = h().boxes[e.get(m)];
      M.label = re.label, re.color !== "" && (M.color = S(re.color)), A(), z("change");
    }
  }
  function me() {
    e.get(m) >= 0 && e.get(m) < h().boxes.length && (h().boxes.splice(e.get(m), 1), V(-1), k() && j(), z("change"));
  }
  function ke(M) {
    h(h().orientation = ((h().orientation + M) % 4 + 4) % 4, !0), e.mutate(C, e.get(C).orientation = h().orientation), Ee();
    for (const I of h().boxes)
      I.onRotate(M);
    A();
  }
  function Ee() {
    if (e.get(u)) {
      if (Z = 1, e.mutate(u, e.get(u).width = e.get(u).clientWidth), e.get(C).setRotatedImage(x), x !== null) {
        if (e.get(C).imageRotatedWidth > e.get(u).width)
          Z = e.get(u).width / e.get(C).imageRotatedWidth, R = Math.round(e.get(C).imageRotatedWidth * Z), G = Math.round(e.get(C).imageRotatedHeight * Z), O = 0, N = 0, ie = R, H = G, e.mutate(u, e.get(u).height = G);
        else {
          R = e.get(C).imageRotatedWidth, G = e.get(C).imageRotatedHeight;
          var M = (e.get(u).width - R) / 2;
          O = M, N = 0, ie = M + R, H = G, e.mutate(u, e.get(u).height = G);
        }
        e.mutate(C, e.get(C).imageWidth = R), e.mutate(C, e.get(C).imageHeight = G);
      } else
        O = 0, N = 0, ie = e.get(u).width, H = e.get(u).height, e.mutate(u, e.get(u).height = e.get(u).clientHeight);
      if (e.get(C).resize(e.get(u).width, e.get(u).height, O, N), ie > 0 && H > 0)
        for (const I of h().boxes)
          I.canvasXmin = O, I.canvasYmin = N, I.canvasXmax = ie, I.canvasYmax = H, I.setScaleFactor(Z);
      A(), z("change");
    }
  }
  const Le = new ResizeObserver(Ee);
  function Ze() {
    for (let M = 0; M < h().boxes.length; M++) {
      let I = h().boxes[M];
      if (!(I instanceof It)) {
        let q = "", ee = "";
        I.hasOwnProperty("color") ? (q = I.color, Array.isArray(q) && q.length === 3 && (q = `rgb(${q[0]}, ${q[1]}, ${q[2]})`)) : q = We[M % We.length], I.hasOwnProperty("label") && (ee = I.label), I = new It(A, W, e.get(C), B, O, N, ie, H, ee, I.xmin, I.ymin, I.xmax, I.ymax, q, i(), o(), l(), c(), w()), h(h().boxes[M] = I, !0);
      }
    }
  }
  function Pe() {
    n() !== null && (x === null || x.src != n()) && (x = new Image(), x.src = n(), x.onload = function() {
      Ee(), A();
    });
  }
  Je(() => {
    if (Array.isArray(_()) && _().length > 0) {
      if (!Array.isArray(b()) || b().length == 0)
        for (let M = 0; M < _().length; M++) {
          let I = We[M % We.length];
          b().push(L(I));
        }
      re.label = _()[0][0], re.color = b()[0];
    }
    g = e.get(u).getContext("2d"), Le.observe(e.get(u)), e.get(m) < 0 && h() !== null && h().boxes.length > 0 && V(0), Pe(), Ee(), A();
  }), e.legacy_pre_effect(() => e.deep_read_state(h()), () => {
    h(), e.mutate(C, e.get(C).orientation = h().orientation), Pe(), Ze(), Ee(), A();
  }), e.legacy_pre_effect_reset(), e.init();
  var je = Zo(), Ve = e.first_child(je), Ke = e.child(Ve), Ie = e.child(Ke);
  e.bind_this(Ie, (M) => e.set(u, M), () => e.get(u)), e.reset(Ke);
  var st = e.sibling(Ke, 2);
  {
    var yt = (M) => {
      var I = Oo(), q = e.child(I);
      let ee;
      var ue = e.child(q);
      ro(ue), e.reset(q);
      var oe = e.sibling(q, 2);
      let ye;
      var Se = e.child(oe);
      io(Se), e.reset(oe);
      var Te = e.sibling(oe, 2);
      {
        var lt = (Ue) => {
          var Ne = Io(), At = e.child(Ne);
          so(At), e.reset(Ne), e.event("click", Ne, () => me()), e.append(Ue, Ne);
        };
        e.if(Te, (Ue) => {
          y() && Ue(lt);
        });
      }
      var et = e.sibling(Te, 2);
      {
        var Et = (Ue) => {
          var Ne = Ho(), At = e.child(Ne);
          lo(At), e.reset(Ne), e.event("click", Ne, () => e.set(te, !0)), e.append(Ue, Ne);
        };
        e.if(et, (Ue) => {
          !D() && e.get(Q) && Ue(Et);
        });
      }
      var Qe = e.sibling(et, 2), pn = e.child(Qe);
      Va(pn), e.reset(Qe);
      var Ft = e.sibling(Qe, 2), vn = e.child(Ft);
      Ia(vn), e.reset(Ft), e.reset(I), e.template_effect(() => {
        ee = e.set_class(q, 1, "icon svelte-1u4bfll", null, ee, { selected: e.get(F) === e.safe_get(r).creation }), ye = e.set_class(oe, 1, "icon svelte-1u4bfll", null, ye, { selected: e.get(F) === e.safe_get(r).drag });
      }), e.event("click", q, () => j()), e.event("click", oe, () => U()), e.event("click", Qe, () => ke(-1)), e.event("click", Ft, () => ke(1)), e.append(M, I);
    };
    e.if(st, (M) => {
      s() && M(yt);
    });
  }
  e.reset(Ve), e.bind_this(Ve, (M) => e.set(f, M), () => e.get(f));
  var $e = e.sibling(Ve, 2);
  {
    var Ct = (M) => {
      {
        let I = e.derived_safe_equal(() => (e.get(m), e.deep_read_state(h()), e.untrack(() => e.get(m) >= 0 && e.get(m) < h().boxes.length ? h().boxes[e.get(m)].label : ""))), q = e.derived_safe_equal(() => (e.get(m), e.deep_read_state(h()), e.untrack(() => e.get(m) >= 0 && e.get(m) < h().boxes.length ? L(h().boxes[e.get(m)].color) : "")));
        Ot(M, {
          get choices() {
            return _();
          },
          get choicesColors() {
            return b();
          },
          get label() {
            return e.get(I);
          },
          get color() {
            return e.get(q);
          },
          $$events: {
            change: be,
            "enter{onModalEditChange}"(ee) {
              e.bubble_event.call(this, t, ee);
            }
          }
        });
      }
    };
    e.if($e, (M) => {
      e.get(ae) && M(Ct);
    });
  }
  var ot = e.sibling($e, 2);
  {
    var Dt = (M) => {
      {
        let I = e.derived_safe_equal(() => (e.get(m), e.deep_read_state(h()), e.untrack(() => e.get(m) >= 0 && e.get(m) < h().boxes.length ? h().boxes[e.get(m)].label : ""))), q = e.derived_safe_equal(() => (e.get(m), e.deep_read_state(h()), e.untrack(() => e.get(m) >= 0 && e.get(m) < h().boxes.length ? L(h().boxes[e.get(m)].color) : "")));
        Ot(M, {
          get choices() {
            return _();
          },
          showRemove: !1,
          get choicesColors() {
            return b();
          },
          get label() {
            return e.get(I);
          },
          get color() {
            return e.get(q);
          },
          get labelDetailLock() {
            return e.get(Q);
          },
          $$events: {
            change: le,
            "enter{onModalNewChange}"(ee) {
              e.bubble_event.call(this, t, ee);
            }
          }
        });
      }
    };
    e.if(ot, (M) => {
      e.get($) && M(Dt);
    });
  }
  var Ae = e.sibling(ot, 2);
  {
    var Be = (M) => {
      {
        let I = e.derived_safe_equal(() => (e.get(m), e.deep_read_state(h()), e.untrack(() => e.get(m) >= 0 && e.get(m) < h().boxes.length ? h().boxes[e.get(m)].label : ""))), q = e.derived_safe_equal(() => (e.get(m), e.deep_read_state(h()), e.untrack(() => e.get(m) >= 0 && e.get(m) < h().boxes.length ? L(h().boxes[e.get(m)].color) : "")));
        Ot(M, {
          get choices() {
            return _();
          },
          showRemove: !1,
          get choicesColors() {
            return b();
          },
          get label() {
            return e.get(I);
          },
          get color() {
            return e.get(q);
          },
          get labelDetailLock() {
            return e.get(Q);
          },
          $$events: {
            change: ce,
            "enter{onDefaultLabelEditChange}"(ee) {
              e.bubble_event.call(this, t, ee);
            }
          }
        });
      }
    };
    e.if(Ae, (M) => {
      e.get(te) && M(Be);
    });
  }
  e.template_effect(() => e.set_style(Ie, `height: ${T() ?? ""}; width: ${E() ?? ""};`)), e.event("pointerdown", Ie, K), e.event("pointerup", Ie, ve), e.event("pointermove", Ie, Ce), e.event("pointercancel", Ie, we), e.event("dblclick", Ie, ge), e.event("wheel", Ie, J), e.event("keydown", Ve, De), e.event("click", Ve, () => e.get(f).focus()), e.append(a, je), e.pop();
}
function No(a, t) {
  e.push(t, !1);
  let r = e.prop(t, "src", 8, void 0), n = e.prop(t, "interactive", 8), s = e.prop(t, "boxesAlpha", 8), i = e.prop(t, "labelList", 8), o = e.prop(t, "labelColors", 8), l = e.prop(t, "boxMinSize", 8), c = e.prop(t, "handleSize", 8), w = e.prop(t, "boxThickness", 8), h = e.prop(t, "height", 8), _ = e.prop(t, "width", 8), b = e.prop(t, "boxSelectedThickness", 8), D = e.prop(t, "value", 12), T = e.prop(t, "disableEditBoxes", 8), E = e.prop(t, "singleBox", 8), k = e.prop(t, "showRemoveButton", 8), y = e.prop(t, "handlesCursor", 8), d = e.prop(t, "useDefaultLabel", 8), p = e.prop(t, "enableKeyboardShortcuts", 8), v = e.mutable_source(), u = e.mutable_source();
  const f = Re();
  e.legacy_pre_effect(
    () => (e.deep_read_state(r()), e.get(u), Fr),
    () => {
      e.set(v, r()), e.set(u, r());
      const g = r();
      Fr(g).then((x) => {
        e.get(u) === g && e.set(v, x);
      });
    }
  ), e.legacy_pre_effect_reset(), e.init(), Vo(a, {
    get interactive() {
      return n();
    },
    get boxAlpha() {
      return s();
    },
    get choices() {
      return i();
    },
    get choicesColors() {
      return o();
    },
    get height() {
      return h();
    },
    get width() {
      return _();
    },
    get boxMinSize() {
      return l();
    },
    get handleSize() {
      return c();
    },
    get boxThickness() {
      return w();
    },
    get boxSelectedThickness() {
      return b();
    },
    get disableEditBoxes() {
      return T();
    },
    get singleBox() {
      return E();
    },
    get showRemoveButton() {
      return k();
    },
    get handlesCursor() {
      return y();
    },
    get useDefaultLabel() {
      return d();
    },
    get enableKeyboardShortcuts() {
      return p();
    },
    get imageUrl() {
      return e.get(v);
    },
    get value() {
      return D();
    },
    set value(g) {
      D(g);
    },
    $$events: { change: () => f("change") },
    $$legacy: !0
  }), e.pop();
}
var Po = e.from_html("<div><!></div>"), jo = e.from_html("<div><!></div>"), qo = e.from_html('<!> <div class="icon-buttons svelte-8v7jpi"><!> <!> <!></div> <div data-testid="image" class="image-container svelte-8v7jpi"><div class="upload-container svelte-8v7jpi"><!> <!> <!></div> <!></div>', 1);
function Uo(a, t) {
  e.push(t, !1);
  var r = this && this.__awaiter || function(j, U, W, X) {
    function ge(be) {
      return be instanceof W ? be : new W(function(le) {
        le(be);
      });
    }
    return new (W || (W = Promise))(function(be, le) {
      function ce(ke) {
        try {
          me(X.next(ke));
        } catch (Ee) {
          le(Ee);
        }
      }
      function xe(ke) {
        try {
          me(X.throw(ke));
        } catch (Ee) {
          le(Ee);
        }
      }
      function me(ke) {
        ke.done ? be(ke.value) : ge(ke.value).then(ce, xe);
      }
      me((X = X.apply(j, U || [])).next());
    });
  };
  let n = e.prop(t, "value", 12), s = e.prop(t, "label", 8, void 0), i = e.prop(t, "show_label", 8), o = e.prop(t, "sources", 24, () => ["upload", "webcam", "clipboard"]), l = e.prop(t, "selectable", 8, !1), c = e.prop(t, "root", 8), w = e.prop(t, "interactive", 8), h = e.prop(t, "i18n", 8), _ = e.prop(t, "showShareButton", 8), b = e.prop(t, "showDownloadButton", 8), D = e.prop(t, "showClearButton", 8), T = e.prop(t, "boxesAlpha", 8), E = e.prop(t, "labelList", 8), k = e.prop(t, "labelColors", 8), y = e.prop(t, "boxMinSize", 8), d = e.prop(t, "handleSize", 8), p = e.prop(t, "height", 8), v = e.prop(t, "width", 8), u = e.prop(t, "boxThickness", 8), f = e.prop(t, "disableEditBoxes", 8), g = e.prop(t, "singleBox", 8), x = e.prop(t, "showRemoveButton", 8), m = e.prop(t, "handlesCursor", 8), F = e.prop(t, "boxSelectedThickness", 8), B = e.prop(t, "max_file_size", 8, null), C = e.prop(t, "cli_upload", 8), O = e.prop(t, "stream_handler", 8), N = e.prop(t, "useDefaultLabel", 8), ie = e.prop(t, "enableKeyboardShortcuts", 8), H = e.mutable_source(), Z = e.mutable_source(!1), R = e.prop(t, "active_source", 12, null);
  function G({ detail: j }) {
    n(new Er()), n(n().image = j, !0), $("upload");
  }
  function ae(j) {
    return r(this, void 0, void 0, function* () {
      const U = yield e.get(H).load_files([new File([j], "webcam.png")]), W = U?.[0] || null;
      W ? (n(new Er()), n(n().image = W, !0)) : n(null), yield xt(), $("change");
    });
  }
  const $ = Re();
  let te = e.mutable_source(!1);
  function Q(j) {
    return r(this, void 0, void 0, function* () {
      j === "clipboard" && e.get(H).paste_clipboard();
    });
  }
  function re() {
    n(null), $("clear"), $("change");
  }
  e.legacy_pre_effect(() => e.get(Z), () => {
    e.get(Z) && re();
  }), e.legacy_pre_effect(() => e.get(te), () => {
    $("drag", e.get(te));
  }), e.legacy_pre_effect(
    () => (e.deep_read_state(R()), e.deep_read_state(o())),
    () => {
      !R() && o() && R(o()[0]);
    }
  ), e.legacy_pre_effect_reset(), e.init();
  var Y = qo(), ne = e.first_child(Y);
  {
    let j = e.derived_safe_equal(() => s() || "Image Annotator");
    va(ne, {
      get show_label() {
        return i();
      },
      get Icon() {
        return on;
      },
      get label() {
        return e.get(j);
      }
    });
  }
  var z = e.sibling(ne, 2), S = e.child(z);
  {
    var L = (j) => {
      {
        let U = e.derived_safe_equal(() => (e.deep_read_state(n()), e.untrack(() => n().image.orig_name || "image")));
        As(j, {
          get href() {
            return e.deep_read_state(n()), e.untrack(() => n().image.url);
          },
          get download() {
            return e.get(U);
          },
          children: (W, X) => {
            {
              let ge = e.derived_safe_equal(() => (e.deep_read_state(h()), e.untrack(() => h()("common.download"))));
              nt(W, {
                get Icon() {
                  return La;
                },
                get label() {
                  return e.get(ge);
                }
              });
            }
          },
          $$slots: { default: !0 }
        });
      }
    };
    e.if(S, (j) => {
      b() && n() !== null && j(L);
    });
  }
  var A = e.sibling(S, 2);
  {
    var V = (j) => {
      Ua(j, {
        get i18n() {
          return h();
        },
        formatter: async (U) => U === null ? "" : `<img src="${await xn(U.image)}" />`,
        get value() {
          return n();
        },
        $$events: {
          share(U) {
            e.bubble_event.call(this, t, U);
          },
          error(U) {
            e.bubble_event.call(this, t, U);
          }
        }
      });
    };
    e.if(A, (j) => {
      _() && n() !== null && j(V);
    });
  }
  var P = e.sibling(A, 2);
  {
    var K = (j) => {
      var U = Po(), W = e.child(U);
      nt(W, {
        get Icon() {
          return Pt;
        },
        label: "Remove Image",
        $$events: { click: re }
      }), e.reset(U), e.append(j, U);
    };
    e.if(P, (j) => {
      D() && n() !== null && w() && j(K);
    });
  }
  e.reset(z);
  var de = e.sibling(z, 2), ve = e.child(de), we = e.child(ve);
  {
    let j = e.derived_safe_equal(() => n() !== null || R() === "webcam"), U = e.derived_safe_equal(() => R() === "clipboard" ? "clipboard" : "image/*"), W = e.derived_safe_equal(() => (e.deep_read_state(o()), e.untrack(() => !o().includes("upload"))));
    e.bind_this(
      Is(we, {
        get hidden() {
          return e.get(j);
        },
        get filetype() {
          return e.get(U);
        },
        get root() {
          return c();
        },
        get max_file_size() {
          return B();
        },
        get disable_click() {
          return e.get(W);
        },
        get upload() {
          return C();
        },
        get stream_handler() {
          return O();
        },
        get uploading() {
          return e.get(Z);
        },
        set uploading(X) {
          e.set(Z, X);
        },
        get dragging() {
          return e.get(te);
        },
        set dragging(X) {
          e.set(te, X);
        },
        $$events: {
          load: G,
          error(X) {
            e.bubble_event.call(this, t, X);
          }
        },
        children: (X, ge) => {
          var be = e.comment(), le = e.first_child(be);
          {
            var ce = (xe) => {
              var me = e.comment(), ke = e.first_child(me);
              e.slot(ke, t, "default", {}, null), e.append(xe, me);
            };
            e.if(le, (xe) => {
              n() === null && xe(ce);
            });
          }
          e.append(X, be);
        },
        $$slots: { default: !0 },
        $$legacy: !0
      }),
      (X) => e.set(H, X),
      () => e.get(H)
    );
  }
  var Ce = e.sibling(we, 2);
  {
    var _e = (j) => {
      eo(j, {
        get root() {
          return c();
        },
        mode: "image",
        include_audio: !1,
        get i18n() {
          return h();
        },
        get upload() {
          return e.get(H);
        },
        $$events: {
          capture: (U) => ae(U.detail),
          stream: (U) => ae(U.detail),
          error(U) {
            e.bubble_event.call(this, t, U);
          },
          drag(U) {
            e.bubble_event.call(this, t, U);
          },
          upload: (U) => ae(U.detail)
        }
      });
    };
    e.if(Ce, (j) => {
      n() === null && R() === "webcam" && j(_e);
    });
  }
  var De = e.sibling(Ce, 2);
  {
    var he = (j) => {
      var U = jo();
      let W;
      var X = e.child(U);
      No(X, {
        get height() {
          return p();
        },
        get width() {
          return v();
        },
        get boxesAlpha() {
          return T();
        },
        get labelList() {
          return E();
        },
        get labelColors() {
          return k();
        },
        get boxMinSize() {
          return y();
        },
        get interactive() {
          return w();
        },
        get handleSize() {
          return d();
        },
        get boxThickness() {
          return u();
        },
        get singleBox() {
          return g();
        },
        get disableEditBoxes() {
          return f();
        },
        get showRemoveButton() {
          return x();
        },
        get handlesCursor() {
          return m();
        },
        get boxSelectedThickness() {
          return F();
        },
        get useDefaultLabel() {
          return N();
        },
        get enableKeyboardShortcuts() {
          return ie();
        },
        get src() {
          return e.deep_read_state(n()), e.untrack(() => n().image.url);
        },
        get value() {
          return n();
        },
        set value(ge) {
          n(ge);
        },
        $$events: { change: () => $("change") },
        $$legacy: !0
      }), e.reset(U), e.template_effect(() => W = e.set_class(U, 1, "image-frame svelte-8v7jpi", null, W, { selectable: l() })), e.append(j, U);
    };
    e.if(De, (j) => {
      n() !== null && j(he);
    });
  }
  e.reset(ve);
  var J = e.sibling(ve, 2);
  {
    var se = (j) => {
      is(j, {
        get sources() {
          return o();
        },
        handle_clear: re,
        handle_select: Q,
        get active_source() {
          return R();
        },
        set active_source(U) {
          R(U);
        },
        $$legacy: !0
      });
    };
    e.if(J, (j) => {
      e.deep_read_state(o()), e.deep_read_state(n()), e.deep_read_state(w()), e.untrack(() => (o().length > 1 || o().includes("clipboard")) && n() === null && w()) && j(se);
    });
  }
  e.reset(de), e.append(a, Y), e.pop();
}
var Yo = e.from_html('<img alt=""/>'), Wo = e.from_html("<div><!></div>");
function rl(a, t) {
  e.push(t, !1);
  let r = e.prop(t, "value", 8), n = e.prop(t, "type", 8), s = e.prop(t, "selected", 8, !1);
  e.init();
  var i = Wo();
  let o;
  var l = e.child(i);
  {
    var c = (w) => {
      var h = Yo();
      e.template_effect(() => e.set_attribute(h, "src", (e.deep_read_state(r()), e.untrack(() => r().url)))), e.append(w, h);
    };
    e.if(l, (w) => {
      r() && w(c);
    });
  }
  e.reset(i), e.template_effect(() => o = e.set_class(i, 1, "container svelte-s3apn9", null, o, {
    table: n() === "table",
    gallery: n() === "gallery",
    selected: s(),
    border: r()
  })), e.append(a, i), e.pop();
}
var Xo = e.from_html("<!> <!>", 1);
function nl(a, t) {
  e.push(t, !0);
  var r = this && this.__awaiter || function(w, h, _, b) {
    function D(T) {
      return T instanceof _ ? T : new _(function(E) {
        E(T);
      });
    }
    return new (_ || (_ = Promise))(function(T, E) {
      function k(p) {
        try {
          d(b.next(p));
        } catch (v) {
          E(v);
        }
      }
      function y(p) {
        try {
          d(b.throw(p));
        } catch (v) {
          E(v);
        }
      }
      function d(p) {
        p.done ? T(p.value) : D(p.value).then(k, y);
      }
      d((b = b.apply(w, h || [])).next());
    });
  };
  class n extends Dn {
    get_data() {
      const h = Object.create(null, { get_data: { get: () => super.get_data } });
      return r(this, void 0, void 0, function* () {
        return yield h.get_data.call(this);
      });
    }
  }
  const s = e.rest_props(t, ["$$slots", "$$events", "$$legacy"]), i = new n(s);
  let o = e.state(!1), l = e.state(e.proxy(i.props.sources ? i.props.sources[0] : null)), c = e.state(e.proxy(i.props.value));
  e.user_effect(() => {
    e.get(c) !== i.props.value && (e.set(c, i.props.value, !0), i.dispatch("change"));
  });
  {
    let w = e.derived(() => e.get(o) ? "focus" : "base");
    Mn(a, {
      get visible() {
        return i.shared.visible;
      },
      variant: "solid",
      get border_mode() {
        return e.get(w);
      },
      padding: !1,
      get elem_id() {
        return i.shared.elem_id;
      },
      get elem_classes() {
        return i.shared.elem_classes;
      },
      get width() {
        return i.props.width;
      },
      allow_overflow: !1,
      get container() {
        return i.shared.container;
      },
      get scale() {
        return i.shared.scale;
      },
      get min_width() {
        return i.shared.min_width;
      },
      children: (h, _) => {
        var b = Xo(), D = e.first_child(b);
        _s(D, e.spread_props(
          {
            get autoscroll() {
              return i.shared.autoscroll;
            },
            get i18n() {
              return i.i18n;
            }
          },
          () => i.shared.loading_status
        ));
        var T = e.sibling(D, 2);
        {
          let E = e.derived(() => i.shared.client?.upload), k = e.derived(() => i.shared.client?.stream);
          Uo(T, {
            get selectable() {
              return i.props._selectable;
            },
            get root() {
              return i.shared.root;
            },
            get sources() {
              return i.props.sources;
            },
            get interactive() {
              return i.shared.interactive;
            },
            get showDownloadButton() {
              return i.props.show_download_button;
            },
            get showShareButton() {
              return i.props.show_share_button;
            },
            get showClearButton() {
              return i.props.show_clear_button;
            },
            get i18n() {
              return i.i18n;
            },
            get boxesAlpha() {
              return i.props.boxes_alpha;
            },
            get height() {
              return i.props.height;
            },
            get width() {
              return i.props.width;
            },
            get labelList() {
              return i.props.label_list;
            },
            get labelColors() {
              return i.props.label_colors;
            },
            get boxMinSize() {
              return i.props.box_min_size;
            },
            get label() {
              return i.shared.label;
            },
            get show_label() {
              return i.shared.show_label;
            },
            get max_file_size() {
              return i.shared.max_file_size;
            },
            get cli_upload() {
              return e.get(E);
            },
            get stream_handler() {
              return e.get(k);
            },
            get handleSize() {
              return i.props.handle_size;
            },
            get boxThickness() {
              return i.props.box_thickness;
            },
            get boxSelectedThickness() {
              return i.props.box_selected_thickness;
            },
            get disableEditBoxes() {
              return i.props.disable_edit_boxes;
            },
            get singleBox() {
              return i.props.single_box;
            },
            get showRemoveButton() {
              return i.props.show_remove_button;
            },
            get handlesCursor() {
              return i.props.handles_cursor;
            },
            get useDefaultLabel() {
              return i.props.use_default_label;
            },
            get enableKeyboardShortcuts() {
              return i.props.enable_keyboard_shortcuts;
            },
            get active_source() {
              return e.get(l);
            },
            set active_source(y) {
              e.set(l, y, !0);
            },
            get value() {
              return i.props.value;
            },
            set value(y) {
              i.props.value = y;
            },
            $$events: {
              change: () => i.dispatch("change"),
              edit: () => i.dispatch("edit"),
              clear: () => {
                i.dispatch("clear");
              },
              drag: ({ detail: y }) => e.set(o, y, !0),
              upload: () => i.dispatch("upload"),
              select: ({ detail: y }) => i.dispatch("select", y),
              share: ({ detail: y }) => i.dispatch("share", y),
              error: ({ detail: y }) => {
                i.dispatch("error", y);
              }
            },
            children: (y, d) => {
              var p = e.comment(), v = e.first_child(p);
              {
                var u = (g) => {
                  Dr(g, {
                    get i18n() {
                      return i.i18n;
                    },
                    type: "image"
                  });
                }, f = (g) => {
                  var x = e.comment(), m = e.first_child(x);
                  {
                    var F = (C) => {
                      Dr(C, {
                        get i18n() {
                          return i.i18n;
                        },
                        type: "clipboard",
                        mode: "short"
                      });
                    }, B = (C) => {
                      ba(C, {
                        unpadded_box: !0,
                        size: "large",
                        children: (O, N) => {
                          on(O);
                        },
                        $$slots: { default: !0 }
                      });
                    };
                    e.if(
                      m,
                      (C) => {
                        e.get(l) === "clipboard" ? C(F) : C(B, !1);
                      },
                      !0
                    );
                  }
                  e.append(g, x);
                };
                e.if(v, (g) => {
                  e.get(l) === "upload" ? g(u) : g(f, !1);
                });
              }
              e.append(y, p);
            },
            $$slots: { default: !0 }
          });
        }
        e.append(h, b);
      },
      $$slots: { default: !0 }
    });
  }
  e.pop();
}
export {
  rl as E,
  nl as I,
  el as g
};
